@@ -34,6 +34,7 @@
 
 //Unit testing code
 #include "testing/testing.h"
+#include "testing/filtertesting.h"
 
 enum
 {
@@ -43,7 +44,7 @@ enum
 class threeDepictApp: public wxApp {
 private:
 
-
+	bool haveRunInitialiser;
 	void redirectWxLogging();
 
 	std::ofstream debugLogStream;
@@ -61,6 +62,7 @@ private:
 public:
 
     threeDepictApp() ;
+    ~threeDepictApp() ;
     bool OnInit();
     virtual void OnInitCmdLine(wxCmdLineParser& parser);
     virtual int OnExit();
@@ -105,6 +107,7 @@ threeDepictApp::threeDepictApp()
 {
        	MainFrame=0;usrLocale=0;
 	dontLoad=false;
+	haveRunInitialiser=false;
 	
 	//Wx 2.9 and up now has assertions auto-enabled. 
 	//Disable for release builds
@@ -116,6 +119,15 @@ threeDepictApp::threeDepictApp()
 	redirectWxLogging();
 }
 
+threeDepictApp::~threeDepictApp()
+{
+	if(!haveRunInitialiser)
+	{
+		cerr << "Intialisation failed. Perhaps we do not have a valid display?" << endl;
+	}
+}
+
+
 void threeDepictApp::redirectWxLogging()
 {
 	//Disable user visible logging on the main thread, this can throw up "error dialogs"
@@ -319,7 +331,9 @@ void threeDepictApp::OnInitCmdLine(wxCmdLineParser& parser)
 
 	parser.SetDesc (g_cmdLineDesc);
 	parser.SetSwitchChars (wxT("-"));
-#ifdef DEBUG
+//under windows, the switch must include the "t" part for some reason.
+// this does not work under linux 
+#if defined(DEBUG) && defined(__WIN32__)
      parser.SetSwitchChars(wxT("-t"));
 #endif
 }
@@ -438,6 +452,7 @@ void threeDepictApp::MacReopenFile(const wxString &filename)
 bool threeDepictApp::OnInit()
 {
     MESSAGE("Intialising application...");
+    haveRunInitialiser=true;
 
     initLanguageSupport();
 	
