@@ -41,6 +41,11 @@ using std::string;
 const unsigned int NUM_XY=2;
 		
 
+//Charge on an electron (coulombs -- aka A.s)
+const float CHARGE_ELECTRON= 1.602176e-19;
+//Atomic mass units per kilo
+const float AMU_PER_KG =  6.0221409e26;
+
 const char *OPS_ENUM_ERRSTRINGS[] =
 {
 	"",
@@ -532,7 +537,7 @@ void computeMToC(THREEDAP_EXPERIMENT &experiment)
 {
 
 	const VOLTAGE_DATA *v,*vNext;
-	v=vNext=0;
+	v=vNext=nullptr;
 
 	unsigned int voltageOffset=0;
 	for(size_t ui=0;ui<experiment.eventData.size();ui++)
@@ -553,7 +558,7 @@ void computeMToC(THREEDAP_EXPERIMENT &experiment)
 				voltageOffset++;
 			}
 			else
-				vNext=0;
+				vNext=nullptr;
 		}
 
 		for(size_t uj=0;uj<experiment.eventData[ui].size();uj++)
