@@ -137,13 +137,13 @@ unsigned int LimitLoadPosFile(unsigned int inputnumcols, unsigned int outputnumc
 	const unsigned int NUMROWS=1;
 	const unsigned int BUFFERSIZE=inputnumcols * sizeof(float) * NUMROWS;
 	const unsigned int BUFFERSIZE2=outputnumcols * sizeof(float) * NUMROWS;
-	char *buffer=new char[BUFFERSIZE];
+	auto buffer=new char[BUFFERSIZE];
 
 	
 	if(!buffer)
 		return POS_ALLOC_FAIL;
 
-	char *buffer2=new char[BUFFERSIZE2];
+	auto buffer2=new char[BUFFERSIZE2];
 	if(!buffer2)
 	{
 		delete[] buffer;
@@ -173,7 +173,6 @@ unsigned int LimitLoadPosFile(unsigned int inputnumcols, unsigned int outputnumc
 	CFile.seekg(0,std::ios::beg);
 	
 	//calculate the number of points stored in the POS file
-	size_t pointCount=0;
 	size_t maxIons;
 	size_t maxCols = inputnumcols * sizeof(float);
 	//regular case
@@ -269,7 +268,6 @@ unsigned int LimitLoadPosFile(unsigned int inputnumcols, unsigned int outputnumc
 			return POS_INF_LOAD_ERROR;	
 		}
 		
-		pointCount++;
 		if(!curProg--)
 		{
 
@@ -461,12 +459,12 @@ unsigned int GenericLoadFloatFile(unsigned int inputnumcols, unsigned int output
 	const unsigned int BUFFERSIZE=inputnumcols * sizeof(float) * NUMROWS;
 	const unsigned int BUFFERSIZE2=outputnumcols * sizeof(float) * NUMROWS;
 
-	char *buffer=new char[BUFFERSIZE];
+	auto buffer=new char[BUFFERSIZE];
 	
 	if(!buffer)
 		return POS_ALLOC_FAIL;
 	
-	char *buffer2=new char[BUFFERSIZE2];
+	auto buffer2=new char[BUFFERSIZE2];
 	if(!buffer2)
 	{
 		delete[] buffer;
@@ -664,10 +662,10 @@ unsigned int limitLoadTextFile(unsigned int maxCols,
 		//Skip unstreamable lines
 		bool unStreamable;
 		unStreamable=false;
-		for(unsigned int ui=0; ui<subStrs.size(); ui++)
+		for(auto & subStr : subStrs)
 		{
 			float f;
-			if(stream_cast(f,subStrs[ui]))
+			if(stream_cast(f,subStr))
 			{
 				unStreamable=true;
 				break;
@@ -985,7 +983,7 @@ unsigned int LoadATOFile(const char *fileName, vector<IonHit> &ions, unsigned in
 		bool veryLargeNumber[2] = { false,false };
 	
 		//Skip through several records, looking for bad float data,
-		float *buffer = new float[LAWATAP_ATO_RECORD_SIZE/4];
+		auto buffer = new float[LAWATAP_ATO_RECORD_SIZE/4];
 		for(size_t ui=0;ui<numToCheck;ui++)
 		{
 			size_t offset;
@@ -1084,7 +1082,7 @@ unsigned int LoadATOFile(const char *fileName, vector<IonHit> &ions, unsigned in
 	//Attempt to detect
 	CFile.seekg(8);
 
-	float *buffer = new float[LAWATAP_ATO_RECORD_SIZE/4];
+	auto buffer = new float[LAWATAP_ATO_RECORD_SIZE/4];
 	size_t curPos=0;	
 
 	if(endianFlip)
@@ -1170,7 +1168,7 @@ unsigned int loadTapsimBinFile(const char *fileName, unsigned int &progress, ATO
 
 	//maximum size of a TAPSIM record, in bytes
 	unsigned int MAX_RECORD_SIZE=18;
-	char *buffer=new char[MAX_RECORD_SIZE];
+	auto buffer=new char[MAX_RECORD_SIZE];
 	if(binaryMode)
 	{
 		size_t numEntries;
@@ -1181,13 +1179,14 @@ unsigned int loadTapsimBinFile(const char *fileName, unsigned int &progress, ATO
 		}
 		
 		//ID specifies atom type
-		const bool idsPresent=true;
+		bool idsPresent;
 		//There is an inconsistency between the example files given and the documentation
 		// The documentation says the ids are optional. The examples have the option disabled, 
 		// but provide the IDs anyway - this changes the payload size.
-		if(!(s[2] == "1" || s[2] == "0" ) )
+		if(s[2] == "1" || s[2] == "0" ) 
+			idsPresent=true;
+		else
 		{
-			//UNknown value, abort
 			delete[] buffer;
 			return TAPSIM_ERR_FILE_FORMAT_FAIL;
 		}
@@ -1300,7 +1299,7 @@ bool writeATO(const std::string &filename,bool flip, unsigned int nPoints)
 
 	const unsigned int LAWATAP_ATO_RECORD_COUNT=14;
 
-	float *buffer = new float[LAWATAP_ATO_RECORD_COUNT];
+	auto buffer = new float[LAWATAP_ATO_RECORD_COUNT];
 	//zero buffer
 	memset(buffer,0,LAWATAP_ATO_RECORD_COUNT*sizeof(float));
 
