@@ -1,6 +1,6 @@
 /*
  * APTClasses.h - Generic APT components header 
- * Copyright (C) 2015  D Haley
+ * Copyright (C) 2018, D Haley
  * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,8 @@ extern const char *LAWATAP_ATO_ERR_STRINGS[];
 
 extern const char *TEXT_LOAD_ERR_STRINGS[];
 
+extern const char *TAPSIM_ERR_STRINGS[];
+
 //!Errors that can be encountered when openning pos files
 enum posErrors
 {
@@ -74,6 +76,8 @@ unsigned int limitLoadTextFile(unsigned int numColsTotal,
 			vector<vector<float> > &data,const char *posFile, const char *deliminator, const size_t limitCount,
 					       	unsigned int &progress, ATOMIC_BOOL &wantAbort,bool strongRandom);
 
+//Load a TAPSIM Binfile
+unsigned int loadTapsimBinFile(const char *filename, unsigned int &progress, ATOMIC_BOOL &wantAbort, vector<IonHit> &posions);
 
 //Load a CAMECA LAWATAP "ATO" formatted file.
 //	- This is a totally different format to the "FlexTAP" ato format
