@@ -61,9 +61,35 @@ const char *rangeErrStrings[] =
 	NTRANS("Too many ranges appeared to have range entries with no usable data (eg, all blank)"),
 	NTRANS("Range file appears to contain malformed data, check things like start and ends of m/c are not equal or flipped."),
 	NTRANS("Range file appears to be inconsistent (eg, overlapping ranges)"),
-	NTRANS("No ion name mapping found  for multiple ion."),
+	NTRANS("No ion name mapping found for multiple ion."),
 	NTRANS("Polyatomic extension range matches multiple masses in first section"),
 	NTRANS("Range file is exceedingly large. Refusing to open"),
+
+	NTRANS("Unable to read range table header (aka table separator)"),
+	NTRANS("Unable to read [Ions] contents, should be of form A=B"),
+	NTRANS("Unable to parse number of ions"),
+	NTRANS("Number of ions seems to be duplicated"),
+	NTRANS("Too many ions in ion block"),
+	NTRANS("Found ranges block before ion block"),
+	NTRANS("Number of ranges seems to be duplicated"),
+	NTRANS("Unable to read number of ranges"),
+	NTRANS("Range line was too short, needs 4 entries per line, minimum"),
+	NTRANS("Range line missing required \":\" separator"),
+
+	NTRANS("Range colour incorrect size, should be 6 bytes"),
+	NTRANS("Range specified as named ion, but ion not found in [Ions] block"),
+	NTRANS("Range had unreadable start value"),
+	NTRANS("Range had unreadable endvalue"),
+	NTRANS("Range name was empty"),
+	NTRANS("Range block had unparsable line, should start with number or range"),
+	NTRANS("Ion block missing"),
+	NTRANS("No ranges found"),
+	NTRANS("Unable to identify the number of basic ions"),
+	NTRANS("Number of ranges specfied in range block, did not match number of ranges read"),
+	NTRANS("Range block contained line that did not match A=xxx format"),
+	NTRANS("Range had unreadable ion multiplicity"),
+	NTRANS("Unable to read volume from range"),
+
 };
 
 const char *RANGE_EXTS[] = { "rng",
@@ -118,7 +144,7 @@ bool RangeFile::decomposeIonNames(const std::string &name,
 	//true - was last, or now am on ion name
 	//false - am still on multiplier
 	bool nameMode=true;
-	for(size_t ui=1;ui<name.size();ui++)
+	for(auto ui=1;ui<name.size();ui++)
 	{
 		if(!isascii(name[ui]))
 			return false;
@@ -143,7 +169,7 @@ bool RangeFile::decomposeIonNames(const std::string &name,
 				// This means unitary spec.
 				std::string s;
 				s=name.substr(lastMarker,ui-lastMarker);
-				fragments.push_back(make_pair(s,1));
+				fragments.emplace_back(s,1);
 				lastMarker=ui;
 			}
 		}
@@ -166,7 +192,7 @@ bool RangeFile::decomposeIonNames(const std::string &name,
 				size_t multiplicity;
 				stream_cast(multiplicity,sDigit);
 
-				fragments.push_back(make_pair(s,multiplicity));
+				fragments.emplace_back(s,multiplicity);
 				
 				lastMarker=ui;
 				nameMode=true;
@@ -181,7 +207,7 @@ bool RangeFile::decomposeIonNames(const std::string &name,
 		//record fragment
 		std::string s;
 		s=name.substr(lastMarker,name.size()-lastMarker);
-		fragments.push_back(make_pair(s,1));
+		fragments.emplace_back(s,1);
 	}
 	else
 	{
@@ -192,19 +218,19 @@ bool RangeFile::decomposeIonNames(const std::string &name,
 		size_t multiplicity;
 		stream_cast(multiplicity,sDigit);
 		
-		fragments.push_back(make_pair(s,multiplicity));
+		fragments.emplace_back(s,multiplicity);
 	}
 
 
 	//Spin through dataset and collect the non-unique fragment
 	vector<bool> toKill(fragments.size(),false);
-	for(size_t ui=0;ui<fragments.size();ui++)
+	for(auto ui=0;ui<fragments.size();ui++)
 	{
 		//skip empty fragments
 		if(fragments[ui].first.empty())
 			continue;	
 
-		for(size_t uj=ui+1;uj<fragments.size();uj++)
+		for(auto uj=ui+1;uj<fragments.size();uj++)
 		{
 			//skip empty fragments
 			if(fragments[uj].first.empty())
@@ -246,6 +272,7 @@ std::string RangeFile::envDropChargeState(const std::string &strName)
 
 //Given the name-frequency pairing vector, see if there
 // is a match in the map of composed names
+//Returns the "matchOffset", which is the ionID of the correct range
 bool matchComposedName(const std::map<string,size_t> &composedNames,
 	       
 		const vector<pair<string,size_t> > &namesToFind, size_t &matchOffset)
@@ -257,11 +284,10 @@ bool matchComposedName(const std::map<string,size_t> &composedNames,
 	// and the multiplicity
 	//of that fragment (eg, AuHg2 would become  { Au ,1} {Hg,2})
 	fragmentVec.reserve(composedNames.size());
-	for(std::map<string,size_t>::const_iterator it=composedNames.begin();
-			it!=composedNames.end();++it)
+	for(const auto & composedName : composedNames)
 	{
 		vector<pair<string,size_t> > frags;
-		if(!RangeFile::decomposeIonNames(it->first,frags))
+		if(!RangeFile::decomposeIonNames(composedName.first,frags))
 			frags.clear();
 
 			
@@ -343,6 +369,22 @@ bool matchComposedName(const std::map<string,size_t> &composedNames,
 		}
 	}
 
+	//Convert the fragment vector offset (which matches the order from
+	// the incoming composedNames map) to the ionID (given by the composed names second entry)
+	unsigned int mapOffset=0;
+	for(const auto & composedName : composedNames)
+	{
+
+		if(matchOffset==mapOffset)
+		{
+			//Fix the meaning of matchOffset to be useful to the outside world
+			matchOffset=composedName.second;
+			break;
+		}
+
+		mapOffset++;
+	}
+
 	//Return OK, iff we have exactly one match
 	return (matchOffset !=(size_t) - 1);
 }
@@ -364,6 +406,8 @@ const RangeFile &RangeFile::operator=(const RangeFile &oth)
 	colours=oth.colours;
 	ranges=oth.ranges;
 	ionIDs=oth.ionIDs;
+	rangeVolumes=oth.rangeVolumes;
+
 	enforceConsistency=oth.enforceConsistency;
 	errState=oth.errState;
 	warnMessages=oth.warnMessages;
@@ -395,9 +439,9 @@ unsigned int RangeFile::write(std::ostream &f, size_t format) const
 
 			//Construct the table header
 			f<< "-------------";
-			for(unsigned int ui=0;ui<ionNames.size() ; ui++)
+			for(const auto & ionName : ionNames)
 			{
-				f << " " << ionNames[ui].first;
+				f << " " << ionName.first;
 			}
 
 			f << std::endl;
@@ -461,7 +505,7 @@ unsigned int RangeFile::write(std::ostream &f, size_t format) const
 			f << "[Ions]" << endl;
 			f << "Number=" << ionNames.size() << endl;
 			
-			for(size_t ui=0;ui<ionNames.size();ui++)
+			for(auto ui=0;ui<ionNames.size();ui++)
 			{
 				f << "Ion" << ui+1 <<"=" << ionNames[ui].first << endl;
 			}
@@ -471,7 +515,7 @@ unsigned int RangeFile::write(std::ostream &f, size_t format) const
 
 
 
-			for(size_t ui=0;ui<ranges.size();ui++)
+			for(auto ui=0;ui<ranges.size();ui++)
 			{
 				ColourRGBA tmpRgba;
 				tmpRgba.fromRGBf(colours[ui]);
@@ -481,25 +525,33 @@ unsigned int RangeFile::write(std::ostream &f, size_t format) const
 				colString=colString.substr(1);
 				ASSERT(colString.size() == 6);
 
-				//FIXME: This is incomplete. we need to break the species apart into its 
+				//FIXME: This is incomplete. We need to break the species apart into its 
 				// components, then decide to use the Element:count notation, or the Name:species notation
 				string strName;
 				strName=ionNames[ionIDs[ui]].first;
 				if(elementSet.find(strName) != elementSet.end())
 				{
 					f << "Range" << ui+1 <<"=" 
-					<< ranges[ui].first << " " << ranges[ui].second <<
-					" " << strName << ":1" << 
+					<< ranges[ui].first << " " << ranges[ui].second << " ";
+
+					if(rangeVolumes.size())
+						f << rangeVolumes[ui] << " ";
+
+					f << strName << ":1" << 
 					" Color:" << colString << endl;
 				}
 				else
 				{
 					//Difference is we have to use the "Name" parameter if not in set
 					
-					f << "Range" << ui+1 <<"=" 
-					<< ranges[ui].first << " " << ranges[ui].second <<
-					" " << "Name:" << strName << " " << strName << ":1" << 
-					" Color:" << colString << endl;
+					f << "Range" << ui+1 <<"=" << ranges[ui].first << 
+						" " << ranges[ui].second << " ";
+
+					if(rangeVolumes.size())
+						f << rangeVolumes[ui] << " ";
+					
+					f<< "Name:" << strName << " " << strName 
+						<< ":1" << " Color:" << colString << endl;
 
 				}
 			}
@@ -529,6 +581,7 @@ void RangeFile::clear()
 	ionNames.clear();
 	colours.clear();
 	ranges.clear();
+	rangeVolumes.clear();
 	
 	errState=0;
 }
@@ -671,7 +724,7 @@ unsigned int RangeFile::openDoubleRNG(FILE *fpRange)
 	//Spin forwards to the "polyatomic extension" line
 
 		
-	char *inBuffer = new char[MAX_LINE_SIZE];
+	auto inBuffer = new char[MAX_LINE_SIZE];
 	// skip over <LF> 
 	char *ret;
 	ret=fgets((char *)inBuffer, MAX_LINE_SIZE, fpRange); 
@@ -702,13 +755,13 @@ unsigned int RangeFile::openDoubleRNG(FILE *fpRange)
 	vector< pair<size_t,size_t> > rangeMatches;
 	//IonID from the first dataset that we will need to replace
 	vector<size_t> overrideIonID;
-	for(size_t ui=0;ui<tmpRange[0].getNumRanges();ui++)
+	for(auto ui=0;ui<tmpRange[0].getNumRanges();ui++)
 	{
-		for(size_t uj=0;uj<tmpRange[1].getNumRanges();uj++)
+		for(auto uj=0;uj<tmpRange[1].getNumRanges();uj++)
 		{
 			if (tmpRange[0].getRange(ui) == tmpRange[1].getRange(uj))
 			{
-				rangeMatches.push_back(make_pair(ui,uj));
+				rangeMatches.emplace_back(ui,uj);
 				overrideIonID.push_back(tmpRange[0].getIonID((unsigned int)ui));
 			}
 		}
@@ -735,7 +788,7 @@ unsigned int RangeFile::openDoubleRNG(FILE *fpRange)
 	}
 
 	//Replace ionnames with new ion name and colour
-	for(size_t ui=0;ui<overrideIonID.size();ui++)
+	for(auto ui=0;ui<overrideIonID.size();ui++)
 	{
 		size_t ids[2];
 		ids[0]=overrideIonID[ui];
@@ -769,14 +822,14 @@ unsigned int RangeFile::openRNG( FILE *fpRange)
 	if((errCode=readRNGHeader(fpRange, ionNames, colours,numRanges,numIons)))
 		return errCode;
 
-	char *inBuffer = new char[MAX_LINE_SIZE];
+	auto inBuffer = new char[MAX_LINE_SIZE];
 	// skip over <LF> 
 	char *ret;
 	ret=fgets((char *)inBuffer, MAX_LINE_SIZE, fpRange); 
 	if(!ret || strlen(ret) >= MAX_LINE_SIZE-1)
 	{
 		delete[] inBuffer;
-		return RANGE_ERR_FORMAT;
+		return RANGE_ERR_DASHHEADER;
 	}
 	// read the column header line 
 	ret=fgets((char *)inBuffer, MAX_LINE_SIZE, fpRange); 
@@ -784,7 +837,7 @@ unsigned int RangeFile::openRNG( FILE *fpRange)
 	if(!ret || strlen(ret) >= MAX_LINE_SIZE-1)
 	{
 		delete[] inBuffer;
-		return RANGE_ERR_FORMAT;
+		return RANGE_ERR_DASHHEADER;
 	}
 
 	//We should be at the line which has lots of dashes
@@ -850,11 +903,11 @@ unsigned int RangeFile::openRNG( FILE *fpRange)
 	//-- Build a sparse vector of composed ions
 	std::map<string,size_t> composeMap;
 
-	for(size_t uj=0;uj<numIons;uj++)
+	for(auto uj=0;uj<numIons;uj++)
 	{
 		bool maybeComposed;
 		maybeComposed=true;
-		for(size_t ui=0; ui<numRanges;ui++)
+		for(auto ui=0; ui<numRanges;ui++)
 		{
 			//Scan through the range listing to try to
 			//find a non-zero entries
@@ -879,7 +932,7 @@ unsigned int RangeFile::openRNG( FILE *fpRange)
 
 	//Loop through each range's freq table entries, to determine if
 	// the ion is composed (has more than one "1" in multiplicity listing)
-	for(size_t ui=0;ui<numRanges;ui++)
+	for(auto ui=0;ui<numRanges;ui++)
 	{
 		std::map<size_t,size_t > freqEntries;
 		size_t freq;
@@ -889,7 +942,7 @@ unsigned int RangeFile::openRNG( FILE *fpRange)
 		//--
 		freqEntries.clear();
 		freq=0;
-		for(size_t uj=0;uj<numIons;uj++)
+		for(auto uj=0;uj<numIons;uj++)
 		{
 			size_t thisEntry;
 			thisEntry=frequencyEntries[numIons*ui+uj];
@@ -916,7 +969,7 @@ unsigned int RangeFile::openRNG( FILE *fpRange)
 				//We have a multiple, but no way of composing it!
 				// we will need to build our own table entry.
 				// For now, just store the freq tableentry
-				unassignedMultiples.push_back(make_pair(ui,freqEntries));
+				unassignedMultiples.emplace_back(ui,freqEntries);
 				ionIDs.push_back(-2);
 			}
 			else
@@ -928,7 +981,7 @@ unsigned int RangeFile::openRNG( FILE *fpRange)
 				vector<pair<string,size_t> > entries;
 
 				for(map<size_t,size_t>::iterator it=freqEntries.begin();it!=freqEntries.end();++it)
-					entries.push_back(make_pair(ionNames[it->first].first,it->second));
+					entries.emplace_back(ionNames[it->first].first,it->second);
 
 				//try to match the composed name to the entries
 				size_t offset;
@@ -963,18 +1016,6 @@ unsigned int RangeFile::openRNG( FILE *fpRange)
 		}
 	}
 
-	//Loop through any ranges with a bad ionID (== -1), then delete them by popping
-	for(size_t ui=0;ui<ionIDs.size();ui++)
-	{
-		if(ionIDs[ui] == (size_t)-1)
-		{
-			std::swap(ranges[ui],ranges.back());
-			ranges.pop_back();
-
-			std::swap(ionIDs[ui],ionIDs.back());
-			ionIDs.pop_back();
-		}
-	}
 
 
 	//Check for any leftover unhandled cases
@@ -986,7 +1027,7 @@ unsigned int RangeFile::openRNG( FILE *fpRange)
 		//Create a name + list of ranges mapping
 		map<string,vector<int> > newNames;
 		
-		for(size_t ui=0;ui<unassignedMultiples.size();ui++)
+		for(auto ui=0;ui<unassignedMultiples.size();ui++)
 		{
 			ComparePairFirstReverse cmp;
 			//create a flattened name from the map as a unique key
@@ -997,11 +1038,11 @@ unsigned int RangeFile::openRNG( FILE *fpRange)
 			
 			std::map<size_t,size_t> &m=unassignedMultiples[ui].second;
 			for(std::map<size_t,size_t>::const_iterator it=m.begin(); it!=m.end();++it)
-				flatData.push_back(make_pair(it->first,it->second));
+				flatData.emplace_back(it->first,it->second);
 			std::sort(flatData.begin(),flatData.end(),cmp);
 
 			string nameStr;
-			for(size_t uj=0;uj<flatData.size();uj++)
+			for(auto uj=0;uj<flatData.size();uj++)
 			{
 				string tmpStr;
 
@@ -1020,12 +1061,12 @@ unsigned int RangeFile::openRNG( FILE *fpRange)
 		//Create one new name per new string we generated,
 		for(map<string,vector<int> >::iterator it=newNames.begin(); it!=newNames.end();++it)
 		{
-			for(size_t ui=0;ui<it->second.size();ui++)
+			for(auto ui=0;ui<it->second.size();ui++)
 			{
-				ASSERT(ionIDs[it->second[ui]] == (size_t)-2);
+				ASSERT(ionIDs[it->second[ui]] == (unsigned int)-2);
 				ionIDs[it->second[ui]] =ionNames.size();
 			}
-			ionNames.push_back(make_pair(it->first,it->first));
+			ionNames.emplace_back(it->first,it->first);
 			//make a new random colour
 			RGBf col;
 			col.red=rand()/(float)std::numeric_limits<int>::max();
@@ -1037,6 +1078,18 @@ unsigned int RangeFile::openRNG( FILE *fpRange)
 
 	}
 
+	//Loop through any ranges with a bad ionID (== -1), then delete them by popping
+	for(auto ui=ionIDs.size()-1;ui--;)
+	{
+		if(ionIDs[ui] == (unsigned int)-1)
+		{
+			std::swap(ranges[ui],ranges.back());
+			ranges.pop_back();
+
+			std::swap(ionIDs[ui],ionIDs.back());
+			ionIDs.pop_back();
+		}
+	}
 
 	delete[] inBuffer;
 	return 0;
@@ -1069,19 +1122,16 @@ unsigned int RangeFile::detectFileType(const char *rangeFile)
 		if(!f)
 			return RANGE_FORMAT_END_OF_ENUM;
 
-		vector<string> strs;
 		std::string tmpStr;
 		size_t nCount;
-		bool brokeOut=false;
 
 		//retrieve the line
-		if(!getline(f,tmpStr))
-			goto skipoutRNGChecks;	
-
+		getline(f,tmpStr);
 		//strip exterior whitespace
 		tmpStr=stripWhite(tmpStr);
 
 		//break it apart
+		vector<string> strs;
 		splitStrsRef(tmpStr.c_str()," ",strs);
 
 		//Drop the whitepace
@@ -1118,11 +1168,8 @@ unsigned int RangeFile::detectFileType(const char *rangeFile)
 
 		while(nCount--)
 		{
-			if(!getline(f,tmpStr))
-			{
-				tmpStr.clear();
-				break;
-			}
+			getline(f,tmpStr);
+
 			//shouldn't hit eof
 			if(f.eof() || (!f.good()) )
 			{
@@ -1141,15 +1188,9 @@ unsigned int RangeFile::detectFileType(const char *rangeFile)
 
 		//Now, spin forwards until we either hit EOF or our double-dash marker
 		while( ! (f.eof() || f.bad()) )
-		// note windows may not set fail bits properly, so we monitor 
-		// the break on getline
 		{
-			tmpStr.clear();
 			if(!getline(f,tmpStr))
-			{
-				brokeOut=true;
 				break;
-			}
 
 			if(tmpStr.size() > 2 &&
 				tmpStr[0] == '-' && tmpStr[1] == '-')
@@ -1161,13 +1202,12 @@ unsigned int RangeFile::detectFileType(const char *rangeFile)
 			}
 		}
 
-		if(!f.good() || brokeOut)
+		if(!f.good())
 		{
 			//we did not see a double-dash, must be a vanilla ORNL file
 			typeStatus[RANGE_FORMAT_DBL_ORNL]=STATUS_IS_NOT;
 		}
 
-		//FIXME: Don't use a goto?
 skipoutRNGChecks:
 		;
 	}
@@ -1184,8 +1224,8 @@ skipoutRNGChecks:
 
 		//Check for existence of lines that match format section
 		std::vector<string> sections;
-		sections.push_back("[ions]");
-		sections.push_back("[ranges]");
+		sections.emplace_back("[ions]");
+		sections.emplace_back("[ranges]");
 
 		vector<bool> haveSection(sections.size(),false);
 	
@@ -1197,12 +1237,11 @@ skipoutRNGChecks:
 
 			//Get line, stripped of whitespace
 			std::string tmpStr;
-			if(!getline(f,tmpStr))
-				break;
+			getline(f,tmpStr);
 			tmpStr=stripWhite(tmpStr);
 
 			//See if we have this header
-			for(size_t ui=0;ui<sections.size();ui++)
+			for(auto ui=0;ui<sections.size();ui++)
 			{
 				if(sections[ui] == lowercase(tmpStr))
 				{
@@ -1264,7 +1303,7 @@ skipoutRNGChecks:
 	{
 		//OK, there can only be one.  Return the format that has not
 		//  been rejected
-		for(size_t ui=0;ui<typeStatus.size();ui++)
+		for(auto ui=0;ui<typeStatus.size();ui++)
 		{
 			if(typeStatus[ui]==STATUS_IS_MAYBE)
 				return ui;
@@ -1285,7 +1324,7 @@ unsigned int RangeFile::readRNGHeader(FILE *fpRange, vector<pair<string,string>
 			vector<RGBf> &fileColours, unsigned int &numRanges, unsigned int &numIons)
 {
 
-	char *inBuffer= new char[MAX_LINE_SIZE];
+	auto inBuffer= new char[MAX_LINE_SIZE];
 	
 	//Read out the number of ions and ranges in the file	
 	if(fscanf(fpRange, "%64u %64u", &numIons, &numRanges) != 2)
@@ -1380,18 +1419,16 @@ unsigned int RangeFile::readRNGFreqTable(FILE *fpRange, char *inBuffer,const uns
 	string entry;
 	char *ptrBegin;
 	ptrBegin=inBuffer;
-	while(*ptrBegin && *ptrBegin == '-')
+	while(*ptrBegin == '-')
 		ptrBegin++;
 	splitStrsRef(ptrBegin," \n",colHeaders);
 	if(!colHeaders.size() )
-	{
 		return RANGE_ERR_FORMAT_TABLESEPARATOR;
-	}
 	
 	//remove whitespace from each entry
-	for(size_t ui=0;ui<colHeaders.size();ui++)
+	for(auto & colHeader : colHeaders)
 	{
-		colHeaders[ui] = stripChars(colHeaders[ui],"\f\n\r\t ");
+		colHeader = stripChars(colHeader,"\f\n\r\t ");
 	}
 	
 	stripZeroEntries(colHeaders);
@@ -1414,12 +1451,12 @@ unsigned int RangeFile::readRNGFreqTable(FILE *fpRange, char *inBuffer,const uns
 			colHeaders[colHeaders.size()-1]=str.substr(0,str.size()-1);
 
 		//Each column header should match the original ion name
-		for(size_t ui=1;ui<colHeaders.size();ui++)
+		for(auto ui=1;ui<colHeaders.size();ui++)
 		{
 			//look for a corresponding entry in the column headers
 			if(names[ui-1].second != colHeaders[ui])
 			{
-				warnings.push_back(TRANS("Range headings do not match order of the ions listed in the name specifications. The name specification ordering will be used when reading the range table, as the range heading section is declared as a comment in the file-format specifications, and is not to be intepreted by this program. Check range-species associations actually match what you expect."));
+				warnings.emplace_back(TRANS("Range headings do not match order of the ions listed in the name specifications. The name specification ordering will be used when reading the range table, as the range heading section is declared as a comment in the file-format specifications, and is not to be intepreted by this program. Check range-species associations actually match what you expect."));
 				break;
 			}
 
@@ -1435,7 +1472,7 @@ unsigned int RangeFile::readRNGFreqTable(FILE *fpRange, char *inBuffer,const uns
 	{
 
 		//grab the line
-		if(fgets(inBuffer,MAX_LINE_SIZE,fpRange) == NULL)
+		if(fgets(inBuffer,MAX_LINE_SIZE,fpRange) == nullptr)
 			return RANGE_ERR_FORMAT_RANGETABLE;
 		
 	
@@ -1516,7 +1553,7 @@ unsigned int RangeFile::openENV(FILE *fpRange)
 	//Ruoen group "environment file" format
 	//This is not a standard file format, so the
 	//reader is a best-effort implementation, based upon examples
-	char *inBuffer = new char[MAX_LINE_SIZE];
+	auto inBuffer = new char[MAX_LINE_SIZE];
 	unsigned int numRanges;
 	unsigned int numIons;	
 
@@ -1561,7 +1598,7 @@ unsigned int RangeFile::openENV(FILE *fpRange)
 		//Drop any entry data including and after ';'.
 		// Revision 0.3 files show this ;, but it is not clear what
 		// it is supposed to be for. Sample files I have show only zeros in these positions
-		for(size_t ui=0;ui<strVec.size();ui++)
+		for(auto ui=0;ui<strVec.size();ui++)
 		{
 			size_t offset;
 			offset=strVec[ui].find(';');
@@ -1637,7 +1674,7 @@ unsigned int RangeFile::openENV(FILE *fpRange)
 					// long name, so use that for both
 					// the short and long names
 					bool nameExists=false;
-					for(size_t ui=0;ui<ionNames.size();ui++)
+					for(auto ui=0;ui<ionNames.size();ui++)
 					{
 						if (ionNames[ui].first == strVec[0])
 						{
@@ -1652,7 +1689,7 @@ unsigned int RangeFile::openENV(FILE *fpRange)
 					if(nameExists)
 						continue;
 
-					ionNames.push_back(std::make_pair(strVec[0],strVec[0]));
+					ionNames.emplace_back(strVec[0],strVec[0]);
 					//Use the colours (positions 1-3)
 					RGBf colourStruct;
 					if(stream_cast(colourStruct.red,strVec[1])
@@ -1729,7 +1766,7 @@ unsigned int RangeFile::openENV(FILE *fpRange)
 						return RANGE_ERR_FORMAT;
 					}
 
-					ranges.push_back(std::make_pair(rangeStart,rangeEnd));
+					ranges.emplace_back(rangeStart,rangeEnd);
 
 					ionIDs.push_back(thisIonID);
 				}
@@ -1769,7 +1806,7 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 {
 	clear();
 	
-	char *inBuffer = new char[MAX_LINE_SIZE];
+	auto inBuffer = new char[MAX_LINE_SIZE];
 	unsigned int numRanges;
 	unsigned int numBasicIons;
 
@@ -1833,7 +1870,7 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 			if (split.size() != 2)
 			{
 				delete[] inBuffer;
-				return RANGE_ERR_FORMAT;
+				return RANGE_ERR_IONBLOCK_CONTENT;
 			}
 
 			std::string stmp;
@@ -1849,19 +1886,19 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 				if (numBasicIons !=0)
 				{
 					delete[] inBuffer;
-					return RANGE_ERR_FORMAT;
+					return RANGE_ERR_NUMIONS_DUPLICATED;
 				}
 				//Set the number of ions
 				if(stream_cast(numBasicIons, split[1]))
 				{
 					delete[] inBuffer;
-					return RANGE_ERR_FORMAT;
+					return RANGE_ERR_NUMIONS;
 				}
 
 				if (numBasicIons == 0)
 				{
 					delete[] inBuffer;
-					return RANGE_ERR_FORMAT;
+					return RANGE_ERR_NUMIONS;
 				}
 			}
 			else if (split[0].size() >3)
@@ -1875,13 +1912,13 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 					if (basicIonNames.size()  > numBasicIons)
 					{
 						delete[] inBuffer;
-						return RANGE_ERR_FORMAT;
+						return RANGE_ERR_TOO_MANYIONS;
 					}
 				}
 				else
 				{
 					delete[] inBuffer;
-					return RANGE_ERR_FORMAT;
+					return RANGE_ERR_IONBLOCK_CONTENT;
 				}
 			}
 			break;
@@ -1895,7 +1932,7 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 			if (!haveSeenIonBlock)
 			{
 				delete[] inBuffer;
-				return RANGE_ERR_FORMAT;
+				return RANGE_ERR_ION_BLOCK_NOT_PRESENT;
 			}
 			vector<string> split;
 
@@ -1906,7 +1943,7 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 				if (split.size() != 2)
 				{
 					delete[] inBuffer;
-					return RANGE_ERR_FORMAT;
+					return RANGE_ERR_RANGEBLOCK_FORMAT;
 				}
 
 				if (lowercase(split[0].substr(0,5)) == "numbe")
@@ -1916,20 +1953,20 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 					if (numRanges)
 					{
 						delete[] inBuffer;
-						return RANGE_ERR_FORMAT;
+						return RANGE_ERR_DUPLICATE_NUMRANGES;
 					}
 
 					if (stream_cast(numRanges,split[1]))
 					{
 					
 						delete[] inBuffer;
-						return RANGE_ERR_FORMAT;
+						return RANGE_ERR_NUMRANGE_PARSE;
 					}
 
 					if (!numRanges)
 					{
 						delete[] inBuffer;
-						return RANGE_ERR_FORMAT;
+						return RANGE_ERR_NUMRANGE_PARSE;
 					}
 
 				}
@@ -1971,7 +2008,7 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 					stripZeroEntries(split);
 					//Need a minimum of 4 entries here
 					if(split.size() < 4)
-						return RANGE_ERR_FORMAT;
+						return RANGE_ERR_RRNG_IONS_TOOSHORT;
 					
 					//First two contains the range data
 					rngStart=split[0];
@@ -1999,7 +2036,7 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 						if (colonPos == std::string::npos)
 						{
 							delete[] inBuffer;
-							return RANGE_ERR_FORMAT;
+							return RANGE_ERR_RRNG_COLON_SEPARATOR;
 						}
 
 						//Extract the key value pairs
@@ -2008,7 +2045,26 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 						value=split[ui].substr(colonPos+1);
 						if (lowercase(key) == "vol")
 						{
-							//Do nothing
+							//Ion volumes are optional. 
+							// if this is the first time we have seen them
+							// then we should allocate space for these
+							if(!rangeVolumes.size())
+								rangeVolumes.resize(numRanges,0);
+
+							if(ui >=numRanges)
+							{
+								delete[] inBuffer;
+								return RANGE_ERR_MISMATCHED_NUMRANGES;
+							}
+
+
+
+							if(stream_cast(rangeVolumes[ui],value))
+							{
+								delete[] inBuffer;
+								return RANGE_ERR_VOLUME_PARSE;
+							}
+
 						}
 						else if (lowercase(key) == "name")
 						{
@@ -2033,7 +2089,7 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 							if (value.size() !=6)
 							{
 								delete[] inBuffer;
-								return RANGE_ERR_FORMAT;
+								return RANGE_ERR_BADCOLOUR;
 							}
 
 							//Use our custom string parser,
@@ -2053,36 +2109,88 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 						}
 						else
 						{
-							//Basic ion was not in the original [Ions] list. This is not right
-							unsigned int pos=(unsigned int)-1;
-							for (unsigned int uj=0; uj<basicIonNames.size(); uj++)
+							vector<string> commaSplit;
+							splitStrsRef(key.c_str(),',',commaSplit);
+
+							if(commaSplit.size() >1)
 							{
-								if (basicIonNames[uj] == key)
+								if(haveNameField)
+									return RANGE_ERR_FORMAT;
+								//we have something like C,C,Cu (which does happen)
+								// count each case and then create result
+								map<string, unsigned int> uniqMap;
+
+								for(const auto str : commaSplit)
 								{
-									pos = uj;
-									break;
+									//If the ion does not exist in the initial ions declaration, abandon ship
+									if(std::find(basicIonNames.begin(),basicIonNames.end(),str) == basicIonNames.end())
+										return RANGE_ERR_ION_NOT_MAPPED;
+
+
+									//Count the number of occurences in our comma sparated list
+									auto it=uniqMap.find(str);
+									if( it == uniqMap.end())
+										uniqMap.insert(make_pair(str,1));
+									else
+										it->second++;
 								}
-							}
 
-							if (pos == (unsigned int)-1)
-							{
-								delete[] inBuffer;
-								return RANGE_ERR_FORMAT;
-							}
-							//Check the multiplicity of the ion. Should be an integer > 0
-							unsigned int uintVal;
-							if (stream_cast(uintVal,value) || !uintVal)
-							{
-								delete[] inBuffer;
-								return RANGE_ERR_FORMAT;
-							}
+								//Rename the ion by using the uniq map,
+								// such that e.g. "C,C,Cu" -> "C2Cu"
+								string newKey;
+								strIonNameTmp="";
+								for (auto &entry : uniqMap)
+								{
 
-							//If it is  1, then use straight name. Otherwise try to give it a
-							//chemical formula look by mixing in the multiplicity after the key
-							if (uintVal==1)
-								strIonNameTmp+=key;
+									strIonNameTmp+=entry.first;
+								
+									//if multiplicity is non-unitary, append modifier	
+									if(entry.second > 1)
+									{
+										string tmpStr;
+										stream_cast(tmpStr,entry.second);
+
+										strIonNameTmp+=tmpStr;
+									}
+									else if (entry.second <=0)
+										return RANGE_ERR_ION_NOT_MAPPED;
+								}
+							
+
+							}
 							else
-								strIonNameTmp+=key+value;
+							{
+								//Basic ion was not in the original [Ions] list. This is not right
+								unsigned int pos=(unsigned int)-1;
+								for (unsigned int uj=0; uj<basicIonNames.size(); uj++)
+								{
+									if (basicIonNames[uj] == key)
+									{
+										pos = uj;
+										break;
+									}
+								}
+
+								if (pos == (unsigned int)-1)
+								{
+									delete[] inBuffer;
+									return RANGE_ERR_ION_NOT_MAPPED;
+								}
+								//Check the multiplicity of the ion. Should be an integer > 0
+								unsigned int uintVal;
+								if (stream_cast(uintVal,value) || !uintVal)
+								{
+									delete[] inBuffer;
+									return RANGE_ERR_BAD_MULTIPLICITY;
+								}
+
+								//If it is  1, then use straight name. Otherwise try to give it a
+								//chemical formula look by mixing in the multiplicity after the key
+								if (uintVal==1)
+									strIonNameTmp+=key;
+								else
+									strIonNameTmp+=key+value;
+							}
 						}
 					}
 
@@ -2105,14 +2213,14 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 						{
 							delete[] inBuffer;
 						
-							return RANGE_ERR_FORMAT;
+							return RANGE_ERR_BADSTART;
 						}
 
 						if (stream_cast(rngEndV,rngEnd))
 						{
 							delete[] inBuffer;
 						
-							return RANGE_ERR_FORMAT;
+							return RANGE_ERR_BADEND;
 						}
 					}
 
@@ -2136,13 +2244,13 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 							}
 						}
 
-						ranges.push_back(std::make_pair(rngStartV,rngEndV));
+						ranges.emplace_back(rngStartV,rngEndV);
 						if (pos == (unsigned int) -1)
 						{
 							//This is new. Create a new ion,
 							//and use its ionID
-							ionNames.push_back(std::make_pair(strIonNameTmp,
-										     strIonNameTmp));
+							ionNames.emplace_back(strIonNameTmp,
+										     strIonNameTmp);
 							colours.push_back(col);
 							ionIDs.push_back(ionNames.size()-1);
 						}
@@ -2163,7 +2271,7 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 							delete[] inBuffer;
 				
 		
-							return RANGE_ERR_FORMAT;
+							return RANGE_ERR_NAME_EMPTY;
 						}
 
 
@@ -2195,13 +2303,13 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 							}
 						}
 
-						ranges.push_back(std::make_pair(rngStartV,rngEndV));
+						ranges.emplace_back(rngStartV,rngEndV);
 						if (pos == (unsigned int) -1)
 						{
 							//This is new. Create a new ion,
 							//and use its ionID
-							ionNames.push_back(std::make_pair(strNameFieldValue,
-										     strNameFieldValue));
+							ionNames.emplace_back(strNameFieldValue,
+										     strNameFieldValue);
 							colours.push_back(col);
 							ionIDs.push_back(ionNames.size()-1);
 						}
@@ -2216,7 +2324,7 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 				else
 				{
 					delete[] inBuffer;
-					return RANGE_ERR_FORMAT;
+					return RANGE_ERR_BAD_LINE_RANGEBLOCK;
 				}
 
 			}
@@ -2232,11 +2340,17 @@ unsigned int RangeFile::openRRNG(FILE *fpRange)
 
 
 	//If we didn't find anything useful, then thats a formatting error
-	if(!haveSeenIonBlock || !numRanges  || !numBasicIons)
-		return RANGE_ERR_FORMAT;
-	
+	if(!haveSeenIonBlock )
+		return RANGE_ERR_MISSING_IONBLOCK;
+	if(!numRanges)
+		return RANGE_ERR_NO_RANGES;
+			
+	if(!numBasicIons)
+		return RANGE_ERR_NO_BASIC_IONS;
+
+
 	if(numRanges != ranges.size())
-		return RANGE_ERR_FORMAT;
+		return RANGE_ERR_MISMATCHED_NUMRANGES;
 
 	return 0;
 }
@@ -2274,6 +2388,13 @@ void RangeFile::getAllExts(std::vector<std::string> &exts)
 
 bool RangeFile::isSelfConsistent() const
 {
+	ASSERT(ionIDs.size() == ranges.size());
+	ASSERT(ionIDs.empty() || *(std::max_element(ionIDs.begin(),ionIDs.end())) < ionNames.size());
+	ASSERT(rangeVolumes.empty() || ( rangeVolumes.size() == ranges.size()) );
+
+	ASSERT(colours.size() == ionNames.size());
+	
+
 	for(unsigned int ui=0;ui<ranges.size();ui++)
 	{
 		//Check for range zero width
@@ -2306,9 +2427,9 @@ bool RangeFile::isSelfConsistent() const
 
 	
 	//Ensure that the names don't clash
-	for(size_t ui=0;ui<ionNames.size();ui++)
+	for(auto ui=0;ui<ionNames.size();ui++)
 	{
-		for(size_t uj=ui+1;uj<ionNames.size();uj++)
+		for(auto uj=ui+1;uj<ionNames.size();uj++)
 		{
 			if(ionNames[ui].first == ionNames[uj].first ||
 				ionNames[ui].second == ionNames[uj].second)
@@ -2318,17 +2439,17 @@ bool RangeFile::isSelfConsistent() const
 
 
 	//Ensure that names conform to allowed naming scheme
-	for(size_t ui=0;ui<ionNames.size();ui++)
+	for(const auto & ionName : ionNames)
 	{
 		string tmp;
-		tmp=ionNames[ui].first;
+		tmp=ionName.first;
 
 		const char *DISALLOWED_ION_NAMES=" \t\r\n";
 		//TODO : Use whitelist, rather than blacklist
 		if(tmp.find_first_of(DISALLOWED_ION_NAMES)!= string::npos)
 			return false;
 
-		tmp=ionNames[ui].second;
+		tmp=ionName.second;
 		if(tmp.find_first_of(DISALLOWED_ION_NAMES)!= string::npos) 
 			return false;
 	}
@@ -2470,14 +2591,14 @@ void RangeFile::rangeByIon(const std::vector<IonHit> & ions,
 	//TODO: Play with openmp, to see if this is faster.
 	// There will be problems with synchronising writes to the output.
 	// Could try a sampling algorithm to estimate output size
-	for(size_t ui=0;ui<ions.size();ui++)
+	for(const auto & ion : ions)
 	{
 		unsigned int id;
-		id=getIonID(ions[ui].getMassToCharge());
+		id=getIonID(ion.getMassToCharge());
 		if(id == (unsigned int)-1)
 			continue;
 		if(selectedIons[id])
-			output.push_back(ions[ui]);
+			output.push_back(ion);
 	}
 }
 
@@ -2835,25 +2956,29 @@ unsigned int RangeFile::addRange(float start, float end, unsigned int parentIonI
 	if(enforceConsistency)
 	{
 		//Ensure that they do NOT overlap
-		for(unsigned int ui=0;ui<ranges.size();ui++)
+		for(auto & range : ranges)
 		{
 			//Check for start end inside other range
-			if(start > ranges[ui].first && 
-					start<=ranges[ui].second)
+			if(start > range.first && 
+					start<=range.second)
 				return -1;
 
-			if(end > ranges[ui].first && 
-					end<=ranges[ui].second)
+			if(end > range.first && 
+					end<=range.second)
 				return -1;
 
 			//check for start/end spanning range entirely
-			if(start < ranges[ui].first && end > ranges[ui].second)
+			if(start < range.first && end > range.second)
 				return -1;
 		}
 	}
 	//Got this far? Good - valid range. Insert it and move on
 	ionIDs.push_back(parentIonID);
-	ranges.push_back(std::make_pair(start,end));
+	ranges.emplace_back(start,end);
+
+	if(rangeVolumes.size())
+		rangeVolumes.push_back(0);
+	
 
 #ifdef DEBUG
 	if(enforceConsistency)
@@ -2866,15 +2991,18 @@ unsigned int RangeFile::addRange(float start, float end, unsigned int parentIonI
 
 unsigned int RangeFile::addIon(const std::string &shortN, const std::string &longN, const RGBf &newCol)
 {
-	for(unsigned int ui=0; ui<ionNames.size() ;ui++)
+	for(auto & ionName : ionNames)
 	{
-		if(ionNames[ui].first == shortN || ionNames[ui].second == longN)
+		if(ionName.first == shortN || ionName.second == longN)
 			return -1;
 	}
 
-	ionNames.push_back(make_pair(shortN,longN));
+	ionNames.emplace_back(shortN,longN);
 	colours.push_back(newCol);
 
+	if(rangeVolumes.size())
+		rangeVolumes.push_back(0);
+
 	ASSERT(isSelfConsistent());
 	return ionNames.size()-1;
 }
@@ -2885,7 +3013,7 @@ void RangeFile::setIonID(unsigned int range, unsigned int newIonId)
 	ionIDs[range] = newIonId;
 }
 
-void RangeFile::eraseRange(size_t rangeId)
+void RangeFile::eraseRange(unsigned int rangeId)
 {
 	ASSERT(rangeId < ranges.size());
 	std::swap(ranges.back(),ranges[rangeId]);
@@ -2893,14 +3021,20 @@ void RangeFile::eraseRange(size_t rangeId)
 	
 	std::swap(ionIDs.back(),ionIDs[rangeId]);
 	ionIDs.pop_back();	
+
+	if(rangeVolumes.size())
+	{
+		std::swap(rangeVolumes.back(),rangeVolumes[rangeId]);
+		rangeVolumes.pop_back();
+	}
 }
 
-void RangeFile::eraseIon(size_t ionId)
+void RangeFile::eraseIon(unsigned int ionId)
 {
 	
 	//Kill any ranges that belong to this ion
 	vector<bool> killRange(ranges.size(),false);
-	for(size_t ui=0;ui<ionIDs.size(); ui++)
+	for(auto ui=0;ui<ionIDs.size(); ui++)
 	{
 		if(ionIDs[ui]  == ionId)
 			killRange[ui]=true;
@@ -2908,6 +3042,8 @@ void RangeFile::eraseIon(size_t ionId)
 
 	//Remove the desired range and ionID mappings.
 	vectorMultiErase(ranges,killRange);
+	if(rangeVolumes.size())
+		vectorMultiErase(ranges,killRange);
 	vectorMultiErase(ionIDs,killRange);
 
 	//Remove the ion name and colour for the selected ion
@@ -2915,7 +3051,7 @@ void RangeFile::eraseIon(size_t ionId)
 	colours.erase(colours.begin()+ionId);
 
 	//Now, we have to renumber the existing ionIDs, which have shifted down a peg
-	for(size_t ui=0;ui<ionIDs.size();ui++)
+	for(auto ui=0;ui<ionIDs.size();ui++)
 	{
 		//We should have deleted this ionsID
 		ASSERT(ionIDs[ui] != ionId);
@@ -2934,15 +3070,15 @@ bool RangeFile::decompose(RangeFile &rng) const
 {
 	//find the list of decomposables
 	rng=*this;	
-	for(size_t ui=0; ui<ionNames.size(); ui++)
+	for(const auto & ionName : ionNames)
 	{	
 		vector<pair<string,size_t > > fragments;
-		if(!decomposeIonNames(ionNames[ui].first,fragments))
+		if(!decomposeIonNames(ionName.first,fragments))
 			return false;
 
-		for(size_t uj=0; uj<fragments.size();uj++)
+		for(auto & fragment : fragments)
 		{
-			if(rng.getIonID(fragments[uj].first) == (unsigned int)-1)
+			if(rng.getIonID(fragment.first) == (unsigned int)-1)
 			{
 				//make a new random colour
 				RGBf col;
@@ -2950,7 +3086,7 @@ bool RangeFile::decompose(RangeFile &rng) const
 				col.green=rand()/(float)std::numeric_limits<int>::max();
 				col.blue=rand()/(float)std::numeric_limits<int>::max();
 				//Create a new ion to support this fragment
-				rng.addIon(fragments[uj].first,fragments[uj].first,col);
+				rng.addIon(fragment.first,fragment.first,col);
 			}
 		}	
 	}	
@@ -2961,14 +3097,14 @@ bool RangeFile::decompose(RangeFile &rng) const
 
 bool RangeFile::isSelfDecomposable() const
 {
-	for(size_t ui=0; ui<ionNames.size(); ui++)
+	for(const auto & ionName : ionNames)
 	{	
 		vector<pair<string,size_t > > fragments;
-		if(!decomposeIonNames(ionNames[ui].first,fragments))
+		if(!decomposeIonNames(ionName.first,fragments))
 			return false;
 		//ion cannot be decomposed into smaller fragments. 
 		//This is not a decomposable rangefile
-		if(getIonID(ionNames[ui].first) == (unsigned int)-1)
+		if(getIonID(ionName.first) == (unsigned int)-1)
 			return false;
 	}	
 
@@ -2979,7 +3115,7 @@ bool RangeFile::getDecomposition(std::map<unsigned int, vector< std::pair<unsign
 {
 	decomposition.clear();
 	//TODO: Convert to cached, statified map?
-	for(size_t ui=0;ui<ionNames.size(); ui++)
+	for(auto ui=0;ui<ionNames.size(); ui++)
 	{
 		vector<pair<string,size_t> > thisFragment;
 		if(!decomposeIonNames(ionNames[ui].first,thisFragment))
@@ -2989,7 +3125,7 @@ bool RangeFile::getDecomposition(std::map<unsigned int, vector< std::pair<unsign
 		vector<pair<unsigned int, unsigned int> > fragmentAsRanges;
 		fragmentAsRanges.resize(thisFragment.size());
 		
-		for(size_t uj=0;uj<fragmentAsRanges.size();uj++)
+		for(auto uj=0;uj<fragmentAsRanges.size();uj++)
 		{	
 			unsigned int ionID;
 			ionID = getIonID(thisFragment[uj].first);
