@@ -140,7 +140,17 @@ size_t AbundanceData::open(const char *file, bool strict)
 		
 		nodePtr=nodePtr->xmlChildrenNode;
 
+		//This is redundant information, but we should check it anyway
+		if(XMLHelpFwdToElem(nodePtr,"mass"))
+			throw ABUNDANCE_ERROR_MISSING_NODE;
+
+		float meanMass;
+		if(XMLHelpGetProp(meanMass,nodePtr,"value"))
+			throw ABUNDANCE_ERROR_MISSING_NODE;
+
 		vector<ISOTOPE_DATA> curIsotopes;	
+		float runningSum;
+		runningSum=0;
 		//TODO: value checking	
 		while(!XMLHelpFwdToElem(nodePtr,"isotope"))
 		{
@@ -175,6 +185,7 @@ size_t AbundanceData::open(const char *file, bool strict)
 				throw ABUNDANCE_ERROR_BAD_VALUE;
 			else
 				curIsoData.abundanceError=0;
+			runningSum+=curIsoData.mass*curIsoData.abundance;
 
 			curIsotopes.push_back(curIsoData);
 
@@ -183,6 +194,10 @@ size_t AbundanceData::open(const char *file, bool strict)
 			nodeStack.pop();
 		}
 
+		//we don't actually use the meanMass value anywhere,
+		// but we check it for internal consistency
+		ASSERT(fabs(runningSum-meanMass) < 0.1);
+
 		isotopeData.push_back(curIsotopes);
 		curIsotopes.clear();	
 
@@ -219,6 +234,7 @@ size_t AbundanceData::symbolIndex(const char *symbol) const
 
 const ISOTOPE_DATA &AbundanceData::isotope(size_t elemIdx,size_t isotopeIdx) const
 {
+	ASSERT(isotopeData.size());
 	return isotopeData[elemIdx][isotopeIdx];
 }
 
@@ -226,6 +242,7 @@ void AbundanceData::generateIsotopeDist(const vector<size_t> &elementIdx,
 					const vector<size_t> &frequency,
 				vector<pair<float,float> > &massDist, size_t chargeCount) const
 {
+	ASSERT(isotopeData.size());
 	ASSERT(chargeCount);
 	ASSERT(frequency.size() == elementIdx.size());
 	//Search out the given isotopes, and compute the peaks
@@ -233,12 +250,6 @@ void AbundanceData::generateIsotopeDist(const vector<size_t> &elementIdx,
 
 	//map of vectors for the available isotopes
 	map<unsigned int, vector< pair<float,float> > > isotopeMassDist;
-	vector<float> bulkConcentration(frequency.size());
-
-	size_t total=std::accumulate(frequency.begin(),frequency.end(),0);
-
-	for(size_t ui=0;ui<frequency.size();ui++)
-		bulkConcentration[ui]=frequency[ui]/(float)total;
 
 	//For each isotope, retrieve  its (mass,probability dist) values
 	// placing into a map
@@ -257,8 +268,8 @@ void AbundanceData::generateIsotopeDist(const vector<size_t> &elementIdx,
 		{
 			//Compute the probability of this isotope's presence in
 			// the sampled concentration
-			thisIsotope.push_back(make_pair(isotopeData[curIso][uj].mass,
-				isotopeData[curIso][uj].abundance));
+			thisIsotope.emplace_back(isotopeData[curIso][uj].mass,
+				isotopeData[curIso][uj].abundance);
 		}
 
 		isotopeMassDist[curIso] = thisIsotope;
@@ -285,24 +296,24 @@ void AbundanceData::generateIsotopeDist(const vector<size_t> &elementIdx,
 			// distribution
 			if(peakProbs.empty())
 			{
-				//The masses will be added to, and the probabilities multipled	
-				for(vector<pair<float,float> >::const_iterator it=isoBegin;
+				//The masses will be added to, and the probabilities multiplied	
+				for(auto it=isoBegin;
 					it!=isoEnd;++it)
 					peakProbs.push_back(*it);
 			}
 			else
 			{
-				for(size_t uj=0;uj<peakProbs.size();uj++)
+				for(auto & peakProb : peakProbs)
 				{
 				
-					//The masses will be added to, and the probabilities multipled	
-					for(vector<pair<float,float> >::const_iterator it=isoBegin;
+					//The masses will be added to, and the probabilities multiplied	
+					for(auto it=isoBegin;
 						it!=isoEnd;++it)
 					{
 						pair<float,float> newMass;
 
-						newMass.first=peakProbs[uj].first+it->first;
-						newMass.second=peakProbs[uj].second*it->second;
+						newMass.first=peakProb.first+it->first;
+						newMass.second=peakProb.second*it->second;
 						newProbs.push_back(newMass);
 					}
 
@@ -338,9 +349,9 @@ void AbundanceData::generateIsotopeDist(const vector<size_t> &elementIdx,
 	massDist.swap(peakProbs);
 
 
-	for(size_t ui=0;ui<massDist.size();ui++)
+	for(auto & dist : massDist)
 	{
-		massDist[ui].first/=(float)chargeCount;
+		dist.first/=(float)chargeCount;
 	}
 
 }
@@ -364,16 +375,16 @@ void AbundanceData::checkErrors() const
 {
 	//Ensure all isotopes sum to 1-ish
 	// Rounding errors limit our correctness here.
-	for(size_t ui=0;ui<isotopeData.size();ui++)
+	for(const auto & data : isotopeData)
 	{
-		if(!isotopeData[ui].size())
+		if(!data.size())
 			continue;
 
 		float sum;
 		sum=0.0f;
-		for(size_t uj=0; uj<isotopeData[ui].size();uj++)
+		for(size_t uj=0; uj<data.size();uj++)
 		{
-			sum+=isotopeData[ui][uj].abundance;
+			sum+=data[uj].abundance;
 		}
 
 		ASSERT(fabs(sum -1.0f) < 0.000001);
@@ -386,15 +397,15 @@ void AbundanceData::checkErrors() const
 
 	//Enusre all isotopes are uniquely numbered
 	// - loop over each atom
-	for(size_t ui=0;ui<isotopeData.size();ui++)
+	for(const auto & data : isotopeData)
 	{
 		//now ovre each isotope
 		std::set<size_t> uniqNums;
 		uniqNums.clear();
-		for(size_t uj=0; uj<isotopeData[ui].size();uj++)
+		for(size_t uj=0; uj<data.size();uj++)
 		{
-			ASSERT(uniqNums.find(isotopeData[ui][uj].massNumber) == uniqNums.end());
-			uniqNums.insert(isotopeData[ui][uj].massNumber);
+			ASSERT(uniqNums.find(data[uj].massNumber) == uniqNums.end());
+			uniqNums.insert(data[uj].massNumber);
 			
 		}
 	}
