@@ -47,6 +47,8 @@ class IonHit
 		IonHit(float *);
 		//copy constructor
 		IonHit(const IonHit &);
+		//Move constructor
+		IonHit(IonHit&&) = default;
 		IonHit(const Point3D &p, float massToCharge);
 
 		//Size of data when stored in a file record
