@@ -18,6 +18,7 @@
 
 
 #include "vtk.h"
+#include "common/stringFuncs.h"
 
 #include <fstream>
 
@@ -50,17 +51,17 @@ unsigned int vtk_write_legacy(const std::string &filename, unsigned int format,
 		
 
 
-	f << "# vtk DataFile Version 2.0\n";
+	f << "# vtk DataFile Version 3.0\n";
 	f << "Saved using AtomProbe Tools\n";
 	f << "ASCII\n\n";
 
 	f << "DATASET UNSTRUCTURED_GRID\n";
 	f << "POINTS " << ions.size() << " float\n";
 	//Write ion data which is the support points for later scalar data
-	for(unsigned int ui=0;ui<ions.size(); ui++)
+	for(const auto & ion : ions)
 	{
-		f << ions[ui][0] << " " << ions[ui][1] << " "<< 
-			ions[ui][2] << "\n";
+		f << ion[0] << " " << ion[1] << " "<< 
+			ion[2] << "\n";
 	}	
 
 	f << "POINT_DATA " << ions.size() << endl;
@@ -68,9 +69,9 @@ unsigned int vtk_write_legacy(const std::string &filename, unsigned int format,
 	f << "SCALARS masstocharge float\n"; 
 	f << "LOOKUP_TABLE default\n";
 
-	for(unsigned int ui=0;ui<ions.size(); ui++)
+	for(const auto & ion : ions)
 	{
-		f << ions[ui].getMassToCharge() << "\n";
+		f << ion.getMassToCharge() << "\n";
 	}
 
 
@@ -86,7 +87,7 @@ bool testVTKExport()
 
 	//make a cube of ions, each with a differing mass.
 	for(unsigned int ui=0;ui<8;ui++)
-		ions.push_back(IonHit(Point3D(ui &1, (ui & 2) >>1, (ui &4) >>2),ui));
+		ions.emplace_back(IonHit(Point3D(ui &1, (ui & 2) >>1, (ui &4) >>2),ui));
 
 	//export it
 	TEST(vtk_write_legacy("debug.vtk",VTK_ASCII,ions) == 0,"VTK write");
