@@ -43,10 +43,7 @@ PropertyAnimator::PropertyAnimator()
 {
 }
 
-PropertyAnimator::PropertyAnimator(const PropertyAnimator &p) : keyFrames(p.keyFrames)
-{
-
-}
+PropertyAnimator::PropertyAnimator(const PropertyAnimator &p) = default;
 
 void PropertyAnimator::getNthKeyFrame(size_t frameNum,FrameProperties &f) const 
 {
@@ -58,8 +55,8 @@ size_t PropertyAnimator::getMaxFrame() const
 {
 	size_t maxFrame=0;
 	
-	for(size_t ui=0; ui<keyFrames.size();ui++)
-		maxFrame=std::max(maxFrame,keyFrames[ui].getMaxFrame());
+	for(const auto & keyFrame : keyFrames)
+		maxFrame=std::max(maxFrame,keyFrame.getMaxFrame());
 	return maxFrame;
 }
 
@@ -146,10 +143,10 @@ void PropertyAnimator::getPropertiesAtFrame(size_t keyframe,
 	}
 
 	//Now sweep up all the best frames
-	for(map<size_t,size_t>::iterator it=bestFrames.begin(); it!=bestFrames.end(); ++it)
+	for(auto & bestFrame : bestFrames)
 	{
-		propIds.push_back(it->second);
-		props.push_back(keyFrames[it->second]);
+		propIds.push_back(bestFrame.second);
+		props.push_back(keyFrames[bestFrame.second]);
 	}
 
 }
@@ -246,7 +243,7 @@ std::string PropertyAnimator::getInterpolatedFilterData(size_t filterId,
 					&& propertyKey == keyFrames[ui].getPropertyKey())
 			{
 				if(keyFrames[ui].getMaxFrame() <= frame)
-					seenFrames.push_back(make_pair(ui,keyFrames[ui].getMaxFrame()));
+					seenFrames.emplace_back(ui,keyFrames[ui].getMaxFrame());
 			}
 		}
 
@@ -273,9 +270,9 @@ bool PropertyAnimator::writeState(std::ostream &f, unsigned int format, unsigned
 	
 	f << tabs(depth) << "<propertyanimator>" << endl;
 	
-	for(size_t ui=0;ui<keyFrames.size();ui++)
+	for(const auto & keyFrame : keyFrames)
 	{
-		keyFrames[ui].writeState(f,format,depth+1);
+		keyFrame.writeState(f,format,depth+1);
 	}
 
 	f << tabs(depth) << "</propertyanimator>" << endl;
@@ -372,8 +369,8 @@ bool PropertyAnimator::loadState(xmlNodePtr &nodePtr)
 void PropertyAnimator::getIdList(vector<unsigned int> &ids) const
 {
 	set<unsigned int> s;
-	for(size_t ui=0;ui<keyFrames.size();ui++)
-		s.insert(keyFrames[ui].getFilterId());
+	for(const auto & keyFrame : keyFrames)
+		s.insert(keyFrame.getFilterId());
 
 	ids.resize(s.size());
 	std::copy(s.begin(),s.end(),ids.begin());
@@ -415,8 +412,7 @@ FrameProperties::FrameProperties(size_t idFilt,size_t idKey)
 }
 
 FrameProperties::~FrameProperties()
-{
-}
+= default;
 
 void FrameProperties::setInterpMode(size_t mode)
 {
@@ -433,8 +429,8 @@ size_t FrameProperties::getMinFrame() const
 {
 	size_t minFrame=std::numeric_limits<size_t>::max();
 	
-	for(size_t ui=0; ui<frameData.size();ui++)
-		minFrame=std::min(minFrame,frameData[ui].first);
+	for(const auto & data : frameData)
+		minFrame=std::min(minFrame,data.first);
 	return minFrame;
 }
 
@@ -442,21 +438,21 @@ size_t FrameProperties::getMaxFrame() const
 {
 	size_t maxFrame=0;
 	
-	for(size_t ui=0; ui<frameData.size();ui++)
-		maxFrame=std::max(maxFrame,frameData[ui].first);
+	for(const auto & data : frameData)
+		maxFrame=std::max(maxFrame,data.first);
 	return maxFrame;
 }
 
 void FrameProperties::addKeyFrame(size_t frame, 
 		const FilterProperty &p)
 {
-	frameData.push_back(make_pair(frame,p.data));	
+	frameData.emplace_back(frame,p.data);	
 }
 
 void FrameProperties::addKeyFrame(size_t frame, 
 		const std::string &s)
 {
-	frameData.push_back(make_pair(frame,s));	
+	frameData.emplace_back(frame,s);	
 }
 
 bool FrameProperties::writeState(std::ostream &f, unsigned int format, unsigned int depth) const
@@ -468,11 +464,11 @@ bool FrameProperties::writeState(std::ostream &f, unsigned int format, unsigned
 
 	//Dump the frame data vector
 	f << tabs(depth+1) << "<framedata>" << endl;
-	for(unsigned int ui=0;ui<frameData.size();ui++)
+	for(const auto & data : frameData)
 	{
 		f << tabs(depth+2) << "<frame offset=\"" << 
-			frameData[ui].first << "\" data=\"" <<
-				frameData[ui].second << "\"/>" << endl;
+			data.first << "\" data=\"" <<
+				data.second << "\"/>" << endl;
 	}
 	f << tabs(depth+2) << "<interpdata mode=\"" << getInterpMode() <<  "\"/>" << endl; 
 	f << tabs(depth+1) << "</framedata>" << endl;
