@@ -160,11 +160,12 @@ unsigned int ConfigFile::read()
 	//Open the XML file again, but without DTD validation
 	doc = xmlCtxtReadFile(context, filename.c_str(), NULL, XML_PARSE_NONET|XML_PARSE_NOENT);
 
-	if(!doc)
-		return CONFIG_ERR_NOFILE;
 
 	//release the context
 	xmlFreeParserCtxt(context);
+	
+	if(!doc)
+		return CONFIG_ERR_NOFILE;
 
 	//retrieve root node	
 	xmlNodePtr nodePtr = xmlDocGetRootElement(doc);
@@ -502,6 +503,25 @@ unsigned int ConfigFile::read()
 		nodePtr=nodeStack.top();
 		nodeStack.pop();
 
+		//FIXME: COMPAT_BREAK : This did not exist prior to 0.0.21, and may be missing from
+		// some 0.0.21 builds.  In the future this should be an error not to have this feature
+		nodeStack.push(nodePtr);
+		if(!XMLHelpFwdToElem(nodePtr,"shownexperimental"))
+		{
+			std::string str;
+			if(!XMLHelpGetProp(str,nodePtr,"namelist"))
+			{
+				vector<string> subStrs;
+				splitStrsRef(str.c_str(),',',subStrs);
+
+				for(const std::string &s : subStrs)
+					experimentalShownFilters.insert(s);
+			}
+			
+		}
+		nodePtr=nodeStack.top();
+		nodeStack.pop();
+
 
 nodeptrEndJump:
 		;
@@ -556,10 +576,16 @@ bool ConfigFile::write()
 	if(!createConfigDir())
 		return false;
 
+
 	filename = getConfigDir() + std::string("/") + std::string(CONFIG_FILENAME);
 
+	if(!canWriteToFile(filename.c_str()))
+		return false;
+
 	//Open file for output
-	std::ofstream f(filename.c_str());
+	string tmpFileName=stlStr(wxFileName::CreateTempFileName("3depict_config"));
+
+	std::ofstream f(tmpFileName.c_str());
 
 	if(!f)
 		return false;
@@ -633,9 +659,26 @@ bool ConfigFile::write()
 	f << tabs(1) << "<startuptips value=\"" << boolStrEnc(doWantStartupTips) << "\"/>" <<endl;
 	f << tabs(1) << "<wantorthocam value=\"" << boolStrEnc(wantStartupOrthoCam) << "\"/>" <<endl;
 
-	f << "</threeDepictconfig>" << endl;
+	
+	//Build list of filters that user has been shown
+	std::string tmpStr;
+	for(const std::string &str : experimentalShownFilters)
+		tmpStr+=str + ",";
 
-	ASSERT(isValidXML(filename.c_str()));
+	//trim trailing comma
+	if(tmpStr.size() && tmpStr[tmpStr.size()-1] == ',')
+		tmpStr=tmpStr.substr(0,tmpStr.size()-1);
+
+	f << tabs(1) << "<shownexperimental namelist=\"" << tmpStr << "\"/>" << endl;
+
+
+	f << "</threeDepictconfig>" << endl;
+	f.close();
+
+	ASSERT(isValidXML(tmpFileName.c_str()));
+
+	if(!wxRenameFile(tmpFileName,filename))
+		return false;
 
 	return true;
 }
@@ -748,4 +791,14 @@ void ConfigFile::setPlotListSashPos(float fraction)
 	plotListSashPos=fraction;
 }
 
+bool ConfigFile::shownExperimental(const std::string &filterName) const
+{
+	return (experimentalShownFilters.find(filterName) !=experimentalShownFilters.end());
+}
+
+void ConfigFile::setShownExperimental(const std::string &filterName) 
+{
+	experimentalShownFilters.insert(filterName);
+}
+
 
