@@ -20,6 +20,7 @@
 #define CONFIGFILE_H
 
 #include <deque>
+#include <set>
 
 #include "backend/filter.h"
 
@@ -51,9 +52,14 @@ enum
 class ConfigFile 
 {
 	private:
+		//!List of recent files that have been accessed by user
 		std::deque<std::string> recentFiles;
+		//!User-overridden filters to use as default
 		std::vector<Filter *> filterDefaults;
 		
+		//!List of filters that the user has been notified are experimental
+		std::set<std::string>  experimentalShownFilters;
+		
 		//!Did the configuration load from file OK?
 		bool configLoadOK;
 		
@@ -190,6 +196,12 @@ class ConfigFile
 		bool getWantStartupOrthoCam() const { return wantStartupOrthoCam;} 
 
 		void setWantStartupOrthoCam(bool want) { wantStartupOrthoCam=want;}
+
+
+		//!Has the user been shown a warning that the given filter (or configuration thereof) is experimental?
+		bool shownExperimental(const std::string &filterName) const;
+		//!Has the user been shown a warning that the given filter (or configuration thereof)is experimental?
+		void setShownExperimental(const std::string &filterName);
 };
 
 #endif
