@@ -45,9 +45,10 @@ using std::deque;
 
 
 
+std::mutex mtxProgress;
 
 bool Filter::strongRandom= false;
-ATOMIC_BOOL *Filter::wantAbort= 0;
+ATOMIC_BOOL *Filter::wantAbort= nullptr;
 
 const char *STREAM_NAMES[] = { NTRANS("Ion"),
 				NTRANS("Plot"),
@@ -71,16 +72,17 @@ const char *FILTER_NAMES[] = { "posload",
 				"clusteranalysis",
 				"voxelise",
 				"ioninfo",
-				"annotation"
+				"annotation",
+				"voxelload"
 				};
 
 size_t numElements(const vector<const FilterStreamData *> &v, unsigned int mask)
 {
 	size_t nE=0;
-	for(unsigned int ui=0;ui<v.size();ui++)
+	for(auto stream : v)
 	{
-		if((v[ui]->getStreamType() & mask))
-			nE+=v[ui]->getNumBasicObjects();
+		if((stream->getStreamType() & mask))
+			nE+=stream->getNumBasicObjects();
 	}
 
 	return nE;
@@ -207,17 +209,18 @@ void Filter::appendConsoleMessage(const std::string &s)
 
 void Filter::markConsoleCached()
 {
-	for(unsigned int ui=0;ui<consoleOutput.size();ui++)
-		consoleOutput[ui].cached=true;
+	for(auto & output : consoleOutput)
+		output.cached=true;
 }
 
 FilterProperty::FilterProperty()
 {
+	displayShaded=false;
 }
 
 FilterProperty::FilterProperty(size_t keyV, unsigned int typeV, const std::string &nameV, 
 					const std::string &dataV, const std::string &helpTextV) 
-	 : helpText(helpTextV), type(typeV), key(keyV), data(dataV),name(nameV)
+	 : helpText(helpTextV), type(typeV), key(keyV), data(dataV),name(nameV),displayShaded(false)
 {
 	
 #ifdef DEBUG
@@ -228,13 +231,13 @@ FilterProperty::FilterProperty(size_t keyV, unsigned int typeV, const std::strin
 
 FilterProperty::FilterProperty(size_t keyV, const std::string &nameV, 
 		const std::string &dataV, const std::string &helpTextV)
-	 : helpText(helpTextV), type(PROPERTY_TYPE_STRING), key(keyV), data(dataV),name(nameV)
+	 : helpText(helpTextV), type(PROPERTY_TYPE_STRING), key(keyV), data(dataV),name(nameV), displayShaded(false)
 {
 
 }
 FilterProperty::FilterProperty(size_t keyV, const std::string &nameV, 
 					unsigned int dataV, const std::string &helpTextV) 
-	 : helpText(helpTextV), type(PROPERTY_TYPE_INTEGER), key(keyV), name(nameV)
+	 : helpText(helpTextV), type(PROPERTY_TYPE_INTEGER), key(keyV), name(nameV), displayShaded(false)
 {
 	bool res;
 	res=stream_cast(data,dataV);
@@ -247,7 +250,7 @@ FilterProperty::FilterProperty(size_t keyV, const std::string &nameV,
 
 FilterProperty::FilterProperty(size_t keyV, const std::string &nameV, 
 					float dataV, const std::string &helpTextV) 
-	 : helpText(helpTextV), type(PROPERTY_TYPE_REAL), key(keyV), name(nameV)
+	 : helpText(helpTextV), type(PROPERTY_TYPE_REAL), key(keyV), name(nameV), displayShaded(false)
 {
 	bool res;
 	res=stream_cast(data,dataV);
@@ -260,7 +263,7 @@ FilterProperty::FilterProperty(size_t keyV, const std::string &nameV,
 
 FilterProperty::FilterProperty(size_t keyV, const std::string &nameV, 
 					bool dataV, const std::string &helpTextV) 
-	 : helpText(helpTextV), type(PROPERTY_TYPE_BOOL), key(keyV), name(nameV)
+	 : helpText(helpTextV), type(PROPERTY_TYPE_BOOL), key(keyV), name(nameV), displayShaded(false)
 {
 	data=boolStrEnc(dataV);
 #ifdef DEBUG
@@ -271,7 +274,7 @@ FilterProperty::FilterProperty(size_t keyV, const std::string &nameV,
 
 FilterProperty::FilterProperty(size_t keyV, const std::string &nameV, 
 					const Point3D &dataV, const std::string &helpTextV) 
-	 : helpText(helpTextV), type(PROPERTY_TYPE_POINT3D), key(keyV), name(nameV)
+	 : helpText(helpTextV), type(PROPERTY_TYPE_POINT3D), key(keyV), name(nameV), displayShaded(false)
 {
 	stream_cast(data,dataV);
 #ifdef DEBUG
@@ -282,7 +285,7 @@ FilterProperty::FilterProperty(size_t keyV, const std::string &nameV,
 
 FilterProperty::FilterProperty(size_t keyV, const std::string &nameV, 
 					const ColourRGBA &dataV, const std::string &helpTextV) 
-	 : helpText(helpTextV), type(PROPERTY_TYPE_COLOUR), key(keyV), name(nameV)
+	 : helpText(helpTextV), type(PROPERTY_TYPE_COLOUR), key(keyV), name(nameV), displayShaded(false)
 {
 	data=dataV.rgbString();
 
@@ -294,7 +297,7 @@ FilterProperty::FilterProperty(size_t keyV, const std::string &nameV,
 
 FilterProperty::FilterProperty(size_t keyV, const std::string &nameV, 
 					const ColourRGBAf &dataV, const std::string &helpTextV) 
-	 : helpText(helpTextV), type(PROPERTY_TYPE_COLOUR), key(keyV), name(nameV)
+	 : helpText(helpTextV), type(PROPERTY_TYPE_COLOUR), key(keyV), name(nameV), displayShaded(false)
 {
 	data=dataV.toColourRGBA().rgbString();
 
@@ -307,7 +310,7 @@ FilterProperty::FilterProperty(size_t keyV, const std::string &nameV,
 FilterProperty::FilterProperty(size_t keyV, const std::string &nameV, 
 		std::vector<std::pair<unsigned int, string> > &choices, 
 		unsigned int selected, const std::string &helpTextV) 
-	 : helpText(helpTextV), type(PROPERTY_TYPE_CHOICE), key(keyV), name(nameV)
+	 : helpText(helpTextV), type(PROPERTY_TYPE_CHOICE), key(keyV), name(nameV), displayShaded(false)
 {
 
 	data=choiceString(choices,selected);
@@ -400,16 +403,16 @@ void FilterPropGroup::addProperty(const FilterProperty &prop, size_t group)
 
 
 #ifdef DEBUG
-	for(unsigned int ui=0; ui<properties.size();ui++)
+	for(auto & property : properties)
 	{
 		//Check for key uniqueness
-		ASSERT(prop.key != properties[ui].key);
+		ASSERT(prop.key != property.key);
 		//Note, you can't check for help text uniqueness, or key name uniqueness
 		// as these can repeat (eg for range selection).
 	}
 #endif
 
-	keyGroupings.push_back(make_pair(prop.key,group));
+	keyGroupings.emplace_back(prop.key,group);
 	properties.push_back(prop);
 }
 
@@ -437,9 +440,9 @@ void FilterPropGroup::getGroup(size_t targetGroup, vector<FilterProperty> &vec)
 
 bool FilterPropGroup::hasGroup(size_t targetGroup) const
 {
-	for(size_t ui=0;ui<keyGroupings.size();ui++)
+	for(auto keyGrouping : keyGroupings)
 	{
-		if(keyGroupings[ui].second==targetGroup)
+		if(keyGrouping.second==targetGroup)
 			return true;
 	}
 
@@ -464,9 +467,9 @@ const FilterProperty &FilterPropGroup::getPropValue(size_t key) const
 
 bool FilterPropGroup::hasProp(size_t key) const
 {
-	for(size_t ui=0;ui<keyGroupings.size();ui++)
+	for(auto keyGrouping : keyGroupings)
 	{
-		if(keyGroupings[ui].first == key)
+		if(keyGrouping.first == key)
 			return true;
 	}
 
@@ -480,23 +483,23 @@ void FilterPropGroup::checkConsistent() const
 	std::set<size_t> s;
 
 	//Check that each key is unique in the keyGroupings list
-	for(size_t ui=0;ui<keyGroupings.size();ui++)
+	for(auto keyGrouping : keyGroupings)
 	{
-		ASSERT(std::find(s.begin(),s.end(),keyGroupings[ui].first) == s.end());
-		s.insert(keyGroupings[ui].first);
+		ASSERT(std::find(s.begin(),s.end(),keyGrouping.first) == s.end());
+		s.insert(keyGrouping.first);
 	}
 
 	//Check that each key in the properties is also unique
 	s.clear();
-	for(size_t ui=0;ui<properties.size(); ui++)
+	for(const auto & property : properties)
 	{
-		ASSERT(std::find(s.begin(),s.end(),properties[ui].key) == s.end());
-		s.insert(properties[ui].key);
+		ASSERT(std::find(s.begin(),s.end(),property.key) == s.end());
+		s.insert(property.key);
 	}
 
-	for(size_t ui=0;ui<properties.size(); ui++)
+	for(const auto & property : properties)
 	{
-		ASSERT(properties[ui].helpText.size());	
+		ASSERT(property.helpText.size());	
 	}
 
 	//Check that the group names are the same as the number of groups
@@ -504,9 +507,9 @@ void FilterPropGroup::checkConsistent() const
 
 
 	//check that each group has a name
-	for(size_t ui=0;ui<groupNames.size(); ui++)
+	for(const auto & groupName : groupNames)
 	{
-		ASSERT(!groupNames[ui].empty())
+		ASSERT(!groupName.empty())
 	}
 }
 #endif
@@ -515,8 +518,8 @@ void FilterPropGroup::checkConsistent() const
 
 void DrawStreamData::clear()
 {
-	for(unsigned int ui=0; ui<drawables.size(); ui++)
-		delete drawables[ui];
+	for(auto & drawable : drawables)
+		delete drawable;
 }
 
 DrawStreamData::~DrawStreamData()
@@ -606,8 +609,8 @@ bool PlotStreamData::save(const char *filename) const
 	{
 		if(pendingEndl)
 			f << endl;
-		for(size_t ui=0;ui<xyData.size();ui++)
-			f << xyData[ui].first << "\t" << xyData[ui].second << endl;
+		for(auto data : xyData)
+			f << data.first << "\t" << data.second << endl;
 	}
 	else
 	{
@@ -617,8 +620,8 @@ bool PlotStreamData::save(const char *filename) const
 		}
 		else
 			f << "\t\t" << TRANS("Error") << endl;
-		for(size_t ui=0;ui<xyData.size();ui++)
-			f << xyData[ui].first << "\t" << xyData[ui].second << endl;
+		for(auto data : xyData)
+			f << data.first << "\t" << data.second << endl;
 	}
 
 	return true;
@@ -687,6 +690,53 @@ size_t Plot2DStreamData::getNumBasicObjects() const
 	return 0;
 }
 
+bool Plot2DStreamData::save(const char *filename) const
+{
+
+	std::ofstream f(filename);
+
+	if(!f)
+		return false;
+
+	bool pendingEndl = false;
+	if(xLabel.size())
+	{
+		f << xLabel;
+		pendingEndl=true;
+	}
+	if(yLabel.size())
+	{
+		f << "\t" << yLabel;
+		pendingEndl=true;
+	}
+
+	if(intensityLabel.size())
+	{
+		f << "\t" << intensityLabel;
+		pendingEndl=true;
+	}
+
+	if(pendingEndl)
+		f << endl;
+
+	if(scatterIntensity.size())
+	{
+		ASSERT(scatterIntensity.size() == scatterData.size())
+		for(size_t ui=0;ui<scatterData.size();ui++)
+		{
+			f << scatterData[ui].first << "\t" << scatterData[ui].second << 
+				"\t" << scatterIntensity[ui] << endl;
+		}
+	}
+	else
+	{
+		for(auto data : scatterData)
+			f << data.first << "\t" << data.second << endl;
+	}
+
+	return true;
+}
+
 #ifdef DEBUG
 
 void Plot2DStreamData::checkSelfConsistent() const
@@ -713,7 +763,7 @@ void RangeStreamData::checkSelfConsistent() const
 }
 #endif
 
-FilterStreamData::FilterStreamData() : parent(0),cached((unsigned int)-1)
+FilterStreamData::FilterStreamData() : parent(nullptr),cached((unsigned int)-1)
 {
 }
 
@@ -738,14 +788,14 @@ unsigned int IonStreamData::exportStreams(const std::vector<const FilterStreamDa
 
 	if(format != IONFORMAT_VTK)
 	{
-		for(unsigned int ui=0; ui<selectedStreams.size(); ui++)
+		for(auto selectedStream : selectedStreams)
 		{
-			switch(selectedStreams[ui]->getStreamType())
+			switch(selectedStream->getStreamType())
 			{
 				case STREAM_TYPE_IONS:
 				{
 					const IonStreamData *ionData;
-					ionData=((const IonStreamData *)(selectedStreams[ui]));
+					ionData=((const IonStreamData *)selectedStream);
 
 						//Append this ion stream to the posfile
 						IonHit::appendFile(ionData->data,outFile.c_str(),format);
@@ -761,29 +811,29 @@ unsigned int IonStreamData::exportStreams(const std::vector<const FilterStreamDa
 		vector<IonHit> ionvec;
 		//--
 		unsigned int numIons=0;
-		for(unsigned int ui=0; ui<selectedStreams.size(); ui++)
+		for(auto selectedStream : selectedStreams)
 		{
-			switch(selectedStreams[ui]->getStreamType())
+			switch(selectedStream->getStreamType())
 			{
 				case STREAM_TYPE_IONS:
 				{
-					numIons+=selectedStreams[ui]->getNumBasicObjects();
+					numIons+=selectedStream->getNumBasicObjects();
 					break;
 				}
 			}
 		}
 		
 		ionvec.reserve(numIons);
-		for(unsigned int ui=0;ui<selectedStreams.size();ui++)
+		for(auto selectedStream : selectedStreams)
 		{
-			switch(selectedStreams[ui]->getStreamType())
+			switch(selectedStream->getStreamType())
 			{
 				case STREAM_TYPE_IONS:
 				{
 					const IonStreamData *ionData;
-					ionData=((const IonStreamData *)(selectedStreams[ui]));
-					for(unsigned int uj=0;uj<ionData->data.size();uj++)
-						ionvec.push_back(ionData->data[uj]);
+					ionData=((const IonStreamData *)selectedStream);
+					for(const auto & data : ionData->data)
+						ionvec.push_back(data);
 					break;
 				}
 			}
@@ -799,14 +849,14 @@ unsigned int IonStreamData::exportStreams(const std::vector<const FilterStreamDa
 
 IonStreamData::IonStreamData() : 
 	r(1.0f), g(0.0f), b(0.0f), a(1.0f), 
-	ionSize(2.0f), valueType("Mass-to-Charge (amu/e)")
+	ionSize(2.0f), valueType("Mass-to-Charge (Da/e)")
 {
 	streamType=STREAM_TYPE_IONS;
 }
 
 IonStreamData::IonStreamData(const Filter *f) : FilterStreamData(f), 
 	r(1.0f), g(0.0f), b(0.0f), a(1.0f), 
-	ionSize(2.0f), valueType("Mass-to-Charge (amu/e)")
+	ionSize(2.0f), valueType("Mass-to-Charge (Da/e)")
 {
 	streamType=STREAM_TYPE_IONS;
 }
@@ -823,9 +873,9 @@ void IonStreamData::estimateIonParameters(const std::vector<const FilterStreamDa
 	a=1.0;
 
 	//Sum up the relative frequencies
-	for(unsigned int ui=0; ui<inData.size(); ui++)
+	for(auto data : inData)
 	{
-		if(inData[ui]->getStreamType() != STREAM_TYPE_IONS)
+		if(data->getStreamType() != STREAM_TYPE_IONS)
 			continue;	
 
 		//Keep a count of the number of times we see a particlar
@@ -834,7 +884,7 @@ void IonStreamData::estimateIonParameters(const std::vector<const FilterStreamDa
 		map<vector<float> ,unsigned int>::iterator itData;
 	
 		const IonStreamData* p;	
-		p= ((const IonStreamData*)inData[ui]);
+		p= ((const IonStreamData*)data);
 
 		itSize=ionSizeMap.find(p->ionSize);
 		if(itSize == ionSizeMap.end())
@@ -859,29 +909,27 @@ void IonStreamData::estimateIonParameters(const std::vector<const FilterStreamDa
 		 
 	}
 	
-	const vector<float> *tmp=0;
+	const vector<float> *tmp=nullptr;
 	size_t min=0;
 	//find the most frequent ion colour	
-	for(map<vector<float>, unsigned int>::iterator it=ionColourMap.begin();
-		it!=ionColourMap.end(); ++it)
+	for(auto & it : ionColourMap)
 	{
-		if(it->second > min)
+		if(it.second > min)
 		{
-			tmp = &(it->first);
-			min=it->second;
+			tmp = &(it.first);
+			min=it.second;
 		}
 	}
 
 	//Find the most frequent ion size
 	float tmpSize=1.0;
 	min=0;
-	for(map<float, unsigned int>::iterator it=ionSizeMap.begin();
-		it!=ionSizeMap.end(); ++it)
+	for(auto & it : ionSizeMap)
 	{
-		if(it->second > min)
+		if(it.second > min)
 		{
-			tmpSize = it->first;
-			min=it->second;
+			tmpSize = it.first;
+			min=it.second;
 		}
 	}
 
@@ -917,7 +965,7 @@ void IonStreamData::clear()
 IonStreamData *IonStreamData::cloneSampled(float fraction) const
 
 {
-	IonStreamData *out = new IonStreamData;
+	auto out = new IonStreamData;
 
 	out->r=r;
 	out->g=g;
@@ -958,6 +1006,8 @@ VoxelStreamData::VoxelStreamData() : representationType(VOXEL_REPRESENT_POINTCLO
 	data = new Voxels<float>;
 	colourMin=0;
 	colourMax=1;
+
+	showBBox =false;
 }
 
 VoxelStreamData::VoxelStreamData(const Filter *f) : FilterStreamData(f), representationType(VOXEL_REPRESENT_POINTCLOUD),
@@ -975,7 +1025,7 @@ VoxelStreamData::~VoxelStreamData()
 
 size_t VoxelStreamData::getNumBasicObjects() const
 {
-	return data->getSize(); 
+	return data->size(); 
 }
 
 void VoxelStreamData::clear()
@@ -983,12 +1033,12 @@ void VoxelStreamData::clear()
 	data->clear();
 }
 
-RangeStreamData::RangeStreamData() : rangeFile(0)
+RangeStreamData::RangeStreamData() : rangeFile(nullptr)
 {
 	streamType = STREAM_TYPE_RANGE;
 }
 
-RangeStreamData::RangeStreamData(const Filter *f) : FilterStreamData(f), rangeFile(0)
+RangeStreamData::RangeStreamData(const Filter *f) : FilterStreamData(f), rangeFile(nullptr)
 {
 	streamType = STREAM_TYPE_RANGE;
 }
@@ -1001,6 +1051,7 @@ bool RangeStreamData::save(const char *filename, size_t format) const
 Filter::Filter() : cache(true), cacheOK(false)
 {
 	COMPILE_ASSERT( THREEDEP_ARRAYSIZE(STREAM_NAMES) == NUM_STREAM_TYPES);
+	COMPILE_ASSERT( THREEDEP_ARRAYSIZE(FILTER_NAMES) == FILTER_TYPE_ENUM_END);
 	for(unsigned int ui=0;ui<NUM_STREAM_TYPES;ui++)
 		numStreamsLastRefresh[ui]=0;
 }
@@ -1021,9 +1072,9 @@ void Filter::setPropFromRegion(unsigned int method, unsigned int regionID, float
 
 void Filter::clearDevices()
 {
-	for(unsigned int ui=0; ui<devices.size(); ui++)
+	for(auto & device : devices)
 	{
-		delete devices[ui];
+		delete device;
 	}
 	devices.clear();
 }
@@ -1034,10 +1085,10 @@ void Filter::clearCache()
 	cacheOK=false; 
 
 	//Free mem held by objects	
-	for(unsigned int ui=0;ui<filterOutputs.size(); ui++)
+	for(auto & filterOutput : filterOutputs)
 	{
-		ASSERT(filterOutputs[ui]->cached);
-		delete filterOutputs[ui];
+		ASSERT(filterOutput->cached);
+		delete filterOutput;
 	}
 
 	filterOutputs.clear();	
@@ -1086,10 +1137,10 @@ void Filter::propagateStreams(const vector<const FilterStreamData *> &dataIn,
 	//Propagate any inputs that we don't normally block
 	if(invertMask)
 		mask=~mask;
-	for(size_t ui=0;ui<dataIn.size();ui++)
+	for(auto data : dataIn)
 	{
-		if(dataIn[ui]->getStreamType() & mask)
-			dataOut.push_back(dataIn[ui]);
+		if(data->getStreamType() & mask)
+			dataOut.push_back(data);
 	}
 }
 
@@ -1108,14 +1159,14 @@ unsigned int Filter::collateIons(const vector<const FilterStreamData *> &dataIn,
 	size_t offset=0;
 
 
-	for(unsigned int ui=0;ui<dataIn.size() ;ui++)
+	for(auto data : dataIn)
 	{
-		switch(dataIn[ui]->getStreamType())
+		switch(data->getStreamType())
 		{
 			case STREAM_TYPE_IONS: 
 			{
 				const IonStreamData *d;
-				d=((const IonStreamData *)dataIn[ui]);
+				d=((const IonStreamData *)data);
 
 				size_t dataSize=d->data.size();
 
@@ -1149,14 +1200,14 @@ unsigned int Filter::collateIons(const vector<const FilterStreamData *> &dataIn,
 	if(*Filter::wantAbort)
 		return FILTER_ERR_ABORT;
 
-	for(unsigned int ui=0;ui<dataIn.size() ;ui++)
+	for(auto data : dataIn)
 	{
-		switch(dataIn[ui]->getStreamType())
+		switch(data->getStreamType())
 		{
 			case STREAM_TYPE_IONS: 
 			{
 				const IonStreamData *d;
-				d=((const IonStreamData *)dataIn[ui]);
+				d=((const IonStreamData *)data);
 
 				if(extendDataVector(p,d->data,	prog.filterProgress,
 						dataSize))
@@ -1214,29 +1265,46 @@ ProgressData::ProgressData()
 {
 	step=0;
 	maxStep=0;
-	curFilter=0;
+	curFilter=nullptr;
 	filterProgress=0;
 	totalProgress=0;
 	totalNumFilters=0;
 }
 
-
 bool ProgressData::operator==( const ProgressData &oth) const
 {
+	std::lock_guard<std::mutex> g(mtxProgress);
 	if(filterProgress!=oth.filterProgress ||
 		(totalProgress!=oth.totalProgress) ||
 		(totalNumFilters!=oth.totalNumFilters) ||
 		(step!=oth.step) ||
 		(maxStep!=oth.maxStep) ||
 		(curFilter!=oth.curFilter )||
+		(estimatedSteps !=oth.estimatedSteps) ||
 		(stepName!=oth.stepName) )
 		return false;
 
 	return true;
 }
 
+ProgressData::ProgressData(const ProgressData &oth) 
+{
+	std::lock_guard<std::mutex> g(mtxProgress);
+	
+	filterProgress=oth.filterProgress ;
+	totalProgress=oth.totalProgress ;
+	totalNumFilters=oth.totalNumFilters ;
+	step=oth.step ;
+	maxStep=oth.maxStep ;
+	curFilter=oth.curFilter ;
+	stepName=oth.stepName;
+	estimatedSteps=oth.estimatedSteps;	
+}
+
 const ProgressData &ProgressData::operator=(const ProgressData &oth)
 {
+	std::lock_guard<std::mutex> g(mtxProgress);
+
 	filterProgress=oth.filterProgress;
 	totalProgress=oth.totalProgress;
 	totalNumFilters=oth.totalNumFilters;
