@@ -53,6 +53,8 @@ class Voxels;
 
 #include <wx/propgrid/propgrid.h>
 
+#include <mutex>
+
 const unsigned int NUM_CALLBACK=50000;
 
 const unsigned int IONDATA_SIZE=16;
@@ -75,6 +77,7 @@ enum
 	FILTER_TYPE_VOXELS,
 	FILTER_TYPE_IONINFO,
 	FILTER_TYPE_ANNOTATION,
+	FILTER_TYPE_VOXEL_LOAD,
 	FILTER_TYPE_ENUM_END // not a filter. just end of enum
 };
 
@@ -237,6 +240,9 @@ class FilterProperty
 	//!name of property
 	std::string name;
 
+	//!Do we want to display this property with shading?
+	bool displayShaded;
+
 	FilterProperty();
 
 	//Initialise property with explicit type, using string
@@ -382,7 +388,8 @@ public:
 	VoxelStreamData( const Filter *f);
 	size_t getNumBasicObjects() const ;
 	void clear();
-	
+
+	//Voxel representation mode, see VOXEL_REPRESENT for details
 	unsigned int representationType;
 	//Do we want to use a built-in colour map, or a custom eon
 	unsigned int colourMapMode;
@@ -394,12 +401,17 @@ public:
 	float colourMin,colourMax;
 	//RGBA (eg for isosurface) 
 	float r,g,b,a;
-	//Size of "splats" to use when using the point based reporesentation
+	//Size of "splats" to use when using the point based representation
 	float splatSize;
 	//Isosurface value to apply
 	float isoLevel;
 	//!Apply filter to input data stream	
 	Voxels<float> *data;
+
+	//Do we want to show the bounding box?
+	bool showBBox;
+	//RGBA (eg for isosurface) 
+	float bBoxR,bBoxG,bBoxB,bBoxA;
 		
 #ifdef DEBUG
 	const string getName() const { return "Voxel Stream";}; 
@@ -418,7 +430,7 @@ class PlotStreamData : public FilterStreamData
 	public:
 		PlotStreamData();
 		PlotStreamData(const Filter *f);
-
+		//Write out a text version of this plot into a file
 		bool save(const char *filename) const; 
 
 		//erase plot contents	
@@ -490,6 +502,9 @@ class Plot2DStreamData : public FilterStreamData
 		Plot2DStreamData();
 		Plot2DStreamData(const Filter *f);
 
+
+		//Write out a text version of this plot into a file
+		bool save(const char *filename) const; 
 		//erase plot contents	
 		void clear() {xyData.clear();};
 			
@@ -498,6 +513,7 @@ class Plot2DStreamData : public FilterStreamData
 		std::string dataLabel;
 		//Label for X, Y axes
 		std::string xLabel,yLabel;
+		
 
 		unsigned int plotStyle;
 
@@ -513,6 +529,9 @@ class Plot2DStreamData : public FilterStreamData
 		std::vector<std::pair<float,float> > scatterData;
 		//optional intensity data for scatter plots
 		std::vector<float> scatterIntensity;
+		//label for size data
+		std::string intensityLabel;
+
 	
 		//Do we want to plot the scatter intensity in log mode?
 		bool scatterIntensityLog;	
@@ -632,20 +651,11 @@ class Filter
 		//!Propagate the cache into output
 		void propagateCache(std::vector<const FilterStreamData *> &dataOut) const;
 
-		//Set a property, without any checking of the new value 
-		// -clears cache on change
-		// - and skipping if no actual change between old and new prop
-		// returns true if change applied OK.
-		template<class T>	
-		bool applyPropertyNow(T &oldProp,const std::string &newVal, bool &needUp);
 
 		//!Add a new console message
 		void appendConsoleMessage(const std::string &s);
 
 
-		//place a stream object into the filter cache, if required
-		// does not place object into filter output - you need to do that yourself
-		void cacheAsNeeded(FilterStreamData *s); 
 
 		//!Get the generic (applies to any filter) error codes
 		static std::string getBaseErrString(unsigned int errCode);
@@ -895,6 +905,9 @@ class Filter
 		//Abort pointer . This must be  nonzero during filter refreshes
 		static ATOMIC_BOOL *wantAbort;
 
+		//!Obtain the number of progress steps for the refresh (e.g. may have 3 stages of computation)
+		virtual unsigned int getNumSteps() const { return 1; }; 
+
 		//Pure virtual functions
 		//====
 		//!Duplicate filter contents, excluding cache.
@@ -910,6 +923,10 @@ class Filter
 		//!Erase any active devices
 		virtual void clearDevices(); 
 
+		//place a stream object into the filter cache, if required
+		// does not place object into filter output - you need to do that yourself
+		void cacheAsNeeded(FilterStreamData *s); 
+
 		//!Get (approx) number of bytes required for cache
 		virtual size_t numBytesForCache(size_t nObjects) const =0;
 
@@ -989,7 +1006,8 @@ class Filter
 		
 
 		//!Modified version of writeState for packaging. By default simply calls writeState.
-		//value overrides override the values returned by getStateOverrides. In order.	
+		// value overrides override the values returned by getStateOverrides. In order.	
+		// Despite being const, if overridden by a filter, it may not be thread safe, as the filter may ignore const in some cases
 		virtual bool writePackageState(std::ostream &f, unsigned int format,
 				const std::vector<std::string> &valueOverrides,unsigned int depth=0) const {return writeState(f,format,depth);};
 		
@@ -1015,6 +1033,9 @@ class Filter
 		//!Can this filter perform actions that are potentially a security concern?
 		virtual bool canBeHazardous() const {return false;} ;
 
+		//!Are we currently configuread as an experimental filter?
+		virtual bool curConfigurationIsExperimental() const { return false;};
+
 		//!Get the number of outputs for the specified type during the filter's last refresh
 		unsigned int getNumOutput(unsigned int streamType) const;
 
@@ -1032,6 +1053,9 @@ class Filter
 		//Check to see if the filter needs to be refreshed 
 		virtual bool monitorNeedsRefresh() const { return false;};
 
+		//Have the filter update its monitor status, if required. 
+		virtual void updateMonitor() {};
+
 		//Are we a pure data source  - i.e. can function with no input
 		virtual bool isPureDataSource() const { return false;};
 
@@ -1045,6 +1069,12 @@ class Filter
 		static void getStreamsOfType(const std::vector<const FilterStreamData *> &vec, std::vector<const T *> &dataOut);
 
 
+		//Set a property, without any checking of the new value 
+		// -clears cache on change
+		// - and skipping if no actual change between old and new prop
+		// returns true if change applied OK.
+		template<class T>	
+		bool applyPropertyNow(T &oldProp,const std::string &newVal, bool &needUp);
 
 
 #ifdef DEBUG
@@ -1117,6 +1147,11 @@ bool Filter::applyPropertyNow(T &prop, const std::string &val, bool &needUp)
 }
 //--
 
+
+//FIXME: There are clear problems with data races in this class.
+// members should be moved into functions, and
+// locked through e.g. a mutex. However, the performance
+// of this is critical, as progress updating is often in critical zones.
 //!Class that tracks the progress of scene updates
 class ProgressData
 {
@@ -1133,6 +1168,8 @@ class ProgressData
 		unsigned int step;
 		//!Maximum steps
 		unsigned int maxStep;
+		//!Estimated steps for each filter in the refresh
+		vector<unsigned int> estimatedSteps; 
 		
 		//!Pointer to the current filter that is being updated. 
 		const Filter *curFilter;
@@ -1141,6 +1178,7 @@ class ProgressData
 		std::string stepName;
 
 		ProgressData(); 
+		ProgressData(const ProgressData &o);
 
 		bool operator==(const ProgressData &o) const;
 		const ProgressData &operator=(const ProgressData &o);
