@@ -339,7 +339,7 @@ void K3DTreeMk2::ptsInSphere(const Point3D &origin, float radius,
 			{
 				if(leftCube.containedInSphere(origin,sqrRadius))
 				{
-					ASSERT(indexedPoints[nodeIdx].first.sqrDist(origin) <=sqrRadius);
+					ASSERT(indexedPoints[nodeIdx].first.sqrDist(origin) < radius*radius);
 					idxQueue.push(nodes[nodeIdx].childLeft);
 				}
 				else
@@ -357,7 +357,7 @@ void K3DTreeMk2::ptsInSphere(const Point3D &origin, float radius,
 				{
 					//If the right-hand cube is contained within (origin,radius) sphere, then so are all its chilren
 
-					ASSERT(indexedPoints[nodeIdx].first.sqrDist(origin) <=sqrRadius);
+					ASSERT(indexedPoints[nodeIdx].first.sqrDist(origin) < sqrRadius);
 					idxQueue.push(nodes[nodeIdx].childRight);
 				}
 				else
@@ -377,7 +377,7 @@ void K3DTreeMk2::ptsInSphere(const Point3D &origin, float radius,
 	{
 		size_t curIdx;
 		curIdx=idxQueue.front();
-		ASSERT(indexedPoints[curIdx].first.sqrDist(origin) <=sqrRadius);
+		ASSERT(indexedPoints[curIdx].first.sqrDist(origin) < sqrRadius);
 		if(nodes[curIdx].childLeft != (size_t)-1)
 			idxQueue.push(nodes[curIdx].childLeft);
 		
@@ -638,7 +638,7 @@ size_t K3DTreeMk2::findNearestUntagged(const Point3D &searchPt,
 	}while(!(curNode== startNode &&  visit== NODE_THIRD_VISIT));
 
 	if(bestPoint != (size_t) -1)
-		nodes[bestPoint].tagged|=shouldTag;
+		nodes[bestPoint].tagged=(nodes[bestPoint].tagged || shouldTag);
 	return bestPoint;	
 
 }
@@ -1131,7 +1131,7 @@ bool K3DMk2Tests()
 	
 	//First test with single point
 	//--
-	pts.push_back(Point3D(0,0,0));
+	pts.emplace_back(Point3D(0,0,0));
 	tree.resetPts(pts,false);
 
 
@@ -1157,8 +1157,8 @@ bool K3DMk2Tests()
 
 	//Now, try adding more points
 	//---
-	pts.push_back(Point3D(1,1,1));
-	pts.push_back(Point3D(1.1,0.9,0.95));
+	pts.emplace_back(Point3D(1,1,1));
+	pts.emplace_back(Point3D(1.1,0.9,0.95));
 	
 	tree.resetPts(pts,false);
 	TEST(tree.build(),"Tree build");
