@@ -166,12 +166,12 @@ int countBinnedIons(const std::vector<IonHit> &ions, const RangeFile *rng,
 	totalBound.getBound(lowBound,0);
 
 	completedGridEntries.reserve(((float)filteredIons.size()/segmentOptions.nIons)*0.5f);
-	for(size_t ui=0;ui<filteredIons.size(); ui++)
+	for(auto & filteredIon : filteredIons)
 	{	
 		//Find the X y division for the ion
 		unsigned int xPos,yPos;
 		Point3D ionOffset;
-		ionOffset=filteredIons[ui].getPos() - lowBound;
+		ionOffset=filteredIon.getPos() - lowBound;
 		xPos =ionOffset[direction[0]]/binLen[0];
 		yPos = ionOffset[direction[1]]/binLen[1];
 
@@ -188,7 +188,7 @@ int countBinnedIons(const std::vector<IonHit> &ions, const RangeFile *rng,
 		binIdx = rowMajorOffset(xPos,yPos,nBins[1]);
 		
 		//get ion ID
-		ionId=rng->getIonID(filteredIons[ui].getMassToCharge());
+		ionId=rng->getIonID(filteredIon.getMassToCharge());
 		ASSERT(ionId!=(unsigned int)-1);
 
 		//convert ion ID to selection ID
@@ -216,15 +216,15 @@ int countBinnedIons(const std::vector<IonHit> &ions, const RangeFile *rng,
 		{
 #ifdef DEBUG
 			//Set the grid end
-			gridEntries[binIdx].endPt[extrusionAxis] = filteredIons[ui].getPos()[extrusionAxis];
+			gridEntries[binIdx].endPt[extrusionAxis] = filteredIon.getPos()[extrusionAxis];
 #endif
 			completedGridEntries.push_back(gridEntries[binIdx]);
 
 			//Reset the grid for the next round
 			// TODO: Should we initialise zStart to this ion,
 			//   or should we snap it to the next ion we encounter?
-			gridEntries[binIdx].startPt[extrusionAxis] =filteredIons[ui].getPos()[extrusionAxis];
-			gridEntries[binIdx].endPt[extrusionAxis]=filteredIons[ui].getPos()[extrusionAxis]-lowBound[extrusionAxis];
+			gridEntries[binIdx].startPt[extrusionAxis] =filteredIon.getPos()[extrusionAxis];
+			gridEntries[binIdx].endPt[extrusionAxis]=filteredIon.getPos()[extrusionAxis]-lowBound[extrusionAxis];
 
 			//Set the box x-y (where extrusion=z)  coordinates.
 			setGridABCoords(binIdx,direction,nBins,
@@ -275,16 +275,16 @@ void genBinomialHistogram(const vector<GRID_ENTRY> &completedGridEntries,
 	vector<map<unsigned int,unsigned int> >  &mapIonFrequencies = binHist.mapIonFrequencies;
 
 	mapIonFrequencies.resize(nSelected);
-	for(size_t ui=0;ui<completedGridEntries.size();ui++)
+	for(const auto & completedGridEntry : completedGridEntries)
 	{
-		ASSERT(completedGridEntries[ui].nIons.size() == nSelected);
+		ASSERT(completedGridEntry.nIons.size() == nSelected);
 		//Insert all the frequencies for each selected ion into the vector
 		for(size_t uj=0;uj<nSelected;uj++)
 		{
 			//find the frequency we need to update
 			map<unsigned int, unsigned int>::iterator it;
 			size_t val;
-			val=completedGridEntries[ui].nIons[uj];
+			val=completedGridEntry.nIons[uj];
 			it=mapIonFrequencies[uj].find(val);
 
 			//Add these ions to the running total
@@ -558,16 +558,16 @@ void generateTestGridEntries(vector<GRID_ENTRY> &gridEntries, unsigned int &nSel
 	//Fake some binomially sampled data.
 	// The first species will be binomially distributed, then scaled
 	// The second species is fixed to allow the first to fill quota
-	for(size_t ui=0;ui<gridEntries.size();ui++)
+	for(auto & gridEntry : gridEntries)
 	{
 		// Should give a p-value of < 0.05
-		gridEntries[ui].nIons.resize(2);
-		gridEntries[ui].nIons[0]=gsl_ran_binomial(r,PVAL,NTRIALS)/underSkewFactor;
-		gridEntries[ui].nIons[1]=NTRIALS-gridEntries[ui].nIons[0];
+		gridEntry.nIons.resize(2);
+		gridEntry.nIons[0]=gsl_ran_binomial(r,PVAL,NTRIALS)/underSkewFactor;
+		gridEntry.nIons[1]=NTRIALS-gridEntry.nIons[0];
 
-		gridEntries[ui].totalIons=NTRIALS;
-		gridEntries[ui].startPt[2]=0.1;
-		gridEntries[ui].endPt[2]=0.2;
+		gridEntry.totalIons=NTRIALS;
+		gridEntry.startPt[2]=0.1;
+		gridEntry.endPt[2]=0.2;
 	}
 	gsl_rng_free(r);
 }
@@ -590,15 +590,14 @@ bool testBinomialRandomnessTrueNegative()
 	//Compute chi-square
 	//-----------------
 	double chiSq=0;
-	for(map<unsigned int, unsigned int>::iterator it = binHist.mapIonFrequencies[0].begin();
-			it!=binHist.mapIonFrequencies[0].end();++it)
+	for(auto & it : binHist.mapIonFrequencies[0])
 	{
 		double delta,expected;
 		//This function computes the probability p(k) of obtaining k from a binomial distribution with parameters p and n,
 		// gsl_ran_binomial_pdf(k,p,n)
-		expected = gsl_ran_binomial_pdf(it->first,PVAL,NTRIALS)*NSAMPLE;
+		expected = gsl_ran_binomial_pdf(it.first,PVAL,NTRIALS)*NSAMPLE;
 
-		delta=it->second-expected;
+		delta=it.second-expected;
 		chiSq+=delta*delta/expected;
 	}
 	//-----------------
@@ -644,20 +643,19 @@ bool testBinomialRandomnessTruePositive()
 	//-----------------
 	double chiSq=0;
 	vector<double> sortedNumbers;
-	for(map<unsigned int, unsigned int>::iterator it = binHist.mapIonFrequencies[0].begin();
-			it!=binHist.mapIonFrequencies[0].end();++it)
+	for(auto & it : binHist.mapIonFrequencies[0])
 	{
 		//TODO: There are correction factors that we could use here, rather than a full discard
-		if(it->second < BINOMIAL_LOWCOUNT_SKEW_THRESHOLD)
+		if(it.second < BINOMIAL_LOWCOUNT_SKEW_THRESHOLD)
 			continue;
 
 		double delta,expected;
 		//This function computes the probability p(k) of obtaining k from a binomial distribution with parameters p and n,
 		// gsl_ran_binomial_pdf(k,p,n)
-		expected = gsl_ran_binomial_pdf(it->first,PVAL,NTRIALS)*NSAMPLE;
+		expected = gsl_ran_binomial_pdf(it.first,PVAL,NTRIALS)*NSAMPLE;
 
 
-		delta=it->second-expected;
+		delta=it.second-expected;
 		sortedNumbers.push_back(delta/expected);
 	}
 
@@ -776,9 +774,9 @@ bool testBinomialBinning()
 				"binomial binning (auto brick mode)");
 
 	//Check that we counted at least 30% of the ions
-	TEST(g.size() > (float)ions.size()/segOpt.nIons*0.3,"Full bricks only");
+	TEST(g.size() > ions.size()/segOpt.nIons*0.3,"Full bricks only");
 	//Check that the number of grids is less than the number of ions
-	TEST(g.size() <=(float)ions.size()/segOpt.nIons,"Full bricks only");
+	TEST(g.size() <=ions.size()/segOpt.nIons,"Full bricks only");
 
 	size_t total=0;
 	for(size_t ui=0;ui<g.size(); ui++)
