@@ -25,39 +25,6 @@
 using std::vector;
 using std::set;
 
-enum PointDir{ 	POINTDIR_TOGETHER =0,
-                POINTDIR_IN_COMMON,
-                POINTDIR_APART
-             };
-//!Check which way vectors attached to two 3D points "point", 
-/*! Two vectors may point "together", /__\ "apart" \__/  or 
- *  "In common" /__/ or \__\
- */
-unsigned int vectorPointDir(const Point3D &pA, const Point3D &pB, 
-				const Point3D &vC, const Point3D &vD)
-{
-	//Check which way vectors attached to two 3D points "point", 
-	// - "together", "apart" or "in common"
-	
-	//calculate AB.CA, BA.DB
-	float dot1  = (pB-pA).dotProd(vC - pA);
-	float dot2= (pA - pB).dotProd(vD - pB);
-
-	//We shall somewhat arbitrarily call perpendicular cases "together"
-	if(dot1 ==0.0f || dot2 == 0.0f)
-		return POINTDIR_TOGETHER;
-
-	//If they have opposite signs, then they are "in common"
-	if(( dot1  < 0.0f  && dot2 > 0.0f) || (dot1 > 0.0f && dot2 < 0.0f) )
-		return POINTDIR_IN_COMMON;
-
-	if( dot1 < 0.0f && dot2 <0.0f )
-		return POINTDIR_APART; 
-
-	ASSERT(dot1 > 0.0f && dot2 > 0.0f );
-	
-	return POINTDIR_TOGETHER;
-}
 
 //! Returns the shortest distance between a line segment and a given point
 /* The inputs are the ends of the line segment and the point. Uses the formula that 
@@ -325,10 +292,16 @@ unsigned int do2DDelaunay(double *bufXY, unsigned int n,
 		vector<size_t> &ta, vector<size_t> &tb, vector<size_t> &tc)
 {
 	vector<R3> inPts;
+	std::random_device rd;
+	std::mt19937 gen(rd());
+	std::uniform_real_distribution<> realV(-0.001,0.001);
+
 	inPts.resize(n);
 	for(unsigned int ui=0; ui<n; ui++)
 	{
-		inPts[ui]= R3(bufXY[2*ui],bufXY[2*ui+1],0);
+		inPts[ui].r=bufXY[2*ui];
+		inPts[ui].c=bufXY[2*ui+1];
+		inPts[ui].z=realV(gen);
 	}
 	vector<Tri> triVec;
 	if(NewtonApple_Delaunay( inPts, triVec) != 1)
@@ -344,7 +317,6 @@ unsigned int do2DDelaunay(double *bufXY, unsigned int n,
 		tc[ui]=triVec[ui].c;
 	}
 
-
 	return 0;
 }
 
@@ -1152,11 +1124,11 @@ bool testDelaunay()
 {
 	vector<Point3D> p;
 
-	p.push_back(Point3D(0,0,1));
-	p.push_back(Point3D(1,0,1));
-	p.push_back(Point3D(1,1,1));
-	p.push_back(Point3D(0,0,0));
-	p.push_back(Point3D(-1,2,2));
+	p.emplace_back(Point3D(0,0,1));
+	p.emplace_back(Point3D(1,0,1));
+	p.emplace_back(Point3D(1,1,1));
+	p.emplace_back(Point3D(0,0,0));
+	p.emplace_back(Point3D(-1,2,2));
 
 	//just see if we can run the triangulation routine
 	// to retrieve the triangulations
@@ -1176,10 +1148,10 @@ bool testDelaunay()
 	tC.clear();
 
 	//Perform 2D delaunay check
-	p.push_back(Point3D(0,1,0));
-	p.push_back(Point3D(1,1,0));
-	p.push_back(Point3D(1,0,0));
-	p.push_back(Point3D(2,2,0));
+	p.emplace_back(Point3D(0,1,0));
+	p.emplace_back(Point3D(1,1,0));
+	p.emplace_back(Point3D(1,0,0));
+	p.emplace_back(Point3D(2,2,0));
 
 
 	double *buffer = new double[p.size()*2];
@@ -1214,7 +1186,7 @@ bool testConvexHull()
 	IonStreamData *d = new IonStreamData;
 
 	for(unsigned int ui=0;ui<4;ui++)
-		d->data.push_back(IonHit(pTet[ui],ui));
+		d->data.emplace_back(IonHit(pTet[ui],ui));
 
 	vector<const FilterStreamData*> dataStream;
 	dataStream.push_back(d);
@@ -1260,7 +1232,7 @@ bool testConvexHull2()
 	IonStreamData *d = new IonStreamData;
 
 	for(unsigned int ui=0;ui<8;ui++)
-		d->data.push_back(IonHit(pCube[ui],ui));
+		d->data.emplace_back(IonHit(pCube[ui],ui));
 
 	vector<const FilterStreamData*> dataStream;
 	dataStream.push_back(d);
@@ -1289,6 +1261,7 @@ bool testConvexHull2()
 }
 bool testHull()
 {
+	cerr << "Hull tests " << endl;;
 	//Delaunay is not implemented for sweep-hull
 	TEST(testDelaunay(),"delaunay test");
 	TEST(testConvexHull(), "convex hull test (tetrahedron)");
