@@ -26,6 +26,7 @@
 #include <gsl/gsl_randist.h>
 #include <gsl/gsl_multifit.h>
 
+#include <qhull/qhull_a.h>
 
 using std::vector;
 
@@ -76,6 +77,13 @@ void polyFitVector(vector<float> &data, unsigned int maxDegree, vector<float> &c
 
 }
 
+//A bigger MAX_NN_DISTS is better because you will attempt to grab more ram
+//however there is a chance that memory allocation can fail, which currently I do not grab safely
+const unsigned int MAX_NN_DISTS = 0x8000000; //96 MB samples at a time 
+
+
+
+
 //!Generate an NN histogram using NN-max cutoffs 
 unsigned int generateNNHist( const vector<Point3D> &pointList, 
 			const K3DTree &tree,unsigned int nnMax, unsigned int numBins,
