@@ -24,6 +24,9 @@ using std::vector;
 using std::pair;
 using std::make_pair;
 
+//grab size when doing convex hull calculations
+const unsigned int HULL_GRAB_SIZE=4096;
+
 enum
 {
 	KEY_POSITION=1,
@@ -345,18 +348,20 @@ unsigned int AnnotateFilter::refresh(const std::vector<const FilterStreamData *>
 				//and the rest for the actual integer
 				size_t num;
 				num = angleFormatPreDecimal+angleFormatPostDecimal+1;
-				char *buf = new char[num+2];
+				char *buf = new char[num+1];
 
 				std::string tmp,formatStr;
 				formatStr="%";
 				if(angleFormatPreDecimal)
 				{
-					stream_cast(tmp,num+1);
+
+					stream_cast(tmp,angleFormatPreDecimal + angleFormatPostDecimal+2);
 					formatStr+=std::string("0") + tmp;
 				}
 
 				if(angleFormatPostDecimal)
 				{
+
 					stream_cast(tmp,angleFormatPostDecimal);
 					formatStr+=".";
 					formatStr+=tmp;
@@ -596,8 +601,8 @@ void AnnotateFilter::getProperties(FilterPropGroup &propertyList) const
 	vector<pair<unsigned int,string> > choices;
 	for(unsigned int ui=0;ui<ANNOTATION_MODE_END; ui++)
 	{
-		choices.push_back(make_pair(ui,
-					TRANS(annotationModeStrings[ui])));
+		choices.emplace_back(ui,
+					TRANS(annotationModeStrings[ui]));
 	}
 	FilterProperty pMode(KEY_MODE, TRANS("Mode"),
 			choices,annotationMode,TRANS("Type or style of annotation"));
@@ -649,7 +654,7 @@ void AnnotateFilter::getProperties(FilterPropGroup &propertyList) const
 			propertyList.addProperty(pOrigin,curGroup);
 			
 
-			FilterProperty pEnd(KEY_TARGET, TRANS("End"),position,
+			FilterProperty pEnd(KEY_TARGET, TRANS("End"),target,
 					TRANS("3D position to which arrow points"));
 			propertyList.addProperty(pEnd,curGroup);
 			
@@ -750,7 +755,7 @@ void AnnotateFilter::getProperties(FilterPropGroup &propertyList) const
 			vector<pair<unsigned int,string> > choices;
 			
 			for(unsigned int ui=0;ui<RULER_MODE_ENUM_END; ui++)
-				choices.push_back(make_pair(ui, TRANS(rulerModeStrings[ui])));
+				choices.emplace_back(ui, TRANS(rulerModeStrings[ui]));
 
 			FilterProperty pRulerMode(KEY_RULER_MODE, TRANS("Display Style"),
 				choices,rulerMode, TRANS("Set the appearance of the ruler"));
@@ -1314,7 +1319,7 @@ bool AnnotateFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFile
 
 		if(!XMLGetAttrib(nodePtr,linearMeasureTicks,"tickcount"))
 			return false;
-		if(linearMeasureTicks <=0)
+		if(!linearMeasureTicks)
 			return false;
 
 		if(!XMLGetAttrib(nodePtr,fontSizeLinearMeasure,"fontsize"))
