@@ -413,6 +413,10 @@ unsigned int BoundingBoxFilter::refresh(const std::vector<const FilterStreamData
 		return 0;
 	}
 
+	progress.maxStep=1;
+	progress.step=1;
+	progress.filterProgress=0;
+
 	//Compute the bounding box of the incoming streams
 	BoundCube bTotal,bThis;
 	bTotal.setInverseLimits();
@@ -421,106 +425,103 @@ unsigned int BoundingBoxFilter::refresh(const std::vector<const FilterStreamData
 	size_t n=0;
 	Point3D p[4];
 	unsigned int ptCount=0;
-	if(totalSize)
+	for(unsigned int ui=0;ui<dataIn.size();ui++)
 	{
-		for(unsigned int ui=0;ui<dataIn.size();ui++)
+		switch(dataIn[ui]->getStreamType())
 		{
-			switch(dataIn[ui]->getStreamType())
+			case STREAM_TYPE_IONS:
 			{
-				case STREAM_TYPE_IONS:
+				bThis=bTotal;
+				//Grab the first four points to define a volume.
+				//then expand that volume using the boundcube functions.
+				const IonStreamData *d =(const IonStreamData *) dataIn[ui];
+				size_t dataPos=0;
+				unsigned int curProg=NUM_CALLBACK;
+				while(ptCount < 4 && dataPos < d->data.size())
 				{
-					bThis=bTotal;
-					//Grab the first four points to define a volume.
-					//then expand that volume using the boundcube functions.
-					const IonStreamData *d =(const IonStreamData *) dataIn[ui];
-					size_t dataPos=0;
-					unsigned int curProg=NUM_CALLBACK;
-					while(ptCount < 4 && dataPos < d->data.size())
+					for(unsigned int ui=0; ui<d->data.size();ui++)
 					{
-						for(unsigned int ui=0; ui<d->data.size();ui++)
-						{
-							p[ptCount]=d->data[ui].getPosRef();
-							ptCount++;
-							dataPos=ui;
-							if(ptCount >=4) 
-								break;
-						}
+						p[ptCount]=d->data[ui].getPosRef();
+						ptCount++;
+						dataPos=ui;
+						if(ptCount >=4) 
+							break;
 					}
-
-					//Ptcount will be 4 if we have >=4 points in dataset
-					if(ptCount < 4)
-						break;
-					bThis.setBounds(p,4);
-					//Expand the bounding volume
-#ifdef _OPENMP
-					//Parallel version
-					unsigned int nT =omp_get_max_threads(); 
-
-					BoundCube *newBounds= new BoundCube[nT];
-					for(unsigned int ui=0;ui<nT;ui++)
-						newBounds[ui]=bThis;
-
-					bool spin=false;
-					#pragma omp parallel for shared(spin)
-					for(unsigned int ui=dataPos;ui<d->data.size();ui++)
-					{
-						unsigned int thisT=omp_get_thread_num();
-						//OpenMP does not allow exiting. Use spin instead
-						if(spin)
-							continue;
-
-						if(!curProg--)
-						{
-							#pragma omp critical
-							{
-							n+=NUM_CALLBACK;
-							progress.filterProgress= (unsigned int)((float)(n)/((float)totalSize)*100.0f);
-							}
-
-
-							if(thisT == 0)
-							{
-								if(*Filter::wantAbort)
-									spin=true;
-							}
-						}
-
-						newBounds[thisT].expand(d->data[ui].getPosRef());
-					}
-					if(spin)
-					{			
-						delete[] newBounds;
-						return BOUNDINGBOX_ABORT_ERR;
-					}
-
-					for(unsigned int ui=0;ui<nT;ui++)
-						bThis.expand(newBounds[ui]);
-
-					delete[] newBounds;
-#else
-					//Single thread version
-					for(unsigned int ui=dataPos;ui<d->data.size();ui++)
-					{
-						bThis.expand(d->data[ui].getPosRef());
-						if(!curProg--)
-						{
-							n+=NUM_CALLBACK;
-							progress.filterProgress= (unsigned int)((float)(n)/((float)totalSize)*100.0f);
-							if(*Filter::wantAbort)
-								return BOUNDINGBOX_ABORT_ERR;
-						}
-					}
-#endif
-					bTotal.expand(bThis);
-					break;
 				}
-				default:
-					break;
-			}
 
-			//Copy the input data to the output	
-			getOut.push_back(dataIn[ui]);	
+				//Ptcount will be 4 if we have >=4 points in dataset
+				if(ptCount < 4)
+					break;
+				bThis.setBounds(p,4);
+				//Expand the bounding volume
+#ifdef _OPENMP
+				//Parallel version
+				unsigned int nT =omp_get_max_threads(); 
+
+				BoundCube *newBounds= new BoundCube[nT];
+				for(unsigned int ui=0;ui<nT;ui++)
+					newBounds[ui]=bThis;
+
+				bool spin=false;
+				#pragma omp parallel for shared(spin)
+				for(unsigned int ui=dataPos;ui<d->data.size();ui++)
+				{
+					unsigned int thisT=omp_get_thread_num();
+					//OpenMP does not allow exiting. Use spin instead
+					if(spin)
+						continue;
+
+					if(!curProg--)
+					{
+						#pragma omp critical
+						{
+						n+=NUM_CALLBACK;
+						progress.filterProgress= (unsigned int)((float)(n)/((float)totalSize)*100.0f);
+						}
+
+
+						if(thisT == 0)
+						{
+							if(*Filter::wantAbort)
+								spin=true;
+						}
+					}
+
+					newBounds[thisT].expand(d->data[ui].getPosRef());
+				}
+				if(spin)
+				{			
+					delete[] newBounds;
+					return BOUNDINGBOX_ABORT_ERR;
+				}
+
+				for(unsigned int ui=0;ui<nT;ui++)
+					bThis.expand(newBounds[ui]);
+
+				delete[] newBounds;
+#else
+				//Single thread version
+				for(unsigned int ui=dataPos;ui<d->data.size();ui++)
+				{
+					bThis.expand(d->data[ui].getPosRef());
+					if(!curProg--)
+					{
+						n+=NUM_CALLBACK;
+						progress.filterProgress= (unsigned int)((float)(n)/((float)totalSize)*100.0f);
+						if(*Filter::wantAbort)
+							return BOUNDINGBOX_ABORT_ERR;
+					}
+				}
+#endif
+				bTotal.expand(bThis);
+				break;
+			}
+			default:
+				break;
 		}
+
+		//Copy the input data to the output	
+		getOut.push_back(dataIn[ui]);	
 	}
 
 	progress.filterProgress=100;
@@ -575,7 +576,7 @@ void BoundingBoxFilter::getProperties(FilterPropGroup &propertyList) const
 		{
 			std::string tmpStr;
 			tmpStr=TRANS(BOUND_STYLE[ui]);
-			choices.push_back(make_pair(ui,tmpStr));
+			choices.emplace_back(ui,tmpStr);
 		}
 	
 		FilterProperty pStyle(KEY_STYLE, TRANS("Style"),
