@@ -86,6 +86,12 @@ const char CHEM_DIST_DATALABEL[] =NTRANS("Chemistry Distribution");
 
 using std::vector;
 
+//Optimisation tuning value;
+// number of points to expect in a KD query sphere before the bulk query pays off
+//  in terms of algorithm speed
+const float SPHERE_PRESEARCH_CUTOFF = 75;
+
+
 //In link clustering, when we preform size cropping, do we awant to count bulk ions in our analysis?
 const bool WANT_COUNT_BULK_FORCROP=false;
 
@@ -149,7 +155,7 @@ void makeFrequencyTable(const IonStreamData *i ,const RangeFile *r,
 
 	freqTable.clear();
 	for(size_t uj=0;uj<r->getNumIons();uj++)
-		freqTable.push_back(make_pair(r->getName(uj),ionHist[0][uj]));
+		freqTable.emplace_back(r->getName(uj),ionHist[0][uj]);
 
 	for(size_t ui=0;ui<numThreads;ui++)
 		delete[] ionHist[ui];
@@ -301,6 +307,7 @@ Filter *ClusterAnalysisFilter::cloneUncached() const
 	p->wantClusterComposition=wantClusterComposition;
 	p->normaliseComposition = normaliseComposition;
 	p->wantClusterMorphology= wantClusterMorphology;
+	p->wantClusterID= wantClusterID;
 
 	p->haveRangeParent=false; //lets assume not, and this will be reset at ::initFilter time
 
@@ -561,7 +568,13 @@ unsigned int ClusterAnalysisFilter::refresh(const std::vector<const FilterStream
 		paranoidDebugAssert(clusteredCore,clusteredBulk);
 #endif
 	if(wantCropSize)
-		stripClusterBySize(clusteredCore,clusteredBulk,WANT_COUNT_BULK_FORCROP,progress);
+	{
+		unsigned int errCode;
+		errCode=stripClusterBySize(clusteredCore,clusteredBulk,WANT_COUNT_BULK_FORCROP,progress);
+		if(errCode)
+			return errCode;
+	}
+
 
 	bool haveBulk,haveCore;
 	haveBulk=clusteredBulk.size();
@@ -683,6 +696,7 @@ ASSERT(!(haveBulk && !haveCore));
 		p->dataLabel=TRANS("Morphology Plot");
 		p->xLabel=TRANS("\\lambda_1:\\lambda_2 ratio");
 		p->yLabel=TRANS("\\lambda_2:\\lambda_3 ratio");
+		p->intensityLabel=TRANS("Cluster size");
 		p->scatterData.reserve(singularVals.size());
 		p->scatterIntensityLog=true;
 
@@ -800,6 +814,9 @@ ASSERT(!(haveBulk && !haveCore));
 	for(size_t ui=0;ui<clusteredCore.size();ui++)
 		totalSize+=clusteredCore[ui].size();
 	i->data.resize(totalSize);
+	i->estimateIonParameters(dataIn);
+	i->g = i->b = i->r = 0.5;
+
 	
 	if(wantClusterID)
 	{
@@ -931,7 +948,7 @@ void ClusterAnalysisFilter::getProperties(FilterPropGroup &propertyList) const
 	{
 		vector<pair<unsigned int,string> > choices;
 		tmpStr=TRANS("Core Link + Erode");
-		choices.push_back(make_pair((unsigned int)CLUSTER_LINK_ERODE,tmpStr));
+		choices.emplace_back((unsigned int)CLUSTER_LINK_ERODE,tmpStr);
 		
 		FilterProperty pAlgorithm(KEY_CLUSTERANALYSIS_ALGORITHM, TRANS("Algorithm"),
 			choices,algorithm,TRANS("Cluster algorithm mode"));
@@ -1559,6 +1576,20 @@ bool ClusterAnalysisFilter::writeState(std::ostream &f,unsigned int format,
 	return true;
 }
 
+unsigned int ClusterAnalysisFilter::getNumSteps() const
+{
+	//Depending on the user selection, determine the number of steps that are available
+	bool needErosion=enableErosion && enableBulkLink;
+	unsigned int numClusterSteps=4;
+	if(enableBulkLink)
+		numClusterSteps+=2;
+	if(needErosion && enableBulkLink)
+		numClusterSteps++;
+	if(enableCoreClassify)
+		numClusterSteps++;
+	return  numClusterSteps;
+}
+
 size_t ClusterAnalysisFilter::numBytesForCache(size_t nObjects) const
 {
 	return (size_t)nObjects*IONDATA_SIZE;
@@ -1678,7 +1709,7 @@ bool ClusterAnalysisFilter::readState(xmlNodePtr &nodePtr, const std::string &pa
 		return false;
 	
 	nodePtr=tmpPtr;
-	if(!XMLGetNextElemAttrib(nodePtr,wantClusterID,"wantclustermorphology","value"))
+	if(!XMLGetNextElemAttrib(nodePtr,wantClusterID,"wantclusterid","value"))
 	{
 		//COMPAT_BREAK: compat fix, 0.0.16.
 		wantClusterID=false;
@@ -1829,18 +1860,8 @@ unsigned int ClusterAnalysisFilter::refreshLinkClustering(const std::vector<cons
 	//
 	// In the implementation, there are more steps, due to data structure construction
 	// and other computational concerns
-
-	
+	unsigned int numClusterSteps=getNumSteps();	
 	bool needErosion=enableErosion && enableBulkLink;
-	unsigned int numClusterSteps=4;
-	if(enableBulkLink)
-		numClusterSteps+=2;
-	if(needErosion && enableBulkLink)
-		numClusterSteps++;
-	if(enableCoreClassify)
-		numClusterSteps++;
-
-
 
 	//Quick sanity check
 	if(enableBulkLink)
@@ -2620,7 +2641,7 @@ PlotStreamData* ClusterAnalysisFilter::clusterSizeDistribution(const vector<vect
 }
 
 
-bool ClusterAnalysisFilter::stripClusterBySize(vector<vector<IonHit> > &clusteredCore,
+unsigned int ClusterAnalysisFilter::stripClusterBySize(vector<vector<IonHit> > &clusteredCore,
 						vector<vector<IonHit> > &clusteredBulk,
 							bool countBulk,
 							ProgressData &progress) const
@@ -2680,7 +2701,7 @@ bool ClusterAnalysisFilter::stripClusterBySize(vector<vector<IonHit> > &clustere
 
 	}
 
-	return true;
+	return 0;
 }
 
 void ClusterAnalysisFilter::genCompositionVersusSize(const vector<vector<IonHit> > &clusteredCore,
@@ -2836,10 +2857,7 @@ void ClusterAnalysisFilter::genCompositionVersusSize(const vector<vector<IonHit>
 				size_t sum=0;
 				for(size_t uk=0; uk<it->second.size();uk++)
 					sum+=it->second[uk];
-				if(sum)
-					p->xyData[offset].second /=(float)sum;
-				else
-					p->xyData[offset].second=0;
+				p->xyData[offset].second /=(float)sum;
 			}
 			offset++;
 		}
@@ -3385,12 +3403,12 @@ bool ClusterAnalysisFilter::singularValueTest()
 
 	//check the matrix makes sense
 	vector<IonHit> ionVec;
-	ionVec.push_back(IonHit(Point3D(0,0,1),1));	
-	ionVec.push_back(IonHit(Point3D(0,0,-1),1));
-	ionVec.push_back(IonHit(Point3D(1,0,0),1));	
-	ionVec.push_back(IonHit(Point3D(-1,0,0),1));
-	ionVec.push_back(IonHit(Point3D(0,1,0),1));	
-	ionVec.push_back(IonHit(Point3D(0,-1,0),1));
+	ionVec.emplace_back(IonHit(Point3D(0,0,1),1));	
+	ionVec.emplace_back(IonHit(Point3D(0,0,-1),1));
+	ionVec.emplace_back(IonHit(Point3D(1,0,0),1));	
+	ionVec.emplace_back(IonHit(Point3D(-1,0,0),1));
+	ionVec.emplace_back(IonHit(Point3D(0,1,0),1));	
+	ionVec.emplace_back(IonHit(Point3D(0,-1,0),1));
 
 	m = gsl_matrix_alloc(3,3);
 	gsl_matrix_set_zero(m);
@@ -3438,7 +3456,7 @@ bool ClusterAnalysisFilter::singularValueTest()
 			ellipsePt[ui]=p[ui]/SEMI_AXIS[ui];
 
 		if( ellipsePt.sqrMag() < 1.0f)
-			ionVec.push_back(IonHit(p,1.0));
+			ionVec.emplace_back(IonHit(p,1.0));
 	}
 
 	IonHit::makePos(ionVec,"test-ellipsoid.pos");
