@@ -90,6 +90,8 @@ DataLoadFilter::DataLoadFilter() : fileType(FILEDATA_TYPE_POS), doSample(true),
 		index[i] = i;
 	}
 
+	//Disable TOF distortion
+	reconParams.useTOFDistortion=0;
 	//Use a 50nm radius cylinder by default
 	reconParams.radiusCylinder=50;
 
@@ -212,47 +214,14 @@ unsigned int DataLoadFilter::refresh(const std::vector<const FilterStreamData *>
 	//use the cached copy if we have it.
 	if(cacheOK)
 	{
-		bool doUseCache=true;
-		//If we are monitoring the file,
-		//the cache is only valid if we have 
-		//the same timestamp as on the file.
-		if(wantMonitor)
-		{
-			if(!wxFile::Exists((ionFilename)))
-			{
-				monitorTimestamp=-1;
-				monitorSize=-1;
-				doUseCache=false;
-				clearCache();
-			}
-			else
-			{
-				//How can we have a valid cache if we don't
-				//have a valid load time?
-				ASSERT(monitorTimestamp!=-1 && monitorSize!=(size_t)-1);
-
-				size_t fileSizeVal;
-				getFilesize(ionFilename.c_str(),fileSizeVal);
-
-				if(wxFileModificationTime((ionFilename)) ==monitorTimestamp
-					||  fileSizeVal!= monitorSize)
-				{
-					doUseCache=false;
-					clearCache();
-				}
-			}
-		}
 
 		//Use the cache if it is still OK, otherwise use
 		//the full function
-		if(doUseCache)
-		{
-			propagateCache(getOut);
+		propagateCache(getOut);
 
-			propagateStreams(dataIn,getOut);
-			progress.filterProgress=100;
-			return 0;
-		}
+		propagateStreams(dataIn,getOut);
+		progress.filterProgress=100;
+		return 0;
 	}
 
 	//If theres no file, then there is not a lot we can do..
@@ -276,12 +245,6 @@ unsigned int DataLoadFilter::refresh(const std::vector<const FilterStreamData *>
 		return 0;
 	}
 
-	//Update the monitoring timestamp such that we know
-	//when the file was last loaded
-	monitorTimestamp = wxFileModificationTime((ionFilename));
-	size_t tmp;
-	if(getFilesize(ionFilename.c_str(),tmp))
-		monitorSize=tmp;
 
 	IonStreamData *ionData = new IonStreamData;
 	ionData->parent=this;	
@@ -543,7 +506,7 @@ void DataLoadFilter::getProperties(FilterPropGroup &propertyList) const
 	vector<pair<unsigned int,string> > choices;
 
 	for(unsigned int ui=0;ui<FILEDATA_TYPE_ENUM_END; ui++)
-		choices.push_back(make_pair(ui,AVAILABLE_FILEDATA_TYPES[ui]));	
+		choices.emplace_back(ui,AVAILABLE_FILEDATA_TYPES[ui]);	
 
 	FilterProperty pMode(DATALOAD_KEY_FILETYPE, TRANS("File type"),
 			choices,fileType,TRANS("Type of fil to be loaded"));
@@ -566,7 +529,7 @@ void DataLoadFilter::getProperties(FilterPropGroup &propertyList) const
 			for (unsigned int i = 0; i < numColumns; i++) {
 				string tmp;
 				stream_cast(tmp,i);
-				choices.push_back(make_pair(i,tmp));
+				choices.emplace_back(i,tmp);
 			}
 			
 			FilterProperty pX(DATALOAD_KEY_SELECTED_COLUMN0, TRANS("X"),
@@ -643,8 +606,6 @@ void DataLoadFilter::getProperties(FilterPropGroup &propertyList) const
 
 	if(enabled)
 	{
-		std::string tmpStr;
-
 		//FIXME: ATO Files need an implementation of sampling read
 		if(fileType==FILEDATA_TYPE_POS)
 		{
@@ -1315,6 +1276,54 @@ bool DataLoadFilter::monitorNeedsRefresh() const
 }
 
 
+void DataLoadFilter::updateMonitor() 
+{
+	ASSERT(wantMonitor);
+
+	if(cacheOK)
+	{
+		bool doUseCache=true;
+
+		bool fileExists=wxFile::Exists((ionFilename));
+		//If we are monitoring the file,
+		//the cache is only valid if we have 
+		//the same timestamp as on the file.
+		if(!fileExists)
+		{
+			monitorTimestamp=-1;
+			monitorSize=-1;
+			doUseCache=false;
+			clearCache();
+		}
+		else
+		{
+			//How can we have a valid cache if we don't
+			//have a valid load time?
+			ASSERT(monitorTimestamp!=-1 && monitorSize!=(size_t)-1);
+
+			size_t fileSizeVal;
+			getFilesize(ionFilename.c_str(),fileSizeVal);
+
+			if(wxFileModificationTime((ionFilename)) ==monitorTimestamp
+				||  fileSizeVal!= monitorSize)
+			{
+				doUseCache=false;
+				clearCache();
+			}
+		}
+
+		//If we are not using the cache
+		// don't try to later update the file details
+		if(!doUseCache)
+			return;
+	}
+	
+	//Update the monitoring timestamp such that we know
+	//when the file was last loaded
+	monitorTimestamp = wxFileModificationTime((ionFilename));
+	getFilesize(ionFilename.c_str(),monitorSize);
+}
+
 #ifdef DEBUG
 
 
