@@ -125,6 +125,9 @@ class DataLoadFilter:public Filter
 		void setFilename(const std::string &name);
 		void guessNumColumns();
 
+
+		//!Update the monitor code
+		void updateMonitor();
 		//!Set the filter to either use text or pos as requested,
 		// this does not require exposing the file parameter key
 		void setFileMode(unsigned int mode);
