@@ -82,6 +82,11 @@ size_t ExternalProgramFilter::numBytesForCache(size_t nObjects) const
 		return (size_t)-1; //Say we don't know, we are not going to cache anyway.
 }
 
+unsigned int ExternalProgramFilter::getNumSteps() const
+{
+	return 3;
+}
+
 size_t ExternalProgramFilter::substituteVariables(const std::string &commandStr,
 			const vector<string> &ionOutputNames, const vector<string> &plotOutputNames,std::string &substitutedCommand) 
 {
@@ -254,7 +259,7 @@ unsigned int ExternalProgramFilter::refresh(const std::vector<const FilterStream
 
 	
 	}
-	progress.maxStep=3;
+	progress.maxStep=getNumSteps();
 	progress.step=1;
 	progress.stepName=TRANS("Collate Input");	
 	for(unsigned int ui=0;ui<dataIn.size() ;ui++)
@@ -897,8 +902,8 @@ bool ExternalProgramFilter::substituteTest()
 {
 	
 	vector<string> ionNames,plotNames;
-	plotNames.push_back("some Plot.xy");
-	ionNames.push_back("my \"pos file.pos");
+	plotNames.emplace_back("some Plot.xy");
+	ionNames.emplace_back("my \"pos file.pos");
 
 	string myCommandLine;
 	myCommandLine="echo \"My ions are \'%i\'\"";
