@@ -121,9 +121,6 @@ const RangeFile *getRangeFile(const std::vector<const FilterStreamData*> &dataIn
 DrawColourBarOverlay *makeColourBar(float minV, float maxV,size_t nColours,size_t colourMap, bool reverseMap=false, float alpha=1.0f) ;
 
 
-//Create a temporary filename, optionally providing an extension to use/
-// - note that any subdirs will be automatically created if needed.
-std::string createTmpFilename(const char *dir=NULL,const char *extension=NULL);
 
 //Input buffer should be bufXY[ui*2 + offset] (X-> offset=0, Y->offset=1)
 // n - number of input points
@@ -131,6 +128,96 @@ std::string createTmpFilename(const char *dir=NULL,const char *extension=NULL);
 unsigned int do2DDelaunay(double *bufXY, unsigned int n, 
 		std::vector<size_t> &ta, std::vector<size_t> &tb, std::vector<size_t> &tc);
 
+
+
+
+//Shared voxel property output for visualisation of voxel contents
+// this is used by several filters
+class VoxelAppearanceProperties
+{
+	private:
+		Filter *parent;
+
+		void getTexturedSlice(const Voxels<float> &v, 
+			size_t axis,float offset, size_t interpolateMode,
+			float &minV,float &maxV,DrawTexturedQuad &texQ) const;
+	public:
+
+		//Constructor, requires parent filter data
+		explicit VoxelAppearanceProperties(Filter *p);
+
+
+		//Interpolation mode to use when slicing	
+		size_t sliceInterpolate;
+		//Axis that is normal to the slice 0,1,2 => x,y,z
+		size_t sliceAxis;
+		//Fractional offset from lower bound of data cube [0,1]
+		float sliceOffset;
+		
+		//Plane and normal for free slice. Note that the plane coordinate is in reduced voxel coords for each axis
+		Point3D freeSlicePlane,freeSliceNormal; 
+
+		ColourRGBAf rgba;
+
+		//!3D Point Representation size
+		float splatSize;
+
+		//!Isosurface level
+		float isoLevel;
+
+		//!If using volume render mode, this is the transfer function to apply
+		std::vector<std::pair<float, ColourRGBAf>  > transferFunction;
+
+		//!Default output representation mode
+		unsigned int representation;
+
+		//!Whether to use a built-in or custom colour map
+		bool builtinColourmap;
+
+		//!Colour map to use when using axial slices
+		unsigned int colourMap;
+
+		//Number of colour levels for colour map
+		size_t nColours;
+		//Whether to show the colour map bar or not
+		bool showColourBar;
+		//Whether to use an automatic colour bound, or to use user spec
+		bool autoColourMap;
+		//Colour map start/end
+		float colourMapBounds[2];
+
+		//Do we want to show the bounding box?
+		bool showBoundBox;
+		
+		//Colour for bounding box (if shown)
+		ColourRGBAf boundColour;
+
+		//Write a serialised representation of the properites
+		void writeState(std::ostream &f, unsigned int format, unsigned int depth) const;
+
+		unsigned int readState(xmlNodePtr &node);
+
+
+		unsigned int refresh(Voxels<float> &v, vector<const FilterStreamData *> &getOut,
+				std::vector<SelectionDevice *> &devices) const;
+		
+
+		void getProperties(FilterPropGroup &propertyList, size_t &curGroup,
+				unsigned int keyOffset) const;
+
+		bool setProperty(unsigned int keyOffset, unsigned int key, bool &handled,
+					const string &value, bool &cacheOK, bool &needUpdate,
+					vector<FilterStreamData *> &filterOutputs);
+
+		//!Get the human-readable options for the visual representation (enum)
+		static std::string getRepresentTypeString(int type);
+
+		//Assignment to other voxel Appearnance
+		void operator=(const VoxelAppearanceProperties &);
+};
+
+
+
 #ifdef DEBUG 
 
 //Test functions
