@@ -94,8 +94,8 @@ IonClipFilter::IonClipFilter() : primitiveType(PRIMITIVE_PLANE),
 {
 	COMPILE_ASSERT(THREEDEP_ARRAYSIZE(PRIMITIVE_NAMES) == PRIMITIVE_END);
 
-	vectorParams.push_back(Point3D(0.0,0.0,0.0));
-	vectorParams.push_back(Point3D(0,1.0,0.0));
+	vectorParams.emplace_back(Point3D(0.0,0.0,0.0));
+	vectorParams.emplace_back(Point3D(0,1.0,0.0));
 };
 
 Filter *IonClipFilter::cloneUncached() const
@@ -392,74 +392,71 @@ unsigned int IonClipFilter::refresh(const std::vector<const FilterStreamData *>
 	try
 	{
 
-		size_t totalSize=numElements(dataIn,STREAM_TYPE_IONS);
-		if(totalSize)
+		std::map<pair<size_t,bool>,size_t> primitiveTypeMap;
+
+		using std::make_pair;
+		//map the primitive enum type, and the clip inversion state
+		// to the CropHelper clip mode
+		primitiveTypeMap[make_pair((size_t)PRIMITIVE_SPHERE,false)]=CROP_SPHERE_INSIDE;
+		primitiveTypeMap[make_pair((size_t)PRIMITIVE_SPHERE,true)]=CROP_SPHERE_OUTSIDE;
+		primitiveTypeMap[make_pair((size_t)PRIMITIVE_PLANE,false)]=CROP_PLANE_FRONT;
+		primitiveTypeMap[make_pair((size_t)PRIMITIVE_PLANE,true)]=CROP_PLANE_BACK;
+		primitiveTypeMap[make_pair((size_t)PRIMITIVE_CYLINDER,false)]=CROP_CYLINDER_INSIDE_AXIAL;
+		primitiveTypeMap[make_pair((size_t)PRIMITIVE_CYLINDER,true)]=CROP_CYLINDER_OUTSIDE;
+		primitiveTypeMap[make_pair((size_t)PRIMITIVE_AAB,false)]=CROP_AAB_INSIDE;
+		primitiveTypeMap[make_pair((size_t)PRIMITIVE_AAB,true)]=CROP_AAB_OUTSIDE;
+
+		size_t mode;
+		mode = primitiveTypeMap[make_pair(primitiveType,invertedClip)];
+		size_t totalSize=numElements(dataIn);
+		CropHelper cropper(totalSize,mode,vectorParams,scalarParams  );
+
+		float minProg,maxProg;
+		size_t cumulativeSize=0;
+		for(unsigned int ui=0;ui<dataIn.size() ;ui++)
 		{
-			std::map<pair<size_t,bool>,size_t> primitiveTypeMap;
-
-			using std::make_pair;
-			//map the primitive enum type, and the clip inversion state
-			// to the CropHelper clip mode
-			primitiveTypeMap[make_pair((size_t)PRIMITIVE_SPHERE,false)]=CROP_SPHERE_INSIDE;
-			primitiveTypeMap[make_pair((size_t)PRIMITIVE_SPHERE,true)]=CROP_SPHERE_OUTSIDE;
-			primitiveTypeMap[make_pair((size_t)PRIMITIVE_PLANE,false)]=CROP_PLANE_FRONT;
-			primitiveTypeMap[make_pair((size_t)PRIMITIVE_PLANE,true)]=CROP_PLANE_BACK;
-			primitiveTypeMap[make_pair((size_t)PRIMITIVE_CYLINDER,false)]=CROP_CYLINDER_INSIDE_AXIAL;
-			primitiveTypeMap[make_pair((size_t)PRIMITIVE_CYLINDER,true)]=CROP_CYLINDER_OUTSIDE;
-			primitiveTypeMap[make_pair((size_t)PRIMITIVE_AAB,false)]=CROP_AAB_INSIDE;
-			primitiveTypeMap[make_pair((size_t)PRIMITIVE_AAB,true)]=CROP_AAB_OUTSIDE;
-
-			size_t mode;
-			mode = primitiveTypeMap[make_pair(primitiveType,invertedClip)];
-			CropHelper cropper(totalSize,mode,vectorParams,scalarParams  );
-
-			float minProg,maxProg;
-			size_t cumulativeSize=0;
-			for(unsigned int ui=0;ui<dataIn.size() ;ui++)
+			//Loop through each data set
+			switch(dataIn[ui]->getStreamType())
 			{
-				//Loop through each data set
-				switch(dataIn[ui]->getStreamType())
+				case STREAM_TYPE_IONS:
 				{
-					case STREAM_TYPE_IONS:
+					d=new IonStreamData;
+					d->parent=this;
+					minProg=cumulativeSize/(float)totalSize;
+					cumulativeSize+=d->data.size();
+					maxProg=cumulativeSize/(float)totalSize;
+
+					//Filter input data to output data.
+					if(cropper.runFilter(((const IonStreamData *)dataIn[ui])->data,
+						d->data,minProg,maxProg,progress.filterProgress))
 					{
-						d=new IonStreamData;
-						d->parent=this;
-						minProg=cumulativeSize/(float)totalSize;
-						cumulativeSize+=d->data.size();
-						maxProg=cumulativeSize/(float)totalSize;
-
-						//Filter input data to output data.
-						if(cropper.runFilter(((const IonStreamData *)dataIn[ui])->data,
-							d->data,minProg,maxProg,progress.filterProgress))
-						{
-							delete d;
-							return CALLBACK_FAIL; 
-						}
-
-						if(d->data.size())
-						{
-							//Copy over other attributes
-							d->r = ((IonStreamData *)dataIn[ui])->r;
-							d->g = ((IonStreamData *)dataIn[ui])->g;
-							d->b =((IonStreamData *)dataIn[ui])->b;
-							d->a =((IonStreamData *)dataIn[ui])->a;
-							d->ionSize =((IonStreamData *)dataIn[ui])->ionSize;
-
-							//getOut is const, so shouldn't be modified
-							cacheAsNeeded(d);
-
-							getOut.push_back(d);
-							d=0;
-						}
-						else
-							delete d;
-						break;
+						delete d;
+						return CALLBACK_FAIL; 
 					}
-					default:
-						//Just copy across the ptr, if we are unfamiliar with this type
-						getOut.push_back(dataIn[ui]);	
-						break;
+
+					if(d->data.size())
+					{
+						//Copy over other attributes
+						d->r = ((IonStreamData *)dataIn[ui])->r;
+						d->g = ((IonStreamData *)dataIn[ui])->g;
+						d->b =((IonStreamData *)dataIn[ui])->b;
+						d->a =((IonStreamData *)dataIn[ui])->a;
+						d->ionSize =((IonStreamData *)dataIn[ui])->ionSize;
+
+						//getOut is const, so shouldn't be modified
+						cacheAsNeeded(d);
+
+						getOut.push_back(d);
+						d=0;
+					}
+					else
+						delete d;
+					break;
 				}
+				default:
+					//Just copy across the ptr, if we are unfamiliar with this type
+					getOut.push_back(dataIn[ui]);	
+					break;
 			}
 		}
 	}
@@ -488,14 +485,14 @@ void IonClipFilter::getProperties(FilterPropGroup &propertyList) const
 
 	vector<pair<unsigned int,string> > choices;
 
-	choices.push_back(make_pair((unsigned int)PRIMITIVE_SPHERE ,
-				primitiveStringFromID(PRIMITIVE_SPHERE)));
-	choices.push_back(make_pair((unsigned int)PRIMITIVE_PLANE ,
-				primitiveStringFromID(PRIMITIVE_PLANE)));
-	choices.push_back(make_pair((unsigned int)PRIMITIVE_CYLINDER ,
-				primitiveStringFromID(PRIMITIVE_CYLINDER)));
-	choices.push_back(make_pair((unsigned int)PRIMITIVE_AAB,
-				primitiveStringFromID(PRIMITIVE_AAB)));
+	choices.emplace_back((unsigned int)PRIMITIVE_SPHERE ,
+				primitiveStringFromID(PRIMITIVE_SPHERE));
+	choices.emplace_back((unsigned int)PRIMITIVE_PLANE ,
+				primitiveStringFromID(PRIMITIVE_PLANE));
+	choices.emplace_back((unsigned int)PRIMITIVE_CYLINDER ,
+				primitiveStringFromID(PRIMITIVE_CYLINDER));
+	choices.emplace_back((unsigned int)PRIMITIVE_AAB,
+				primitiveStringFromID(PRIMITIVE_AAB));
 
 	FilterProperty pPrimitive(KEY_PRIMITIVE_TYPE, TRANS("Primitive"),
 			choices,primitiveType,TRANS("Shape of clipping object"));
@@ -611,7 +608,7 @@ bool IonClipFilter::setProperty(unsigned int key,
 					if(vectorParams.size() !=1)
 					{
 						vectorParams.clear();
-						vectorParams.push_back(Point3D(0,0,0));
+						vectorParams.emplace_back(Point3D(0,0,0));
 					}
 					if(scalarParams.size()!=1)
 					{
@@ -623,8 +620,8 @@ bool IonClipFilter::setProperty(unsigned int key,
 					if(vectorParams.size() >2)
 					{
 						vectorParams.clear();
-						vectorParams.push_back(Point3D(0,0,0));
-						vectorParams.push_back(Point3D(0,1,0));
+						vectorParams.emplace_back(Point3D(0,0,0));
+						vectorParams.emplace_back(Point3D(0,1,0));
 					}
 					else if (vectorParams.size() ==2)
 					{
@@ -632,7 +629,7 @@ bool IonClipFilter::setProperty(unsigned int key,
 					}
 					else if(vectorParams.size() ==1)
 					{
-						vectorParams.push_back(Point3D(0,1,0));
+						vectorParams.emplace_back(Point3D(0,1,0));
 					}
 
 					scalarParams.clear();
@@ -644,12 +641,12 @@ bool IonClipFilter::setProperty(unsigned int key,
 					}
 					else if(vectorParams.size() ==1)
 					{
-						vectorParams.push_back(Point3D(0,1,0));
+						vectorParams.emplace_back(Point3D(0,1,0));
 					}
 					else if(!vectorParams.size())
 					{
-						vectorParams.push_back(Point3D(0,0,0));
-						vectorParams.push_back(Point3D(0,1,0));
+						vectorParams.emplace_back(Point3D(0,0,0));
+						vectorParams.emplace_back(Point3D(0,1,0));
 
 					}
 
@@ -664,12 +661,12 @@ bool IonClipFilter::setProperty(unsigned int key,
 					if(vectorParams.size() >2)
 					{
 						vectorParams.clear();
-						vectorParams.push_back(Point3D(0,0,0));
-						vectorParams.push_back(Point3D(1,1,1));
+						vectorParams.emplace_back(Point3D(0,0,0));
+						vectorParams.emplace_back(Point3D(1,1,1));
 					}
 					else if(vectorParams.size() ==1)
 					{
-						vectorParams.push_back(Point3D(1,1,1));
+						vectorParams.emplace_back(Point3D(1,1,1));
 					}
 					//check to see if any components of the
 					//corner offset are zero; we disallow a
