@@ -233,12 +233,13 @@ unsigned int IonColourFilter::refresh(const std::vector<const FilterStreamData *
 
 		}
 	}
+	progress.filterProgress=100;
 
 	//create the colour bar as needed
 	if(foundIons && showColourBar)
 	{
 		DrawStreamData *d = new DrawStreamData;
-		d->drawables.push_back(makeColourBar(mapBounds[0],mapBounds[1],nColours,colourMap,reverseMap,alpha));
+		d->drawables.emplace_back(makeColourBar(mapBounds[0],mapBounds[1],nColours,colourMap,reverseMap,alpha));
 		d->parent=this;
 		cacheAsNeeded(d);
 		getOut.push_back(d);
@@ -298,7 +299,7 @@ void IonColourFilter::getProperties(FilterPropGroup &propertyList) const
 	size_t curGroup=0;
 
 	for(unsigned int ui=0;ui<COLOURMAP_ENUM_END; ui++)
-		choices.push_back(make_pair(ui,getColourMapName(ui)));
+		choices.emplace_back(ui,getColourMapName(ui));
 	FilterProperty pColourMap(KEY_IONCOLOURFILTER_COLOURMAP, TRANS("Colour Map"),choices,
 			colourMap,TRANS("Colour scheme used to assign points colours by value"));
 	propertyList.addProperty(pColourMap,curGroup);
