@@ -210,15 +210,6 @@ unsigned int IonDownsampleFilter::refresh(const std::vector<const FilterStreamDa
 	progress.stepName=TRANS("Sampling");
 
 	size_t totalSize = numElements(dataIn,STREAM_TYPE_IONS);
-
-	//Check to see if we have anything to do
-	if(!totalSize)
-	{
-		progress.filterProgress=100;
-		return 0;
-	}
-
-	//Switch between per-species and normal modes
 	if(!perSpecies)	
 	{
 		for(size_t ui=0;ui<dataIn.size() ;ui++)
@@ -227,6 +218,8 @@ unsigned int IonDownsampleFilter::refresh(const std::vector<const FilterStreamDa
 			{
 				case STREAM_TYPE_IONS: 
 				{
+					if(!totalSize)
+						continue;
 
 					IonStreamData *d;
 					d=new IonStreamData;
@@ -533,7 +526,7 @@ void IonDownsampleFilter::getProperties(FilterPropGroup &propertyList) const
 		}
 		else
 		{
-			FilterProperty pOutputFrac(KEY_IONDOWNSAMPLE_COUNT, TRANS("Out Fraction"),
+			FilterProperty pOutputFrac(KEY_IONDOWNSAMPLE_FRACTION, TRANS("Out Fraction"),
 				 float(fraction),TRANS("Sample this fraction of points"));
 			propertyList.addProperty(pOutputFrac,curGroup);
 
