@@ -1,6 +1,6 @@
 /*
  *	ionDownsample.h - Filter to perform sampling without replacement on input ion data
- *	Copyright (C) 2015, D Haley 
+ *	Copyright (C) 2018, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -47,13 +47,18 @@ class IonDownsampleFilter : public Filter
 		//!Should we use a per-species split or not?
 		bool perSpecies;	
 		//This is filter's enabled ranges. 0 if we don't have a range
+#ifdef HAVE_CPP_1X
+		std::unique_ptr<RangeStreamData> rsdIncoming;
+#else
 		RangeStreamData *rsdIncoming;
+#endif
 
 		//!Fractions to output for species specific
 		std::vector<float> ionFractions;
 		std::vector<size_t> ionLimits;
 	public:
 		IonDownsampleFilter();
+		~IonDownsampleFilter();
 		//!Duplicate filter contents, excluding cache.
 		Filter *cloneUncached() const;
 		//!Returns FILTER_TYPE_IONDOWNSAMPLE
