@@ -21,6 +21,8 @@
 #include "algorithms/mass.h"
 #include "algorithms/convexHull.h"
 
+#include "../APT/ionMapFile.h"
+
 #include "config.h"
 
 using std::vector;
@@ -45,6 +47,7 @@ enum
 {
 	ERR_USER_ABORT=1,
 	ERR_BAD_QHULL,
+	ERR_REMAPFILE_OPEN,
 	IONINFO_ERR_ENUM_END
 };
 
@@ -111,7 +114,7 @@ bool getRectilinearBounds(const std::vector<const FilterStreamData *> &dataIn, B
 	return true;
 }
 
-IonInfoFilter::IonInfoFilter() : wantIonCounts(true), wantNormalise(false),
+IonInfoFilter::IonInfoFilter() : wantIonCounts(true), wantNormalise(false), wantIonRemap(false),
 	range(0), wantVolume(false), volumeAlgorithm(VOLUME_MODE_RECTILINEAR),
 	cubeSideLen(1.0f), fitMode(FIT_MODE_NONE), massBackStart(1.2),massBackEnd(1.8),binWidth(0.05)
 {
@@ -119,6 +122,12 @@ IonInfoFilter::IonInfoFilter() : wantIonCounts(true), wantNormalise(false),
 	cache=true; //By default, we should cache, but decision is made higher up
 }
 
+IonInfoFilter::~IonInfoFilter()
+{
+	if(range)
+		delete range;
+}
+
 void IonInfoFilter::initFilter(const std::vector<const FilterStreamData *> &dataIn,
 				std::vector<const FilterStreamData *> &dataOut)
 {
@@ -171,6 +180,17 @@ void IonInfoFilter::initFilter(const std::vector<const FilterStreamData *> &data
 
 }
 
+unsigned int IonInfoFilter::getNumSteps() const 
+{
+	unsigned int maxStep=0;
+	if(wantIonCounts)
+		maxStep++;
+	if(wantVolume)
+		maxStep++;
+
+	return maxStep;
+}
+
 Filter *IonInfoFilter::cloneUncached() const
 {
 	IonInfoFilter *p=new IonInfoFilter();
@@ -178,9 +198,12 @@ Filter *IonInfoFilter::cloneUncached() const
 	p->wantIonCounts=wantIonCounts;
 	p->wantVolume=wantVolume;
 	p->wantNormalise=wantNormalise;
+	p->wantIonRemap=wantIonRemap;
 	p->cubeSideLen=cubeSideLen;
 	p->volumeAlgorithm=volumeAlgorithm;
 
+	p->remapFilename=remapFilename;
+
 	//We are copying whether to cache or not,
 	//not the cache itself
 	p->cache=cache;
@@ -204,10 +227,25 @@ unsigned int IonInfoFilter::refresh(const std::vector<const FilterStreamData *>
 		return 0;
 	}
 
+	IonMapTable remapTable;
+	bool readyForRemap=false;
+	if(wantIonRemap && remapFilename.size())
+	{
+		if(remapTable.read(remapFilename.c_str()))
+			return ERR_REMAPFILE_OPEN;
+
+		readyForRemap=true;
+	}
+	
+	progress.maxStep=getNumSteps();
+	progress.step=0;
+
 	//Compute ion counts/composition as needed
 	if(wantIonCounts)
 	{
-		
+		progress.step++;
+		progress.filterProgress=0;
+		progress.stepName=TRANS("Ion counts");	
 		std::string str;
 		//Count the number of ions
 		if(range)
@@ -251,6 +289,8 @@ unsigned int IonInfoFilter::refresh(const std::vector<const FilterStreamData *>
 				const IonStreamData  *i; 
 				i = (const IonStreamData *)dataIn[ui];
 
+				//FIXME: Gcc > 6.3 supports openmp reduction on arrays. 
+				// Implement after April 2019
 				for(size_t uj=0;uj<i->data.size(); uj++)
 				{
 					unsigned int idIon;
@@ -278,50 +318,124 @@ unsigned int IonInfoFilter::refresh(const std::vector<const FilterStreamData *>
 				}
 			}
 			
-			stream_cast(str,numTotalPoints);
 			str=std::string(TRANS("--Counts--") );
 			appendConsoleMessage(str);
 			
 			//sum all ions *except* the unranged.
 			for(size_t ui=0;ui<numIons.size()-1;ui++)
 				numRanged+=numIons[ui];
-				
+			
+			//Show the raw totals - do not show the remapped counts here, as we will do it elsewhere
 			if(wantNormalise)
 			{
 				stream_cast(str,numRanged);
-				str=TRANS("Total Ranged\t")+str;
+				if(readyForRemap)
+					str=TRANS("Total ranged (without remap)") + str;
+				else
+					str=TRANS("Total Ranged\t")+str;
 			}
 			else
 			{
 				stream_cast(str,numTotalPoints);
-				str=TRANS("Total (incl. unranged)\t")+str;
+				if(readyForRemap)
+					str=TRANS("Total (incl. unranged,without remap)\t")+str;
+				else
+					str=TRANS("Total (incl. unranged)\t")+str;
 			}
+
+
+
 			appendConsoleMessage(str);
 			appendConsoleMessage("");
 
-			//Print out the ion count table
-			for(size_t ui=0;ui<numIons.size();ui++)
+			if(!readyForRemap)
 			{
-				if(wantNormalise)
+				//Print out the raw ion count table
+				for(size_t ui=0;ui<numIons.size();ui++)
 				{
-					if(numRanged)
-						stream_cast(str,((float)numIons[ui])/(float)numRanged);
+					if(wantNormalise)
+					{
+						if(numRanged)
+							stream_cast(str,((float)numIons[ui])/(float)numRanged);
+						else
+							str=TRANS("n/a");
+					}
 					else
-						str=TRANS("n/a");
+						stream_cast(str,numIons[ui]);
+				
+					if(ui!=numIons.size()-1)
+						str=std::string(r->getName(ui)) + std::string("\t") + str;
+					else
+					{
+						//output unranged count 
+						str=std::string(TRANS("Unranged")) + std::string("\t") + str;
+					}
+
+					appendConsoleMessage(str);
 				}
-				else
-					stream_cast(str,numIons[ui]);
-			
-				if(ui!=numIons.size()-1)
-					str=std::string(r->getName(ui)) + std::string("\t") + str;
-				else
+			}
+			else
+			{
+				vector<string> ionNames,remappedNames;
+				vector<unsigned int> ionCounts,remappedCounts;
+				
+				for(auto i=0;i<numIons.size()-1;i++)
 				{
-					//output unranged count 
-					str=std::string(TRANS("Unranged")) + std::string("\t") + str;
+					ionCounts.push_back(numIons[i]);
+					ionNames.push_back(r->getName(i));
+				}
+			
+
+				//Remap the counts using the table
+				remapTable.remapCounts(ionNames,ionCounts,
+						remappedNames,remappedCounts,false);
+
+				//Compute the total reapped ions
+				unsigned int numRemapped;
+				numRemapped=std::accumulate(remappedCounts.begin(),
+								remappedCounts.end(),0);
+				//The last entry is unranged
+				unsigned int unrangeCount=0;
+				if(numIons.size())
+				{
+					unrangeCount=numIons[numIons.size()-1];
+					//Remove the unranged count
+					numIons.pop_back();
 				}
 
-				appendConsoleMessage(str);
+
+				//Print out the raw ion count table
+				for(auto ui=0;ui<remappedNames.size();ui++)
+				{
+					if(wantNormalise)
+					{
+						if(numRanged && numRemapped)
+							stream_cast(str,((float)remappedCounts[ui])/(float)numRemapped);
+						else
+							str=TRANS("n/a");
+					}
+					else
+						stream_cast(str,remappedCounts[ui]);
+				
+					str=std::string(remappedNames[ui]) + std::string("\t") + str;
+
+					appendConsoleMessage(str);
+				}
+
+				//output unranged count, if relevant 
+				if(!wantNormalise)
+				{
+					stream_cast(str,unrangeCount);
+					str=std::string(TRANS("Unranged")) + std::string("\t") + str;
+					appendConsoleMessage(str);
+				}
+				else if (unrangeCount)
+				{
+					str=TRANS("Unranged ions ignored");
+					appendConsoleMessage(str);
+				}
 			}
+			
 			str=std::string("----------");
 			appendConsoleMessage(str);
 	
@@ -333,12 +447,16 @@ unsigned int IonInfoFilter::refresh(const std::vector<const FilterStreamData *>
 			str=std::string(TRANS("Number of points : ") )+ str;
 			appendConsoleMessage(str);
 		}
+	
+		progress.filterProgress=100;
 	}
 
 	float computedVol=0;
 	//Compute volume as needed
 	if(wantVolume)
 	{
+		progress.step++;
+		progress.stepName=TRANS("Volume");
 		switch(volumeAlgorithm)
 		{
 			case VOLUME_MODE_RECTILINEAR:
@@ -394,6 +512,7 @@ unsigned int IonInfoFilter::refresh(const std::vector<const FilterStreamData *>
 
 		}
 	
+		progress.filterProgress=100;	
 #ifdef DEBUG
 		lastVolume=computedVol;
 #endif
@@ -450,6 +569,21 @@ void IonInfoFilter::getProperties(FilterPropGroup &propertyList) const
 			 wantIonCounts,TRANS("Display compositional data for points in console"));
 						
 		propertyList.addProperty(pCounts,curGroup);
+		if(wantIonCounts)
+		{
+			FilterProperty pWantIonRemap(IONINFO_KEY_REMAP_IONS,TRANS("Remap ions"),
+						wantIonRemap, TRANS("Break up ion counts/compositions"));
+			propertyList.addProperty(pWantIonRemap,curGroup);
+
+			if(wantIonRemap)
+			{
+				FilterProperty pRemapFile(IONINFO_KEY_REMAP_FILE, PROPERTY_TYPE_FILE,
+						TRANS("Remap File"), remapFilename,
+						TRANS("File describing how ions are to be broken up"));
+
+				propertyList.addProperty(pRemapFile,curGroup);
+			}
+		}
 	}
 	else
 	{
@@ -471,7 +605,7 @@ void IonInfoFilter::getProperties(FilterPropGroup &propertyList) const
 		choices.clear();
 		for(unsigned int ui=0;ui<FIT_MODE_ENUM_END; ui++)
 		{
-			choices.push_back(make_pair((unsigned int)ui,
+			choices.emplace_back((unsigned int)ui,
 						TRANS(BACKGROUND_MODE_STRING[ui])));
 		}
 		str=choiceString(choices,fitMode);
@@ -533,8 +667,8 @@ void IonInfoFilter::getProperties(FilterPropGroup &propertyList) const
 		choices.clear();
 		for(unsigned int ui=0;ui<VOLUME_MODE_END; ui++)
 		{
-			choices.push_back(make_pair((unsigned int)ui,
-						TRANS(volumeModeString[ui])));
+			choices.emplace_back((unsigned int)ui,
+						TRANS(volumeModeString[ui]));
 		}
 		
 		FilterProperty pAlgorithm(IONINFO_KEY_VOLUME_ALGORITHM, TRANS("Algorithm"),
@@ -649,6 +783,18 @@ bool IonInfoFilter::setProperty(  unsigned int key,
 			
 			break;
 		}
+		case IONINFO_KEY_REMAP_FILE:
+		{
+			if(!applyPropertyNow(remapFilename,value,needUpdate))
+				return false;
+			break;
+		}
+		case IONINFO_KEY_REMAP_IONS:
+		{
+			if(!applyPropertyNow(wantIonRemap,value,needUpdate))
+				return false;
+			break;
+		}
 		default:
 			ASSERT(false);
 	}
@@ -661,6 +807,7 @@ std::string  IonInfoFilter::getSpecificErrString(unsigned int code) const
 	const char *errStrs[] = { "",
 		"Aborted",
 		"Bug? Problem with qhull library, cannot run convex hull.",
+		"Unable to read remap file, or its contents.",
 	};
 	
 	COMPILE_ASSERT(THREEDEP_ARRAYSIZE(errStrs) == IONINFO_ERR_ENUM_END);
@@ -720,11 +867,13 @@ bool IonInfoFilter::writeState(std::ostream &f,unsigned int format, unsigned int
 			f << tabs(depth+1) << "<wantioncounts value=\""<<wantIonCounts<< "\"/>"  << endl;
 			f << tabs(depth+1) << "<wantnormalise value=\""<<wantNormalise<< "\"/>"  << endl;
 			f << tabs(depth+1) << "<wantvolume value=\""<<wantVolume<< "\"/>"  << endl;
+			f << tabs(depth+1) << "<wantionremap value=\"" << boolStrEnc(wantIonRemap) << "\"/>" << endl;
 			f << tabs(depth+1) << "<volumealgorithm value=\""<<volumeAlgorithm<< "\"/>"  << endl;
 			f << tabs(depth+1) << "<cubesidelen value=\""<<cubeSideLen<< "\"/>"  << endl;
 			f << tabs(depth+1) << "<background mode=\"" << fitMode << "\">" << endl;
 				f << tabs(depth+2) << "<fitwindow start=\"" << massBackStart<< "\" end=\"" << massBackEnd << "\"/>" << endl;
 			f << tabs(depth+1) << "</background>" << endl;
+			f << tabs(depth+1) << "<remapfilename value=\"" << escapeXML(convertFileStringToCanonical(remapFilename)) << "\"/>" << endl;
 
 			f << tabs(depth) << "</" <<trueName()<< ">" << endl;
 			break;
@@ -737,6 +886,30 @@ bool IonInfoFilter::writeState(std::ostream &f,unsigned int format, unsigned int
 	return true;
 }
 
+bool IonInfoFilter::writePackageState(std::ostream &f, unsigned int format,
+			const std::vector<std::string> &valueOverrides, unsigned int depth) const
+{
+	if(remapFilename.empty())
+		return writeState(f,format,depth);
+
+
+	//Temporarily modify the state of the filter, then call writestate
+	string tmpFilename=remapFilename;
+
+	ASSERT(valueOverrides.size() == 1);
+	//override const -- naughty, but we know what we are doing...
+	const_cast<IonInfoFilter*>(this)->remapFilename=valueOverrides[0];
+	bool result;
+	result=writeState(f,format,depth);
+	const_cast<IonInfoFilter*>(this)->remapFilename=tmpFilename;
+
+	return true;
+}
+
+void IonInfoFilter::getStateOverrides(std::vector<string> &externalAttribs) const 
+{
+	externalAttribs.push_back(remapFilename);
+}
 bool IonInfoFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileDir)
 {
 	using std::string;
@@ -774,6 +947,21 @@ bool IonInfoFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	if(!boolStrDec(tmpStr,wantVolume))
 		return false;
 	//--=
+	//--
+	//TODO: COMPAT : did not exist prior to 0.0.22
+	// internal revision : 592af3968ddf
+	xmlNodePtr tmpNode=nodePtr;
+	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"wantionremap","value"))
+	{
+		wantIonRemap=false;
+		nodePtr=tmpNode;
+	}
+	else
+	{
+		if(!boolStrDec(tmpStr,wantIonRemap))
+			return false;
+	}
+	//--=
 
 	//--
 	unsigned int tmpInt;
@@ -796,7 +984,7 @@ bool IonInfoFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 	//--=
 
 	//Retrieve background fitting mode, if we have it
-	// Only available 3Depict >= 0.0.18
+	// TODO: COMPAT : Only available 3Depict >= 0.0.18
 	// internal rev > 3e41b89299f4
 	if(!XMLHelpFwdToElem(nodePtr,"background"))
 	{
@@ -818,6 +1006,22 @@ bool IonInfoFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 		nodePtr=tmpNode;
 	}
 
+	//TODO: COMPAT : did not exist prior to 0.0.22
+	// internal revision > 592af3968ddf
+	//--
+	if(!XMLGetNextElemAttrib(nodePtr,tmpStr,"remapfilename","value"))
+		remapFilename="";
+	else
+	{
+		remapFilename=convertFileStringToNative(tmpStr);
+
+		//Convert from relative to absolute if we are reading a package
+		convertFileStringToAbsolute(stateFileDir, remapFilename);
+		//Convert from "canonical" 3Depict filename to OS native
+		remapFilename = convertFileStringToNative(remapFilename);
+	}
+	//--
+
 	return true;
 }
 
