@@ -30,7 +30,9 @@ enum
 	IONINFO_KEY_BACKMODE,
 	IONINFO_KEY_BACK_MASSSTART,
 	IONINFO_KEY_BACK_MASSEND,
-	IONINFO_KEY_BACK_BINSIZE
+	IONINFO_KEY_BACK_BINSIZE,
+	IONINFO_KEY_REMAP_IONS,
+	IONINFO_KEY_REMAP_FILE
 };
 
 //!Ion derived information filter, things like volume, composition, etc.
@@ -43,6 +45,13 @@ class IonInfoFilter : public Filter
 		//!Do we want to normalise the ion count data?
 		bool wantNormalise;
 
+		//!Do we want to remap the ion information
+		bool wantIonRemap;
+
+		//!Name of file to use for the remap
+		std::string remapFilename;
+
+
 
 		//!Parent rangefile in tree
 		RangeStreamData *range;
@@ -80,13 +89,18 @@ class IonInfoFilter : public Filter
 		//!Constructor
 		IonInfoFilter();
 
+		~IonInfoFilter();
+
 		//!Duplicate filter contents, excluding cache.
 		Filter *cloneUncached() const;
 
 		//Perform filter intialisation, for pre-detection of range data
 		virtual void initFilter(const std::vector<const FilterStreamData *> &dataIn,
 				std::vector<const FilterStreamData *> &dataOut);
-		
+	
+		//!Obtain the number of steps required to perform configure computation
+		unsigned int getNumSteps() const;	
+			
 		//!Apply filter to new data, updating cache as needed. Vector
 		// of returned pointers must be deleted manually, first checking
 		// ->cached.
@@ -121,6 +135,12 @@ class IonInfoFilter : public Filter
 		 */
 		bool writeState(std::ostream &f, unsigned int format,
 							unsigned int depth) const;
+		//!Write the package state 
+		bool writePackageState(std::ostream &f, unsigned int format,
+				const std::vector<std::string> &valueOverrides,unsigned int depth=0) const;
+
+		//!Obtain the overrides for the state (used indirectly when writing package)
+		virtual void getStateOverrides(std::vector<std::string> &overrides) const ; 
 
 		//!Read state from XML  stream, using xml format
 		/* Current supported formats are STATE_FORMAT_XML
