@@ -20,6 +20,7 @@
 
 #include "filterCommon.h"
 #include "geometryHelpers.h"
+#include "../APT/ionMapFile.h"
 
 using std::vector;
 using std::string;
@@ -44,6 +45,7 @@ enum
 	ERR_NUMBINS=1,
 	ERR_MEMALLOC,
 	ERR_ABORT,
+	ERR_REMAPFILE_OPEN,
 	ERR_COMP_ENUM_END
 };
 
@@ -59,7 +61,7 @@ const unsigned int MINEVENTS_DEFAULT =10;
 
 
 ProfileFilter::ProfileFilter() : primitiveType(PRIMITIVE_CYLINDER_AXIAL),
-	showPrimitive(true), lockAxisMag(false),normalise(true), fixedBins(0),
+	showPrimitive(true), lockAxisMag(false),normalise(true), wantIonRemap(false),fixedBins(0),
 	nBins(1000), binWidth(0.5f), minEvents(MINEVENTS_DEFAULT), rgba(0,0,1), plotStyle(0)
 {
 	COMPILE_ASSERT(THREEDEP_ARRAYSIZE(PRIMITIVE_NAME) == PRIMITIVE_END);
@@ -68,8 +70,8 @@ ProfileFilter::ProfileFilter() : primitiveType(PRIMITIVE_CYLINDER_AXIAL),
 	errMode.mode=PLOT_ERROR_NONE;
 	errMode.movingAverageNum=4;
 	
-	vectorParams.push_back(Point3D(0.0,0.0,0.0));
-	vectorParams.push_back(Point3D(0,20.0,0.0));
+	vectorParams.emplace_back(Point3D(0.0,0.0,0.0));
+	vectorParams.emplace_back(Point3D(0,20.0,0.0));
 	scalarParams.push_back(DEFAULT_RADIUS);
 
 	haveRangeParent=false;
@@ -79,7 +81,7 @@ ProfileFilter::ProfileFilter() : primitiveType(PRIMITIVE_CYLINDER_AXIAL),
 //range data (if any), mass to charge and the output table
 void ProfileFilter::binIon(unsigned int targetBin, const RangeStreamData* rng, 
 	const map<unsigned int,unsigned int> &ionIDMapping,
-	vector<vector<size_t> > &frequencyTable, float massToCharge) 
+	vector<vector<unsigned int> > &frequencyTable, float massToCharge) 
 {
 	//if we have no range data, then simply increment its position in a 1D table
 	//which will later be used as "count" data (like some kind of density plot)
@@ -91,7 +93,7 @@ void ProfileFilter::binIon(unsigned int targetBin, const RangeStreamData* rng,
 		//disallow this.
 		if(targetBin < frequencyTable[0].size())
 		{
-			vector<size_t>::iterator it;
+			vector<unsigned int>::iterator it;
 			it=frequencyTable[0].begin()+targetBin;
 			#pragma omp critical
 			(*it)++;
@@ -109,8 +111,7 @@ void ProfileFilter::binIon(unsigned int targetBin, const RangeStreamData* rng,
 		unsigned int ionID=rng->rangeFile->getIonID(rangeID); 
 		unsigned int pos;
 		pos = ionIDMapping.find(ionID)->second;
-		vector<size_t>::iterator it;
-		it=frequencyTable[pos].begin()+targetBin;
+		auto it=frequencyTable[pos].begin()+targetBin;
 		#pragma omp critical
 		(*it)++;
 	}
@@ -131,6 +132,9 @@ Filter *ProfileFilter::cloneUncached() const
 
 	p->wantDensity=wantDensity;
 	p->normalise=normalise;	
+	p->wantIonRemap=wantIonRemap;
+	p->remapFilename=remapFilename;
+
 	p->fixedBins=fixedBins;
 	p->lockAxisMag=lockAxisMag;
 	
@@ -325,7 +329,7 @@ unsigned int ProfileFilter::refresh(const std::vector<const FilterStreamData *>
 			
 
 	//Ion Frequencies (composition specific if rangefile present)
-	vector<vector<size_t> > ionFrequencies;
+	vector<vector<unsigned int> > ionFrequencies;
 	
 	RangeStreamData *rngData=0;
 	if(!wantDensity)
@@ -354,6 +358,7 @@ unsigned int ProfileFilter::refresh(const std::vector<const FilterStreamData *>
 	}
 
 	//Indirection vector to convert ionFrequencies position to ionID mapping.
+	// this is needed as some of the upstream ions may be disabled
 	//Should only be used in conjunction with rngData == true
 	std::map<unsigned int,unsigned int> ionIDMapping,inverseIDMapping;
 	//Allocate space for the frequency table
@@ -363,9 +368,6 @@ unsigned int ProfileFilter::refresh(const std::vector<const FilterStreamData *>
 		unsigned int enabledCount=0;
 		for(unsigned int ui=0;ui<rngData->rangeFile->getNumIons();ui++)
 		{
-			//TODO: Might be nice to detect if an ions ranges
-			//are all, disabled then if they are, enter this "if"
-			//anyway
 			if(rngData->enabledIons[ui])
 			{
 				//Keep the forwards mapping for binning
@@ -412,7 +414,7 @@ unsigned int ProfileFilter::refresh(const std::vector<const FilterStreamData *>
 
 
 	size_t n=0;
-	size_t totalSize=max(numElements(dataIn),(size_t)1);
+	size_t totalSize=numElements(dataIn);
 
 	map<size_t,size_t> primitiveMap;
 	primitiveMap[PRIMITIVE_CYLINDER_AXIAL] = CROP_CYLINDER_INSIDE_AXIAL;
@@ -512,6 +514,7 @@ unsigned int ProfileFilter::refresh(const std::vector<const FilterStreamData *>
 	//Perform the appropriate normalisation
 	if(!rngData && normalise)
 	{
+		needNormalise=true;
 		// For density plots, normalise by
 		//  the volume of the primitive's shell
 		switch(primitiveType)
@@ -583,7 +586,35 @@ unsigned int ProfileFilter::refresh(const std::vector<const FilterStreamData *>
 
 	}
 
-	
+
+	IonMapTable remapTable;
+	vector<string> remappedNames;
+	if(wantIonRemap && rngData)
+	{
+		//We need to pass the ionFrequencies and their identities to remap
+		if(remapTable.read(remapFilename.c_str()))
+			return ERR_REMAPFILE_OPEN;
+
+		vector<string> inputNames;
+		inputNames.resize(ionFrequencies.size());
+
+		for(auto idx=0;idx<ionFrequencies.size();idx++)
+		{
+			unsigned int thisIonID;
+			thisIonID = inverseIDMapping.find(idx)->second;
+			inputNames[idx] = rngData->rangeFile->getName(thisIonID);
+		}
+
+		vector<vector<unsigned int> > remappedCounts;
+
+		//Remap the counts using the table
+		remapTable.remapCounts(inputNames,ionFrequencies,
+				remappedNames,remappedCounts,false);
+
+		//swap the original counts with the remapped values
+		ionFrequencies.swap(remappedCounts);
+
+	}
 	//Create the plots
 	PlotStreamData *plotData[ionFrequencies.size()];
 	for(unsigned int ui=0;ui<ionFrequencies.size();ui++)
@@ -615,19 +646,63 @@ unsigned int ProfileFilter::refresh(const std::vector<const FilterStreamData *>
 		//Give the plot a title like TRANS("Myplot:Mg" (if have range) or "MyPlot") (no range)
 		if(rngData)
 		{
-			unsigned int thisIonID;
-			thisIonID = inverseIDMapping.find(ui)->second;
-			plotData[ui]->dataLabel = getUserString() + string(":") 
-					+ rngData->rangeFile->getName(thisIonID);
+			if(!wantIonRemap)
+			{
+				unsigned int thisIonID;
+				thisIonID = inverseIDMapping.find(ui)->second;
+				plotData[ui]->dataLabel = getUserString() + string(":") 
+						+ rngData->rangeFile->getName(thisIonID);
 
-		
-			//Set the plot colour to the ion colour	
-			RGBf col;
-			col=rngData->rangeFile->getColour(thisIonID);
+			
+				//Set the plot colour to the ion colour	
+				RGBf col;
+				col=rngData->rangeFile->getColour(thisIonID);
 
-			plotData[ui]->r =col.red;
-			plotData[ui]->g =col.green;
-			plotData[ui]->b =col.blue;
+				plotData[ui]->r =col.red;
+				plotData[ui]->g =col.green;
+				plotData[ui]->b =col.blue;
+			}
+			else
+			{
+				plotData[ui]->dataLabel = getUserString() + string(":") +
+						remappedNames[ui];
+				RGBf col;
+				//See if we have the original colour for the ion
+				unsigned int ionID;
+				ionID=rngData->rangeFile->getIonID(remappedNames[ui]);
+				if(ionID !=(unsigned int)-1)
+					col=rngData->rangeFile->getColour(ionID);
+				else
+				{
+					//We have an ion we didn't know about before.
+					// make up a stable colour using the ion name
+					
+					//Use a hash to make a platform specific stable 
+					// hex value
+					std::hash<std::string> hashFunc;
+					size_t hashV = hashFunc(remappedNames[ui]);
+
+					string s=intToHex(hashV);
+
+					ASSERT(s.size() == 8);
+
+					//Use the last 6 digits of the hex string
+					// to set the final colour
+					unsigned char c[3];
+					hexStrToUChar(s.substr(2,2),c[0]);
+					hexStrToUChar(s.substr(4,2),c[1]);
+					hexStrToUChar(s.substr(6,2),c[2]);
+					col.red = c[0]/255.0f;
+					col.green= c[1]/255.0f;
+					col.blue= c[2]/255.0f;
+
+
+				}
+
+				plotData[ui]->r =col.red;
+				plotData[ui]->g =col.green;
+				plotData[ui]->b =col.blue;
+			}
 
 		}
 		else
@@ -659,7 +734,7 @@ unsigned int ProfileFilter::refresh(const std::vector<const FilterStreamData *>
 				float normFactor=normalisationFactor[uj];
 
 				//keep the data if we are not using minimum threshold for normalisation, or we met the 
-				// threhsold
+				// threshold
 				plotData[ui]->xyData.push_back(
 					std::make_pair(xPos,
 					normFactor*(float)ionFrequencies[ui][uj]));
@@ -701,7 +776,8 @@ std::string  ProfileFilter::getSpecificErrString(unsigned int code) const
 	const char *errCodes[] =   { "",
 		"Too many bins in comp. profile.",
 		"Not enough memory for comp. profile.",
-		"Aborted composition prof." }; 
+		"Aborted composition prof.",
+		"Unable to read remap table"}; 
 
 	COMPILE_ASSERT(THREEDEP_ARRAYSIZE(errCodes) == ERR_COMP_ENUM_END);
 	ASSERT(code < ERR_COMP_ENUM_END);
@@ -817,8 +893,8 @@ bool ProfileFilter::setProperty( unsigned int key,
 						if(vectorParams.size() <2 )
 						{
 							vectorParams.clear();
-							vectorParams.push_back(Point3D(0,0,0));
-							vectorParams.push_back(Point3D(0,20,0));
+							vectorParams.emplace_back(Point3D(0,0,0));
+							vectorParams.emplace_back(Point3D(0,20,0));
 						}
 						else
 							vectorParams.resize(2);
@@ -847,7 +923,7 @@ bool ProfileFilter::setProperty( unsigned int key,
 						if(vectorParams.size() >1)
 							vectorParams.resize(1);
 						else
-							vectorParams.push_back(Point3D(0,0,0));
+							vectorParams.emplace_back(Point3D(0,0,0));
 					}
 
 					if(scalarParams.size() !=1)
@@ -897,6 +973,18 @@ bool ProfileFilter::setProperty( unsigned int key,
 				return false;
 			break;	
 		}
+		case PROFILE_KEY_WANTREMAP:
+		{
+			if(!applyPropertyNow(wantIonRemap,value,needUpdate))
+				return false;
+			break;	
+		}
+		case PROFILE_KEY_REMAPFILE:
+		{
+			if(!applyPropertyNow(remapFilename,value,needUpdate))
+				return false;
+			break;	
+		}
 		case PROFILE_KEY_LOCKAXISMAG:
 		{
 			if(!applyPropertyNow(lockAxisMag,value,needUpdate))
@@ -985,7 +1073,7 @@ void ProfileFilter::getProperties(FilterPropGroup &propertyList) const
 		for(unsigned int ui=0;ui<PRIMITIVE_END;ui++)
 		{
 			str =TRANS(PRIMITIVE_NAME[ui]);
-			choices.push_back(make_pair(ui,str));
+			choices.emplace_back(ui,str);
 		}
 		FilterProperty pPrimitive(PROFILE_KEY_PRIMITIVETYPE, TRANS("Primitive type"),
 				choices,primitiveType,TRANS("Basic shape to use for profile"));
@@ -1058,31 +1146,46 @@ void ProfileFilter::getProperties(FilterPropGroup &propertyList) const
 	{
 		ASSERT(primitiveType!=PRIMITIVE_CYLINDER_RADIAL);
 		FilterProperty pBinWidth(PROFILE_KEY_BINWIDTH, TRANS("Bin Width"),
-						nBins,TRANS("Size of each bin in profile"));
+						binWidth,TRANS("Size of each bin in profile"));
 		propertyList.addProperty(pBinWidth,curGroup);
 	}
 
 	FilterProperty pNormalise(PROFILE_KEY_NORMALISE, TRANS("Normalise"),
-		nBins,TRANS("Convert bin counts into relative frequencies in each bin"));
+		normalise,TRANS("Convert bin counts into relative frequencies in each bin"));
 	propertyList.addProperty(pNormalise,curGroup);
 	
 	FilterProperty pMinEvents(PROFILE_KEY_MINEVENTS, TRANS("Min. Events"),
 		minEvents,TRANS("Drop data that does not have this many events"));
 	propertyList.addProperty(pMinEvents,curGroup);
-	
+
+	if(haveRangeParent)
+	{
+		FilterProperty pRemap(PROFILE_KEY_WANTREMAP, TRANS("Remap Ions"),
+			wantIonRemap,TRANS("Break apart ions into components, using a remap file?"));
+		propertyList.addProperty(pRemap,curGroup);
+
+		if(wantIonRemap)
+		{
+		
+			FilterProperty pRemapFilename(PROFILE_KEY_REMAPFILE, PROPERTY_TYPE_FILE,TRANS("Remap file"),
+				remapFilename,TRANS("\"Remap\" file that describes how the ions can be broken apart"));
+			propertyList.addProperty(pRemapFilename,curGroup);
+		}
+	}
+
 	propertyList.setGroupTitle(curGroup,TRANS("Settings"));	
 	curGroup++;
 	
 	//Let the user know what the valid values for plot type are
 	vector<pair<unsigned int,string> > choices;
 	tmpStr=plotString(PLOT_LINE_LINES);
-	choices.push_back(make_pair((unsigned int) PLOT_LINE_LINES,tmpStr));
+	choices.emplace_back((unsigned int) PLOT_LINE_LINES,tmpStr);
 	tmpStr=plotString(PLOT_LINE_BARS);
-	choices.push_back(make_pair((unsigned int)PLOT_LINE_BARS,tmpStr));
+	choices.emplace_back((unsigned int)PLOT_LINE_BARS,tmpStr);
 	tmpStr=plotString(PLOT_LINE_STEPS);
-	choices.push_back(make_pair((unsigned int)PLOT_LINE_STEPS,tmpStr));
+	choices.emplace_back((unsigned int)PLOT_LINE_STEPS,tmpStr);
 	tmpStr=plotString(PLOT_LINE_STEM);
-	choices.push_back(make_pair((unsigned int)PLOT_LINE_STEM,tmpStr));
+	choices.emplace_back((unsigned int)PLOT_LINE_STEM,tmpStr);
 
 	FilterProperty pPlotType(PROFILE_KEY_PLOTTYPE, TRANS("Plot Type"),
 			choices,plotStyle,TRANS("Visual style for plot"));
@@ -1102,9 +1205,9 @@ void ProfileFilter::getProperties(FilterPropGroup &propertyList) const
 	
 	choices.clear();
 	tmpStr=plotErrmodeString(PLOT_ERROR_NONE);
-	choices.push_back(make_pair((unsigned int) PLOT_ERROR_NONE,tmpStr));
+	choices.emplace_back((unsigned int) PLOT_ERROR_NONE,tmpStr);
 	tmpStr=plotErrmodeString(PLOT_ERROR_MOVING_AVERAGE);
-	choices.push_back(make_pair((unsigned int) PLOT_ERROR_MOVING_AVERAGE,tmpStr));
+	choices.emplace_back((unsigned int) PLOT_ERROR_MOVING_AVERAGE,tmpStr);
 
 	tmpStr= choiceString(choices,errMode.mode);
 	p.name=TRANS("Err. Estimator");
@@ -1389,7 +1492,7 @@ bool ProfileFilter::readState(xmlNodePtr &nodePtr, const std::string &stateFileD
 		if(stream_cast(z,tmpStr))
 			return false;
 
-		vectorParams.push_back(Point3D(x,y,z));
+		vectorParams.emplace_back(Point3D(x,y,z));
 	}
 	//===	
 
@@ -1636,8 +1739,8 @@ bool testCompositionCylinder()
 	//Generate two compositions for the test dataset
 	{
 	vector<std::pair<float,float>  > vecCompositions;
-	vecCompositions.push_back(make_pair(2.0f,0.5f));
-	vecCompositions.push_back(make_pair(3.0f,0.5f));
+	vecCompositions.emplace_back(2.0f,0.5f);
+	vecCompositions.emplace_back(3.0f,0.5f);
 	synthComposition(vecCompositions,d->data);
 	}
 
@@ -1748,8 +1851,8 @@ bool testDensityCylinder()
 	//Generate two compositions for the test dataset
 	{
 	vector<std::pair<float,float>  > vecCompositions;
-	vecCompositions.push_back(make_pair(2.0f,0.5f));
-	vecCompositions.push_back(make_pair(3.0f,0.5f));
+	vecCompositions.emplace_back(2.0f,0.5f);
+	vecCompositions.emplace_back(3.0f,0.5f);
 	synthComposition(vecCompositions,d->data);
 	}
 
@@ -1804,6 +1907,8 @@ bool testDensityCylinder()
 		}
 	}
 
+	ASSERT(plotData);
+
 	float sum=0;
 	for(size_t ui=0;ui<plotData->xyData.size(); ui++)
 		sum+=plotData->xyData[ui].second;
