@@ -39,7 +39,9 @@ enum
 	PROFILE_KEY_COLOUR,
 	PROFILE_KEY_ERRMODE,
 	PROFILE_KEY_AVGWINSIZE,
-	PROFILE_KEY_LOCKAXISMAG
+	PROFILE_KEY_LOCKAXISMAG,
+	PROFILE_KEY_WANTREMAP,
+	PROFILE_KEY_REMAPFILE
 };
 //!Filter that does composition or density profiles for various primitives
 class ProfileFilter : public Filter
@@ -64,9 +66,15 @@ class ProfileFilter : public Filter
 		bool wantDensity;
 		//!Frequency or percentile mode (0 - frequency; 1-normalised (ion freq))
 		bool normalise;
+		//!Do we want to remap the ion information
+		bool wantIonRemap;
+		//!Name of file to use for the remap
+		std::string remapFilename;
+
 		//!Use fixed bins?
 		bool fixedBins;
 		
+		
 		//!number of bins (if using fixed bins)
 		unsigned int nBins;
 		//!Width of each bin (if using fixed width)
@@ -91,7 +99,7 @@ class ProfileFilter : public Filter
 		
 		//!internal function for binning an ion dependant upon range data
 		static void binIon(unsigned int targetBin, const RangeStreamData* rng, const std::map<unsigned int,unsigned int> &ionIDMapping,
-			std::vector<std::vector<size_t> > &frequencyTable, float massToCharge);
+			std::vector<std::vector<unsigned int> > &frequencyTable, float massToCharge);
 
 		static unsigned int getPrimitiveId(const std::string &s);;
 
