@@ -558,37 +558,25 @@ void RangeFileFilter::getProperties(FilterPropGroup &p) const
 
 	size_t curGroup=0;
 
-	prop.name=TRANS("File");
-	//Wx- acceptable string format
-	prop.type=PROPERTY_TYPE_FILE;
-	prop.helpText=TRANS("File to use for range data");
-	prop.key=RANGE_KEY_RANGE_FILENAME;
-	prop.data=rngName;
-	prop.dataSecondary=TRANS(RANGEFILE_WX_CONSTANT);
+	FilterProperty pFile(KEY_RANGE_FILENAME, PROPERTY_TYPE_FILE,TRANS("File"),
+		rngName,TRANS("File to use for range data"));
+	pFile.dataSecondary=TRANS(RANGEFILE_WX_CONSTANT);
 
+	p.addProperty(pFile,curGroup);	
 
-	p.addProperty(prop,curGroup);	
-
-	std::string tmpStr;
-	tmpStr=boolStrEnc(dropUnranged);
-	prop.name=TRANS("Drop unranged");
-	prop.type=PROPERTY_TYPE_BOOL;
-	prop.helpText=TRANS("Remove unranged points when generating output");
-	prop.key=RANGE_KEY_DROP_UNRANGED;
-	prop.data=tmpStr;
-
-	p.addProperty(prop,curGroup);
+	FilterProperty pDropUnranged(KEY_DROP_UNRANGED,TRANS("Drop unranged"),
+			dropUnranged,TRANS("Remove unranged points when generating output"));
+	p.addProperty(pDropUnranged ,curGroup);
+	
 	p.setGroupTitle(curGroup,TRANS("File"));
 
 	curGroup++;
 
+
+	FilterProperty pLegend( KEY_ENABLE_LEGEND,TRANS("Legend"),
+		showLegend,TRANS("Display colour legend for enabled ions"));
 	
-	prop.name = TRANS("Legend");
-	prop.type = PROPERTY_TYPE_BOOL;
-	prop.helpText = TRANS("Display colour legend for enabled ions");
-	prop.key= RANGE_KEY_ENABLE_LEGEND;
-	prop.data=boolStrEnc(showLegend);
-	p.addProperty(prop,curGroup);
+	p.addProperty(pLegend,curGroup);
 	p.setGroupTitle(curGroup,TRANS("View"));
 	curGroup++;
 
@@ -609,7 +597,7 @@ void RangeFileFilter::getProperties(FilterPropGroup &p) const
 		prop.helpText=TRANS("Enable/disable all ions at once");
 		prop.data=str;
 		prop.type=PROPERTY_TYPE_BOOL;
-		prop.key=RANGE_KEY_ENABLE_ALL_IONS;
+		prop.key=KEY_ENABLE_ALL_IONS;
 
 		p.addProperty(prop,curGroup);
 
@@ -625,7 +613,9 @@ void RangeFileFilter::getProperties(FilterPropGroup &p) const
 			prop.helpText=TRANS("Enable/disable specified ion");
 			prop.data=rng.getName(ui);
 			prop.type=PROPERTY_TYPE_STRING;
-			prop.key=NUM_ROWS_ION*ui+1+RANGE_KEY_ENABLE_ALL_IONS;
+			prop.key=NUM_ROWS_ION*ui+1+KEY_ENABLE_ALL_IONS;
+			//Shade every second entry
+			prop.displayShaded = ui&1;
 
 			p.addProperty(prop,curGroup);
 
@@ -636,7 +626,8 @@ void RangeFileFilter::getProperties(FilterPropGroup &p) const
 			prop.type=PROPERTY_TYPE_BOOL;
 			prop.helpText=TRANS("If true, ion is used in output");
 			prop.data=str;
-			prop.key=NUM_ROWS_ION*ui+2+RANGE_KEY_ENABLE_ALL_IONS;
+			prop.key=NUM_ROWS_ION*ui+2+KEY_ENABLE_ALL_IONS;
+			prop.displayShaded = ui&1;
 		
 			p.addProperty(prop,curGroup);
 
@@ -649,7 +640,8 @@ void RangeFileFilter::getProperties(FilterPropGroup &p) const
 
 			prop.type=PROPERTY_TYPE_COLOUR;
 			prop.helpText=TRANS("Colour used to represent ion");
-			prop.key=NUM_ROWS_ION*ui+3+RANGE_KEY_ENABLE_ALL_IONS;
+			prop.key=NUM_ROWS_ION*ui+3+KEY_ENABLE_ALL_IONS;
+			prop.displayShaded = ui&1;
 
 			p.addProperty(prop,curGroup);
 		}
@@ -675,7 +667,7 @@ void RangeFileFilter::getProperties(FilterPropGroup &p) const
 		prop.helpText=TRANS("Enable/disable all ranges");
 		prop.data=str;
 		prop.type=PROPERTY_TYPE_BOOL;
-		prop.key=RANGE_KEY_ENABLE_ALL_RANGES;
+		prop.key=KEY_ENABLE_ALL_RANGES;
 	
 		p.addProperty(prop,curGroup);
 		
@@ -691,14 +683,19 @@ void RangeFileFilter::getProperties(FilterPropGroup &p) const
 			prop.data=str;
 			prop.type=PROPERTY_TYPE_BOOL;
 			prop.helpText=TRANS("Enable/disable specified range (ion must also be enabled to activiate range)");
-			prop.key=RANGE_KEY_ENABLE_ALL_RANGES+NUM_ROWS_RANGE*ui+1;
+			prop.key=KEY_ENABLE_ALL_RANGES+NUM_ROWS_RANGE*ui+1;
+			//Shade every second entry
+			prop.displayShaded = ui&1;
+			
 			p.addProperty(prop,curGroup);
 
 			prop.name=string(TRANS("Ion ")) + suffix;
 			prop.data=rng.getName(rng.getIonID(ui));
 			prop.type=PROPERTY_TYPE_STRING;
 			prop.helpText=TRANS("Name of ion associate to this range");
-			prop.key=RANGE_KEY_ENABLE_ALL_RANGES+NUM_ROWS_RANGE*ui+2;
+			prop.key=KEY_ENABLE_ALL_RANGES+NUM_ROWS_RANGE*ui+2;
+			//Shade every second entry
+			prop.displayShaded = ui&1;
 			p.addProperty(prop,curGroup);
 
 			std::pair<float,float > thisRange;
@@ -710,7 +707,9 @@ void RangeFileFilter::getProperties(FilterPropGroup &p) const
 			prop.data=rangeVal;
 			prop.type=PROPERTY_TYPE_REAL;
 			prop.helpText=TRANS("Start value for range");
-			prop.key=RANGE_KEY_ENABLE_ALL_RANGES + NUM_ROWS_RANGE*ui +3;
+			prop.key=KEY_ENABLE_ALL_RANGES + NUM_ROWS_RANGE*ui +3;
+			//Shade every second entry
+			prop.displayShaded = ui&1;
 			p.addProperty(prop,curGroup);
 		
 			stream_cast(rangeVal,thisRange.second);
@@ -718,7 +717,9 @@ void RangeFileFilter::getProperties(FilterPropGroup &p) const
 			prop.data=rangeVal;
 			prop.type=PROPERTY_TYPE_REAL;
 			prop.helpText=TRANS("Stopping value for range`");
-			prop.key=RANGE_KEY_ENABLE_ALL_RANGES+NUM_ROWS_RANGE*ui+4;
+			prop.key=KEY_ENABLE_ALL_RANGES+NUM_ROWS_RANGE*ui+4;
+			//Shade every second entry
+			prop.displayShaded = ui&1;
 			p.addProperty(prop,curGroup);
 		}
 		p.setGroupTitle(curGroup,TRANS("Ranges"));
@@ -736,7 +737,7 @@ bool RangeFileFilter::setProperty(unsigned int key,
 
 	switch(key)
 	{
-		case RANGE_KEY_RANGE_FILENAME:
+		case KEY_RANGE_FILENAME:
 		{
 			if(value != rngName)
 			{
@@ -766,13 +767,13 @@ bool RangeFileFilter::setProperty(unsigned int key,
 
 			break;
 		}
-		case RANGE_KEY_DROP_UNRANGED: //Enable/disable unranged dropping
+		case KEY_DROP_UNRANGED: //Enable/disable unranged dropping
 		{
 			if(!applyPropertyNow(dropUnranged,value,needUpdate))
 				return false;
 			break;
 		}	
-		case RANGE_KEY_ENABLE_LEGEND:
+		case KEY_ENABLE_LEGEND:
 		{
 			if(!cacheOK || !cache)
 			{
@@ -818,7 +819,7 @@ bool RangeFileFilter::setProperty(unsigned int key,
 			needUpdate=true;
 			break;
 		}	
-		case RANGE_KEY_ENABLE_ALL_RANGES:
+		case KEY_ENABLE_ALL_RANGES:
 		{
 
 			bool allEnable;
@@ -841,7 +842,7 @@ bool RangeFileFilter::setProperty(unsigned int key,
 
 			break;
 		}
-		case RANGE_KEY_ENABLE_ALL_IONS:
+		case KEY_ENABLE_ALL_IONS:
 		{
 
 			bool allEnable;
@@ -865,15 +866,15 @@ bool RangeFileFilter::setProperty(unsigned int key,
 		}
 		default:
 		{
-			if(key < RANGE_KEY_ENABLE_ALL_RANGES)
+			if(key < KEY_ENABLE_ALL_RANGES)
 			{
 				//structured group, each with NUM_ROWS_ION per grouping.
 				//The ion ID is simply the row number/NUM_ROWS_ION.
 				//similarly the element is given by remainder 
-				unsigned int ionID=((key-1)-RANGE_KEY_ENABLE_ALL_IONS)/NUM_ROWS_ION;
+				unsigned int ionID=((key-1)-KEY_ENABLE_ALL_IONS)/NUM_ROWS_ION;
 				ASSERT(ionID < rng.getNumIons());
-				ASSERT(key <=NUM_ROWS_ION*rng.getNumIons()+RANGE_KEY_ENABLE_ALL_IONS);
-				unsigned int prop = ((key-1)-RANGE_KEY_ENABLE_ALL_IONS)-ionID*NUM_ROWS_ION;
+				ASSERT(key <=NUM_ROWS_ION*rng.getNumIons()+KEY_ENABLE_ALL_IONS);
+				unsigned int prop = ((key-1)-KEY_ENABLE_ALL_IONS)-ionID*NUM_ROWS_ION;
 
 				switch(prop)
 				{
@@ -932,8 +933,8 @@ bool RangeFileFilter::setProperty(unsigned int key,
 			}
 			else
 			{
-				unsigned int rangeId=((key-1)-RANGE_KEY_ENABLE_ALL_RANGES)/NUM_ROWS_RANGE;
-				unsigned int prop = ((key-1)-RANGE_KEY_ENABLE_ALL_RANGES)-rangeId*NUM_ROWS_RANGE;
+				unsigned int rangeId=((key-1)-KEY_ENABLE_ALL_RANGES)/NUM_ROWS_RANGE;
+				unsigned int prop = ((key-1)-KEY_ENABLE_ALL_RANGES)-rangeId*NUM_ROWS_RANGE;
 				switch(prop)
 				{
 					//Range active
@@ -961,18 +962,19 @@ bool RangeFileFilter::setProperty(unsigned int key,
 					//Ion ID
 					case 1: 
 					{
-						unsigned int newID;
+						unsigned int newId;
+						newId=rng.getIonID(value);
 
-						if(stream_cast(newID,value))
+						if(newId== (unsigned int)-1) 
 							return false;
 
-						if(newID == rng.getIonID(rangeId))
+						if(newId == rng.getIonID(rangeId))
 							return false;
 
-						if(newID > rng.getNumRanges())
+						if(newId > rng.getNumRanges())
 							return false;
 
-						rng.setIonID(rangeId,newID);
+						rng.setIonID(rangeId,newId);
 						needUpdate=true;
 						break;
 					}
@@ -1381,6 +1383,10 @@ DrawStreamData *RangeFileFilter::createLegend() const
 }
 #ifdef DEBUG
 
+
+//Insert *non overlapping* ranges.
+const unsigned int RNG_NUM[]={10,14};
+const unsigned int RNG_OFFSET[]={0,20};
 bool testRanged();
 //bool testRangeWithOnOffs();
 bool testUnranged();
@@ -1398,6 +1404,28 @@ bool testUnranged()
 	return true;
 }
 
+RangeFile generateTestRange()
+{
+
+	//Now build some range data
+	RangeFile rng;
+
+	string longName,shortName;
+	
+	RGBf col;
+	col.red=col.green=col.blue=1;
+	shortName="Bl"; longName="Blahium";
+	unsigned int ionID;
+	ionID=rng.addIon(shortName,longName,col);
+	rng.addRange((float)RNG_OFFSET[0],(float)(RNG_OFFSET[0]+RNG_NUM[0]-1),ionID);
+
+	shortName="Pl"; longName="Palatherum";
+	ionID=rng.addIon(shortName,longName,col);
+	rng.addRange((float)RNG_OFFSET[1],(float)(RNG_OFFSET[1]+RNG_NUM[1]-1),ionID);
+
+	return rng;
+}
+
 bool testRanged()
 {
 	vector<const FilterStreamData*> streamIn,streamOut;
@@ -1416,25 +1444,7 @@ bool testRanged()
 	
 	streamIn.push_back(d);
 
-	//Now build some range data
-	RangeFile rng;
-
-	//Insert *non overlapping* ranges.
-	const unsigned int NUM[]={10,14};
-	const unsigned int OFFSET[]={0,20};
-	string longName,shortName;
-	
-	RGBf col;
-	col.red=col.green=col.blue=1;
-	shortName="Bl"; longName="Blahium";
-	unsigned int ionID;
-	ionID=rng.addIon(shortName,longName,col);
-	rng.addRange((float)OFFSET[0],(float)(OFFSET[0]+NUM[0]-1),ionID);
-
-	shortName="Pl"; longName="Palatherum";
-	ionID=rng.addIon(shortName,longName,col);
-	rng.addRange((float)OFFSET[1],(float)(OFFSET[1]+NUM[1]-1),ionID);
-
+	RangeFile rng=generateTestRange();
 	//-----
 
 	//Run the range filter
@@ -1469,9 +1479,9 @@ bool testRanged()
 
 	//Ion stream output - ranges + unranged
 	TEST(numIons.size() == 2, "Ranged ionstream count");
-	TEST(std::find(numIons.begin(),numIons.end(),NUM[0]) 
+	TEST(std::find(numIons.begin(),numIons.end(),RNG_NUM[0]) 
 			!= numIons.end(), "ion count test (1)");
-	TEST(std::find(numIons.begin(),numIons.end(),NUM[1]) 
+	TEST(std::find(numIons.begin(),numIons.end(),RNG_NUM[1]) 
 			!= numIons.end(), "ion count test (2)");
 	
 	for(unsigned int uj=0;uj<streamOut.size(); uj++)
