@@ -23,12 +23,12 @@
 
 enum
 {
-	RANGE_KEY_RANGE_ACTIVE=1,
-	RANGE_KEY_DROP_UNRANGED,
-	RANGE_KEY_RANGE_FILENAME,
-	RANGE_KEY_ENABLE_LEGEND,
-	RANGE_KEY_ENABLE_ALL_IONS, //Limited to ~100K ions
-	RANGE_KEY_ENABLE_ALL_RANGES=100000,
+	KEY_RANGE_ACTIVE=1,
+	KEY_DROP_UNRANGED,
+	KEY_RANGE_FILENAME,
+	KEY_ENABLE_LEGEND,
+	KEY_ENABLE_ALL_IONS, //Limited to ~100K ions
+	KEY_ENABLE_ALL_RANGES=100000,
 };
 
 //!Range file filter
@@ -72,7 +72,7 @@ class RangeFileFilter : public Filter
 		RangeFileFilter(); 
 		//!Duplicate filter contents, excluding cache.
 		Filter *cloneUncached() const;
-		void setRangeFilename(std::string filename){rngName=filename;};
+		void setRangeFilename(const std::string &filename){rngName=filename;};
 
 		//!Returns -1, as range file cache size is dependant upon input.
 		virtual size_t numBytesForCache(size_t nObjects) const;
