@@ -84,7 +84,7 @@ SpectrumPlotFilter::SpectrumPlotFilter()
 	minPlot=0;
 	maxPlot=150;
 	autoExtrema=true;	
-	binWidth=0.05;
+	binWidth=0.02;
 	plotStyle=0;
 	logarithmic=1;
 	fitMode=0;
@@ -423,6 +423,7 @@ unsigned int SpectrumPlotFilter::refresh(const std::vector<const FilterStreamDat
 
 	}
 
+	PlotStreamData *plotBack=0;
 	if(fitMode!= FIT_MODE_NONE)
 	{
 		BACKGROUND_PARAMS backParams;
@@ -466,7 +467,7 @@ unsigned int SpectrumPlotFilter::refresh(const std::vector<const FilterStreamDat
 					nBins,backParams.intensity,backgroundHist);
 
 				//Create a new plot which shows the spectrum's background
-				PlotStreamData *plotBack = new PlotStreamData;
+				plotBack = new PlotStreamData;
 				plotBack->parent = this;
 				plotBack->dataLabel=string(TRANS("Background:")) + d->dataLabel;	
 				plotBack->plotMode=d->plotMode;
@@ -484,14 +485,11 @@ unsigned int SpectrumPlotFilter::refresh(const std::vector<const FilterStreamDat
 					if(d->xyData[ui].first <=0)
 						continue;
 		
-					plotBack->xyData.push_back( std::make_pair(d->xyData[ui].first,
-							intensityPerBin/(2.0*sqrtf(d->xyData[ui].first))));
+					plotBack->xyData.emplace_back( d->xyData[ui].first,
+							intensityPerBin/(2.0*sqrtf(d->xyData[ui].first)));
 			
 				}
 
-				cacheAsNeeded(plotBack);
-
-				getOut.push_back(plotBack);
 			}
 			else
 			{
@@ -522,23 +520,52 @@ unsigned int SpectrumPlotFilter::refresh(const std::vector<const FilterStreamDat
 
 	if(normaliseMode != NORMALISE_NONE)
 	{
-		normalise(d->xyData);
+		float scaleFact;
+		scaleFact=normalise(d->xyData);
 		switch(normaliseMode)
 		{
 			case NORMALISE_MAX:
 			case NORMALISE_MAX_IN_BOUND:
 				d->yLabel=TRANS("Relative ") + d->yLabel;
+				if(plotBack)
+					plotBack->yLabel=TRANS("Relative ") + d->yLabel;
 				break;
 			case NORMALISE_INTEGRAL_ONE:
 				d->yLabel=TRANS("Probability Density"); 
-				
+				if(plotBack)
+					plotBack->yLabel=TRANS("Probability Density"); 
 				break;	
 
 			default:
 				ASSERT(false);
 
 		}
+
+		if(plotBack)
+		{
+			switch(fitMode)
+			{
+				case FIT_MODE_NONE:
+					//Do nothing
+					break;
+				case FIT_MODE_CONST_TOF:
+					for(unsigned int ui=0;ui<plotBack->xyData.size();ui++)
+						plotBack->xyData[ui].second/=scaleFact;
+					break;
+				default:
+					ASSERT(false);
+			}
+		}	
 	}	
+
+	if(plotBack)
+	{
+		cacheAsNeeded(plotBack);
+		getOut.push_back(plotBack);
+
+	}
+
+	
 	cacheAsNeeded(d);
 	
 	getOut.push_back(d);
@@ -549,13 +576,13 @@ unsigned int SpectrumPlotFilter::refresh(const std::vector<const FilterStreamDat
 }
 
 
-void SpectrumPlotFilter::normalise(vector<pair<float,float> > &xyData) const
+float SpectrumPlotFilter::normalise(vector<pair<float,float> > &xyData) const
 {
 	float scaleFact=0;
 	switch(normaliseMode)
 	{
 		case NORMALISE_NONE:
-			return;
+			return 1.0f;
 		case NORMALISE_MAX:
 			for(size_t ui=0;ui<xyData.size();ui++)
 			{
@@ -594,6 +621,8 @@ void SpectrumPlotFilter::normalise(vector<pair<float,float> > &xyData) const
 			xyData[ui].second/=scaleFact;
 		}
 	}
+
+	return scaleFact;
 }
 
 
@@ -635,7 +664,7 @@ void SpectrumPlotFilter::getProperties(FilterPropGroup &propertyList) const
 	for(unsigned int ui=0;ui<NORMALISE_ENUM_END;ui++)
 	{	
 		tmpStr=TRANS(NORMALISE_STRING[ui]);
-		choices.push_back(make_pair( ui,tmpStr));
+		choices.emplace_back( ui,tmpStr);
 	}
 	FilterProperty pNormalise(KEY_SPECTRUM_NORMALISE, TRANS("Normalisation"),
 		 choices,normaliseMode,TRANS("Rescale the plot height, to make inter-spectrum comparisons easier"));
@@ -658,7 +687,7 @@ void SpectrumPlotFilter::getProperties(FilterPropGroup &propertyList) const
 	for(unsigned int ui=PLOT_LINE_LINES; ui<PLOT_LINE_STEM+1;ui++)
 	{
 		tmpStr=plotString(ui);
-		choices.push_back(make_pair( ui,tmpStr));
+		choices.emplace_back( ui,tmpStr);
 	}
 	
 	FilterProperty pPlotType(KEY_SPECTRUM_PLOTTYPE, TRANS("Plot Type"),
@@ -677,7 +706,7 @@ void SpectrumPlotFilter::getProperties(FilterPropGroup &propertyList) const
 	for(unsigned int ui=0;ui<FIT_MODE_ENUM_END; ui++)
 	{
 		tmpStr=TRANS(BACKGROUND_MODE_STRING[ui]);
-		choices.push_back(make_pair(ui,tmpStr));
+		choices.emplace_back(ui,tmpStr);
 	}
 	
 	
@@ -959,7 +988,7 @@ bool SpectrumPlotFilter::setProperty( unsigned int key,
 		}
 		case KEY_SPECTRUM_NORMALISE:
 		{
-			unsigned int newMode;
+			unsigned int newMode=(unsigned int)-1;
 			for(size_t ui=0;ui<NORMALISE_ENUM_END; ui++)
 			{
 				if(string(NORMALISE_STRING[ui]) == string(value))
