@@ -277,11 +277,7 @@ unsigned int TransformFilter::refresh(const std::vector<const FilterStreamData *
 					}
 				}
 			}
-
-			if(numCentres)
-				vectorParams[0]=massCentre*1.0/(float)numCentres;
-			else
-				vectorParams[0]=massCentre;
+			vectorParams[0]=massCentre*1.0/(float)numCentres;
 			break;
 
 		}
@@ -1158,7 +1154,7 @@ void TransformFilter::getProperties(FilterPropGroup &propertyList) const
 	{
 	vector<pair<unsigned int,string> > choices;
 	for(unsigned int ui=0;ui<MODE_ENUM_END; ui++)
-		choices.push_back(make_pair(ui,TRANS(TRANSFORM_MODE_STRING[ui])));
+		choices.emplace_back(ui,TRANS(TRANSFORM_MODE_STRING[ui]));
 	FilterProperty pMode(KEY_MODE, TRANS("Mode"),
 			choices,transformMode,TRANS("Algorithm to use to transform point data"));
 	propertyList.addProperty(pMode,curGroup);
@@ -1173,7 +1169,7 @@ void TransformFilter::getProperties(FilterPropGroup &propertyList) const
 	{
 		vector<pair<unsigned int,string> > choices;
 		for(unsigned int ui=0;ui<ORIGINMODE_END;ui++)
-			choices.push_back(make_pair(ui,getOriginTypeString(ui)));
+			choices.emplace_back(ui,getOriginTypeString(ui));
 		
 		FilterProperty pOriginMode(KEY_ORIGINMODE, TRANS("Origin mode"),
 				choices,originMode,TRANS("Select how transform origin is computed"));
@@ -1281,7 +1277,7 @@ void TransformFilter::getProperties(FilterPropGroup &propertyList) const
 		{
 			vector<pair<unsigned int,string> > choices;
 			for(unsigned int ui=0;ui<NOISETYPE_END;ui++)
-				choices.push_back(make_pair(ui,getNoiseTypeString(ui)));
+				choices.emplace_back(ui,getNoiseTypeString(ui));
 			FilterProperty pNoiseType(KEY_NOISETYPE, TRANS("Noise Type"),
 							choices,noiseType,TRANS("Method to use to degrade point data"));
 			propertyList.addProperty(pNoiseType,curGroup);
@@ -1358,22 +1354,22 @@ bool TransformFilter::setProperty(  unsigned int key,
 			switch(transformMode)
 			{
 				case MODE_SCALE_ISOTROPIC:
-					vectorParams.push_back(Point3D(0,0,0));
+					vectorParams.emplace_back(Point3D(0,0,0));
 					scalarParams.push_back(1.0f);
 					break;
 				case MODE_SCALE_ANISOTROPIC:
-					vectorParams.push_back(Point3D(0,0,0));
-					vectorParams.push_back(Point3D(1,1,1));
+					vectorParams.emplace_back(Point3D(0,0,0));
+					vectorParams.emplace_back(Point3D(1,1,1));
 					break;
 				case MODE_TRANSLATE:
-					vectorParams.push_back(Point3D(0,0,0));
+					vectorParams.emplace_back(Point3D(0,0,0));
 					break;
 				case MODE_TRANSLATE_VALUE:
 					scalarParams.push_back(100.0f);
 					break;
 				case MODE_ROTATE:
-					vectorParams.push_back(Point3D(0,0,0));
-					vectorParams.push_back(Point3D(1,0,0));
+					vectorParams.emplace_back(Point3D(0,0,0));
+					vectorParams.emplace_back(Point3D(1,0,0));
 					scalarParams.push_back(0.0f);
 					break;
 				case MODE_VALUE_SHUFFLE:
