@@ -19,6 +19,8 @@
 #define VOXELISE_H
 #include "../filter.h"
 
+#include "filterCommon.h"
+
 #include "common/voxels.h"
 
 #include "../../common/translation.h"
@@ -51,10 +53,7 @@ private:
 	//This is filter's enabled ranges
 	RangeStreamData *rsdIncoming;
 	
-	ColourRGBAf rgba;
 
-	//!If using volume render mode, this is the transfer function to apply
-	std::vector<std::pair<float, ColourRGBAf>  > transferFunction;
 
 	//!Filter mode to apply to data before output
 	unsigned int filterMode;
@@ -65,44 +64,18 @@ private:
 	//!Gaussian filter standard deviation
 	float gaussDev;
 
-	//!3D Point Representation size
-	float splatSize;
+	//!Enable threshold based masking
+	bool thresholdMaskEnable;
 
-	//!Isosurface level
-	float isoLevel;
-	//!Default output representation mode
-	unsigned int representation;
-
-	//!Whether to use a built-in or custom colour map
-	bool builtinColourmap;
-
-	//!Colour map to use when using axial slices
-	unsigned int colourMap;
-
-	//Number of colour levels for colour map
-	size_t nColours;
-	//Whether to show the colour map bar or not
-	bool showColourBar;
-	//Whether to use an automatic colour bound, or to use user spec
-	bool autoColourMap;
-	//Colour map start/end
-	float colourMapBounds[2];
-
-	//Interpolation mode to use when slicing	
-	size_t sliceInterpolate;
-	//Axis that is normal to the slice 0,1,2 => x,y,z
-	size_t sliceAxis;
-	//Fractional offset from lower bound of data cube [0,1]
-	float sliceOffset;
+	//!Manually specified threshold value, in counts
+	unsigned int threshMaskValue;
 	
-	//Plane and normal for free slice. Note that the plane coordinate is in reduced voxel coords for each axis
-	Point3D freeSlicePlane,freeSliceNormal; 
+	//!Whether we should mask to max or min
+	bool threshMaskToMax;
 
+	//The view properties for the voxel
+	VoxelAppearanceProperties voxAppearance;
 
-	//Obtain a textured slice from the given voxel set
-	void getTexturedSlice(const Voxels<float> &f,
-		size_t axis,float offset, size_t interpolateMode,
-		float &minV, float &maxV, DrawTexturedQuad &texQ) const;
 
 	BoundCube lastBounds;
 
@@ -132,8 +105,6 @@ public:
 	static std::string getNormaliseTypeString(int type);
 	//!Get the human-readable options for filtering, based upon enum 
 	static std::string getFilterTypeString(int type);
-	//!Get the human-readable options for the visual representation (enum)
-	static std::string getRepresentTypeString(int type);
 	//!Get the human-readable options for boundary behaviour during filtering, based upon enum 
 	static std::string getFilterBoundTypeString(int type);
 	
@@ -182,7 +153,9 @@ public:
 			else nb[i] = (unsigned long long)((high[i] - low[i])/(float)widths[i]) + 1;
 		}
 	}
-
+#ifdef ENABLE_LIBVD 
+	bool curConfigurationIsExperimental() const;
+#endif
 	//FIXME: Hack. This is here to allow the export function to process this.
 	// the export function should actually look at the tree, and propagate manually
 	const Voxels<float> &peekCache() { return voxelCache;};
