@@ -290,6 +290,8 @@ const FilterTree &FilterTree::operator=(const FilterTree &orig)
 		(*it)=(*it)->cloneUncached();
 	}
 
+	//Ensure that we do not have any data from the original tree
+	initFilterTree();
 	return *this;
 }
 
@@ -354,6 +356,46 @@ void FilterTree::initFilterTree() const
 	}
 }
 
+void FilterTree::updateMonitor() 
+{
+	
+	
+	//Destroy any caches that belong to monitored filters that need
+	//refreshing. Failing to do this can lead to filters being skipped
+	//during the refresh 
+	for(tree<Filter *>::iterator filterIt=filters.begin();
+			filterIt!=filters.end();++filterIt)
+	{
+		//We need to clear the cache of *all* 
+		//downstream filters, as otherwise
+		//their cache's could block our update.
+		if((*filterIt)->monitorNeedsRefresh())
+		{
+			for(tree<Filter *>::pre_order_iterator it(filterIt);it!= filters.end(); ++it)
+			{
+				//Do not traverse siblings
+				if(filters.depth(filterIt) >= filters.depth(it) && it!=filterIt )
+					break;
+			
+				(*it)->clearCache();
+			}
+		}
+	}
+	
+	
+	//Go through each filter, and update the internal monitor status for that filter
+	// This is to prevent filters from looping in case of an error (demand refresh, error, demand refresh again)
+	for(tree<Filter * >::pre_order_iterator filtIt=filters.begin();
+					filtIt!=filters.end(); ++filtIt)
+	{
+		Filter *f;
+		f=*filtIt;
+
+		if(f->monitorNeedsRefresh())
+			f->updateMonitor();
+	}
+}
+
 void FilterTree::clear() 
 {
 	for(tree<Filter *>::iterator filterIt=filters.begin();
@@ -582,7 +624,7 @@ void FilterTree::getFilterRefreshStarts(vector<tree<Filter *>::iterator > &propS
 unsigned int FilterTree::refreshFilterTree(list<FILTER_OUTPUT_DATA > &outData, 
 		std::vector<SelectionDevice *> &devices,
 		vector<ConsoleMessage > &consoleMessages,
-	       	ProgressData &curProg, ATOMIC_BOOL &abortRefresh) const
+	       	ProgressData &curProg, ATOMIC_BOOL &abortRefresh) 
 {
 
 	//initially, we should not want to abort refreshing 
@@ -599,29 +641,13 @@ unsigned int FilterTree::refreshFilterTree(list<FILTER_OUTPUT_DATA > &outData,
 	if(!filters.size())
 		return 0;	
 
-	//Destroy any caches that belong to monitored filters that need
-	//refreshing. Failing to do this can lead to filters being skipped
-	//during the refresh 
-	for(tree<Filter *>::iterator filterIt=filters.begin();
-			filterIt!=filters.end();++filterIt)
-	{
-		//We need to clear the cache of *all* 
-		//downstream filters, as otherwise
-		//their cache's could block our update.
-		if((*filterIt)->monitorNeedsRefresh())
-		{
-			for(tree<Filter *>::pre_order_iterator it(filterIt);it!= filters.end(); ++it)
-			{
-				//Do not traverse siblings
-				if(filters.depth(filterIt) >= filters.depth(it) && it!=filterIt )
-					break;
-			
-				(*it)->clearCache();
-			}
-		}
-	}
 
+	//Update all the internal state for filters
+	// which are using the "monitor" feature
+	updateMonitor();
 
+	//Run a pre-refresh initialisation, which propagates things like
+	// rangefiles
 	initFilterTree();
 
 	// -- Build data streams --	
@@ -634,6 +660,7 @@ unsigned int FilterTree::refreshFilterTree(list<FILTER_OUTPUT_DATA > &outData,
 	inDataStack.push(curData);
 
 
+	//Identify the filters that are data exits (leaf filters)
 	std::set<Filter*> leafFilters;
 	for(tree<Filter*>::leaf_iterator  it=filters.begin_leaf();
 			it!=filters.end_leaf(); ++it)
@@ -649,7 +676,28 @@ unsigned int FilterTree::refreshFilterTree(list<FILTER_OUTPUT_DATA > &outData,
 	getFilterRefreshStarts(baseTreeNodes);
 	curProg.totalNumFilters=countChildFilters(filters,baseTreeNodes)+baseTreeNodes.size();
 
+	//The number of sub-steps in each prgoress entry
+	vector<unsigned int> nStepsProgress;
 
+	//Looping over the filters, find the number of steps each filter will take, if we can.
+	// may not be possible fr all filters.
+	for(auto itPos=0u; itPos < baseTreeNodes.size();itPos++)
+	{
+		//Depth-first search from root node, refreshing filters as we proceed.
+		for(tree<Filter * >::pre_order_iterator filtIt=baseTreeNodes[itPos];
+						filtIt!=filters.end(); ++filtIt)
+		{
+			//Check to see if this node is a child of the base node.
+			//if not, move on.
+			if( filtIt!= baseTreeNodes[itPos] &&
+				!isChild(filters,baseTreeNodes[itPos],filtIt))
+				continue;
+
+			nStepsProgress.push_back((*filtIt)->getNumSteps());
+		}
+	}
+	ASSERT(nStepsProgress.size() ==curProg.totalNumFilters);
+	curProg.estimatedSteps=nStepsProgress;
 
 	for(unsigned int itPos=0;itPos<baseTreeNodes.size(); itPos++)
 	{
@@ -853,7 +901,7 @@ unsigned int FilterTree::refreshFilterTree(list<FILTER_OUTPUT_DATA > &outData,
 			else if(curData.size())
 			{
 				//The filter has created an output. Record it for passing to updateScene
-				outData.push_back(make_pair(currentFilter,curData));
+				outData.emplace_back(currentFilter,curData);
 				refreshCollector.forgetPointers(curData);
 			}	
 			//Cur data is recorded either in outData or on the data stack
@@ -929,27 +977,10 @@ bool FilterTree::setFilterProperty(Filter *targetFilter, unsigned int key,
 	//modify the downstream objects
 	if(needUpdate)
 	{
-		for(tree<Filter * >::pre_order_iterator filtIt=filters.begin();
-						filtIt!=filters.end(); ++filtIt)
-		{
-			if(targetFilter == *filtIt)
-			{
-				//Kill all cache below filtIt
-				for(tree<Filter *>::pre_order_iterator it(filtIt);it!= filters.end(); ++it)
-				{
-					//Do not traverse siblings
-					if(filters.depth(filtIt) >= filters.depth(it) && it!=filtIt )
-						break;
-
-					//Do not clear the cache for the target filter. 
-					//This is the responsibility of the setProperty function for the filter
-					if(*it !=targetFilter)
-						(*it)->clearCache();
-				}
-				break;
-			}
-		}
-
+		//Do not clear the cache for the target filter. 
+		//This is the responsibility of the setProperty function for the filter
+		// as it may know that it can do trickery to avoid an unnecessary invalidation
+		clearCache(targetFilter,false);
 	}
 
 	initFilterTree();
@@ -1498,12 +1529,12 @@ void FilterTree::safeDeleteFilterList( std::list<FILTER_OUTPUT_DATA> &outData,
 						size_t typeMask, bool maskPrevents) 
 {
 	//Loop through the list of vectors of filterstreamdata, then drop any elements that are deleted
+	// Note the No-op at the loop iterator. this is needed so we can safely .erase()
 	for(list<FILTER_OUTPUT_DATA> ::iterator it=outData.begin(); 
 							it!=outData.end(); ) 
 	{
 		vector<bool> killV;
 		killV.resize(it->second.size(),false);
-		//Note the No-op at the loop iterator. this is needed so we can safely .erase()
 		for(size_t ui=0;ui<it->second.size();ui++)
 		{
 			const FilterStreamData* f;
@@ -1512,7 +1543,7 @@ void FilterTree::safeDeleteFilterList( std::list<FILTER_OUTPUT_DATA> &outData,
 			//NOTE: the XOR flips the action of the mask. if maskprevents is true, then this logical switch
 			//prevents the masked item from being deleted. If not, ONLY the masked types are deleted.
 			//In any case, a zero mask makes this whole thing not do anything, and everything gets deleted.
-			if(typeMask && ( ((bool)(f->getStreamType() & typeMask)) ^ !maskPrevents)) 
+			if(typeMask && ( XOR(((bool)(f->getStreamType() & typeMask)) , !maskPrevents))) 
 				continue;
 			
 			//Output data is uncached - delete it
@@ -1787,7 +1818,9 @@ void FilterTree::cloneSubtree(FilterTree &f,const Filter *targetFilt) const
 	for(tree<Filter*>::iterator it=f.filters.begin();it!=f.filters.end(); ++it)
 		*it= (*it)->cloneUncached();
 
-	
+	//Run initialisation code, to ensure we don't have any trailing
+	// information from ouroriginal tree
+	f.initFilterTree();	
 }
 
 void FilterTree::setCachePercent(unsigned int newCache)
@@ -1952,6 +1985,22 @@ void FilterTree::clearCache(const Filter *filter,bool includeSelf)
 	}
 }
 
+
+void FilterTree::propagateInvalidCaches()
+{
+	vector<Filter *> clearBase;
+	for(tree<Filter * >::iterator it=filters.begin(); 
+					it!=filters.end(); ++it)
+	{
+		if((*it)->haveCache())
+			clearBase.push_back((*it));
+	}
+
+	//Clear the child caches
+	for( auto f : clearBase)
+		clearCache(f,false);
+}
+
 void FilterTree::clearCacheByType(unsigned int type)
 {
 	//Build a list of all filters who we need to invalidate
