@@ -116,6 +116,9 @@ class FilterTree
 		//---	
 		//!Run the initialisation stage of the filter processing
 		void initFilterTree() const;
+		
+		//!Update all of the monitor data in the filter tree
+		void updateMonitor();
 
 		bool setFilterProperty(Filter *f, unsigned int key,
 				const std::string &value, bool &needUpdate);
@@ -126,7 +129,7 @@ class FilterTree
 		unsigned int refreshFilterTree(	
 			std::list<FILTER_OUTPUT_DATA> &outData,
 			std::vector<SelectionDevice *> &devices,std::vector<ConsoleMessage > &consoleMessages,
-						ProgressData &curProg, ATOMIC_BOOL &abortRefresh) const;
+						ProgressData &curProg, ATOMIC_BOOL &abortRefresh);
 
 		static std::string getRefreshErrString(unsigned int errCode);
 		
@@ -200,6 +203,10 @@ class FilterTree
 		//!Invalidate the cache of a given Filter and all its children. 
 		// set to 0 to clear all.
 		void clearCache(const Filter *filt,bool includeSelf=true);
+
+		//!Invalidate the caches of any filters which are children of filters
+		// with invalid caches
+		void propagateInvalidCaches();
 		
 		
 		//!Invalidate the cache of a given type of filter
