@@ -1,6 +1,6 @@
 /*
  *	filtertreeAnalyse.cpp - Performs correctness checking of filter trees
- *	Copyright (C) 2015, D Haley 
+ *	Copyright (C) 2018, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -178,6 +178,8 @@ void FilterTreeAnalyse::analyse(const FilterTree &f)
 	//check for unranged data required by child
 	checkUnrangedData(f);
 
+	//Check root filters are data source
+	checkRootIsDataSource(f);
 
 	emitTypes.clear();
 	blockTypes.clear();
@@ -515,6 +517,23 @@ bool filterAltersComposition(const Filter *f)
 	return affectsComposition;
 }
 
+void FilterTreeAnalyse::checkRootIsDataSource(const FilterTree &f)
+{
+	const tree<Filter *> &treeFilt=f.getTree();
+	for(tree<Filter*>::sibling_iterator it = treeFilt.begin(); it!=treeFilt.end(); ++it)
+	{
+		if(!(*it)->isPureDataSource())
+		{
+			FILTERTREE_ERR treeErr;
+			treeErr.reportedFilters.push_back(*it);
+			treeErr.verboseReportMessage = TRANS("Filter cannot generate data, but has no input - it is at the tree base.");
+			treeErr.shortReportMessage = TRANS("Non data-generating filter at root");
+			treeErr.severity=ANALYSE_SEVERITY_ERROR; //This is definitely a bad thing.
+			analysisResults.push_back(treeErr);
+		}
+	}
+}
+
 bool filterAffectedByComposition(const Filter *f, bool haveRngParent)
 {
 	FilterPropGroup props;
