@@ -174,12 +174,14 @@ string plotErrmodeString(unsigned int plotID)
 PlotRegion::PlotRegion()
 {
 	accessMode=ACCESS_MODE_ENUM_END;
-	parentObject=0;
+	parentObject=nullptr;
+	id=(unsigned int)-1;
 }
 
 PlotRegion::PlotRegion(size_t updateAccessMode,void *parentObj)
 {
 	setUpdateMethod(updateAccessMode,parentObj);
+	id=(unsigned int)-1;
 }
 
 void PlotRegion::setUpdateMethod(size_t updateAccessMode,void *parentObj)
@@ -209,6 +211,7 @@ void PlotRegion::updateParent(size_t regionChangeType,
 {
 	ASSERT(newPositions.size() >= bounds.size());
 	ASSERT(parentObject);
+	ASSERT(id !=(unsigned int)-1);
 
 	//Update the parent object, using the requested access mode for the parent
 	switch(accessMode)
@@ -328,8 +331,8 @@ PlotWrapper::PlotWrapper()
 
 PlotWrapper::~PlotWrapper()
 {
-	for(size_t ui=0;ui<plottingData.size();ui++)
-		delete plottingData[ui];
+	for(auto & data : plottingData)
+		delete data;
 }
 
 const PlotWrapper &PlotWrapper::operator=(const PlotWrapper &p)
@@ -365,6 +368,13 @@ const PlotWrapper &PlotWrapper::operator=(const PlotWrapper &p)
 	return *this;
 }
 
+void PlotWrapper::setRegionGroup(size_t plotId,RegionGroup &r)
+{
+	size_t offset=plotIDHandler.getPos(plotId);
+	//Overwrite the plot's region group
+	plottingData[offset]->regionGroup=r;
+}
+
 std::string PlotWrapper::getTitle(size_t plotId) const
 {
 	unsigned int plotPos=plotIDHandler.getPos(plotId);
@@ -386,6 +396,19 @@ size_t PlotWrapper::getParentType(size_t plotId) const
 	
 }
 
+void PlotWrapper::clearFilterCache(unsigned int plotV, unsigned int regionID)
+{
+	ASSERT(plotV < plottingData.size());
+
+	RegionGroup *rg;
+	rg= &(plottingData[plotV]->regionGroup);
+
+	ASSERT(regionID < rg->regions.size());
+	Filter *parentFilt = rg->regions[regionID].getParentAsFilter();
+
+	parentFilt->clearCache();
+}
+
 unsigned int PlotWrapper::addPlot(PlotBase *p)
 {
 #ifdef DEBUG
@@ -413,8 +436,8 @@ void PlotWrapper::clear(bool preserveVisiblity)
 		{
 			if(plottingData[ui]->visible && plottingData[ui]->parentObject)
 			{
-				lastVisiblePlots.push_back(std::make_pair(plottingData[ui]->parentObject,
-								plottingData[ui]->parentPlotIndex));
+				lastVisiblePlots.emplace_back(plottingData[ui]->parentObject,
+								plottingData[ui]->parentPlotIndex);
 			}
 		}
 	}
@@ -423,8 +446,8 @@ void PlotWrapper::clear(bool preserveVisiblity)
 
 
 	//Free the plotting data pointers
-	for(size_t ui=0;ui<plottingData.size();ui++)
-		delete plottingData[ui];
+	for(auto & data : plottingData)
+		delete data;
 
 	plottingData.clear();
 	plotIDHandler.clear();
@@ -525,15 +548,15 @@ void PlotWrapper::scanBounds(float &xMin,float &xMax,float &yMin,float &yMax) co
 	yMin=std::numeric_limits<float>::max();
 	yMax=-std::numeric_limits<float>::max();
 
-	for(unsigned int uj=0;uj<plottingData.size(); uj++)
+	for(auto data : plottingData)
 	{
 		//only consider the bounding boxes from visible plots
-		if(!plottingData[uj]->visible)
+		if(!data->visible)
 			continue;
 
 		//Expand our bounding box to encompass that of this visible plot
 		float tmpXMin,tmpXMax,tmpYMin,tmpYMax;
-		plottingData[uj]->getBounds(tmpXMin,tmpXMax,tmpYMin,tmpYMax);
+		data->getBounds(tmpXMin,tmpXMax,tmpYMin,tmpYMax);
 
 		xMin=std::min(xMin,tmpXMin);
 		xMax=std::max(xMax,tmpXMax);
@@ -550,17 +573,17 @@ void PlotWrapper::bestEffortRestoreVisibility()
 	//Try to match up the last visible plots to the
 	//new plots. Use index and owner as guiding data
 
-	for(unsigned int uj=0;uj<plottingData.size(); uj++)
-		plottingData[uj]->visible=false;
+	for(auto & data : plottingData)
+		data->visible=false;
 	
-	for(unsigned int ui=0; ui<lastVisiblePlots.size();ui++)
+	for(auto & lastVisiblePlot : lastVisiblePlots)
 	{
-		for(unsigned int uj=0;uj<plottingData.size(); uj++)
+		for(auto & data : plottingData)
 		{
-			if(plottingData[uj]->parentObject == lastVisiblePlots[ui].first
-				&& plottingData[uj]->parentPlotIndex == lastVisiblePlots[ui].second)
+			if(data->parentObject == lastVisiblePlot.first
+				&& data->parentPlotIndex == lastVisiblePlot.second)
 			{
-				plottingData[uj]->visible=true;
+				data->visible=true;
 				break;
 			}
 		
@@ -596,12 +619,12 @@ void PlotWrapper::getAppliedBounds(mglPoint &min, mglPoint &max) const
 		minY=std::numeric_limits<float>::max();
 		maxY=-std::numeric_limits<float>::max();
 		
-		for(unsigned int ui=0;ui<plottingData.size(); ui++)
+		for(auto data : plottingData)
 		{
-			if(plottingData[ui]->visible)
+			if(data->visible)
 			{
 				float tmpMinX,tmpMinY,tmpMaxX,tmpMaxY;
-				plottingData[ui]->getBounds(
+				data->getBounds(
 					tmpMinX,tmpMaxX,tmpMinY,tmpMaxY);
 
 				minX=std::min(minX,tmpMinX);
@@ -751,33 +774,33 @@ void PlotWrapper::drawPlot(mglGraph *gr, bool &haveUsedLog) const
 	//Compute the bounding box in data coordinates	
 	std::string xLabel,yLabel,plotTitle;
 
-	for(unsigned int ui=0;ui<plottingData.size(); ui++)
+	for(auto data : plottingData)
 	{
-		if(plottingData[ui]->visible)
+		if(data->visible)
 		{
 
 			if(!xLabel.size())
-				xLabel=plottingData[ui]->getXLabel();
+				xLabel=data->getXLabel();
 			else
 			{
 
-				if(xLabel!=plottingData[ui]->getXLabel())
+				if(xLabel!=data->getXLabel())
 					xLabel=string(TRANS("Multiple data types"));
 			}
 			if(!yLabel.size())
-				yLabel=plottingData[ui]->getYLabel();
+				yLabel=data->getYLabel();
 			else
 			{
 
-				if(yLabel!=plottingData[ui]->getYLabel())
+				if(yLabel!=data->getYLabel())
 					yLabel=string(TRANS("Multiple data types"));
 			}
 			if(!haveMultiTitles && !plotTitle.size())
-				plotTitle=plottingData[ui]->getTitle();
+				plotTitle=data->getTitle();
 			else
 			{
 
-				if(plotTitle!=plottingData[ui]->getTitle())
+				if(plotTitle!=data->getTitle())
 				{
 					plotTitle="";
 					haveMultiTitles=true;
@@ -812,15 +835,15 @@ void PlotWrapper::drawPlot(mglGraph *gr, bool &haveUsedLog) const
 			bool useLogPlot=false;
 
 		
-			for(unsigned int ui=0;ui<plottingData.size(); ui++)
+			for(auto data : plottingData)
 			{
-				if(!plottingData[ui]->visible)
+				if(!data->visible)
 					continue;
 
-				if(plottingData[ui]->getMode()!= PLOT_MODE_1D)
+				if(data->getMode()!= PLOT_MODE_1D)
 					continue;
 			
-				if(((Plot1D*)plottingData[ui])->wantLogPlot()) 
+				if(((Plot1D*)data)->wantLogPlot()) 
 					useLogPlot=true;
 			}
 
@@ -834,13 +857,13 @@ void PlotWrapper::drawPlot(mglGraph *gr, bool &haveUsedLog) const
 			if(min.y == 0 && useLogPlot)
 			{
 				float minYVal=0.1;
-				for(size_t ui=0;ui<plottingData.size();ui++)
+				for(auto data : plottingData)
 				{
-					if(!plottingData[ui]->visible || plottingData[ui]->getMode() !=PLOT_MODE_1D)
+					if(!data->visible || data->getMode() !=PLOT_MODE_1D)
 						continue;
 
 					float tmp ;
-					tmp=((Plot1D*)plottingData[ui])->getSmallestNonzero();
+					tmp=((Plot1D*)data)->getSmallestNonzero();
 					if(tmp >0)
 						minYVal=std::min(tmp,minYVal);
 
@@ -872,13 +895,13 @@ void PlotWrapper::drawPlot(mglGraph *gr, bool &haveUsedLog) const
 			//---
 
 			//Loop through the plots, drawing them as needed
-			for(unsigned int ui=0;ui<plottingData.size();ui++)
+			for(auto data : plottingData)
 			{
-				if(plottingData[ui]->getPlotMode() != PLOT_MODE_1D)
+				if(data->getPlotMode() != PLOT_MODE_1D)
 					continue;
 
 				Plot1D *curPlot;
-				curPlot=(Plot1D*)plottingData[ui];
+				curPlot=(Plot1D*)data;
 
 				//If a plot is not visible, it cannot own a region
 				//nor have a legend in this run.
@@ -914,12 +937,12 @@ void PlotWrapper::drawPlot(mglGraph *gr, bool &haveUsedLog) const
 				rMinY = max.y + (max.y-min.y)*(ABOVE_AXIS_CONST-0.025);
 				rMaxY = max.y + (max.y-min.y)*(ABOVE_AXIS_CONST+0.025);
 
-				for(size_t ui=0; ui<overlapXCoords.size();ui++)
+				for(auto & overlapXCoord : overlapXCoords)
 				{
 					float rMinX, rMaxX; 
 					
-					rMinX=overlapXCoords[ui].first;
-					rMaxX=overlapXCoords[ui].second;
+					rMinX=overlapXCoord.first;
+					rMaxX=overlapXCoord.second;
 
 
 					//Make sure we don't leave the plot boundary
@@ -949,12 +972,12 @@ void PlotWrapper::drawPlot(mglGraph *gr, bool &haveUsedLog) const
 			
 			gr->Axis();
 			bool wantColourbar=false;
-			for(unsigned int ui=0;ui<plottingData.size();ui++)
+			for(auto data : plottingData)
 			{
-				if(!plottingData[ui]->visible)
+				if(!data->visible)
 					continue;
 				Plot2DFunc *curPlot;
-				curPlot=(Plot2DFunc*)plottingData[ui];
+				curPlot=(Plot2DFunc*)data;
 
 				if(curPlot->getMode() == PLOT_2D_DENS)
 				{
@@ -989,8 +1012,8 @@ void PlotWrapper::drawPlot(mglGraph *gr, bool &haveUsedLog) const
 
 void PlotWrapper::hideAll()
 {
-	for(unsigned int ui=0;ui<plottingData.size(); ui++)
-		plottingData[ui]->visible=false;
+	for(auto & data : plottingData)
+		data->visible=false;
 	plotChanged=true;
 }
 
@@ -1042,10 +1065,10 @@ void PlotWrapper::getRegionOverlaps(vector<pair<size_t,size_t> > &ids,
 	ids.clear();
 	coords.clear();
 
-	for(size_t uk=0;uk<plottingData.size(); uk++)
+	for(auto data : plottingData)
 	{
 		RegionGroup *r;
-		r=&(plottingData[uk]->regionGroup);
+		r=&(data->regionGroup);
 
 		r->getOverlaps(ids,coords);
 	}
@@ -1054,9 +1077,9 @@ void PlotWrapper::getRegionOverlaps(vector<pair<size_t,size_t> > &ids,
 unsigned int PlotWrapper::getNumVisible() const
 {
 	unsigned int num=0;
-	for(unsigned int ui=0;ui<plottingData.size();ui++)
+	for(auto data : plottingData)
 	{
-		if(plottingData[ui]->visible)
+		if(data->visible)
 			num++;
 	}
 	
@@ -1086,18 +1109,18 @@ void PlotWrapper::moveRegion(unsigned int plotID, unsigned int regionId, bool re
 void PlotWrapper::switchOutRegionParent(std::map<const RangeFileFilter *, RangeFile> &switchMap)
 {
 
-	for(size_t ui=0;ui<plottingData.size();ui++)
+	for(auto & data : plottingData)
 	{
 		PlotBase *pb;
-		pb=plottingData[ui];
+		pb=data;
 		
 		RegionGroup *rg;
 		rg = &(pb->regionGroup);
-		for(size_t uj=0; uj<rg->regions.size();uj++)
+		for(auto & region : rg->regions)
 		{
 			//Obtain the parent filter f rthis region, then re-map it
 			// to the rangefile
-			Filter *parentFilt = rg->regions[uj].getParentAsFilter();
+			Filter *parentFilt = region.getParentAsFilter();
 
 			if(parentFilt->getType() != FILTER_TYPE_RANGEFILE)
 				continue;
@@ -1106,7 +1129,7 @@ void PlotWrapper::switchOutRegionParent(std::map<const RangeFileFilter *, RangeF
 			ASSERT(switchMap.find(rngFilt) != switchMap.end());
 
 			//Set the update method to use the new rangefile
-			rg->regions[uj].setUpdateMethod(PlotRegion::ACCESS_MODE_RANGEFILE,
+			region.setUpdateMethod(PlotRegion::ACCESS_MODE_RANGEFILE,
 						&(switchMap[rngFilt]));
 		}
 	}
@@ -1248,7 +1271,7 @@ Plot1D::Plot1D()
 
 PlotBase *Plot1D::clone() const
 {
-	Plot1D *p = new Plot1D;
+	auto p = new Plot1D;
 
 	p->logarithmic=logarithmic;
 	p->xValues=xValues;
@@ -1636,7 +1659,7 @@ void Plot1D::getRawData(std::vector<std::vector< float> > &rawData,
 		
 		rawData.push_back(dummy);
 		rawData.back().swap(tmp);
-		labels.push_back(string(TRANS("error")));
+		labels.emplace_back(TRANS("error"));
 	}
 }
 
@@ -1647,21 +1670,21 @@ void Plot1D::drawRegions(mglGraph *gr,
 	//Mathgl palette colour name
 	string colourCode;
 
-	for(unsigned int uj=0;uj<regionGroup.regions.size();uj++)
+	for(const auto & region : regionGroup.regions)
 	{
 		//Compute region bounds, such that it will not exceed the axis
 		float rMinX, rMaxX, rMinY,rMaxY;
 		rMinY = min.y;
 		rMaxY = max.y;
-		rMinX = std::max((float)min.x,regionGroup.regions[uj].bounds[0].first);
-		rMaxX = std::min((float)max.x,regionGroup.regions[uj].bounds[0].second);
+		rMinX = std::max((float)min.x,region.bounds[0].first);
+		rMaxX = std::min((float)max.x,region.bounds[0].second);
 		
 		//Prevent drawing inverted regionGroup.regions
 		if(rMaxX > rMinX && rMaxY > rMinY)
 		{
-			colourCode = mglColourCode(regionGroup.regions[uj].r,
-						regionGroup.regions[uj].g,
-						regionGroup.regions[uj].b);
+			colourCode = mglColourCode(region.r,
+						region.g,
+						region.b);
 			gr->FaceZ(mglPoint(rMinX,rMinY,-1),rMaxX-rMinX,rMaxY-rMinY,
 					colourCode.c_str());
 					
@@ -1672,10 +1695,10 @@ void Plot1D::drawRegions(mglGraph *gr,
 float Plot1D::getSmallestNonzero() const
 {
 	float minNonzero=std::numeric_limits<float>::max();
-	for(size_t ui=0;ui<yValues.size();ui++)
+	for(float yValue : yValues)
 	{
-		if(yValues[ui] > 0)
-			minNonzero=std::min(yValues[ui] ,minNonzero);
+		if(yValue > 0)
+			minNonzero=std::min(yValue ,minNonzero);
 	}
 
 	if(minNonzero == std::numeric_limits<float>::max())
@@ -1693,6 +1716,8 @@ Plot2DFunc::Plot2DFunc()
 	traceStyle=PLOT_2D_DENS;
 	wantLog=false;
 	wantColourbar=false;
+	wantFixedAspect=false;
+	aspectRatio=1;
 }
 
 void Plot2DFunc::setData(const Array2D<float> &a,
@@ -1713,7 +1738,7 @@ bool Plot2DFunc::isEmpty() const
 
 PlotBase * Plot2DFunc::clone() const
 {
-	Plot2DFunc *pb = new Plot2DFunc;
+	auto pb = new Plot2DFunc;
 
 	pb->xyValues=xyValues;
 
@@ -1790,7 +1815,12 @@ void Plot2DFunc::drawPlot(mglGraph *graph) const
 		colourStr+=mglColourCode(rgb[0]/255.0f,rgb[1]/255.0f,rgb[2]/255.0f,pos);
 	}
 
+	//Do we want a fixed aspect ratio?
+	if(wantFixedAspect)
+		graph->Aspect(1.0f,aspectRatio);
+
 	graph->Axis("xy");
+
 	graph->SetCut(false);
 	graph->SetRange('c',minV,maxV); //set colour range
 	string mglStr;
@@ -1821,6 +1851,8 @@ Plot2DScatter::Plot2DScatter()
 	traceStyle=PLOT_2D_SCATTER;
 	plotMode=PLOT_MODE_2D;
 	scatterIntensityLog=false;
+	r=g=0;
+	b=1;
 }
 
 void Plot2DScatter::setData(const vector<pair<float,float> > &f) 
@@ -1843,7 +1875,7 @@ bool Plot2DScatter::isEmpty() const
 
 PlotBase *Plot2DScatter::clone() const
 {
-	Plot2DScatter *pb = new Plot2DScatter;
+	auto pb = new Plot2DScatter;
 
 	pb->points=points;
 
@@ -1883,7 +1915,7 @@ void Plot2DScatter::drawPlot(mglGraph *graph) const
 
 	if(intensity.empty())
 	{
-		float *bufSize = new float[points.size()];
+		auto bufSize = new float[points.size()];
 		for(unsigned int ui=0;ui<points.size();ui++)
 			bufSize[ui]=1;
 		sizeDat.Set(bufSize,points.size());
@@ -1898,7 +1930,7 @@ void Plot2DScatter::drawPlot(mglGraph *graph) const
 		else
 		{	
 			//if plotting in log mode, do so!
-			float *bufSize = new float[intensity.size()];
+			auto bufSize = new float[intensity.size()];
 			for(unsigned int ui=0;ui<intensity.size();ui++)
 				bufSize[ui]=log10f(intensity[ui]+1.0f);
 			sizeDat.Set(bufSize,intensity.size());
@@ -1986,17 +2018,17 @@ void RegionGroup::addRegion(unsigned int regionID,const std::string &name, float
 
 	PlotRegion region(PlotRegion::ACCESS_MODE_FILTER,parentFilter);
 	//1D plots only have one bounding direction
-	region.bounds.push_back(std::make_pair(start,end));
+	region.bounds.emplace_back(start,end);
 	//Set the ID for the  region
 	region.id = regionID;
 	region.label=name;
 #ifdef DEBUG
 	//Ensure ID value is unique per parent
-	for(size_t ui=0;ui<regions.size();ui++)
+	for(auto & region : regions)
 	{
-		if(regions[ui].getParentAsFilter()== parentFilter)
+		if(region.getParentAsFilter()== parentFilter)
 		{
-			ASSERT(regionID !=regions[ui].id);
+			ASSERT(regionID !=region.id);
 		}
 	}
 #endif
@@ -2121,9 +2153,8 @@ void RegionGroup::getOverlaps(vector<pair<size_t,size_t> > &ids,
 				// and their coordinates, in plot units
 				if(rangesOverlap(minA,maxA,minB,maxB))
 				{
-					overlapIdCache.push_back(make_pair(ui,uj));
-					overlapCoordsCache.push_back(
-						make_pair(std::max(minA,minB),std::min(maxA,maxB)) );
+					overlapIdCache.emplace_back(ui,uj);
+					overlapCoordsCache.emplace_back(std::max(minA,minB),std::min(maxA,maxB));
 				}
 			}
 		}
@@ -2132,22 +2163,16 @@ void RegionGroup::getOverlaps(vector<pair<size_t,size_t> > &ids,
 	}
 
 	ids.reserve(ids.size() + overlapIdCache.size());
-	for(unsigned int ui=0;ui<overlapIdCache.size();ui++)
-		ids.push_back(overlapIdCache[ui]);
+	for(auto & id : overlapIdCache)
+		ids.push_back(id);
 
 	coords.reserve(coords.size() + overlapCoordsCache.size());
-	for(unsigned int ui=0;ui<overlapCoordsCache.size();ui++)
-		coords.push_back(overlapCoordsCache[ui]);
+	for(auto & coord : overlapCoordsCache)
+		coords.push_back(coord);
 
 }
 
 
-void PlotWrapper::setRegionGroup(size_t plotId,RegionGroup &r)
-{
-	size_t offset=plotIDHandler.getPos(plotId);
-	//Overwrite the plot's region group
-	plottingData[offset]->regionGroup=r;
-}
 
 
 void PlotOverlays::draw(mglGraph *gr,
@@ -2162,27 +2187,27 @@ void PlotOverlays::draw(mglGraph *gr,
 	//Draw the overlays in black
 	colourCode = mglColourCode(0.0,0.0,0.0);
 	
-	for(size_t ui=0;ui<overlayData.size();ui++)
+	for(const auto & data : overlayData)
 	{
-		if(!overlayData[ui].enabled)
+		if(!data.enabled)
 			continue;
 
 		vector<float> bufX,bufY;
 		float maxV;
 		maxV=-std::numeric_limits<float>::max();
 
-		bufX.resize(overlayData[ui].coordData.size());
-		bufY.resize(overlayData[ui].coordData.size());
-		for(size_t uj=0;uj<overlayData[ui].coordData.size();uj++)	
+		bufX.resize(data.coordData.size());
+		bufY.resize(data.coordData.size());
+		for(size_t uj=0;uj<data.coordData.size();uj++)	
 		{
-			bufX[uj]=overlayData[ui].coordData[uj].first;
-			bufY[uj]=overlayData[ui].coordData[uj].second;
+			bufX[uj]=data.coordData[uj].first;
+			bufY[uj]=data.coordData[uj].second;
 			
 			maxV=std::max(maxV,bufY[uj]);
 		}
 
 		//Rescale to plot size
-		for(size_t uj=0;uj<overlayData[ui].coordData.size();uj++)
+		for(size_t uj=0;uj<data.coordData.size();uj++)
 		{
 			bufY[uj]*=boundMax.y/maxV*0.95;
 		}
@@ -2194,7 +2219,7 @@ void PlotOverlays::draw(mglGraph *gr,
 		//TODO: Deprecate me. Upstream now allows single stems
 		//Draw stems. can't use stem plot due to mathgl bug whereby single stems
 		// will not be drawn
-		for(size_t uj=0;uj<overlayData[ui].coordData.size();uj++)
+		for(size_t uj=0;uj<data.coordData.size();uj++)
 		{
 			if(bufX[uj]> boundMin.x && bufX[uj]< boundMax.x && 
 					boundMin.y < bufY[uj])
@@ -2202,7 +2227,7 @@ void PlotOverlays::draw(mglGraph *gr,
 				//Print labels near to the text
 				const float STANDOFF_FACTOR=1.05;
 				gr->Puts(mglPoint(bufX[uj],bufY[uj]*STANDOFF_FACTOR),
-					overlayData[ui].title.c_str());
+					data.title.c_str());
 			}
 		}
 
