@@ -418,6 +418,12 @@ class Plot2DFunc : public PlotBase
 
 		//Which colourmap (COLOURMAP_*) do we want to use?
 		unsigned int colourMap;
+
+		//true if we want the final plot to have a fixed aspect ratio
+		bool wantFixedAspect;
+
+		//If wantFixedAspect is set, then this specifies the Y:X aspect ratio
+		float aspectRatio;
 	public:
 		Plot2DFunc();
 		virtual bool isEmpty() const;
@@ -444,6 +450,9 @@ class Plot2DScatter : public PlotBase
 	private:
 		std::vector<std::pair<float,float> > points;
 		std::vector<float > intensity;
+
+		//string to use if we are labelling the intensity, otherwise empty
+		std::string intensityLabel;
 	public:
 		//Do we want to display the points in logarithmic terms?
 		bool scatterIntensityLog;
@@ -463,6 +472,8 @@ class Plot2DScatter : public PlotBase
 		//reset the data stored in the plot
 		void setData(const std::vector<std::pair<float,float> > &pts);
 		void setData(const std::vector<std::pair<float,float> > &pts ,const std::vector<float> &intens);
+
+		void setIntensityLabel(const string &s) { intensityLabel=s;}
 };
 
 //Wrapper class for containing multiple plots 
@@ -567,6 +578,9 @@ class PlotWrapper
 		const void *getParent(unsigned int plotID) { ASSERT(plotID < plottingData.size()); return plottingData[plotID]->parentObject;}
 
 		unsigned int getParentIndex(unsigned int plotId) const { ASSERT(plotId < plottingData.size()); return plottingData[plotId]->parentPlotIndex;}
+
+		//!Clear the parent cache associated with a given plot and region
+		void clearFilterCache(unsigned int plotId, unsigned int regionID);
 		//!Set the plotting mode.
 		void setTraceStyle(unsigned int plotID,unsigned int mode);
 
