@@ -22,6 +22,8 @@
 #include "common/xmlHelper.h"
 #include "common/stringFuncs.h"
 
+#include "wx/wxcommon.h"
+
 const unsigned int MAX_UNDO_SIZE=10;
 
 #include <unistd.h>
@@ -134,15 +136,15 @@ void AnalysisState::clear()
 
 void AnalysisState::clearCams()
 {
-	for(size_t ui=0;ui<savedCameras.size();ui++)
-		delete savedCameras[ui];
+	for(auto & savedCamera : savedCameras)
+		delete savedCamera;
 	savedCameras.clear();
 }
 
 void AnalysisState::clearEffects()
 {
-	for(size_t ui=0;ui<effects.size();ui++)
-		delete effects[ui];
+	for(auto & effect : effects)
+		delete effect;
 
 	effects.clear();
 
@@ -156,8 +158,14 @@ unsigned int AnalysisState::getStateWriterVersion()
 bool AnalysisState::save(const char *cpFilename, std::map<string,string> &fileMapping,
 		bool writePackage, bool setStateModifyLevel) 
 {
+
+	if(!canWriteToFile(cpFilename))
+		return false;
+
+	std::string tmpFile = stlStr(wxFileName::CreateTempFileName(string(PROGRAM_NAME) + string("-state-")));
+
 	//Open file for output
-	std::ofstream f(cpFilename);
+	std::ofstream f(tmpFile);
 
 	if(!f)
 		return false;
@@ -186,10 +194,10 @@ bool AnalysisState::save(const char *cpFilename, std::map<string,string> &fileMa
 	//write plot status
 	f << tabs(1) << "<plotstatus legend=\"" << boolStrEnc(plotLegendEnable) << "\">"  << endl;
 	
-	for(size_t ui=0;ui<enabledStartupPlots.size(); ui++)
+	for(auto & enabledStartupPlot : enabledStartupPlots)
 	{
 		
-		f<< tabs(2) << "<enableplot filter=\"" << escapeXML(enabledStartupPlots[ui].first) << "\" id=\"" << enabledStartupPlots[ui].second << "\"/>" << endl;
+		f<< tabs(2) << "<enableplot filter=\"" << escapeXML(enabledStartupPlot.first) << "\" id=\"" << enabledStartupPlot.second << "\"/>" << endl;
 	}
 	f<<tabs(1) << "</plotstatus>" << endl;
 
@@ -233,10 +241,10 @@ bool AnalysisState::save(const char *cpFilename, std::map<string,string> &fileMa
 	//First camera is the "working" camera, which is unnamed
 	f << tabs(2) << "<active value=\"" << activeCamera << "\"/>" << endl;
 	
-	for(unsigned int ui=0;ui<savedCameras.size();ui++)
+	for(auto & savedCamera : savedCameras)
 	{
 		//ask each camera to write its own state, tab indent 2
-		savedCameras[ui]->writeState(f,STATE_FORMAT_XML,2);
+		savedCamera->writeState(f,STATE_FORMAT_XML,2);
 	}
 	f <<tabs(1) <<  "</cameras>" << endl;
 	
@@ -244,11 +252,11 @@ bool AnalysisState::save(const char *cpFilename, std::map<string,string> &fileMa
 	{
 		f << tabs(1) << "<stashedfilters>" << endl;
 
-		for(unsigned int ui=0;ui<stashedTrees.size();ui++)
+		for(auto & stashedTree : stashedTrees)
 		{
-			f << tabs(2) << "<stash name=\"" << stashedTrees[ui].first
+			f << tabs(2) << "<stash name=\"" << stashedTree.first
 				<< "\">" << endl;
-			stashedTrees[ui].second.saveXML(f,fileMapping,
+			stashedTree.second.saveXML(f,fileMapping,
 					writePackage,useRelativePathsForSave,3);
 			f << tabs(2) << "</stash>" << endl;
 		}
@@ -263,8 +271,8 @@ bool AnalysisState::save(const char *cpFilename, std::map<string,string> &fileMa
 	if(effects.size())
 	{
 		f <<tabs(1) <<  "<effects>" << endl;
-		for(unsigned int ui=0;ui<effects.size();ui++)
-			effects[ui]->writeState(f,STATE_FORMAT_XML,1);
+		for(auto & effect : effects)
+			effect->writeState(f,STATE_FORMAT_XML,1);
 		f <<tabs(1) <<  "</effects>" << endl;
 
 	}
@@ -275,10 +283,10 @@ bool AnalysisState::save(const char *cpFilename, std::map<string,string> &fileMa
 		//Write the flattened tree - "path" -  data
 		f << tabs(1) << "<animationstate>" << endl;
 		f << tabs(2) << "<animationtree>" << endl;
-		for(unsigned int ui=0;ui<animationPaths.size();ui++)
+		for(auto & animationPath : animationPaths)
 		{
-			f << tabs(3) << "<entry key=\"" << animationPaths[ui].second << "\" path=\"" 
-					<< animationPaths[ui].first << "\"/>" << endl;
+			f << tabs(3) << "<entry key=\"" << animationPath.second << "\" path=\"" 
+					<< animationPath.first << "\"/>" << endl;
 		}
 		f << tabs(2) << "</animationtree>" << endl;
 
@@ -291,6 +299,12 @@ bool AnalysisState::save(const char *cpFilename, std::map<string,string> &fileMa
 	//Close XMl tag.	
 	f<< "</threeDepictstate>" << endl;
 
+	f.close();
+
+	//Try to overwrite the actual target. Abort if this doesn't work
+	if(!wxRenameFile(tmpFile,cpFilename))
+		return false;
+
 	//Debug check to ensure we have written a valid xml file
 	ASSERT(isValidXML(cpFilename));
 
@@ -385,10 +399,10 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 		
 		//Now in threeDepictstate tag
 		nodePtr = nodePtr->xmlChildrenNode;
-		xmlChar *xmlString;
 		//check for version tag & number
 		if(!XMLHelpFwdToElem(nodePtr,"writer"))
 		{
+			xmlChar *xmlString;
 			xmlString=xmlGetProp(nodePtr, (const xmlChar *)"version"); 
 
 			if(xmlString)
@@ -401,8 +415,8 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 				{
 					//Check between the writer reported version, and the current program version
 					vector<string> vecStrs;
-					vecStrs.push_back(tmpVer);
-					vecStrs.push_back(PROGRAM_VERSION);
+					vecStrs.emplace_back(tmpVer);
+					vecStrs.emplace_back(PROGRAM_VERSION);
 
 					if(getMaxVerStr(vecStrs)!=PROGRAM_VERSION)
 					{
@@ -440,6 +454,7 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 			throw 1;
 		}
 
+		xmlChar *xmlString;
 		xmlString=xmlGetProp(nodePtr,(const xmlChar *)"r");
 		if(!xmlString)
 		{
@@ -546,7 +561,7 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 				if(XMLHelpGetProp(filterPath,enablePlotPtr,"filter"))
 					break;
 
-				enabledStartupPlots.push_back(make_pair(unescapeXML(filterPath),plotID));
+				enabledStartupPlots.emplace_back(unescapeXML(filterPath),plotID);
 			}
 
 		}
@@ -597,7 +612,7 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 				std::string tmpStr;
 				tmpStr =(const char *)nodePtr->name;
 				Camera *thisCam;
-				thisCam=0;
+				thisCam=nullptr;
 				
 				//work out the camera type
 				if(tmpStr == "persplookat")
@@ -623,10 +638,10 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 				// so we can receive invalid data. We have to enforce validity
 				bool haveCameraAlready;
 				haveCameraAlready=false;
-				for(unsigned int ui=0; ui<newCameraVec.size() ; ui++)
+				for(auto & cam : newCameraVec)
 				{
 					//Ignore duplicate camera
-					if(thisCam->getUserString() == newCameraVec[ui]->getUserString())
+					if(thisCam->getUserString() == cam->getUserString())
 					{
 						haveCameraAlready=true;
 						break;
@@ -637,7 +652,7 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 				else
 				{
 					delete thisCam;
-					thisCam=0;
+					thisCam=nullptr;
 				}	
 			}
 
@@ -673,6 +688,8 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 					throw 1;
 				}
 				stashName=(char *)xmlString;
+				xmlFree(xmlString);
+
 
 				if(!stashName.size())
 				{
@@ -697,7 +714,7 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 				
 				//if there were any valid elements loaded (could be empty, for exmapl)
 				if(newStashTree.size())
-					newStashes.push_back(make_pair(stashName,newStashTree));
+					newStashes.emplace_back(stashName,newStashTree);
 			}
 
 			nodePtr=nodeStack.top();
@@ -728,9 +745,9 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 				}
 
 				//Check the effects are unique
-				for(unsigned int ui=0;ui<newEffectVec.size();ui++)
+				for(auto & effect : newEffectVec)
 				{
-					if(newEffectVec[ui]->getType()== e->getType())
+					if(effect->getType()== e->getType())
 					{
 						delete e;
 						errStream << TRANS("Duplicate effect found") << tmpStr << TRANS(" cannot use.") << std::endl;
@@ -795,7 +812,7 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 				//--
 
 
-				animationPathTmp.push_back(make_pair(path,val));
+				animationPathTmp.emplace_back(path,val);
 			}
 
 			nodePtr=nodeStack.top();
@@ -861,7 +878,7 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 	//spin through
 
 	bool defaultSet = false;
-	for(unsigned int ui=0;ui<newCameraVec.size();ui++)
+	for(auto & cam : newCameraVec)
 	{
 		//If there is no userstring, then its a  "default"
 		// camera (one that does not show up to the users,
@@ -869,15 +886,15 @@ bool AnalysisState::loadInternal(const char *cpFilename, bool doMerge, std::ostr
 		// set it directly. Otherwise, its a user camera.
 
 		//if there are multiple without a string, only use the first
-		if(newCameraVec[ui]->getUserString().size())
+		if(cam->getUserString().size())
 		{
-			savedCameras.push_back(newCameraVec[ui]);
+			savedCameras.push_back(cam);
 		}
 		else if (!defaultSet)
 		{
 			ASSERT(savedCameras.size());
 			delete savedCameras[0];
-			savedCameras[0]=newCameraVec[ui];
+			savedCameras[0]=cam;
 			defaultSet=true;
 		}
 
@@ -957,16 +974,16 @@ void AnalysisState::merge(const AnalysisState &otherState)
 	newStashes.resize(otherState.stashedTrees.size());
 	for(size_t ui=0;ui<otherState.stashedTrees.size();ui++)
 		newStashes[ui]=otherState.stashedTrees[ui];
-	for(unsigned int ui=0;ui<newStashes.size();ui++)
+	for(auto & newStash : newStashes)
 	{
 		//protect against overload (very unlikely)
 		unsigned int maxCount;
 		maxCount=100;
-		while(hasFirstInPairVec(stashedTrees,newStashes[ui]) && --maxCount)
-			newStashes[ui].first+=TRANS("-merge");
+		while(hasFirstInPairVec(stashedTrees,newStash) && --maxCount)
+			newStash.first+=TRANS("-merge");
 
 		if(maxCount)
-			stashedTrees.push_back(newStashes[ui]);
+			stashedTrees.push_back(newStash);
 		else
 		{
 			WARN(false," Unable to merge stashes correctly. This is improbable, so please report this.");
@@ -983,33 +1000,33 @@ void AnalysisState::merge(const AnalysisState &otherState)
 	
 
 	const vector<Camera *> &newCameraVec = otherState.savedCameras;	
-	for(unsigned int ui=0;ui<newCameraVec.size();ui++)
+	for(auto cam : newCameraVec)
 	{
 		//Don't merge the default camera (which has no name)
-		if(newCameraVec[ui]->getUserString().empty())
+		if(cam->getUserString().empty())
 			continue;
 
 		//Keep trying new names appending "-merge" each time to obtain a new, and hopefully unique name
 		// Abort after many times
 		unsigned int maxCount;
 		maxCount=100;
-		while(camNameExists(newCameraVec[ui]->getUserString()) && --maxCount)
+		while(camNameExists(cam->getUserString()) && --maxCount)
 		{
-			newCameraVec[ui]->setUserString(newCameraVec[ui]->getUserString()+"-merge");
+			cam->setUserString(cam->getUserString()+"-merge");
 		}
 
 		//If we have any attempts left, then it worked
 		if(maxCount)
-			savedCameras.push_back(newCameraVec[ui]->clone());
+			savedCameras.push_back(cam->clone());
 	}
 }
 
 
 bool AnalysisState::camNameExists(const std::string &s) const
 {
-	for(size_t ui=0; ui<savedCameras.size(); ui++) 
+	for(auto savedCamera : savedCameras) 
 	{
-		if (savedCameras[ui]->getUserString() == s ) 
+		if (savedCamera->getUserString() == s ) 
 			return true;
 	}
 	return false;
@@ -1196,9 +1213,19 @@ void AnalysisState::addStashedToFilters(const Filter *parentFilter, unsigned int
 	pair<string,FilterTree> f;
 	copyStashedTree(stashOffset,f);
 
-	size_t filterId;
-	filterId =treeState.getIdByFilter(parentFilter);
-	treeState.addFilterTree(f.second,filterId);
+	if(parentFilter)
+	{
+		//we have a specific insertion point for this stash
+		// use that to add
+		size_t filterId;
+		filterId =treeState.getIdByFilter(parentFilter);
+		treeState.addFilterTree(f.second,filterId);
+	}
+	else
+	{
+		//Add the stash to the base of the tree
+		treeState.addFilterTree(f.second);
+	}
 }
 
 void AnalysisState::copyStashedTrees(std::vector<std::pair<string,FilterTree > > &s) const
@@ -1276,9 +1303,9 @@ bool AnalysisState::hasStateOverrides() const
 	if(treeState.hasStateOverrides())
 		return true;
 
-	for(size_t ui=0;ui<stashedTrees.size();ui++)
+	for(const auto & stashedTree : stashedTrees)
 	{
-		if(stashedTrees[ui].second.hasStateOverrides())
+		if(stashedTree.second.hasStateOverrides())
 			return true;
 	}
 
@@ -1320,7 +1347,7 @@ void TreeState::addFilter(Filter *f, size_t parentId)
 	if(!isBase)
 		filterTree.addFilter(f,filterMap[parentId]);
 	else
-		filterTree.addFilter(f,0);
+		filterTree.addFilter(f,nullptr);
 
 
 	vector<bool> idInUse(filterMap.size()+1,false);
@@ -1350,7 +1377,7 @@ void TreeState::addFilterTree(FilterTree &f, size_t parentId)
 	bool isBase = (parentId == (size_t)-1);
 
 	if(isBase)
-		filterTree.addFilterTree(f,0);
+		filterTree.addFilterTree(f,nullptr);
 	else
 	{
 		ASSERT(filterMap.size());
@@ -1386,8 +1413,8 @@ void TreeState::switchoutFilterTree(FilterTree &f)
 	}
 
 	//Overwrite the internal map
-	for(map<size_t,Filter*>::iterator it=filterMap.begin();it!=filterMap.end();++it)
-		it->second=filterRemap[it->second];
+	for(auto & it : filterMap)
+		it.second=filterRemap[it.second];
 
 
 	//Swap the internal tree with our clone
@@ -1402,7 +1429,7 @@ bool TreeState::copyFilter(size_t toCopy, size_t newParent,bool copyToRoot)
 	
 	bool ret;
 	if(copyToRoot)
-		ret=filterTree.copyFilter(filterMap[toCopy],0);
+		ret=filterTree.copyFilter(filterMap[toCopy],nullptr);
 	else
 	
 		ret=filterTree.copyFilter(filterMap[toCopy],filterMap[newParent]);
@@ -1431,10 +1458,10 @@ const Filter* TreeState::getFilterById(size_t filterId) const
 
 size_t TreeState::getIdByFilter(const Filter* f) const
 {
-	for(map<size_t,Filter*>::const_iterator it=filterMap.begin(); it!=filterMap.end();++it)
+	for(auto it : filterMap)
 	{
-		if(it->second == f)
-			return it->first;
+		if(it.second == f)
+			return it.first;
 	}	
 
 	ASSERT(false);
@@ -1461,10 +1488,10 @@ void TreeState::removeFilterSubtree(size_t filterId)
 	//FIXME: Faster implementation involving removal from map
 	//--
 	map<size_t,Filter*> newMap;
-	for(map<size_t,Filter*>::iterator it=filterMap.begin(); it!=filterMap.end();++it)
+	for(auto & it : filterMap)
 	{
-		if(filterTree.contains(it->second))
-			newMap[it->first] = it->second;
+		if(filterTree.contains(it.second))
+			newMap[it.first] = it.second;
 	}
 	newMap.swap(filterMap);
 	//--
@@ -1583,6 +1610,11 @@ void TreeState::pushUndoStack()
 		undoFilterStack.pop_front();
 
 	undoFilterStack.push_back(filterTree);
+
+	//Ensure that any internal state that is specific
+	// to the original tree is fully removed (eg range pointers)
+	undoFilterStack.back().initFilterTree();
+
 	redoFilterStack.clear();
 }
 
