@@ -114,11 +114,11 @@ void VisController::updateScene(RefreshController *r)
 	list<FILTER_OUTPUT_DATA> &sceneData = r->getRefreshData();
 	list< vector<const FilterStreamData *> > dataOnly;
 
-	for(list<FILTER_OUTPUT_DATA>::iterator it=sceneData.begin(); it!=sceneData.end();++it)
+	for(auto & it : sceneData)
 	{
 		vector<const FilterStreamData *> t;
-		t.resize(it->second.size());
-		std::copy(it->second.begin(),it->second.end(),t.begin());
+		t.resize(it.second.size());
+		std::copy(it.second.begin(),it.second.end(),t.begin());
 		dataOnly.push_back(t);
 	}	
 	
@@ -176,7 +176,7 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 	throttleSceneInput(sceneData,throttleMap);
 
 	//-- Build buffer of new objects to send to scene
-	for(list<vector<const FilterStreamData *> > ::iterator it=sceneData.begin(); 
+	for(auto it=sceneData.begin(); 
 							it!=sceneData.end(); ++it)
 	{
 
@@ -259,7 +259,7 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 					ASSERT(plotData->plotMode == PLOT_MODE_1D);
 					
 					//Create a 1D plot
-					Plot1D *plotNew= new Plot1D;
+					auto plotNew= new Plot1D;
 
 					plotNew->setData(plotData->xyData);
 					for(unsigned int ui=0;ui<2;ui++)
@@ -307,7 +307,7 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 					
 					plotID=targetPlots.addPlot(plotNew);
 
-					plotLabels.push_back(make_pair(plotID,plotData->dataLabel));
+					plotLabels.emplace_back(plotID,plotData->dataLabel);
 					
 					break;
 				}
@@ -346,7 +346,7 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 						case PLOT_2D_SCATTER:
 						{
 							//Create a 2D plot
-							Plot2DScatter *p = new Plot2DScatter;
+							auto p = new Plot2DScatter;
 							//set the plot info
 							if(plotData->scatterIntensity.size())
 								p->setData(plotData->scatterData,plotData->scatterIntensity);
@@ -354,6 +354,7 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 								p->setData(plotData->scatterData);
 
 							p->scatterIntensityLog=plotData->scatterIntensityLog;
+							p->setIntensityLabel(plotData->intensityLabel);
 
 							plotNew=p;				
 							break;
@@ -373,7 +374,7 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 					
 					// -----
 
-					plotLabels.push_back(make_pair(plotID,plotData->dataLabel));
+					plotLabels.emplace_back(plotID,plotData->dataLabel);
 					break;
 				}
 				case STREAM_TYPE_DRAW:
@@ -420,7 +421,7 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 					//Technically, we are violating const-ness
 					VoxelStreamData *vSrc = (VoxelStreamData *)(filterData);
 					//Create a new Field3D
-					Voxels<float> *v = new Voxels<float>;
+					auto v = new Voxels<float>;
 
 					//Make a copy if cached; otherwise just steal it.
 					if(vSrc->cached)
@@ -436,7 +437,7 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 						case VOXEL_REPRESENT_POINTCLOUD:
 						{
 							//Create 3D scalar field drawable
-							DrawField3D  *d = new DrawField3D;
+							auto d = new DrawField3D;
 							d->setField(v);
 #ifdef ENABLE_LIBVD
 							if(vSrc->representationType == VOXEL_REPRESENT_VOLUME_RENDER)
@@ -465,18 +466,19 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 							//Set the min/max colour values
 							d->setColourMinMax(vSrc->colourMin,vSrc->colourMax);
 							
-							d->setBoxColours(vSrc->r,vSrc->g,vSrc->b,vSrc->a);
+							d->setBoxColours(vSrc->bBoxR,vSrc->bBoxG,
+										vSrc->bBoxB,vSrc->bBoxA);
 							d->setPointSize(vSrc->splatSize);
 							d->setAlpha(vSrc->a);
 							d->wantsLight=false;
-							d->setDrawBox(false);
+							d->setDrawBox(vSrc->showBBox);
 
 							sceneDrawables.push_back(d);
 							break;
 						}
 						case VOXEL_REPRESENT_ISOSURF:
 						{
-							DrawIsoSurface *d = new DrawIsoSurface;
+							auto d = new DrawIsoSurface;
 
 							d->swapVoxels(v);
 							d->setColour(vSrc->r,vSrc->g,
@@ -486,6 +488,22 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 							d->wantsLight=true;
 
 							sceneDrawables.push_back(d);
+
+
+							if(vSrc->showBBox)
+							{
+								auto dr=new DrawRectPrism;
+
+								BoundCube b;
+								v->getBounds(b);
+								dr->setAxisAligned(b);
+								//FIXME: provide colour
+								dr->setColour(1.0f,0.0f,0.0f);
+								dr->wantsLight=false;
+								sceneDrawables.push_back(dr);
+
+
+							}
 							break;
 						}
 	
@@ -503,7 +521,7 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 			if( (!filterData->cached && releaseData) || deleteIt)
 			{
 				delete filterData;
-				filterData=0;	
+				filterData=nullptr;	
 			}
 			
 
@@ -512,10 +530,9 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 	}
 
 	//Free the rate-limited points
-	for(map<const IonStreamData *, const IonStreamData*>::iterator it =throttleMap.begin();
-		it!=throttleMap.end();++it)
+	for(auto & it : throttleMap)
 	{
-		delete it->second;
+		delete it.second;
 	}
 	throttleMap.clear();	
 	//---
@@ -524,10 +541,10 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 
 	//Check how many points we have. Too many can cause the display list to crash
 	size_t totalIonCount=0;
-	for(unsigned int ui=0;ui<sceneDrawables.size();ui++)
+	for(auto & sceneDrawable : sceneDrawables)
 	{
-		if(sceneDrawables[ui]->getType() == DRAW_TYPE_MANYPOINT)
-			totalIonCount+=((const DrawManyPoints*)(sceneDrawables[ui]))->getNumPts();
+		if(sceneDrawable->getType() == DRAW_TYPE_MANYPOINT)
+			totalIonCount+=((const DrawManyPoints*)sceneDrawable)->getNumPts();
 	}
 	
 	
@@ -609,10 +626,10 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 		displayList = new DrawDispList();
 
 		bool listStarted=false;
-		for(unsigned int ui=0;ui<drawIons.size(); ui++)
+		for(auto & drawIon : drawIons)
 		{
 			BoundCube b;
-			drawIons[ui]->getBoundingBox(b);
+			drawIon->getBoundingBox(b);
 			if(b.isValid())
 			{
 
@@ -621,11 +638,11 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 					displayList->startList(false);
 					listStarted=true;
 				}
-				displayList->addDrawable(drawIons[ui]);
-				delete drawIons[ui];
+				displayList->addDrawable(drawIon);
+				delete drawIon;
 			}
 			else
-				scene.addDrawable(drawIons[ui]);
+				scene.addDrawable(drawIon);
 		}
 
 		if(listStarted)	
@@ -638,13 +655,13 @@ void VisController::updateScene(list<vector<const FilterStreamData *> > &sceneDa
 	}
 	else
 	{
-		for(unsigned int ui=0;ui<drawIons.size(); ui++)
-			scene.addDrawable(drawIons[ui]);
+		for(auto & drawIon : drawIons)
+			scene.addDrawable(drawIon);
 	}
 
 	//add all drawable objects (not ions)	
-	for(size_t ui=0;ui<sceneDrawables.size();ui++)
-		scene.addDrawable(sceneDrawables[ui]);
+	for(auto & sceneDrawable : sceneDrawables)
+		scene.addDrawable(sceneDrawable);
 	
 	sceneDrawables.clear();
 	scene.computeSceneLimits();
@@ -671,16 +688,15 @@ void VisController::throttleSceneInput(list<vector<const FilterStreamData *> > &
 	//Need to cull
 	float cullFraction = (float)limitIonOutput/(float)inputIonCount;
 
-	for(list<vector<const FilterStreamData *> >::iterator it=sceneData.begin(); 
-							it!=sceneData.end(); ++it)
+	for(auto & it : sceneData)
 	{
-		for(unsigned int ui=0;ui<it->size(); ui++)
+		for(unsigned int ui=0;ui<it.size(); ui++)
 		{
-			if((*it)[ui]->getStreamType() != STREAM_TYPE_IONS)
+			if(it[ui]->getStreamType() != STREAM_TYPE_IONS)
 				continue;
 			//Obtain the ion data pointer
 			const IonStreamData *ionData;
-			ionData=((const IonStreamData *)((*it)[ui]));
+			ionData=((const IonStreamData *)(it[ui]));
 
 
 			//Duplicate this object, then forget
@@ -724,25 +740,25 @@ void VisController::updateRawGrid() const
 		ASSERT(labels[ui].size() == plotData[ui].size());
 
 		startCol=curCol;
-		for(unsigned int uj=0;uj<labels[ui].size();uj++)
+		for(auto & label : labels[ui])
 		{
 			std::string s;
-			s=(labels[ui][uj]);
+			s=label;
 			targetRawGrid->SetColLabelValue(curCol,(s));
 			curCol++;
 		}
 
 		//set the data
-		for(unsigned int uj=0;uj<plotData[ui].size();uj++)
+		for(auto & data : plotData[ui])
 		{
 			//Check to see if we need to add rows to make our data fit
-			if(plotData[ui][uj].size() > targetRawGrid->GetNumberRows())
-				targetRawGrid->AppendRows(plotData[ui][uj].size()-targetRawGrid->GetNumberRows());
+			if(data.size() > targetRawGrid->GetNumberRows())
+				targetRawGrid->AppendRows(data.size()-targetRawGrid->GetNumberRows());
 
-			for(unsigned int uk=0;uk<plotData[ui][uj].size();uk++)
+			for(unsigned int uk=0;uk<data.size();uk++)
 			{
 				std::string tmpStr;
-				stream_cast(tmpStr,plotData[ui][uj][uk]);
+				stream_cast(tmpStr,data[uk]);
 				targetRawGrid->SetCellValue(uk,startCol,(tmpStr));
 			}
 			startCol++;
