@@ -114,7 +114,7 @@ void popLocale()
 	localeStaticType=0;
 
 	free(oldLocaleStatic);
-	oldLocaleStatic=0;
+	oldLocaleStatic=nullptr;
 }
 
 
@@ -297,8 +297,7 @@ string veryFuzzyTimeSince( time_t origTime, time_t nowTime)
 }
 
 ColourRGBA::ColourRGBA()
-{
-}
+= default;
 
 ColourRGBA::ColourRGBA(unsigned char r, unsigned char g, unsigned char b, unsigned char a) 
 {
@@ -483,8 +482,7 @@ bool ColourRGBA::operator!=(const ColourRGBAf &oth) const
 
 
 ColourRGBAf::ColourRGBAf()
-{
-}
+= default;
 
 ColourRGBAf::ColourRGBAf(float r, float g, float b, float a) 
 {
@@ -721,22 +719,22 @@ void BoundCube::setBounds(const std::vector<Point3D> &points)
 {
 	
 	setInverseLimits();	
-	for(unsigned int ui=0; ui<points.size(); ui++)
+	for(const auto & point : points)
 	{
 		for(unsigned int uj=0; uj<3; uj++)
 		{
-			if(points[ui].getValue(uj) < bounds[uj][0])
+			if(point.getValue(uj) < bounds[uj][0])
 			{
 				{
-				bounds[uj][0] = points[ui].getValue(uj);
+				bounds[uj][0] = point.getValue(uj);
 				valid[uj][0]=true;
 				}
 			}
 			
-			if(points[ui].getValue(uj) > bounds[uj][1])
+			if(point.getValue(uj) > bounds[uj][1])
 			{
 				{
-				bounds[uj][1] = points[ui].getValue(uj);
+				bounds[uj][1] = point.getValue(uj);
 				valid[uj][1]=true;
 				}
 			}
@@ -744,9 +742,9 @@ void BoundCube::setBounds(const std::vector<Point3D> &points)
 	}
 
 #ifdef DEBUG
-	for(unsigned int ui=0; ui<points.size(); ui++)
+	for(const auto & point : points)
 	{
-		ASSERT(containsPt(points[ui]));
+		ASSERT(containsPt(point));
 	}
 #endif
 }
@@ -932,9 +930,9 @@ bool BoundCube::isValid() const
 bool BoundCube::isFlat() const
 {
 	//Test the limits being inverted or equated
-	for(unsigned int ui=0;ui<3; ui++)
+	for(auto bound : bounds)
 	{
-		if(fabs(bounds[ui][0] - bounds[ui][1]) < std::numeric_limits<float>::epsilon())
+		if(fabs(bound[0] - bound[1]) < std::numeric_limits<float>::epsilon())
 			return true;
 	}	
 
@@ -946,9 +944,9 @@ bool BoundCube::isNumericallyBig() const
 	const float TOO_BIG=sqrtf(std::numeric_limits<float>::max());
 	for(unsigned int ui=0;ui<2; ui++)
 	{
-		for(unsigned int uj=0;uj<3; uj++)
+		for(auto bound : bounds)
 		{
-			if(TOO_BIG < fabs(bounds[uj][ui]))
+			if(TOO_BIG < fabs(bound[ui]))
 				return true;
 		}
 	}
@@ -997,13 +995,13 @@ void BoundCube::expand(const Point3D &p)
 void BoundCube::expand(float f) 
 {
 	//If self not valid, ensure that it will be after this run
-	for(unsigned int ui=0; ui<3; ui++)
+	for(auto & bound : bounds)
 	{
 		//Check lower bound is lower to new pt
-		bounds[ui][0]-=f;
+		bound[0]-=f;
 
 		//Check upper bound is upper to new pt
-		bounds[ui][1]+=f;
+		bound[1]+=f;
 	}
 }
 
@@ -1289,11 +1287,10 @@ void UniqueIDHandler::clear()
 unsigned int UniqueIDHandler::getPos(unsigned int id) const
 {
 
-	for(list<std::pair<unsigned int, unsigned int> >::const_iterator it=idList.begin();
-			it!=idList.end(); ++it)
+	for(auto it : idList)
 	{
-		if(id == it->second)
-			return it->first;
+		if(id == it.second)
+			return it.first;
 	}
 	ASSERT(false);
 	return 0;
@@ -1301,7 +1298,7 @@ unsigned int UniqueIDHandler::getPos(unsigned int id) const
 
 void UniqueIDHandler::killByPos(unsigned int pos)
 {
-	for(list<std::pair<unsigned int, unsigned int> >::iterator it=idList.begin();
+	for(auto it=idList.begin();
 			it!=idList.end(); ++it)
 	{
 		if(pos  == it->first)
@@ -1312,21 +1309,19 @@ void UniqueIDHandler::killByPos(unsigned int pos)
 	}
 
 	//Decrement the items, which were further along, in order to maintain the mapping	
-	for(list<std::pair<unsigned int, unsigned int> >::iterator it=idList.begin();
-			it!=idList.end(); ++it)
+	for(auto & it : idList)
 	{
-		if( it->first > pos)
-			it->first--;
+		if( it.first > pos)
+			it.first--;
 	}
 }
 
 unsigned int UniqueIDHandler::getId(unsigned int pos) const
 {
-	for(list<std::pair<unsigned int, unsigned int> >::const_iterator it=idList.begin();
-			it!=idList.end(); ++it)
+	for(auto it : idList)
 	{
-		if(pos == it->first)
-			return it->second;
+		if(pos == it.first)
+			return it.second;
 	}
 
 	ASSERT(false);
@@ -1343,10 +1338,9 @@ unsigned int UniqueIDHandler::genId(unsigned int pos)
 	{
 		bool idTaken;
 		idTaken=false;
-		for(list<std::pair<unsigned int, unsigned int> >::iterator it=idList.begin();
-				it!=idList.end(); ++it)
+		for(auto & it : idList)
 		{
-			if(ui == it->second)
+			if(ui == it.second)
 			{
 				idTaken=true;
 				break;
@@ -1367,9 +1361,8 @@ unsigned int UniqueIDHandler::genId(unsigned int pos)
 void UniqueIDHandler::getIds(std::vector<unsigned int> &idVec) const
 {
 	//most wordy way of saying "spin through list" ever.
-	for(list<std::pair<unsigned int, unsigned int> >::const_iterator it=idList.begin();
-			it!=idList.end(); ++it)
-		idVec.push_back(it->second);
+	for(auto it : idList)
+		idVec.push_back(it.second);
 }
 
 
@@ -1635,7 +1628,7 @@ unsigned int loadTextStringData(const char *cpFilename, vector<vector<string> >
 
 	dataVec.clear();
 
-	char *inBuffer= new char[BUFFER_SIZE];
+	auto inBuffer= new char[BUFFER_SIZE];
 	//Grab a line from the file
 	CFile.getline(inBuffer,BUFFER_SIZE);
 	while(!CFile.eof())
@@ -1739,18 +1732,18 @@ bool BoundCube::test()
 		Point3D(0.5,0.5,0.5),Point3D(0,0,1),pts);
 
 	TEST(pts.size() == 4,"plane intersect test");
-	for(unsigned int ui=0;ui<pts.size();ui++)
+	for(auto & pt : pts)
 	{
-		TEST(EQ_TOL(pts[ui][2],0.5),"intersect test");
+		TEST(EQ_TOL(pt[2],0.5),"intersect test");
 	}
 
 	pts.clear();
 	b.getPlaneIntersectVertices(
 		Point3D(0.5,0.5,0.5),Point3D(1,1,0),pts);
 	TEST(pts.size() == 4,"plane intersect test");
-	for(unsigned int ui=0;ui<pts.size();ui++)
+	for(auto & pt : pts)
 	{
-		TEST( (EQ_TOL(pts[ui][2],0) || EQ_TOL(pts[ui][2],1)) ,"intersect test");
+		TEST( (EQ_TOL(pt[2],0) || EQ_TOL(pt[2],1)) ,"intersect test");
 	}
 	pts.clear();
 	b.getPlaneIntersectVertices(
