@@ -21,6 +21,8 @@
 #define BASICS_H
 //!Basic objects header file
 
+#include <gsl/gsl_rng.h>
+#include <gsl/gsl_randist.h>
 
 #if (_MSC_VER >= 1600) ||  (__cplusplus > 199711L) 
 	#define HAVE_CPP_1X
@@ -87,6 +89,11 @@ inline int fpeek(FILE *stream)
 	return c;
 }
 
+inline bool XOR(bool a, bool b)
+{
+	return a == !b;
+}
+
 template<class T>
 bool rangesOverlap( const T &minA, const T &maxA,
 			const T &minB, const T &maxB)
@@ -331,8 +338,18 @@ public:
         setInvalid();
     }
 
+    //Declare copy constructor
+    BoundCube(const BoundCube &) = default;
+    //Declare move constructor
+    BoundCube(BoundCube &&) = default;
+
     BoundCube(const Point3D &p1, const Point3D &p2);
 
+    BoundCube(const std::vector<Point3D> &pts)
+    {
+	    setBounds(pts);
+    }
+
     void setBounds(float xMin,float yMin,float zMin,
                    float xMax,float yMax,float zMax) {
         bounds[0][0]=xMin; bounds[1][0]=yMin; bounds[2][0]=zMin;
@@ -562,6 +579,7 @@ class ColourRGBAf
 template<class T> size_t randomSelect(std::vector<T> &result, const std::vector<T> &source, 
 							RandNumGen &rng, size_t num,unsigned int &progress, ATOMIC_BOOL &wantAbort, bool strongRandom=false)
 {
+	progress=0;
 	//If there are not enough points, just copy it across in whole
 	if(source.size() <= num)
 	{
@@ -570,6 +588,7 @@ template<class T> size_t randomSelect(std::vector<T> &result, const std::vector<
 		for(size_t ui=0; ui<num; ui++)
 			result[ui] = source[ui]; 
 	
+		progress=100;
 		return num;
 	}
 
@@ -577,89 +596,19 @@ template<class T> size_t randomSelect(std::vector<T> &result, const std::vector<
 
 	if(strongRandom || source.size() < 4)
 	{
-
-		size_t numTicksNeeded;
-		//If the number of items is larger than half the source size,
-		//switch to tracking vacancies, rather than data
-		if(num < source.size()/2)
-			numTicksNeeded=num;
-		else
-			numTicksNeeded=source.size()-num;
-
-		//Randomly selected items 
-		//---------
-		std::vector<size_t> ticks;
-		ticks.resize(numTicksNeeded);
-
-		//Create an array of numTicksNeededbers and fill 
-		for(size_t ui=0; ui<numTicksNeeded; ui++)
-			ticks[ui]=(size_t)(rng.genUniformDev()*(source.size()-1));
-
-		std::sort(ticks.begin(),ticks.end());
-		std::vector<size_t>::iterator newLast;
-		newLast=std::unique(ticks.begin(),ticks.end());	
-		ticks.erase(newLast,ticks.end());
-
-		//Top up with unique entries
-		//TODO: Overcommit & Discard implementation?
-		// - Should be possible to predict how many we need after collisions, and then overcommit and discard randomly. Removes need to loop-sort like this
-		while(ticks.size() < numTicksNeeded && !wantAbort)
-		{
-			size_t moreTicks=numTicksNeeded-ticks.size();
-			for(size_t uk=0;uk<moreTicks;uk++)
-			{
-				//This is actually not too bad. the collision probability is at most 50%
-				//due the switching behaviour above, for any large number of items 
-				//So this is at worst case nlog(n) (I think)
-				ticks.push_back((size_t)(rng.genUniformDev()*(float)(source.size()-1)));
-	
-			}
-
-			std::sort(ticks.begin(),ticks.end());
-			newLast=std::unique(ticks.begin(),ticks.end());	
-			ticks.erase(newLast,ticks.end());
-		}
-
-		if(wantAbort)
-			return -1;
-
-		ASSERT(ticks.size() == numTicksNeeded);
-		//---------
+		//FIXME: When C++17 is standard, use std::sample
+		gsl_rng_env_setup();
+		gsl_rng *r = gsl_rng_alloc(gsl_rng_default);
 		
-		//Transfer the output
-		if(num < source.size()/2)
-		{
-			size_t pos=0;
-			for(std::vector<size_t>::iterator it=ticks.begin();it!=ticks.end();++it)
-			{
+		gsl_rng_set(r,rng.genInt());
+		//Use GSL to do the selection. Downside is we lose progress.
+		// Upside is that it should be faster, and less likely to contain bugs
+		void *d = const_cast<T*>(result.data());
+		void *s = const_cast<T*>(source.data());
+		gsl_ran_choose(r,d,num,s,source.size(),sizeof(T));
 
-				result[pos]=source[*it];
-				pos++;
-				progress= (unsigned int)((float)(pos)/((float)num)*100.0f);
-			}
-		}
-		else
-		{
-			//Sort the ticks properly (mostly sorted anyway..)
-			std::sort(ticks.begin(),ticks.end());
+		gsl_rng_free(r);
 
-			unsigned int curTick=0;
-			for(size_t ui=0;ui<source.size(); ui++)
-			{
-				//Don't copy if this is marked
-				if(ui == ticks[curTick])
-					curTick++;
-				else
-				{
-					ASSERT(result.size() > (ui-curTick));
-					result[ui-curTick]=source[ui];
-				}
-				
-				progress= (unsigned int)(((float)(ui)/(float)source.size())*100.0f);
-			}
-		}
-
-		ticks.clear();
 	}	
 	else
 	{
@@ -706,6 +655,7 @@ template<class T> size_t randomSelect(std::vector<T> &result, const std::vector<
 
 	}
 
+	progress=100;
 	return num;
 }
 
@@ -873,4 +823,34 @@ void vectorMultiErase(std::vector<T> &vec, const std::vector<bool> &wantKill)
 	vec.resize(vec.size()-shift);
 }
 
+
+//!Transpose the contents of a nested vector, such that v[i][j] becomes vOut[j][i]
+// Input vectors must be rectangular (v[i][1..n] all same size)
+template<class T>
+void vectorTranspose(const std::vector<std::vector<T> > &v, 
+		std::vector<std::vector<T> > &vOut)
+{
+	//Handle empty case
+	vOut.clear();
+
+	if(!v.size())
+		return;
+
+	vOut.resize(v[0].size());
+
+	for(auto i=0;i<vOut.size();i++)
+		vOut[i].resize(v.size());
+
+	for(auto i=0;i<v.size();i++)
+	{
+		//Check equi-size
+		ASSERT(v[0].size() == v[i].size());
+
+#pragma omp parallel for
+		for(auto j=0;j<v[i].size();j++)
+			vOut[j][i] = v[i][j];
+
+	}
+}
+
 #endif
