@@ -65,13 +65,16 @@ enum
 };
 
 
+//FIXME: Is ther ewomewhere else to put this?
 //!Structure to handle error bar drawing in plot
-struct PLOT_ERROR
+class PLOT_ERROR
 {
-	//!Plot data estimator mode
-	unsigned int mode;
-	//!Number of data points for moving average
-	unsigned int movingAverageNum;
+	public:
+		PLOT_ERROR() { mode=PLOT_ERROR_NONE; movingAverageNum=1;};
+		//!Plot data estimator mode
+		unsigned int mode;
+		//!Number of data points for moving average
+		unsigned int movingAverageNum;
 };
 
 extern const char *RANGEFILE_WX_CONSTANT;
