@@ -418,8 +418,8 @@ bool Point3D::parse(const std::string &str)
 
 	splitStrsRef(tmpStr.c_str(),ALLOWABLE_SEPARATORS,
 			components);
-	for(size_t ui=0;ui<components.size();ui++)
-		components[ui]=stripWhite(components[ui]);
+	for(auto & component : components)
+		component=stripWhite(component);
 	
 	//Drop the blank bits from the field
 	vector<string>::iterator rmIt;
@@ -1135,11 +1135,11 @@ void scatterPointsInPolygon(const vector<Point3D> &polygon, const Point3D &norma
 	//normalise the weight to total area,
 	// and accumulate
 	float cumSum=0.0f;;
-	for(unsigned int ui=0;ui<weights.size();ui++)
+	for(float & weight : weights)
 	{
-		weights[ui]/=area;
-		cumSum+=weights[ui];
-		weights[ui]=cumSum;
+		weight/=area;
+		cumSum+=weight;
+		weight=cumSum;
 	}
 	
 	unsigned int nScatter = ceil(scatterDensity*area);
@@ -1215,6 +1215,31 @@ void applyQuaternion(vector<Point3D> &pts,Quaternion &q)
 
 }
 
+unsigned int vectorPointDir(const Point3D &pA, const Point3D &pB, 
+				const Point3D &vC, const Point3D &vD)
+{
+	//Check which way vectors attached to two 3D points "point", 
+	// - "together", "apart" or "in common"
+	
+	//calculate AB.CA, BA.DB
+	float dot1  = (pB-pA).dotProd(vC - pA);
+	float dot2= (pA - pB).dotProd(vD - pB);
+
+	//We shall somewhat arbitrarily call perpendicular cases "together"
+	if(dot1 ==0.0f || dot2 == 0.0f)
+		return POINTDIR_TOGETHER;
+
+	//If they have opposite signs, then they are "in common"
+	if(( dot1  < 0.0f  && dot2 > 0.0f) || (dot1 > 0.0f && dot2 < 0.0f) )
+		return POINTDIR_IN_COMMON;
+
+	if( dot1 < 0.0f && dot2 <0.0f )
+		return POINTDIR_APART; 
+
+	ASSERT(dot1 > 0.0f && dot2 > 0.0f );
+	
+	return POINTDIR_TOGETHER;
+}
 #ifdef DEBUG
 
 bool testMathfuncs()
