@@ -50,6 +50,12 @@ class Point3D
 					{ value[0] = v[0], value[1] = v[1], value[2] = v[2];}
                 inline Point3D(double *v)
 					{ value[0] = v[0], value[1] = v[1], value[2] = v[2];}
+
+		//Copy constructor
+		Point3D(const Point3D &p) =default;
+		//Move constructor
+		Point3D(Point3D &&p) =default;
+
                 //!Set by value (ith dim 0, 1 2)
                 inline void setValue(unsigned int ui, float val){value[ui]=val;};
 				//!Set all values
@@ -328,6 +334,16 @@ void scatterPointsInPolygon(const std::vector<Point3D> &polygon, const Point3D &
 void rotatePointsToXYPlane(std::vector<Point3D> &pts, const Point3D &normal, 
 					const Point3D &origin, Quaternion &q);
 
+enum PointDir{ 	POINTDIR_TOGETHER =0,
+                POINTDIR_IN_COMMON,
+                POINTDIR_APART
+             };
+//!Check which way vectors attached to two 3D points "point", 
+/*! Two vectors may point "together", /__\ "apart" \__/  or 
+ *  "In common" /__/ or \__\
+ */
+unsigned int vectorPointDir(const Point3D &pA, const Point3D &pB, 
+				const Point3D &vC, const Point3D &vD);
 //Unstable vector mean (does not sort prior to computing mean. Error propagation uncontrolled)
 //Vector must be nonzero sized
 template<class T>
