@@ -32,6 +32,8 @@ using std::string;
 using std::endl;
 using std::list;
 using std::cerr;
+using std::map;
+using std::pair;
 
 enum
 {
@@ -61,6 +63,167 @@ float signVal(unsigned int val)
 		return -1;
 }
 
+//! Returns the shortest distance between a facet and a Point 
+/*! The inputs are the facet points (ABC) and the point P.
+ * distance is shortest using standard plane version 
+ * \f$ D = \vec{AB} \cdot \vec{n} \f$ 
+ * iff dot products to each combination of \f$ \left( AP,BP,CP \right) \leq 0 \f$
+ * otherwise closest point is on the boundary of the simplex.
+ * tested by shortest distance to each line segment (E is shortest pt. AB is line segement)
+ * \f$ \vec{E} = \frac{\vec{AB}}{|\vec{AB}|} 
+ *  ( \vec{PB} \cdot \vec{AB})\f$
+ */
+float distanceToFacet(const Point3D &fA, const Point3D &fB, 
+			const Point3D &fC, const Point3D &normal, const Point3D &p);
+
+
+enum
+{
+	CLOSEST_TYPE_FACE,
+	CLOSEST_TYPE_EDGE,
+	CLOSEST_TYPE_VERTEX
+};
+
+//! Returns the shortest distance between a line segment and a given point
+/* The inputs are the ends of the line segment and the point. Uses the formula that 
+ * \f$ 
+ * D = \abs{\vec{PE}}\f$
+ * \f[ 
+ * \mathrm{~if~} \vec{PA} \cdot \vec{AB} > 0 
+ * \rightarrow \vec{PE} = \vec{A} 
+ * \f]
+ * \f[
+ * \mathrm{~if~} \vec{AB} \cdot \vec{PB} > 0 ~\&~ \vec{PA} \cdot \vec{AB} < 0
+ * \rightarrow \vec{PB} \cdot \frac{\vec{AB}}{\abs{\vec{AB}}} 
+ * \f]
+ * \f[
+ * \mathrm{~if~} \vec{PB} \cdot \vec{AB} < 0 
+ * \rightarrow \vec{B} 
+ * \f]
+ */
+float sqrDistanceToSegment(const Point3D &fA, const Point3D &fB, const Point3D &p)
+{
+
+	//If the vectors a pointing "together" then use  point-line formula
+	if(vectorPointDir(fA,fB,p,p) == POINTDIR_TOGETHER)
+	{
+		Point3D closestPt;
+		Point3D vAB= fB-fA;
+
+		//Use formula d^2 = |(B-A)(cross)(A-P)|^2/|B-A|^2
+		return (vAB.crossProd(fA-p)).sqrMag()/(vAB.sqrMag());
+	}
+
+	return std::min(fB.sqrDist(p), fA.sqrDist(p));
+}
+
+//!Find the distance between a point, and a triangular facet -- may be positive or negative
+// closestType returns 0 for face, 1 for edge, 2 for vertex
+// closestId is set by CLOSEST_TYPE
+float sqrDistanceToFacet(const Point3D &fA, const Point3D &fB, 
+			const Point3D &fC,  const Point3D &normal,const Point3D &p, 
+			unsigned int &closestType, unsigned int &closestId)
+{
+	Point3D pTri[3];
+	pTri[0]=fA;
+	pTri[1]=fB;
+	pTri[2]=fC;
+
+	bool insideTri;
+
+	float baryCentricCoord[3];
+	for(size_t ui=0; ui<3;ui++)
+	{
+		//Find the midpoint of the triangle on this axis
+		Point3D mid,tmp;
+		mid = (pTri[(ui+1)%3] -pTri[ui])*0.5f + pTri[ui];
+		//Vector between current "apex" and midpoint of opposite side
+		tmp = (pTri[(ui+2)%3]-mid);
+
+		baryCentricCoord[ui] = tmp.dotProd(p -mid)/(tmp.mag());
+	}
+
+	//we are only inside the triangle if all barycentric coords 
+	// say we are.
+	insideTri=true;
+	for(size_t ui=0;ui<3;ui++)
+	{
+		insideTri&= ( (0.0f <=baryCentricCoord[ui]) &&  
+				(baryCentricCoord[ui] <=1.0f) );
+	}
+	if(insideTri)
+	{
+		//Point lies above/below facet, and projects normally directly onto it, 
+		// use plane formula
+		closestType=CLOSEST_TYPE_FACE;
+
+		float temp;
+		temp = (p-fA).dotProd(normal);
+
+		//check that the other points were not better than this!
+		ASSERT(sqrt(fA.sqrDist(p)) >= fabs(temp) - sqrt(std::numeric_limits<float>::epsilon()));
+		ASSERT(sqrt(fB.sqrDist(p)) >= fabs(temp) - sqrt(std::numeric_limits<float>::epsilon()));
+		ASSERT(sqrt(fC.sqrDist(p)) >= fabs(temp) - sqrt(std::numeric_limits<float>::epsilon()));
+
+		return temp; 
+	}
+		
+	//Could be a vertex, or an edge
+	float bestSqrDistVertex=std::numeric_limits<float>::max();
+	unsigned int bestVertex=(unsigned int)-1;
+	for(unsigned int ui=0;ui<3;ui++)
+	{
+		float fTmp;
+		fTmp = p.sqrDist(pTri[ui]);
+
+		if(bestSqrDistVertex > fTmp )
+		{
+			bestVertex=ui;
+			bestSqrDistVertex=fTmp;
+		}
+	}
+
+	ASSERT(bestVertex != (unsigned int)-1);
+
+	//if so, we have to check each edge for its closest point
+	//then pick the best
+	float bestSqrDist[3];
+	bestSqrDist[0] = sqrDistanceToSegment(fA,fB,p);
+	bestSqrDist[1] = sqrDistanceToSegment(fA,fC,p);
+	bestSqrDist[2] = sqrDistanceToSegment(fB,fC,p);
+
+	unsigned int offset=0;
+	if(bestSqrDist[0] < bestSqrDist[1])
+	{
+		if(bestSqrDist[0]  < bestSqrDist[2])
+			offset=0;
+		else
+			offset=2;
+
+	}
+	else
+	{
+		if(bestSqrDist[1] < bestSqrDist[2])
+			offset=1;
+		else
+			offset=2;
+	}
+
+	if(bestSqrDist[offset] < bestSqrDistVertex)
+	{
+		closestId = offset;
+		closestType=CLOSEST_TYPE_EDGE;
+		return bestSqrDist[offset];
+
+	}
+
+	closestId = bestVertex;
+	closestType=CLOSEST_TYPE_VERTEX;
+	return bestSqrDistVertex;
+
+
+}
+
 size_t findMaxLessThanOrEq(const vector< std::pair<size_t,size_t> > &v,
 			size_t value)
 {
@@ -92,7 +255,7 @@ float Determinant(float **a,int n)
 		//recurisve det
 		det = 0;
 		for (j1=0; j1<n; j1++) {
-			float **m = new float*[n-1];
+			auto m = new float*[n-1];
 			for (i=0; i<n-1; i++)
 				m[i] = new float[n-1];
 			for (i=1; i<n; i++) {
@@ -262,6 +425,39 @@ int intersect_RayTriangle( const Point3D &rayStart, const Point3D &rayEnd,
 
 //---- END This section under specific licence ---
 
+//Square distance between a line segment and a point in 3D space
+float sqrDistanceToSegment(const Point3D &fA, const Point3D &fB, const Point3D &p, unsigned int &closestIdx)
+{
+
+	//If the vectors ar pointing "together" then use  point-line formula
+	if((p-fA).dotProd(p-fB) < 0)
+	{
+		//Closest point is on the line sgement
+		closestIdx=1;
+
+		Point3D closestPt;
+		Point3D vAB= fB-fA;
+
+		//Use formula d^2 = |(B-A)(cross)(A-P)|^2/|B-A|^2
+		return (vAB.crossProd(fA-p)).sqrMag()/(vAB.sqrMag());
+	}
+
+	//Distances to a and b
+	float fADist,fBDist;
+	fADist = fA.sqrDist(p);
+	fBDist = fB.sqrDist(p);
+	if(fADist < fBDist)
+	{
+		closestIdx=0;
+		return fADist;
+	}
+	else
+	{
+		closestIdx=2;
+		return fBDist;
+	}
+}
+
 //Creates a list of pair,vector of point indices that are within a certain
 // tolerance radius of one another. Output first value in list will be strictly increasing. (i.e. it->first < (it+1)->first, regardless of it position)
 
@@ -271,7 +467,7 @@ int intersect_RayTriangle( const Point3D &rayStart, const Point3D &rayEnd,
 
 //TODO: Unify these two overloads!
 //--
-void findNearVerticies(float tolerance, const vector<Point3D> &ptVec,
+void findNearVertices(float tolerance, const vector<Point3D> &ptVec,
 		vector<std::pair<size_t,vector<size_t> > > &clusterList)
 {
 	ASSERT(!clusterList.size());
@@ -302,7 +498,7 @@ void findNearVerticies(float tolerance, const vector<Point3D> &ptVec,
 		if(curClustered.size())
 		{
 			marked[ui]=true;
-			clusterList.push_back(std::make_pair(ui,curClustered));
+			clusterList.emplace_back(ui,curClustered);
 			curClustered.clear();
 		}
 
@@ -310,7 +506,7 @@ void findNearVerticies(float tolerance, const vector<Point3D> &ptVec,
 
 }
 
-void findNearVerticies(float tolerance, const vector<Point3D> &ptVec,
+void findNearVertices(float tolerance, const vector<Point3D> &ptVec,
 		std::list<std::pair<size_t,vector<size_t> > > &clusterList)
 {
 	ASSERT(clusterList.empty());
@@ -341,7 +537,7 @@ void findNearVerticies(float tolerance, const vector<Point3D> &ptVec,
 		if(curClustered.size())
 		{
 			marked[ui]=true;
-			clusterList.push_back(std::make_pair(ui,curClustered));
+			clusterList.emplace_back(ui,curClustered);
 			curClustered.clear();
 		}
 
@@ -349,7 +545,94 @@ void findNearVerticies(float tolerance, const vector<Point3D> &ptVec,
 }
 //--
 
+//Barentzen & Aanaes, "Signed distance computation using the angle weighte psuedonormal"
+void Mesh::calculateAngleWeightedPsNormal(vector<Point3D> &faceNorm, 
+						vector<Point3D> &edgeNorm,
+						vector<Point3D> &vertexNorm) const
+{
 
+	//Compute the face normals for the triangle
+	calculateFaceNormals(faceNorm);
+
+	//Find the edge adjacency data
+	map<pair<size_t,size_t>,vector<size_t> > eMap;
+	getTriEdgeAdjacencyMapMk2(eMap);
+
+	//Compute the edge psuedo normals
+	calculateEdgeNormals(eMap,faceNorm,edgeNorm);
+
+	//Compute the vertex->triangle adjacency map
+	vector<vector<size_t> > vMap;
+	getTriVertexAdjacencyMap(vMap);
+
+	//Obtain the angle weighted normals for each vertex
+	getVertexAngleWeightedNormal(vMap, faceNorm,vertexNorm);
+
+}
+
+void Mesh::calculateFaceNormals(vector<Point3D> &faceNorm) const
+{
+	faceNorm.resize(triangles.size());
+
+	for(size_t ui=0;ui<triangles.size();ui++)
+		getTriNormal(ui,faceNorm[ui]);
+}
+
+void Mesh::calculateEdgeNormals(const std::map<std::pair<size_t,size_t>,std::vector<size_t> > &adjacencyMap,
+				const vector<Point3D> &faceNorm,
+				vector<Point3D> &edgeNorm) const
+{
+	ASSERT(faceNorm.size() == triangles.size());
+
+	//guessing that there are as many edges as triangles. In an infinite plane sheet
+	// there will be 3 edges per triangle, but each edge shared with another triangle,
+	// so this goes to 1.5 times. However, in a finite mesh, there will be more edges per triangle
+	edgeNorm.reserve(adjacencyMap.size());
+	map< pair<size_t,size_t> , pair<size_t,Point3D> > edgeNormMap;
+	for(const auto & it : adjacencyMap)
+	{
+		map<pair<size_t,size_t>,pair<size_t,Point3D> >::iterator itNorm;
+		itNorm=edgeNormMap.find(it.first);
+		//If we don't have the edge yet, make it
+		if(itNorm !=edgeNormMap.end())
+		{
+			for(unsigned int ui=0; ui<it.second.size();ui++)
+				itNorm->second.second+=faceNorm[it.second[ui]];
+			itNorm->second.first +=it.second.size();
+		}
+		else
+		{
+			//we have the edge, simply increment it and sum the vectors
+			pair<size_t,size_t> edge;
+			edge=it.first;
+
+			pair<size_t,Point3D> pN;
+			pN.first = it.second.size();
+			pN.second=Point3D(0,0,0);
+			for(unsigned int ui=0;ui<it.second.size();ui++)
+				pN.second+=faceNorm[((it.second)[ui])];
+			
+			edgeNormMap[edge]=pN;
+
+		}
+	}
+
+	size_t offset=0;
+	edgeNorm.resize(edgeNormMap.size());
+	for(auto itM=edgeNormMap.begin(); itM!=edgeNormMap.end(); itM++)
+	{
+		//Divide the summed edge normal vector by the normalisation count to compute
+		// mean edge normal
+		edgeNorm[offset] = itM->second.second*1.0f/(float)itM->second.first;
+		offset++;
+		
+	}
+
+#pragma omp parallel for
+	for(unsigned int ui=0;ui<edgeNorm.size();ui++)
+		edgeNorm[ui].normalise();
+
+}
 
 void Mesh::print(std::ostream &o) const
 {	
@@ -964,7 +1247,7 @@ void Mesh::mergeDuplicateVertices(float tol)
 
 	//Find the duplicates 
 	// placing duplicates into a list of sorted vectors of duplicate indices
-	findNearVerticies(tol,nodes,dups);
+	findNearVertices(tol,nodes,dups);
 	for(size_t ui=0;ui<dups.size();ui++)
 	{
 		std::sort(dups[ui].second.begin(),
@@ -1022,11 +1305,10 @@ void Mesh::mergeDuplicateVertices(float tol)
 
 	//obtain the set of vertices that have now been orphaned
 	vector<size_t> toRemove;
-	for(vector<pair<size_t,vector<size_t> > >::iterator it=dups.begin();
-		it!=dups.end();++it)
+	for(auto & dup : dups)
 	{
-		for(size_t ui=0;ui<it->second.size();ui++)
-			toRemove.push_back(it->second[ui]);
+		for(size_t ui=0;ui<dup.second.size();ui++)
+			toRemove.push_back(dup.second[ui]);
 	}
 
 	std::sort(toRemove.begin(),toRemove.end());
@@ -1393,7 +1675,7 @@ void Mesh::resurface(unsigned int newPhys)
 				}
 
 				if(!triClothedFace)
-					triMaps.push_back(std::make_pair(ui,uj));
+					triMaps.emplace_back(ui,uj);
 
 			}
 				
@@ -1479,7 +1761,7 @@ void Mesh::setTriangleMesh(const std::vector<float> &ptsX,
 	
 	const float MAX_SQR_RAD=0.001f;
 	std::list<std::pair<size_t,vector<size_t> > > clusterList;
-	findNearVerticies(MAX_SQR_RAD,ptVec,clusterList);
+	findNearVertices(MAX_SQR_RAD,ptVec,clusterList);
 
 
 	//FIXME: This is totally inefficient.
@@ -1495,10 +1777,10 @@ void Mesh::setTriangleMesh(const std::vector<float> &ptsX,
 
 	//Now run through the original mapping, and generate the new modified mapping.
 	//this maps old point -> "rally pt"
-	for(std::list<std::pair<size_t, vector<size_t> > >::iterator it=clusterList.begin();it!=clusterList.end();++it)
+	for(auto & it : clusterList)
 	{
-		for(size_t uj=0;uj<it->second.size();uj++)
-			triangleMapping[it->second[uj]]=it->first;
+		for(size_t uj=0;uj<it.second.size();uj++)
+			triangleMapping[it.second[uj]]=it.first;
 	}
 
 
@@ -2160,7 +2442,7 @@ void Mesh::getTriEdgeAdjacencyMap(std::vector<std::list<size_t> > &adj) const
 			//Compute the intersection of the two tri lookup table rows
 			list<size_t> intersect;
 			intersect=triLookup[v1];
-			for(list<size_t>::iterator it=intersect.begin();it!=intersect.end();)
+			for(auto it=intersect.begin();it!=intersect.end();)
 			{
 				if( find(triLookup[v2].begin(),triLookup[v2].end(),*it) == triLookup[v2].end())
 				{
@@ -2172,11 +2454,11 @@ void Mesh::getTriEdgeAdjacencyMap(std::vector<std::list<size_t> > &adj) const
 			}
 
 			//OK, so the intersection of the two lookups is the triangles attached to the nodes.
-			for(list<size_t>::iterator it=intersect.begin();it!=intersect.end();++it)
+			for(auto & it : intersect)
 			{
 				//Disallow self adjacency
-				if(*it !=ui)
-					adj[ui].push_back(*it);
+				if(it !=ui)
+					adj[ui].push_back(it);
 			}
 
 
@@ -2185,6 +2467,52 @@ void Mesh::getTriEdgeAdjacencyMap(std::vector<std::list<size_t> > &adj) const
 	}
 }
 
+void Mesh::getTriEdgeAdjacencyMapMk2(std::map<pair<size_t,size_t> ,
+			std::vector<size_t> > &eMap) const
+{
+	eMap.clear();
+
+	for(unsigned int ui=0;ui<triangles.size(); ui++)
+	{
+		//Build edge list
+		pair<size_t,size_t> edge;
+		for(unsigned int uj=0;uj<3;uj++)
+		{
+			//Make edge in (small,large) pairing
+			edge=make_pair(triangles[ui].p[uj],triangles[ui].p[(uj+1)%3]);
+			if(edge.first > edge.second)
+				std::swap(edge.first,edge.second);
+
+			//add edge-triangle linkage, updating map as needed
+			auto it=eMap.find(edge);
+			if( it== eMap.end())
+			{
+				vector<size_t> l;
+				l.push_back(ui);
+				eMap[edge] = l;
+			}
+			else
+				it->second.push_back(ui);
+		}
+	}
+
+}
+
+
+void Mesh::getTriVertexAdjacencyMap(std::vector<std::vector<size_t> > &vMap) const
+{
+	vMap.clear();
+
+	//Create a lookup table of vertices -> triangles
+	vMap.resize(nodes.size());
+	for(size_t ui=0; ui<triangles.size();ui++)
+	{
+		for(unsigned int uj=0;uj<3;uj++)
+			vMap[triangles[ui].p[uj]].push_back(ui);
+	}
+}
+
+
 unsigned int Mesh::divideMeshSurface(float divisionAngle, unsigned int newPhysGroupStart,
 			const vector<size_t> &physGroupsToSplit)
 {
@@ -2275,14 +2603,14 @@ unsigned int Mesh::divideMeshSurface(float divisionAngle, unsigned int newPhysGr
 			//Expand the boundary using the current boundary triangles
 
 			//loop over the current boundary
-			for(list<size_t>::iterator bIt=boundary.begin();bIt!=boundary.end();++bIt)
+			for(auto & bIt : boundary)
 			{
-				ASSERT(adjacencyMap[*bIt].size());
+				ASSERT(adjacencyMap[bIt].size());
 				//Check the adjacency map of the triangles adjacent to a specific boundary element
-				for(list<size_t>::iterator it=adjacencyMap[*bIt].begin();it!=adjacencyMap[*bIt].end();++it)
+				for(auto it=adjacencyMap[bIt].begin();it!=adjacencyMap[bIt].end();++it)
 				{
 					if(!touchedTris[*it] && 
-						(normalAngle(*bIt,*it) < divisionAngle || fabs(normalAngle(*bIt,*it,true)) < divisionAngle) )
+						(normalAngle(bIt,*it) < divisionAngle || fabs(normalAngle(bIt,*it,true)) < divisionAngle) )
 					{
 						//Alright then, add this new triangle to the potential new boundary
 						//(let us not add straight away, as we would like to expand in a minimum
@@ -2490,7 +2818,7 @@ void Mesh::getCurPhysGroups(std::vector<std::pair<unsigned int, size_t> > &curPh
 		if(!found)
 		{
 			//we've not seen this before...
-			curPhys.push_back(make_pair(triangles[ui].physGroup,1));
+			curPhys.emplace_back(triangles[ui].physGroup,1);
 			std::sort(curPhys.begin(),curPhys.end(),cmp);
 		}
 		
@@ -2694,8 +3022,7 @@ void Mesh::relax(size_t iterations, float relaxFactor)
 			factor=std::count(adjacencyList[ui].begin(),
 					adjacencyList[ui].end(),adjacencyList[ui][uj]);
 		
-			adjacencyFactors[ui].push_back(
-				std::make_pair(adjacencyList[ui][uj],factor));
+			adjacencyFactors[ui].emplace_back(adjacencyList[ui][uj],factor);
 		}
 	}
 	adjacencyList.clear();
@@ -2919,27 +3246,80 @@ void Mesh::pointsInside(const vector<Point3D> &p,
 	}
 }
 
+float Mesh::triVertexAngle(unsigned int tri, unsigned int triVertex) const
+{
+	ASSERT(tri < triangles.size());
+	ASSERT(triVertex < nodes.size());
+	TRIANGLE t;
+	t= triangles[tri];
 
-/*
-size_t Mesh::getNearestTri(const Point3D &p,float &signedDistance) const
+	Point3D v1,v2;
+	if(t.p[0] == triVertex)	
+	{
+		v1=nodes[t.p[2]]-nodes[t.p[0]];
+		v2=nodes[t.p[1]]-nodes[t.p[0]];
+		return v1.angle(v2);
+
+	}
+	else if (t.p[1] == triVertex)
+	{
+		v1=nodes[t.p[2]]-nodes[t.p[1]];
+		v2=nodes[t.p[0]]-nodes[t.p[1]];
+		return v1.angle(v2);
+	}
+	else if (t.p[2] == triVertex)
+	{
+		v1=nodes[t.p[0]]-nodes[t.p[2]];
+		v2=nodes[t.p[1]]-nodes[t.p[2]];
+		return v1.angle(v2);
+	}
+
+	ASSERT(false);
+
+}
+
+void Mesh::getVertexAngleWeightedNormal(const vector<vector<size_t> > &vAdjMap, const vector<Point3D> &triNorm,vector<Point3D> &norm) const
+{
+	ASSERT(vAdjMap.size() == nodes.size());
+	norm.resize(nodes.size());
+	for(unsigned int ui=0;ui<vAdjMap.size();ui++)
+	{
+		norm[ui]=Point3D(0,0,0);
+		for(unsigned int uj=0;uj<vAdjMap[ui].size(); uj++)
+		{
+			float angle;
+			angle = triVertexAngle(vAdjMap[ui][uj],ui);
+			norm[ui]+=triNorm[vAdjMap[ui][uj]]*angle;
+		}
+		//normalise the vector
+		norm[ui].normalise();
+	}
+}
+
+size_t Mesh::getNearestTri(const vector<Point3D> &faceNorms,
+			const Point3D &p,float &sqrDistance,
+			unsigned int &closestType, unsigned int &closestId) const
 {
 	//Loop over all the triangles in order to locate the nearest
 	size_t nearTri  = (size_t)-1;
-	float distance=std::numeric_limits<float>::max();
+	sqrDistance=std::numeric_limits<float>::max();
 	for(size_t ui=0;ui<triangles.size();ui++)
 	{
 		Point3D normal;
-		getTriNormal(ui,normal);
+		normal=faceNorms[ui];
 		
-		float newDist;
-		newDist=signedDistanceToFacet(nodes[triangles[ui].p[0]],
+		float newSqrDist;
+		unsigned int closestTypeT, closestIdT;
+		newSqrDist=sqrDistanceToFacet(nodes[triangles[ui].p[0]],
 					nodes[triangles[ui].p[1]],
-					nodes[triangles[ui].p[2]],normal,p);
-		if(fabs(newDist) < distance)
+					nodes[triangles[ui].p[2]],normal,p,
+					closestTypeT,closestIdT);
+		if(newSqrDist < sqrDistance)
 		{
 			nearTri=ui;
-			distance= fabs(newDist);
-			signedDistance=newDist;
+			closestType=closestTypeT;
+			closestId=closestIdT;
+			sqrDistance= newSqrDist;
 		}
 	}
 
@@ -2947,6 +3327,7 @@ size_t Mesh::getNearestTri(const Point3D &p,float &signedDistance) const
 }
 
 
+/*
 bool Mesh::isOrientedCoherently() const
 {
 	ASSERT(isSane());
@@ -3001,8 +3382,6 @@ bool Mesh::isOrientedCoherently() const
 	return true;
 }
 
-
-
 void Mesh::orientTriEdgesCoherently() 
 {
 	//Need to check circulation of triangles, (edge A->B on one triangle matches that of the other).
@@ -3151,10 +3530,10 @@ bool coherencyTests()
 	//---
 	Mesh m;
 
-	m.nodes.push_back(Point3D(0,0,0));
-	m.nodes.push_back(Point3D(0,0,1));
-	m.nodes.push_back(Point3D(1,0,0));
-	m.nodes.push_back(Point3D(0,1,0));
+	m.nodes.emplace_back(Point3D(0,0,0));
+	m.nodes.emplace_back(Point3D(0,0,1));
+	m.nodes.emplace_back(Point3D(1,0,0));
+	m.nodes.emplace_back(Point3D(0,1,0));
 
 	TRIANGLE t;
 	t.p[0] = 0;
@@ -3191,36 +3570,129 @@ bool coherencyTests()
 
 	return true;
 }
-
-bool nearestTriTest()
+Mesh rightAngleMesh()
 {
 	Mesh m;
+	//Right-angled joined triangles, in XY and YZ plane
+	m.nodes.emplace_back(Point3D(0,0,0));
+	m.nodes.emplace_back(Point3D(1,0,0));
+	m.nodes.emplace_back(Point3D(0,1,0));
+	m.nodes.emplace_back(Point3D(0,0,1));
 
-	//Make an L shaped edge
-	m.nodes.push_back(Point3D(1,0,0));
-	m.nodes.push_back(Point3D(-1,0,0));
-	m.nodes.push_back(Point3D(0,0,1));
-	m.nodes.push_back(Point3D(0,1,0));
-
-
-	//0,3,1
 	TRIANGLE t;
 	t.p[0]=0;
+	t.p[1]=1;
+	t.p[2]=2;
+	m.triangles.push_back(t);
+	t.p[0]=0;
 	t.p[1]=3;
 	t.p[2]=1;
 	m.triangles.push_back(t);
 
-	//0,1,2
-	t.p[0]=0;
-	t.p[1]=1;
-	t.p[2]=2;
-	m.triangles.push_back(t);
+
+	return m;
+}
+
+bool edgeMaptest()
+{
+	Mesh m = rightAngleMesh();
+	vector<list<size_t> > eMap;
+	m.getTriEdgeAdjacencyMap(eMap);
+
+	//Two triangles
+	TEST(eMap.size() ==2, "Triangle count");
+	for(unsigned int ui=0;ui<eMap.size();ui++)
+	{
+		//Two edges per triangle
+		TEST(eMap[ui].size() ==1, "Edge count");
+		for(auto it=eMap[ui].begin();it!=eMap[ui].end(); ++it)
+		{
+			size_t triIdx;
+			triIdx =*it;
+			TEST((triIdx == 0 || triIdx ==1), "triangle edge index");
+		}
+
+	}
+
+	return true;
+}
+
+bool normalTest()
+{
+	Mesh m=rightAngleMesh();
+
+	vector<Point3D> norms;
+	m.calculateFaceNormals(norms);
+
+	TEST(norms.size() == 2,"normal count");
+
+	for(auto ui=0; ui < norms.size(); ui++)
+	{
+		TEST(EQ_TOL(norms[ui].sqrMag(),1),"Normal magnitude");
+	}
+
+	TEST(EQ_TOL(norms[0].dotProd(Point3D(0,0,1)),1),"Normal direction");
+	TEST(EQ_TOL(norms[1].dotProd(Point3D(0,1,0)),1),"Normal direction");
+
+	return true;
+}
+
+bool psuedoNormalTest()
+{
+	using std::map;
+
+	Mesh m;
+	m=rightAngleMesh();
+
+	vector<Point3D> fNorms;
+	m.calculateFaceNormals(fNorms);
+	map<pair<size_t,size_t>,vector<size_t> > eMap;
+	m.getTriEdgeAdjacencyMapMk2(eMap);
+
+	TEST(eMap.size() == 5,"Edge adjacency map tests");
+	vector<Point3D> eNorms;
+	m.calculateEdgeNormals(eMap,fNorms,eNorms);
+
+
+	TEST(eNorms.size() ==5,"Edge normal tetst");
+
+	for(unsigned int ui=0;ui<eNorms.size();ui++)
+	{
+		TEST(EQ_TOL(eNorms[ui].sqrMag(),1),"normal magnitude");
+	}
+
+	vector<vector<size_t> > vMap;
+	m.getTriVertexAdjacencyMap(vMap);
+
+	TEST(vMap.size()==m.nodes.size(),"Vertex adjacency map size (1 per vertex)");
+
+	TEST(vMap[0].size()==2,"Vertex adjacency map size (v0)");
+	TEST(vMap[1].size()==2,"Vertex adjacency map size (v1)");
+	TEST(vMap[2].size()==1,"Vertex adjacency map size (v2)");
+	TEST(vMap[3].size()==1,"Vertex adjacency map size (v3)");
+
+	vector<Point3D> pNorms;
+	m.getVertexAngleWeightedNormal(vMap, fNorms,pNorms);
+
+	return true;
+}
+
+bool nearestTriTest()
+{
+	Mesh m;
+	m=rightAngleMesh();
+
+	vector<Point3D> faceNormals;
+	m.calculateFaceNormals(faceNormals);
 	
 	//Test that the exterior test works, 
-	// using point (0.5,0,0.4)
-	//float dist;
-	//TEST(m.getNearestTri(Point3D(0,0.5,0.4),dist) == 0,"Nearest tri");
-	//TEST(m.getNearestTri(Point3D(0,0.5,0.6),dist) == 1,"Nearest tri");
+	// using points (0,0.5,0.4) and (0,0.5,0.6)
+	float distSqr;
+	unsigned int closestType,closestId;
+	TEST(m.getNearestTri(faceNormals,Point3D(0,0.5,0.4),
+				distSqr,closestType,closestId) == 0,"Nearest tri");
+	TEST(m.getNearestTri(faceNormals,Point3D(0,0.5,0.6),
+				distSqr,closestType,closestId) == 1,"Nearest tri");
 
 	return true;
 
@@ -3229,7 +3701,13 @@ bool nearestTriTest()
 bool meshTests()
 {
 	TEST(coherencyTests(),"Mesh coherency checks");
-	TEST(nearestTriTest(),"Mesh nearest tri");
+	TEST(nearestTriTest(),"Mesh edge adjacency test");
+	TEST(edgeMaptest(),"Mesh nearest tri");
+	TEST(normalTest(),"Mesh nearest tri");
+	TEST(psuedoNormalTest(),"Edge Psuedo normal");
+
+	
+
 	return true;
 }
 
