@@ -23,6 +23,8 @@
 #include <vector>
 #include <fstream>
 #include <list>
+#include <map>
+#include <utility>
 
 //GMSH load constants
 //-----------
@@ -70,7 +72,7 @@ class Mesh
 {
 	private:
 
-		//!Returns true if ui and uj are the same
+		//!Returns true if triangles ui and uj are the same
 		bool sameTriangle(unsigned int ui, unsigned int uj) const;
 		static bool sameTriangle(const TRIANGLE &t1, const TRIANGLE &t2);
 
@@ -86,14 +88,6 @@ class Mesh
 		//!Get a list of all disconnected tetrahedra	
 		void getDisconnectedTets(std::vector<size_t> &tetIdx) const;	
 
-		//!Build an adjacency listing for the triangles in the mesh
-		//using vertex sharing rules
-		//i.e. this will retrieve all vector of all triangles who share edge incidence 
-		// for a specified vertex, eg: <|>  vertex only 
-		//incident triangles eg : |>*<| , will be excluded.
-		//The returned map can be used to perform triangle -> surrounding triangle lookups for shared edge
-		// incidence
-		void getTriEdgeAdjacencyMap(std::vector<std::list<size_t> > &map) const;
 
 		//!Return the normal angle (in rad) between two triangles
 		float normalAngle(size_t triOne,size_t triTwo,bool flip=false ) const;
@@ -103,6 +97,13 @@ class Mesh
 
 		//!Kill specified orphan nodes within this dataset
 		void killOrphanNodes(const std::vector<size_t> &orphans) ;
+
+		//!Obtain the angle that is formed by the given vertex (in mesh node number)
+		float triVertexAngle(unsigned int tri, unsigned int vertex) const;
+
+		//!Find the nearest triangle to a given point, and whether it is closest by
+		// edge, vertex or face
+
 	public:
 		//!Point storage for 3D Data (nodes/coords/vertices..)
 		std::vector<Point3D> nodes;
@@ -223,12 +224,13 @@ class Mesh
 		//Print some statistics about the mesh data
 		void print(std::ostream &o) const;
 
-		//Flip normals in the mesh in order to have coherently oriented normals for all contigous objects.
+		//Flip normals in the mesh in order to have coherently oriented normals for all contiguous objects.
 		//No guarantee is given as to which surface will be inside and which will be outside.
 		//FIXME: BROKEN
 		void orientTriEdgesCoherently() ;
 		
 		//Returns true if the mesh is coherently oriented
+		//FIXME: BROKEN
 		bool isOrientedCoherently()  const;
 
 		//!Kill specified orphan nodes within this dataset
@@ -237,14 +239,53 @@ class Mesh
 		//!Perform vertex weighted relaxation
 		void relax(size_t iterations, float relaxFactor);
 
-		//Find the poitns that lie inside a this mesh
+		//Find the points that lie inside a this mesh
 		void pointsInside(const std::vector<Point3D> &p,
 			std::vector<bool> &meshResults, std::ostream &msgs, bool wantProg) const ;
 
 		//Find the nearest triangle to a particular point
-		size_t getNearestTri(const Point3D &p,float &distance)  const;
+		// this retuns the square-distance, as well as the 
+		// type and ID of the closest sub-elements of the triangle (ie face/edge/vertex)
+		size_t getNearestTri(const std::vector<Point3D> &faceNorm, 
+				const Point3D &p,float &sqrDistance,
+				unsigned int &closestType, unsigned int &closestId) const;
 
+		//Obtain the normal of the given triangle
 		void getTriNormal(size_t tri, Point3D &normal) const;
+
+
+		void calculateAngleWeightedPsNormal(std::vector<Point3D> &faceNorm, 
+						std::vector<Point3D> &edgeNorm,
+						std::vector<Point3D> &vertexNorm) const;
+
+		//Find all the normals to the triangle faces of the mesh
+		void calculateFaceNormals(std::vector<Point3D> &faceNorm) const;
+		
+		//Find all the normals to the triangle edges of the mesh, using an existing adjacency map
+		void calculateEdgeNormals(const std::map<std::pair<size_t,size_t>,std::vector<size_t> > &adjacencyMap,
+				const std::vector<Point3D> &faceNorm,
+				std::vector<Point3D> &edgeNorm) const;
+		
+		//!Build an adjacency listing for the triangles in the mesh to their edges
+		//i.e. this will retrieve all vector of all triangles who share edge incidence 
+		// for a specified vertex, eg: <|>  vertex only 
+		//incident triangles eg : |>*<| , will be excluded.
+		//The returned map can be used to perform triangle -> surrounding triangle lookups for shared edge
+		// incidence
+		void getTriEdgeAdjacencyMap(std::vector<std::list<size_t> > &eMap) const;
+	
+		//!Build edge adjacency map, map any node pair in the network to the incident triangle
+		// Edges are not in triangle orientation order, they are in (smallest,largest) pairing
+		void getTriEdgeAdjacencyMapMk2(std::map<std::pair<size_t,size_t> ,std::vector<size_t> > &eMap) const;
+		
+		//!Build an adjacency listing for the triangles in the mesh to their vertices
+		// output map will have size equal to number of triangles, with list entries as vertex indices
+		void getTriVertexAdjacencyMap(std::vector<std::vector<size_t> > &vMap) const;
+
+
+		//!Obtain the per-vertex angle weighted pseudonormal
+		void  getVertexAngleWeightedNormal(const std::vector<std::vector<size_t> > &vAdjMap, 
+					const std::vector<Point3D> &triNorm,std::vector<Point3D> &norm) const;
 };
 
 #ifdef DEBUG
