@@ -139,11 +139,15 @@ template<class T> class Voxels
 		//!Swap object contents with other voxel object
 		void swap(Voxels<T> &v);
 
-		//!Clone this into another object
+		//!Clone this into another object FIXME: rename to copy
 		void clone(Voxels<T> &newClone) const;
 
 		//!Set the value of a point in the dataset
 		void setPoint(const Point3D &pt, const T &val);
+
+		//!Reverse the data such that vData[ui,uj,uk] == vData[size-ui,uj,uk] (if axis is 0);
+		void reverseAxis(unsigned int axis);
+
 		//!Retrieve the value of a datapoint, this is rounded to the nearest voxel
 		T getPointData(const Point3D &pt) const;
 
@@ -162,7 +166,6 @@ template<class T> class Voxels
 				size_t y, size_t z) const;
 		//!Retrieve the value of a specific voxel
 		inline T getData(size_t x, size_t y, size_t z) const;
-		inline T getData(size_t *array) const;
 		//!Retrieve value of the nth voxel
 		inline T getData(size_t i) const { return voxels[i];}
 
@@ -191,7 +194,6 @@ template<class T> class Voxels
 		void getSlice(size_t normal, size_t offset, T *p) const;
 		//!Get the size of the data field
 		void getSize(size_t &x, size_t &y, size_t &z) const;
-		size_t getSize() const {return voxels.size();};
 
 		//!Resize the data field
 		/*! This will destroy any data that was already in place
@@ -312,7 +314,19 @@ template<class T> class Voxels
 							 size_t boundMode=BOUND_CLIP); 
 		
 		
+		//!Threshold the voxels, keeping either the lower or upper values above this threshold
+		/* Data outside (either above if keepUpper is true, or below threshold if keepUpper is false)
+		* will be set to the new value
+		*/
+		void threshold(const T &thresh, bool keepUpper,const T & newVal); 
+		
+		//!Generate a boolean voxel field stating whether the data is above or below the threshold specified
+		/* Data below the threshold will be true if keepUpper is false, and vice-versa
+		*/
+		void thresholdToBoolMask(const T &thresh, bool keepUpper,Voxels<bool> &result) const; 
 
+		//!Apply a mask to this dataset, where the mask is true (if not inverting), replace with specified val (newVal)
+		void applyMask(const Voxels<bool> &mask, const T &newVal, bool invert=false);
 
 		//!Find the positions of the voxels that are above or below a given value
 		/*! Returns the positions of the voxels' centroids for voxels that have, by default,
@@ -447,6 +461,63 @@ void Voxels<T>::setPoint(const Point3D &point,const T &val)
 	voxels[vigra::Shape3(pos[0],pos[1],pos[2])] = val;
 }
 
+template<class T>
+void Voxels<T>::reverseAxis(unsigned int axis)
+{
+	//FIXME:  less lazy implementation, with less counter jumping
+	switch(axis)
+	{
+		case 0:
+		{
+			for(auto ui=0;ui<binCount[axis];ui++)
+			{
+				for(auto uj=0;uj<binCount[1];uj++)
+				{
+					for(auto uk=0;uk<binCount[2];uk++)
+					{
+						setData(binCount[axis]-ui-1,uj,uk,
+							getData(ui,uj,uk));
+					}
+				}
+			}
+			break;
+		}
+		case 1:
+		{
+			for(auto ui=0;ui<binCount[axis];ui++)
+			{
+				for(auto uj=0;uj<binCount[2];uj++)
+				{
+					for(auto uk=0;uk<binCount[0];uk++)
+					{
+						setData(uk,binCount[axis]-ui-1,uj,
+							getData(uk,ui,uj));
+					}
+				}
+			}
+			break;
+		}
+		case 2:
+		{
+			for(auto ui=0;ui<binCount[axis];ui++)
+			{
+				for(auto uj=0;uj<binCount[0];uj++)
+				{
+					for(auto uk=0;uk<binCount[1];uk++)
+					{
+						setData(uj,uk,binCount[axis]-ui-1,
+							getData(uj,uk,ui));
+					}
+				}
+			}
+			break;
+		}
+		default:
+			ASSERT(false);
+	}
+
+}
+
 template<class T>
 void Voxels<T>::setData(size_t x, size_t y, 
 			size_t z, const T &val)
@@ -998,6 +1069,13 @@ template<class T>
 void Voxels<T>::setBounds(const Point3D &pMin, const Point3D &pMax)
 {
 	ASSERT(voxels.size());
+#ifdef DEBUG
+	for(auto ui=0;ui<3;ui++)
+	{
+		ASSERT(pMin[ui] <=pMax[ui]);
+	}
+#endif
+
 	minBound=pMin;
 	maxBound=pMax;
 }
@@ -1257,6 +1335,98 @@ void Voxels<T>::thresholdForPosition(std::vector<Point3D> &p, const T &thresh, b
 	}
 }
 
+template<class T>
+void Voxels<T>::threshold(const T &thresh, bool keepUpper, const T &newVal)
+{
+
+	if(keepUpper)
+	{
+#pragma omp parallel for
+		for(size_t ui=0;ui<(size_t)binCount[0]; ui++)
+		{
+			for(size_t uj=0;uj<binCount[1]; uj++)
+			{
+				for(size_t uk=0;uk<binCount[2]; uk++)
+				{
+					if( getData(ui,uj,uk) < thresh)
+						setData(ui,uj,uk,newVal);
+				}
+			}
+		}
+	}
+	else
+	{
+#pragma omp parallel for
+		for(size_t ui=0;ui<(size_t)binCount[0]; ui++)
+		{
+			for(size_t uj=0;uj<binCount[1]; uj++)
+			{
+				for(size_t uk=0;uk<binCount[2]; uk++)
+				{
+					if( getData(ui,uj,uk) > thresh)
+						setData(ui,uj,uk,newVal);
+				}
+			}
+		}
+	}
+}
+
+template<class T>
+void Voxels<T>::thresholdToBoolMask(const T &thresh, bool keepUpper, Voxels<bool> &result) const
+{
+	result.resize(binCount[0],binCount[1],binCount[2],
+				minBound,maxBound);
+	
+#pragma omp parallel for
+	for(size_t ui=0;ui<(size_t)binCount[0]; ui++)
+	{
+		for(size_t uj=0;uj<binCount[1]; uj++)
+		{
+			for(size_t uk=0;uk<binCount[2]; uk++)
+			{
+				bool res;
+				res=(getData(ui,uj,uk) > thresh); 
+				
+				result.setData(ui,uj,uk,XOR(keepUpper,res));
+			}
+		}
+	}
+
+}
+
+template<class T>
+void Voxels<T>::applyMask(const Voxels<bool> &mask, const T&newVal,bool invert)
+{
+	ASSERT(mask.size() == size());
+	ASSERT(mask.getMinBounds()== minBound);
+	ASSERT(mask.getMaxBounds() == maxBound);
+#ifdef DEBUG
+	size_t v[3];
+	mask.getSize(v[0],v[1],v[2]);
+	for(auto i=0;i<3;i++)
+	{
+		ASSERT(v[i] == binCount[i]);
+	}
+#endif
+
+	if(invert)
+	{
+		for(auto i=0; i<voxels.size(); i++)
+		{
+			if(!mask.getData(i))
+				voxels[i]=newVal;
+		}
+	}
+	else
+	{
+		for(auto i=0; i<voxels.size(); i++)
+		{
+			if(mask.getData(i))
+				voxels[i]=newVal;
+		}
+	}
+}
+
 template<class T>
 void Voxels<T>::binarise(Voxels<T> &result, const T &thresh, 
 				const T &onThresh, const T &offThresh) const
@@ -1334,13 +1504,13 @@ int Voxels<T>::countPoints( const std::vector<Point3D> &points, bool noWrap, boo
 		if(*voxelsWantAbort)
 			return VOXEL_ABORT_ERR;
 		
-		T value;
 		getIndex(x,y,z,points[ui]);
 
 		//Ensure it lies within the dataset	
 		if(x < binCount[0] && y < binCount[1] && z< binCount[2])
 		{
 			{
+				T value;
 				value=getData(x,y,z)+T(1);
 
 				//Prevent wrap-around errors
