@@ -59,11 +59,11 @@ std::string unescapeXML(const std::string &input)
 		"&apos;",
 		"&quot;",
 		"&amp;",
-		0
+		nullptr
 	} ;
 
 	std::string data=input;
-	for( size_t i = 0 ; refs[i] != NULL ; i++ )
+	for( size_t i = 0 ; refs[i] != nullptr ; i++ )
 	{
 		std::string::size_type pos = data.find( refs[i] ) ;
 
@@ -100,6 +100,24 @@ template<> unsigned int XMLHelpGetProp(std::string  &prop,xmlNodePtr node, strin
 	return 0;
 }
 
+template<>
+bool XMLGetNextElemAttrib(xmlNodePtr &nodePtr, std::string &v, const char *nodeName, const char *attrib)
+{
+	xmlChar *xmlString;
+	//====
+	if(XMLHelpFwdToElem(nodePtr,nodeName))
+		return false;
+
+	xmlString=xmlGetProp(nodePtr,(const xmlChar *)attrib);
+	if(!xmlString)
+		return false;
+	v=(char *)xmlString;
+
+	xmlFree(xmlString);
+
+	return true;
+}
+
 //Specialisation for string. The stream_cast used by default will fail on empty string
 template<>
 bool XMLGetAttrib(xmlNodePtr &nodePtr, std::string &v, const char *attrib)
@@ -138,7 +156,7 @@ unsigned int XMLHelpFwdToElem(xmlNodePtr &node, const char *nodeName)
 	do
 	{	
 		node=node->next;
-	}while(node != NULL &&  
+	}while(node != nullptr &&  
 		xmlStrcmp(node->name,(const xmlChar *) nodeName));
 	return (!node);
 }
