@@ -55,8 +55,7 @@ Camera::Camera() : lock(false),origin(0.0f,0.0f,0.0f), viewDirection(0.0f,0.0f,-
 }
 
 Camera::~Camera()
-{
-}
+= default;
 
 
 Point3D Camera::getOrigin() const
@@ -170,7 +169,7 @@ CameraLookAt::CameraLookAt()  : target(Point3D(0,0,0)),fovAngle(90.0f),
 
 Camera *CameraLookAt::clone() const
 {
-	CameraLookAt *retCam = new CameraLookAt;
+	auto retCam = new CameraLookAt;
 
 	retCam->origin =origin;
 	retCam->viewDirection=viewDirection;
@@ -191,8 +190,7 @@ Camera *CameraLookAt::clone() const
 }
 
 CameraLookAt::~CameraLookAt()
-{
-}
+= default;
 
 void CameraLookAt::setTarget(const Point3D &pt)
 {
@@ -614,9 +612,9 @@ void CameraLookAt::getProperties(CameraProperties &p) const
 	std::vector<std::pair<unsigned int,string> > choices;
 	string tmp;
 	tmp=TRANS("Perspective");
-	choices.push_back(make_pair((unsigned int)PROJECTION_MODE_PERSPECTIVE,tmp));
+	choices.emplace_back((unsigned int)PROJECTION_MODE_PERSPECTIVE,tmp);
 	tmp=TRANS("Orthogonal");
-	choices.push_back(make_pair((unsigned int)PROJECTION_MODE_ORTHOGONAL,tmp));
+	choices.emplace_back((unsigned int)PROJECTION_MODE_ORTHOGONAL,tmp);
 	
 	cp.data=choiceString(choices,projectionMode);
 	cp.name=TRANS("Projection");
