@@ -31,18 +31,22 @@
 
 //Static class variables
 //====
-const Camera *DrawableObj::curCamera = 0;
+const Camera *DrawableObj::curCamera = nullptr;
 
 float DrawableObj::backgroundR;
 float DrawableObj::backgroundG;
 float DrawableObj::backgroundB;
 
 bool DrawableObj::useAlphaBlend;
-TexturePool *DrawableObj::texPool=0;
+TexturePool *DrawableObj::texPool=nullptr;
 
 unsigned int DrawableObj::winX;
 unsigned int DrawableObj::winY;
 
+
+#ifdef ENABLE_LIBVD
+bool glewInited=false;
+#endif
 //==
 
 
@@ -68,7 +72,7 @@ void drawCone(const Point3D &axisVec, const Point3D &origin,
 	Point3D rotAxis;
 	rotAxis=zAxis.crossProd(axis);
 	
-	Point3D *ptArray = new Point3D[numSegments];
+	auto ptArray = new Point3D[numSegments];
 
 	const float ROT_TOL=sqrtf(std::numeric_limits<float>::epsilon()) ;
 
@@ -283,8 +287,7 @@ DrawableObj::DrawableObj() : active(true), haveChanged(true), canSelect(false),
 }
 
 DrawableObj::~DrawableObj()
-{
-}
+= default;
 	
 	
 float DrawableObj::getHighContrastValue() 
@@ -334,7 +337,7 @@ void DrawableObj::clearTexPool()
 {
 	ASSERT(texPool);
 	delete texPool;
-	texPool=0;
+	texPool=nullptr;
 }
 
 Point3D DrawableObj::getCentroid() const
@@ -360,12 +363,11 @@ DrawPoint::DrawPoint(const Point3D &p) : origin(p), r(1.0f), g(1.0f), b(1.0f),a(
 }
 
 DrawPoint::~DrawPoint()
-{
-}
+= default;
 
 DrawableObj* DrawPoint::clone() const
 {
-	DrawPoint *d = new DrawPoint(*this);
+	auto d = new DrawPoint(*this);
 	return d;
 }
 
@@ -403,12 +405,11 @@ DrawVector::DrawVector() : origin(0.0f,0.0f,0.0f), vector(0.0f,0.0f,1.0f),drawAr
 }
 
 DrawVector::~DrawVector()
-{
-}
+= default;
 
 DrawableObj* DrawVector::clone() const
 {
-	DrawVector *d = new DrawVector(*this);
+	auto d = new DrawVector(*this);
 	return d;
 }
 
@@ -546,13 +547,12 @@ DrawTriangle::DrawTriangle() : r(1.0f), g(1.0f),b(1.0f),a(1.0f)
 }
 
 DrawTriangle::~DrawTriangle()
-{
-}
+= default;
 
 
 DrawableObj* DrawTriangle::clone() const
 {
-	DrawTriangle *d = new DrawTriangle(*this);
+	auto d = new DrawTriangle(*this);
 	return d;
 }
 
@@ -574,14 +574,14 @@ void DrawTriangle::draw() const
 {
 	glColor4f(r,g,b,a);
 	glBegin(GL_TRIANGLES);
-		for(size_t ui=0;ui<3;ui++)
-			glVertex3fv(vertices[ui].getValueArr());
+		for(const auto & vertex : vertices)
+			glVertex3fv(vertex.getValueArr());
 	glEnd();
 }
 
 DrawableObj* DrawQuad::clone() const
 {
-	DrawQuad *d = new DrawQuad(*this);
+	auto d = new DrawQuad(*this);
 	return d;
 }
 
@@ -641,8 +641,8 @@ void DrawQuad::recomputeParams(const vector<Point3D> &vecs,
 
 			Point3D delta = vecs[0]-curOrig;
 
-			for(size_t ui=0;ui<4;ui++)
-				vertices[ui]+=delta;
+			for(auto & vertex : vertices)
+				vertex+=delta;
 
 
 			break;
@@ -652,7 +652,7 @@ void DrawQuad::recomputeParams(const vector<Point3D> &vecs,
 	}
 }
 
-DrawTexturedQuad::DrawTexturedQuad() :textureData(0), textureId((unsigned int)-1), noColour(false) , needsBinding(true)
+DrawTexturedQuad::DrawTexturedQuad() :textureData(nullptr), textureId((unsigned int)-1), noColour(false) , needsBinding(true)
 {
 }
 
@@ -786,7 +786,7 @@ void DrawPolygon::setVertices(const vector<Point3D> &p)
 
 DrawableObj *DrawPolygon::clone() const
 {
-	DrawPolygon *d= new DrawPolygon;
+	auto d= new DrawPolygon;
 	d->r=r;
 	d->g=g;
 	d->b=b;
@@ -816,8 +816,8 @@ void DrawPolygon::draw() const
 			glColor4f(r,g,b,a);
 			glBegin(GL_LINE_LOOP);
 
-			for(unsigned int ui=0;ui<vertices.size();ui++)
-				glVertex3fv(vertices[ui].getValueArr());
+			for(const auto & vertex : vertices)
+				glVertex3fv(vertex.getValueArr());
 			glEnd();
 			break;
 		};
@@ -843,8 +843,7 @@ DrawTriangleMesh::DrawTriangleMesh()
 }
 
 DrawTriangleMesh::~DrawTriangleMesh()
-{
-}
+= default;
 
 void DrawTriangleMesh::draw() const
 {
@@ -862,16 +861,16 @@ void DrawTriangleMesh::draw() const
 			if(deltaOrigin.sqrMag() > 0)
 				glTranslatef(deltaOrigin[0],deltaOrigin[1],deltaOrigin[2]);
 			glBegin(GL_TRIANGLES);
-			for(unsigned int ui=0;ui<triIndices.size();ui++)
+			for(const auto & triIndex : triIndices)
 			{
 				for(unsigned int uj=0;uj<3;uj++)
 				{
 					float rgba[4];
 					for( unsigned int uk=0;uk<3; uk++)
-						rgba[uk]=triIndices[ui].col[uj].v[uk];
+						rgba[uk]=triIndex.col[uj].v[uk];
 					rgba[3]=alpha;
 					glColor4fv(rgba);
-					glVertex3fv(pts[triIndices[ui].idx[uj]].getValueArr());
+					glVertex3fv(pts[triIndex.idx[uj]].getValueArr());
 				}
 			}
 			glEnd();
@@ -882,11 +881,11 @@ void DrawTriangleMesh::draw() const
 			{
 				glBegin(GL_LINES);
 				glColor4f(0,0,1.0f,1.0f);
-				for(unsigned int ui=0;ui<triIndices.size();ui++)
+				for(const auto & triIndex : triIndices)
 				{
 					for(unsigned int uj=0;uj<4;uj++)
 					{
-						glVertex3fv(pts[triIndices[ui].idx[(uj%3)]].getValueArr());
+						glVertex3fv(pts[triIndex.idx[(uj%3)]].getValueArr());
 					}
 				}
 				glEnd();
@@ -956,7 +955,7 @@ DrawSphere::~DrawSphere()
 
 DrawableObj *DrawSphere::clone() const
 {
-	DrawSphere *d = new DrawSphere();
+	auto d = new DrawSphere();
 	d->r=r;
 	d->g=g;
 	d->b=b;
@@ -1227,13 +1226,12 @@ DrawManyPoints::DrawManyPoints() : r(1.0f),g(1.0f),b(1.0f),a(1.0f), size(1.0f)
 }
 
 DrawManyPoints::~DrawManyPoints() 
-{
-}
+= default;
 
 
 DrawableObj* DrawManyPoints::clone() const
 {
-	DrawManyPoints *d = new DrawManyPoints(*this);
+	auto d = new DrawManyPoints(*this);
 	return d;
 }
 
@@ -1304,9 +1302,9 @@ void DrawManyPoints::draw() const
 	glBegin(GL_POINTS);
 		glColor4f(r,g,b,a);
 		//TODO: Consider Vertex buffer objects. would be faster, but less portable.
-		for(unsigned int ui=0; ui<pts.size(); ui++)
+		for(const auto & pt : pts)
 		{
-			glVertex3fv(pts[ui].getValueArr());
+			glVertex3fv(pt.getValueArr());
 		}
 	glEnd();
 }
@@ -1388,14 +1386,14 @@ void DrawDispList::draw() const
 //========
 
 
-DrawGLText::DrawGLText(std::string fontFile, unsigned int mode) :font(0),fontString(fontFile),
+DrawGLText::DrawGLText(std::string fontFile, unsigned int mode) :font(nullptr),fontString(fontFile),
 	curFontMode(mode), origin(0.0f,0.0f,0.0f), 
 	r(0.0),g(0.0),b(0.0),a(1.0), up(0.0f,1.0f,0.0f),  
 	textDir(1.0f,0.0f,0.0f), readDir(0.0f,0.0f,1.0f), 
 	isOK(true),ensureReadFromNorm(true) 
 {
 
-	font=0;
+	font=nullptr;
 	switch(mode)
 	{
 		case FTGL_BITMAP:
@@ -1419,7 +1417,7 @@ DrawGLText::DrawGLText(std::string fontFile, unsigned int mode) :font(0),fontStr
 		default:
 			//Don't do this. Use valid font numbers
 			ASSERT(false);
-			font=0; 
+			font=nullptr; 
 	}
 
 	//In case of allocation failure or invalid font num
@@ -1440,13 +1438,13 @@ DrawGLText::DrawGLText(std::string fontFile, unsigned int mode) :font(0),fontStr
 	alignVertMode = DRAWTEXT_ALIGN_LOWER;
 }
 
-DrawGLText::DrawGLText(const DrawGLText &oth) : font(0), fontString(oth.fontString),
+DrawGLText::DrawGLText(const DrawGLText &oth) : font(nullptr), fontString(oth.fontString),
 	curFontMode(oth.curFontMode), origin(oth.origin), r(oth.r),
 	g(oth.g), b(oth.b), a(oth.a), up(oth.up), textDir(oth.textDir),
 	readDir(oth.readDir),isOK(oth.isOK), ensureReadFromNorm(oth.ensureReadFromNorm)
 {
 
-	font=0;
+	font=nullptr;
 	switch(curFontMode)
 	{
 		case FTGL_BITMAP:
@@ -1470,7 +1468,7 @@ DrawGLText::DrawGLText(const DrawGLText &oth) : font(0), fontString(oth.fontStri
 		default:
 			//Don't do this. Use valid font numbers
 			ASSERT(false);
-			font=0; 
+			font=nullptr; 
 	}
 
 	//In case of allocation failure or invalid font num
@@ -1698,7 +1696,7 @@ DrawGLText::~DrawGLText()
 	if(font)
 	{
 		delete font;
-		font=0;
+		font=nullptr;
 	}
 }
 
@@ -1840,7 +1838,7 @@ DrawGL2DText::DrawGL2DText(const std::string &fontFile)
 	fontString=fontFile;
 
 	const unsigned int mode = FTGL_POLYGON;
-	font=0;
+	font=nullptr;
 	switch(mode)
 	{
 		case FTGL_BITMAP:
@@ -1864,7 +1862,7 @@ DrawGL2DText::DrawGL2DText(const std::string &fontFile)
 		default:
 			//Don't do this. Use valid font numbers
 			ASSERT(false);
-			font=0; 
+			font=nullptr; 
 	}
 
 	if(!font || font->Error())
@@ -1890,7 +1888,7 @@ DrawGL2DText::~DrawGL2DText()
 	if(font)
 	{
 		delete font;
-		font=0;
+		font=nullptr;
 	}
 }
 
@@ -1964,7 +1962,7 @@ void DrawGL2DText::getBoundingBox(BoundCube &b) const
 
 DrawableObj *DrawGL2DText::clone() const
 {
-	DrawGL2DText *d = new DrawGL2DText(fontString);
+	auto d = new DrawGL2DText(fontString);
 
 	d->strText=strText;
 	d->position[0]=position[0];
@@ -1989,12 +1987,11 @@ DrawRectPrism::DrawRectPrism() : drawMode(DRAW_WIREFRAME), r(1.0f), g(1.0f), b(1
 }
 
 DrawRectPrism::~DrawRectPrism()
-{
-}
+= default;
 
 DrawableObj *DrawRectPrism::clone() const
 {
-	DrawRectPrism *dR= new DrawRectPrism(*this);
+	auto dR= new DrawRectPrism(*this);
 	return dR;
 }
 
@@ -2143,8 +2140,7 @@ void DrawRectPrism::recomputeParams(const vector<Point3D> &vecs,
 }
 
 DrawableOverlay::~DrawableOverlay()
-{
-}
+= default;
 
 DrawTexturedQuadOverlay::DrawTexturedQuadOverlay()  
 :  textureId(-1),textureOK(false)
@@ -2222,8 +2218,7 @@ DrawProgressCircleOverlay::DrawProgressCircleOverlay()
 }
 
 DrawProgressCircleOverlay::~DrawProgressCircleOverlay()
-{
-}
+= default;
 
 void DrawProgressCircleOverlay::reset()
 {
@@ -2233,12 +2228,19 @@ void DrawProgressCircleOverlay::reset()
 	curFilter=0;	
 }
 
+void DrawProgressCircleOverlay::setFilterStepEstimates(const vector<unsigned int> &v)
+{
+	estimatedSteps=v;
+}
+
 void DrawProgressCircleOverlay::draw( )const
 {
-	if(!maxStep)
+	if(!totalFilters)
 		return;
 
-	ASSERT(curFilter <=totalFilters);
+	ASSERT(estimatedSteps.size() == totalFilters);
+
+	ASSERT(curFilter <totalFilters);
 	//TODO: Is this redundant? might be already handled
 	// by scene?
 	glMatrixMode(GL_PROJECTION);	
@@ -2256,7 +2258,8 @@ void DrawProgressCircleOverlay::draw( )const
 				                       
 	//size of gap to fit, in degrees
 	const float FILTER_SPACING_ANGLE= 20.0f/(float)totalFilters;
-	//Angular step when drawing wheel
+	//Angular step when drawing wheel triangle mesh (ie angles between
+	// triangle vertices from centre of wheel. Wheel is drawn as a triangle fan
 	const float DEG_STEP= 2;
 	
 	//fraction of radius for inner section
@@ -2266,97 +2269,115 @@ void DrawProgressCircleOverlay::draw( )const
 	radiusOut = std::min(height,width)/2.0f;
 	radiusIn= radiusOut*IN_RADIUS_FRACTION; 
 
-
-
-	//Allows for gap between each step, and one at start and end
-	float thetaPerFilter = (360.0f - FILTER_SPACING_ANGLE*(totalFilters))/totalFilters;
 		
-	//Draw the complete filters 
-	float curTheta=FILTER_SPACING_ANGLE/2.0f;	
-	for(size_t ui=1;ui<curFilter;ui++)
-	{
-		drawSection(DEG_STEP,
-			IN_RADIUS_FRACTION*radiusIn, 
-			radiusOut,curTheta, 
-			curTheta+thetaPerFilter,true);
-		curTheta+=thetaPerFilter+FILTER_SPACING_ANGLE;
-	}
-
-
 	float visGrey=getHighContrastValue();
 
-	//Draw the completed Steps
-	float thetaPerStep =  thetaPerFilter/maxStep;
-	for(size_t ui=1;ui<step;ui++)
+	//Working in degrees
+	// - first in pair is start of segment (degrees)
+	// - second in pair is end of segment
+	vector<pair<float,float> > thetaSegments;
+
+	unsigned int nSegments=totalFilters;
+	float thetaPerFilter = 360.0f/nSegments;
+
+	//Pre-compute all the angles, so we are not summing all the time
+	// which makes the code fragile
+	for(auto ui=0;ui<nSegments;ui++)
 	{
+		//We want to have equi-spaced segments, with the centre of the 
+		// gaps to be aligned to the 0-degree position
+		thetaSegments.push_back(
+			make_pair(thetaPerFilter*ui +FILTER_SPACING_ANGLE/2,
+				thetaPerFilter*(ui+1)-FILTER_SPACING_ANGLE + FILTER_SPACING_ANGLE/2)
+			);
+	}
+
+	//Draw the sections for filters that we have completed
+	for(size_t ui=0;ui<curFilter;ui++)
+	{
+		//Draw the sections that are for this filter
 		drawSection(DEG_STEP,
 			IN_RADIUS_FRACTION*radiusIn, 
-			radiusOut,curTheta, 
-			curTheta+thetaPerStep,true);
-		curTheta+=thetaPerStep;
+			radiusOut,thetaSegments[ui].first,
+			thetaSegments[ui].second,true);
+	}
 
-		if(ui < step-1)
+	//Draw all the sections still to come
+	for(size_t ui=curFilter+1; ui<thetaSegments.size();ui++)
+	{
+		float startDeg,endDeg;
+		startDeg=thetaSegments[ui].first;
+		endDeg = thetaSegments[ui].second;
+
+		const float STEP_SEP_DEG=4.0f;
+		//Draw each step for the progress still to come, in incomplete style
+		float thetaPerSubStep;
+		thetaPerSubStep=(endDeg- startDeg)/estimatedSteps[ui];
+		for(size_t uj=0; uj<estimatedSteps[ui]; uj++)
 		{
-			//Draw a line to mark the step
-			glColor4f(visGrey,0.0f,0.0f,1.0f);
-			glBegin(GL_LINES);
-				glVertex3f(radiusIn*sin(curTheta),radiusIn*cos(curTheta),0);
-				glVertex3f(radiusOut*sin(curTheta),radiusOut*cos(curTheta),0);
-			glEnd();
+			//This is the start and end, if there were no gaps
+			float stepStart,stepEnd;
+			stepStart=startDeg + (uj*thetaPerSubStep);
+			stepEnd=startDeg + (uj+1)*thetaPerSubStep;
+
+			//Don't draw gap at the start or end
+			if(uj > 0)
+				stepStart+=STEP_SEP_DEG/2.0f;
+			if(uj+1 < estimatedSteps[ui])
+				stepEnd-=STEP_SEP_DEG/2.0f;
+
+			//Don't draw all the way to fill the whole arc, leave a gap
+			// between steps, except for the last step
+			drawSection(DEG_STEP,
+				IN_RADIUS_FRACTION*radiusIn, 
+				radiusOut, stepStart,stepEnd,false);
+				
+		}
+
+	}
+
+	//Now draw the segments for the active filter
+	{
+		float startDeg,endDeg;
+		startDeg=thetaSegments[curFilter].first;
+		endDeg = thetaSegments[curFilter].second;
+
+		const float STEP_SEP_DEG=4.0f;
+		//Draw each step for the progress still to come, in incomplete style
+		float thetaPerSubStep;
+		thetaPerSubStep=(endDeg- startDeg)/estimatedSteps[curFilter];
+		for(size_t uj=0; uj<estimatedSteps[curFilter]; uj++)
+		{
+			//This is the start and end, if there were no gaps
+			float stepStart,stepEnd;
+			stepStart=startDeg + (uj*thetaPerSubStep);
+			stepEnd=startDeg + (uj+1)*thetaPerSubStep;
+
+			if(uj > 0)
+				stepStart+=STEP_SEP_DEG/2.0f;
+			if(uj+1 < estimatedSteps[curFilter])
+				stepEnd-=STEP_SEP_DEG/2.0f;
+
+			//Don't draw all the way to fill the whole arc, leave a gap
+			// between steps, except for the last step.
+			// The step should be drawn as inactive if above current step
+			drawSection(DEG_STEP,
+				IN_RADIUS_FRACTION*radiusIn, 
+				radiusOut, stepStart,stepEnd,uj < step-1);
+
+			if(uj+1 == step)
+			{
+				float partialStepEnd = (stepEnd-stepStart)*stepProgress/100 + stepStart;
+
+				drawSection(DEG_STEP,
+					IN_RADIUS_FRACTION*radiusIn, 
+					radiusOut, stepStart,partialStepEnd,true);
+
+			}
+				
 		}
 	}
-	//Draw the current step
-	if(stepProgress == 100)
-	{
-		drawSection(DEG_STEP,
-			IN_RADIUS_FRACTION*radiusIn, 
-			radiusOut,curTheta, 
-			curTheta+thetaPerStep,true);
-	}
-	else if (!stepProgress)
-	{
-		drawSection(DEG_STEP,
-			IN_RADIUS_FRACTION*radiusIn, 
-			radiusOut,curTheta, 
-			curTheta+thetaPerStep,false);
-	}
-	else
-	{
-		//draw two segments, one with the current progress value in the complete style
-		float interpFrac = (float)stepProgress/100.0f;
-		drawSection(DEG_STEP,
-			IN_RADIUS_FRACTION*radiusIn, 
-			radiusOut,curTheta, 
-			curTheta+thetaPerStep*interpFrac,true);
-		// and one with the incomplete style
-		drawSection(DEG_STEP,
-			IN_RADIUS_FRACTION*radiusIn, 
-			radiusOut,curTheta+thetaPerStep*interpFrac, 
-			curTheta+thetaPerStep,false);
-
-	}
-	curTheta+=thetaPerStep;
-	//Draw the remaining incomplete steps
-	for(size_t ui=step+1; ui<=maxStep;ui++)
-	{
-		drawSection(DEG_STEP,
-			IN_RADIUS_FRACTION*radiusIn, 
-			radiusOut,curTheta, 
-			curTheta+thetaPerStep,false);
-		curTheta+=thetaPerStep;
-	}
-
-	curTheta+=FILTER_SPACING_ANGLE;
-
-	//Draw the incomplete filters
-	for(size_t ui=curFilter+1; ui<=totalFilters;ui++)
-	{
-		drawSection(DEG_STEP,
-			IN_RADIUS_FRACTION*radiusIn, 
-			radiusOut,curTheta, 
-			curTheta+thetaPerFilter,false);
-		curTheta+=thetaPerFilter+FILTER_SPACING_ANGLE;
-	}
+	//Draw the sections for this fulter
 	
 	glPopMatrix(); //Pop modelview matrix
 
@@ -2372,12 +2393,12 @@ void DrawProgressCircleOverlay::draw( )const
 void DrawProgressCircleOverlay::drawSection(unsigned int degreeStep, 
 	float rIn, float rOut,float startTheta, float stopTheta, bool complete) const
 {
-	//TODO: all calulations that call this should use radiians	
+	//TODO: all calculations that call this should use radians	
 	float startThetaRad = startTheta*M_PI/180.0f;
 	float endThetaRad = stopTheta*M_PI/180.0f;
 	float degStepRad = degreeStep*M_PI/180.0f;
 
-	unsigned int nSegments = (endThetaRad-startThetaRad)/degStepRad;
+	unsigned int nSegments = (endThetaRad-startThetaRad)/degStepRad +1;
 
 	if(!nSegments)
 		return;
@@ -2770,7 +2791,7 @@ void DrawPointLegendOverlay::addItem(const std::string &s, float r, float g, flo
 	rgb.v[0]=r;
 	rgb.v[1]= g;
 	rgb.v[2]= b;
-	legendItems.push_back(make_pair(s,rgb));
+	legendItems.emplace_back(s,rgb);
 }
 
 
@@ -2884,7 +2905,7 @@ void DrawField3D::draw() const
 							
 								RGBThis rThis;
 								rThis.v[0]=rgb[0]; rThis.v[1]=rgb[1];rThis.v[2]=rgb[2];
-								ptsCache.push_back(make_pair(field->getPoint(uiX,uiY,uiZ)+delta,rThis));
+								ptsCache.emplace_back(field->getPoint(uiX,uiY,uiZ)+delta,rThis);
 							}
 						}
 					}
@@ -2954,13 +2975,21 @@ void DrawField3D::draw() const
 #ifdef ENABLE_LIBVD
 		case VOLUME_RENDER_ACCUMULATE:
 		{
+
+			//Ensure that GLEW is running
+			if(!glewInited)
+			{
+				glewInit();
+				glewInited=true;
+			}
+
 			if(!volumeRenderCacheOK)
 			{
 
 				size_t sx,sy,sz;
 				field->getSize(sx,sy,sz);
 				
-				unsigned short *data = new unsigned short[128*128*128];
+				unsigned short *data = new unsigned short[sx*sy*sz];
 
 				size_t fieldSize=field->size();
 
@@ -2976,7 +3005,15 @@ void DrawField3D::draw() const
 					data[ui]=std::min(std::max(0.0f,f),255.0f); 
 				}
 				//Send the data to the volume renderer
-				volumeRenderer.update(data,sx,sy,sz);
+				try
+				{
+					volumeRenderer.update(data,sx,sy,sz);
+				}
+				catch(...)
+				{
+					delete[] data;
+					return;
+				}
 				delete[] data;
 				
 				
@@ -3010,7 +3047,16 @@ void DrawField3D::draw() const
 					p[3] = (float)alphaThis/255.0f; 
 				}
 
-				volumeRenderer.updateLut(lut,256);
+				try
+				{
+					volumeRenderer.updateLut(lut,256);
+				}
+				catch(...)
+				{
+					WARN(false,"Caught exception in LUT");
+					delete[] lut;
+					return;
+				}
 
 				delete[] lut;
 
@@ -3033,7 +3079,15 @@ void DrawField3D::draw() const
 			glScaled(bc.getSize(0),bc.getSize(1),bc.getSize(2));
 
 			//Draw the volume
-			volumeRenderer.display();
+			try
+			{
+				volumeRenderer.display();
+			}
+			catch(...)
+			{
+				WARN(false,"excpetion when volume rendering"); 
+			}
+
 
 
 			glPopAttrib();
