@@ -23,7 +23,7 @@
 
 #ifdef ENABLE_LIBVD 
 #include <GL/glew.h>
-#include <libvd/display3d.h>
+#include <libvd/display/display3d.h>
 #endif
 
 
@@ -1203,7 +1203,8 @@ class DrawProgressCircleOverlay : public DrawAnimatedOverlay
 		unsigned int totalFilters;
 		//Filter that we are analysing (0->n-1)
 		unsigned int curFilter;
-		
+	
+		vector<unsigned int> estimatedSteps;	
 
 		//Draw a 2D wheel shaped section. Complete variable toggles the style of the drawing from a completed, to a n incompleted segment
 		void drawSection(unsigned int degreeStep, 
@@ -1212,6 +1213,8 @@ class DrawProgressCircleOverlay : public DrawAnimatedOverlay
 		DrawProgressCircleOverlay();
 		~DrawProgressCircleOverlay();
 		void setCurFilter(unsigned int v) { curFilter= v;}
+
+		void setFilterStepEstimates(const vector<unsigned int> &v);
 		void setMaxStep(unsigned int v) { maxStep= v;}
 		void setNumFilters(unsigned int v) { totalFilters= v;}
 		void setProgress(unsigned int newProg) { ASSERT(newProg <=100); stepProgress = newProg;}
