@@ -1,6 +1,6 @@
 /*
  *	IsoSurface.cpp - Isosurface interface generation
- *	Copyright (C) 2015, D Haley 
+ *	Copyright (C) 2018, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 #include "isoSurface.h"
 
 #include "common/assertion.h"
-#include "common/voxels.h"
 
 #include <map>
 #include <list>
@@ -446,11 +445,11 @@ int a2iTriangleConnectionTable[256][16] =
 };
 
 //a2fVertexOffset lists the positions, relative to vertex0, of each of the 8 vertices of a cube
-static const float a2fVertexOffset[8][3] =
+/*static const float a2fVertexOffset[8][3] =
 {
         {0.0, 0.0, 0.0},{1.0, 0.0, 0.0},{1.0, 1.0, 0.0},{0.0, 1.0, 0.0},
         {0.0, 0.0, 1.0},{1.0, 0.0, 1.0},{1.0, 1.0, 1.0},{0.0, 1.0, 1.0}
-};
+};*/
 
 //The deltas for the vertex offsets.  This is the int version of a2fVertexOffset
 const unsigned int VERTEX_OFFSET[8][3] = 
@@ -460,6 +459,7 @@ const unsigned int VERTEX_OFFSET[8][3] =
 };
 
 //a2iEdgeConnection lists the index of the endpoint vertices for each of the 12 edges of the cube
+/*
 static const int a2iEdgeConnection[12][2] = 
 {
         {0,1}, {1,2}, {2,3}, {3,0},
@@ -474,6 +474,7 @@ static const float a2fEdgeDirection[12][3] =
         {1.0, 0.0, 0.0},{0.0, 1.0, 0.0},{-1.0, 0.0, 0.0},{0.0, -1.0, 0.0},
         {0.0, 0.0, 1.0},{0.0, 0.0, 1.0},{ 0.0, 0.0, 1.0},{0.0,  0.0, 1.0}
 };
+*/
 
 //Mapping between edges as defined in a2iEdgeConenction, (and thus implicitly in edge table)
 //and the voxels.h definition
@@ -515,7 +516,7 @@ void marchingCubes(const Voxels<float> &v,float isoValue, vector<TriangleWithVer
 		{
 		for(size_t iZ = 0; iZ < nz-1; iZ++)
 		{
-			iEdgeFlags=iFlagIndex=0;
+			iFlagIndex=0;
 			Point3D position;
 			//Lower left corner of cell for dual grid
 			position=v.getPoint(iX,iY,iZ) + gridSpacing*0.5;
