@@ -36,11 +36,11 @@ const char ANIMATE_PROGRESS_BASENAME[] = {
 
 
 
-Scene::Scene() : tempCam(0), cameraSet(true), outWinAspect(1.0f), noticeText(getDefaultFontFile())
+Scene::Scene() : tempCam(nullptr), cameraSet(true), outWinAspect(1.0f), noticeText(getDefaultFontFile())
 {
 	MESSAGE("Scene Constructor");
 	glewInited=false;
-	visControl=0;
+	visControl=nullptr;
 
 	lastHovered=lastSelected=(unsigned int)(-1);
 	lockInteract=false;
@@ -187,8 +187,8 @@ unsigned int Scene::initDraw()
 
 	if(useEffects)
 	{
-		for(unsigned int ui=0;ui<effects.size();ui++)
-			passes=std::max(passes,effects[ui]->numPassesNeeded());
+		for(auto & effect : effects)
+			passes=std::max(passes,effect->numPassesNeeded());
 	}
 
 	return passes;
@@ -196,15 +196,15 @@ unsigned int Scene::initDraw()
 
 bool Scene::hasOverlays() const
 {
-	for(unsigned int ui=0;ui<objects.size();ui++)
+	for(auto object : objects)
 	{
-		if(objects[ui]->isOverlay())
+		if(object->isOverlay())
 			return true;
 	}
 	
-	for(unsigned int ui=0;ui<refObjects.size();ui++)
+	for(auto refObject : refObjects)
 	{
-		if(refObjects[ui]->isOverlay())
+		if(refObject->isOverlay())
 			return true;
 	}
 
@@ -268,18 +268,18 @@ void Scene::draw(bool noUpdateCam)
 	// vector, so we can sort them together
 	unsigned int depthSortCount=0;
 	//Perform depth sorting of object vectors if needed
-	for(unsigned int ui=0;ui<refObjects.size();ui++)
+	for(auto & refObject : refObjects)
 	{
-		if(refObjects[ui]->needsDepthSorting())
+		if(refObject->needsDepthSorting())
 			depthSortCount++;
 	}
 	if(depthSortCount>1 )
 		depthSort(refObjects);
 
 	depthSortCount=0;
-	for(unsigned int ui=0;ui<objects.size();ui++)
+	for(auto & object : objects)
 	{
-		if(objects[ui]->needsDepthSorting())
+		if(object->needsDepthSorting())
 			depthSortCount++;
 	}
 	if(depthSortCount>1 )
@@ -292,10 +292,10 @@ void Scene::draw(bool noUpdateCam)
 		if(useEffects)
 		{
 			bool needCamUpdate=false;
-			for(unsigned int ui=0;ui<effects.size();ui++)
+			for(auto & effect : effects)
 			{
-				effects[ui]->enable(passNumber);
-				needCamUpdate|=effects[ui]->needCamUpdate();
+				effect->enable(passNumber);
+				needCamUpdate|=effect->needCamUpdate();
 			}
 
 			if(cameraSet && !noUpdateCam && needCamUpdate )
@@ -468,19 +468,19 @@ void Scene::drawOverlays(bool noUpdateCam) const
 
 
 
-	for(unsigned int ui=0;ui<refObjects.size();ui++)
+	for(auto refObject : refObjects)
 	{
-		if(refObjects[ui]->isOverlay())
+		if(refObject->isOverlay())
 		{
-			refObjects[ui]->draw();
+			refObject->draw();
 		}
 	}
 	
-	for(unsigned int ui=0;ui<objects.size();ui++)
+	for(auto object : objects)
 	{
-		if(objects[ui]->isOverlay())
+		if(object->isOverlay())
 		{
-			objects[ui]->draw();
+			object->draw();
 		}
 	}
 	
@@ -520,9 +520,9 @@ void Scene::drawHoverOverlay()
 	vector<const SelectionBinding *> binder;
 	//!Devices for interactive object properties
 	const std::vector<SelectionDevice *> &selectionDevices = visControl->getSelectionDevices();
-	for(unsigned int uj=0;uj<selectionDevices.size();uj++)
+	for(auto selectionDevice : selectionDevices)
 	{
-		if(selectionDevices[uj]->getAvailBindings(objects[lastHovered],binder))
+		if(selectionDevice->getAvailBindings(objects[lastHovered],binder))
 		{
 			haveBinding=true;
 			break;
@@ -756,13 +756,13 @@ void Scene::commitTempCam()
 	ASSERT(tempCam);
 	std::swap(activeCam, tempCam);
 	delete tempCam;
-	tempCam=0;
+	tempCam=nullptr;
 }
 
 void Scene::discardTempCam()
 {
 	delete tempCam;
-	tempCam=0;
+	tempCam=nullptr;
 }
 
 void Scene::setTempCam()
@@ -806,8 +806,8 @@ void Scene::clearAll()
 
 void Scene::clearObjs()
 {
-	for(unsigned int ui=0; ui<objects.size(); ui++)
-		delete objects[ui];
+	for(auto & object : objects)
+		delete object;
 	objects.clear();
 	lastHovered=-1;
 }
@@ -871,17 +871,17 @@ void Scene::computeSceneLimits()
 	boundCube.setInverseLimits();
 
 	BoundCube b;
-	for(unsigned int ui=0; ui<objects.size(); ui++)
+	for(auto & object : objects)
 	{
-		objects[ui]->getBoundingBox(b);
+		object->getBoundingBox(b);
 	
 		if(b.isValid())	
 			boundCube.expand(b);
 	}
 
-	for(unsigned int ui=0; ui<refObjects.size(); ui++)
+	for(auto & refObject : refObjects)
 	{
-		refObjects[ui]->getBoundingBox(b);
+		refObject->getBoundingBox(b);
 		
 		if(b.isValid())	
 			boundCube.expand(b);
@@ -934,13 +934,16 @@ unsigned int Scene::glSelect(bool storeSelected)
 	ASSERT(!lockInteract);
 
 	glClear(  GL_DEPTH_BUFFER_BIT );
+
+	glDisable(GL_CULL_FACE); //Turn off face culling
+
 	//Shouldn't be using a temporary camera.
 	//temporary cameras are only active during movement operations
 	ASSERT(!tempCam);
 	
 	
 	// Need to load a base name so that the other calls can replace it
-	GLuint *selectionBuffer = new GLuint[512];
+	auto selectionBuffer = new GLuint[512];
 	glSelectBuffer(512, selectionBuffer);
 	glRenderMode(GL_SELECT);
 	glInitNames();
@@ -1012,6 +1015,7 @@ unsigned int Scene::glSelect(bool storeSelected)
 	delete[] selectionBuffer;
 
 	glPopMatrix();
+	glEnable(GL_CULL_FACE); //Re-activate face culling
 	
 	//Record the last item if required.
 	if(storeSelected)
@@ -1108,20 +1112,20 @@ void Scene::applyDevice(float startX, float startY, float curX, float curY,
 
 	vector<SelectionBinding*> activeBindings;
 	std::vector<SelectionDevice *> &selectionDevices = visControl->getSelectionDevices();
-	for(unsigned int ui=0;ui<selectionDevices.size();ui++)
+	for(auto & selectionDevice : selectionDevices)
 	{
-		if(selectionDevices[ui]->getBinding(
+		if(selectionDevice->getBinding(
 			objects[lastSelected],mouseFlags,keyFlags,binder))
 			activeBindings.push_back(binder);
 	}
 
-	for(unsigned int ui=0;ui<activeBindings.size();ui++)
+	for(auto & activeBinding : activeBindings)
 	{
 		//Convert the mouse-XY coords into a world coordinate, depending upon mouse/
 		//key cobinations
 		Point3D worldVec;
 		Point3D vectorCoeffs[2];
-		activeBindings[ui]->computeWorldVectorCoeffs(mouseFlags,keyFlags,
+		activeBinding->computeWorldVectorCoeffs(mouseFlags,keyFlags,
 					vectorCoeffs[0],vectorCoeffs[1]);	
 
 		//Apply vector coeffs, dependant upon binding
@@ -1133,7 +1137,7 @@ void Scene::applyDevice(float startX, float startY, float curX, float curY,
 				+ forwardsDir*vectorCoeffs[1][2]*(curY-startY);
 		worldVec*=viewWidth;
 		
-		activeBindings[ui]->applyTransform(worldVec,permanent);
+		activeBinding->applyTransform(worldVec,permanent);
 	}
 
 	computeSceneLimits();
@@ -1188,8 +1192,8 @@ void Scene::removeEffect(unsigned int uniqueID)
 
 void Scene::clearEffects()
 {
-	for(size_t ui=0;ui<effects.size();ui++)
-		delete effects[ui];
+	for(auto & effect : effects)
+		delete effect;
 
 	effects.clear();
 	effectIDs.clear();
