@@ -1,6 +1,6 @@
 /*
  * 	scene.h - Opengl interaction header. 
- *	Copyright (C) 2015, D Haley 
+ *	Copyright (C) 2018, D Haley 
 
  *	This program is free software: you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 
 class Scene;
 class VisController;
-class Filter;
 
 #include "drawables.h"
 
@@ -31,6 +30,8 @@ class Filter;
 #include "glDebug.h"
 
 #include <vector>
+#include <deque>
+#include <string>
 
 //!The scene class brings together elements such as objects, lights, and cameras
 //to enable scene rendering
@@ -130,9 +131,26 @@ class Scene
 		//!Draw a specified vector of objects
 		void drawObjectVector(const std::vector<const DrawableObj*> &objects, bool &lightsOn, bool drawOpaques=true) const;
 
+		//!Draw the notifications as required
+		void drawNotifications() const;
+
+		//!Update the notification stack
+		void updateNotifications();
+
+		//!Depth sort an object vector
+		void depthSort(vector<const DrawableObj *> &objVec);
+
+
 		//!Disable copy constructor by making private
 		Scene &operator=(const Scene &);
-				
+		
+		//!Current notification text
+		DrawGL2DText noticeText;
+		//Stack of messages to display to user one at a time
+		std::deque<string> noticeMessages;
+		//last time a message was shown
+		timeval lastMessageTime;
+
 	public:
 		DrawProgressCircleOverlay progressCircle;
 		
@@ -191,6 +209,9 @@ class Scene
 
 		void resetProgressAnim() ;
 
+		//!Set the messages that will be shown to the user briefly
+		void setNotificationMessages(const vector<string> &messages);
+
 
 		//!remove a drawable object
 		void removeDrawable(unsigned int);
@@ -322,6 +343,16 @@ class Scene
 		//!Clear effects vector
 		void clearEffects();
 
+		//!Add a text notification to be displayed at a future point
+		void addNotice(const std::string &s);
+
+		//!Return if we need to update for notification messages
+		/// FIXME : This may be too aggressive. Perhaps a minimum alpha, or time difference
+		bool messageRedrawNeeded() const { return !noticeMessages.empty(); }
+
+		//!Remove all notifications
+		void clearNotifications() { noticeMessages.clear() ; lastMessageTime.tv_sec=0; lastMessageTime.tv_usec=0;} 
+
 		static std::string getGlVersion() { return  std::string((char *)glGetString(GL_VERSION)); }
 };
 
