@@ -29,9 +29,9 @@
 
 // end wxGlade
 
-wxWindow *exportPosYieldWindow=0;
+wxWindow *exportPosYieldWindow=nullptr;
 bool abortOp;
-wxStopWatch *exportPosDelayTime=0;
+wxStopWatch *exportPosDelayTime=nullptr;
 
 
 using std::list;
@@ -105,8 +105,8 @@ ExportPosDialog::ExportPosDialog(wxWindow* parent, int id, const wxString& title
 ExportPosDialog::~ExportPosDialog()
 {
 	delete exportPosDelayTime;
-	exportPosDelayTime=0;
-	exportPosYieldWindow=0;
+	exportPosDelayTime=nullptr;
+	exportPosYieldWindow=nullptr;
 	//Should have called cleanup before exiting.
 	ASSERT(!haveRefreshed);
 }
@@ -135,7 +135,7 @@ void ExportPosDialog::initialiseData(FilterTree &f)
 	//Steal the filter tree contents
 	f.swap(filterTree);
 	vector<const Filter*> dummyPersist;
-	upWxTreeCtrl(filterTree,treeData,filterMap,dummyPersist,0);	
+	upWxTreeCtrl(filterTree,treeData,filterMap,dummyPersist,nullptr);	
 
 	vector<SelectionDevice *> devices;
 	ProgressData p;
@@ -193,18 +193,18 @@ void ExportPosDialog::OnTreeFiltersSelChanged(wxTreeEvent &event)
 
 	typedef std::pair<Filter *,vector<const FilterStreamData * > > filterOutputData;
 	//Spin through the output list, looking for this filter's contribution
-	for(list<filterOutputData>::iterator it=outputData.begin();it!=outputData.end();++it)
+	for(auto & it : outputData)
 	{
 		//Is this the filter we are looking for?
-		if(it->first == targetFilter)
+		if(it.first == targetFilter)
 		{
 			//huzzah.
 			std::string label;
 
-			for(unsigned int ui=0;ui<it->second.size();ui++)
+			for(unsigned int ui=0;ui<it.second.size();ui++)
 			{
 				const IonStreamData *ionData;
-				ionData=(const IonStreamData *)((it->second)[ui]);
+				ionData=(const IonStreamData *)((it.second)[ui]);
 				
 				wxColour c;
 				c.Set((unsigned char)(ionData->r*255),
@@ -221,7 +221,7 @@ void ExportPosDialog::OnTreeFiltersSelChanged(wxTreeEvent &event)
 				
 				listAvailable->SetItemBackgroundColour(ui,c);
 
-				availableFilterData.push_back((it->second)[ui]);
+				availableFilterData.push_back((it.second)[ui]);
 			}
 		}
 
@@ -247,7 +247,7 @@ void ExportPosDialog::OnListSelectedItemActivate(wxListEvent &event)
 	unsigned int item=event.GetIndex();
 
 	unsigned int thisIdx=0;
-	for(list<const FilterStreamData *>::iterator it=selectedFilterData.begin();
+	for(auto it=selectedFilterData.begin();
 			it!=selectedFilterData.end(); ++it)
 	{
 		if(thisIdx == item)
@@ -302,10 +302,10 @@ void ExportPosDialog::OnBtnAddAll(wxCommandEvent &event)
 	selectedFilterData.clear();
 	typedef std::pair<Filter *,vector<const FilterStreamData * > > filterOutputData;
 
-	for(list<filterOutputData>::iterator it=outputData.begin();it!=outputData.end();++it)
+	for(auto & it : outputData)
 	{
-		for(unsigned int uj=0;uj<it->second.size();uj++)
-			selectedFilterData.push_back(it->second[uj]);
+		for(unsigned int uj=0;uj<it.second.size();uj++)
+			selectedFilterData.push_back(it.second[uj]);
 	}
 
 
@@ -341,11 +341,10 @@ void ExportPosDialog::updateSelectedList()
 
 	unsigned int idx=0;
 	std::string label;
-	for(list<const FilterStreamData *>::iterator it=selectedFilterData.begin();
-				it!=selectedFilterData.end(); ++it)
+	for(auto & it : selectedFilterData)
 	{
 		const IonStreamData *ionData;
-		ionData=(const IonStreamData *)(*it);
+		ionData=(const IonStreamData *)it;
 		
 		wxColour c;
 		c.Set((unsigned char)(ionData->r*255),
@@ -416,12 +415,11 @@ void ExportPosDialog::getExportVec(std::vector<const FilterStreamData * > &v) co
 	{
 		v.reserve(outputData.size());
 
-		for(list<filterOutputData>::const_iterator it=outputData.begin();
-							it!=outputData.end();++it)
+		for(const auto & it : outputData)
 		{
-			for(unsigned int ui=0;ui<it->second.size();ui++)
+			for(unsigned int ui=0;ui<it.second.size();ui++)
 			{
-				v.push_back(it->second[ui]);
+				v.push_back(it.second[ui]);
 				//Ensure pointer is valid by forcing a dereference
 				ASSERT(v.back()->getStreamType() == STREAM_TYPE_IONS);
 			}
@@ -432,13 +430,8 @@ void ExportPosDialog::getExportVec(std::vector<const FilterStreamData * > &v) co
 	{
 		//If the user wants to perform custom picking, then only "selected" to be
 		//exported
-		v.reserve(selectedFilterData.size());
-		for(list<const FilterStreamData *>::const_iterator it=selectedFilterData.begin();
-				it!=selectedFilterData.end(); ++it)
-		{
-			v.push_back(*it);
-		}
-
+		std::copy(selectedFilterData.begin(),selectedFilterData.end(),
+				std::back_inserter(v));
 	}
 }
 
