@@ -228,10 +228,10 @@ void ExportRngDialog::addRangeData(std::vector<const Filter *> rangeData)
 void ExportRngDialog::updateRangeList()
 {
 	listRanges->DeleteAllItems();
-	for(unsigned int ui=0;ui<rngFilters.size(); ui++)
+	for(auto & rngFilter : rngFilters)
 	{
 		const RangeFileFilter *rangeData;
-		rangeData=(RangeFileFilter *)rngFilters[ui];
+		rangeData=(RangeFileFilter *)rngFilter;
 		std::string tmpStr;
 		long itemIndex;
 	       	itemIndex=listRanges->InsertItem(0, (rangeData->getUserString())); 
