@@ -239,7 +239,7 @@ RangeEditorDialog::RangeEditorDialog(wxWindow* parent, int id, const wxString& t
     plotPanel->enableRegionSelfUpdate(true);
 
     lastFocused=GRID_FOCUS_NONE;
-    currentRange=0;
+    currentRange=nullptr;
     checkShowOverlay->SetValue(true);
 
     haveSetTextFocus=false;
@@ -284,11 +284,10 @@ void RangeEditorDialog::getModifiedRanges(map<const RangeFile *, const RangeFile
 {
 	//modRanges.reserve(modifiedRanges.size());
 
-	for(RFMAP::const_iterator it = modifiedRanges.begin() ;
-			it!= modifiedRanges.end(); ++it)
+	for(const auto & modifiedRange : modifiedRanges)
 	{
-		const RangeFile *r = &(it->first->getRange());
-		modRanges[r]=&(it->second);
+		const RangeFile *r = &(modifiedRange.first->getRange());
+		modRanges[r]=&(modifiedRange.second);
 	}
 }
 
@@ -326,39 +325,38 @@ void RangeEditorDialog::setPlotWrapper(const PlotWrapper  &p)
 
 
 	std::set<const RangeFileFilter *> ranges;
-	for(size_t ui=0;ui<regions.size();ui++)
+	for(auto & region : regions)
 	{
 		//Region data is actually empty.
-		if(regions[ui].second.empty())
+		if(region.second.empty())
 		{
 			//ignore this plot
-			ignoreList.insert(regions[ui].first);
+			ignoreList.insert(region.first);
 			continue;
 		}
 		
 		const Filter *parentFilt;
-		parentFilt = regions[ui].second[0].getParentAsFilter();
+		parentFilt = region.second[0].getParentAsFilter();
 
 		if(parentFilt->getType() != FILTER_TYPE_RANGEFILE)
 		{
 			//ignore this plot
-			ignoreList.insert(regions[ui].first);
+			ignoreList.insert(region.first);
 			continue;
 		}
 		
 		//Remember that we need to (shortly) create a new rangefile for this
 		ranges.insert((const RangeFileFilter *)parentFilt);
 		//Create a mapping between the plot and its owned rangefile
-		plotToRangeFileMap[regions[ui].first]=(const RangeFileFilter*)parentFilt;
+		plotToRangeFileMap[region.first]=(const RangeFileFilter*)parentFilt;
 	}
 	//--
 
 	//create a copy of the range file that are the to-be-modified ranges
-	for(set<const RangeFileFilter *>::const_iterator it=ranges.begin();
-		it != ranges.end(); ++it)
+	for(auto range : ranges)
 	{
-		modifiedRanges[*it]=((*it)->getRange());
-		modifiedRanges[*it].setEnforceConsistent(false);
+		modifiedRanges[range]=(range->getRange());
+		modifiedRanges[range].setEnforceConsistent(false);
 	}
 
 	//Now, change the behaviour of region updating for the plot wrapper
@@ -404,7 +402,7 @@ void RangeEditorDialog::setCurrentRange(size_t forceSelected)
 	// we cannot have any current range
 	if(!listPlots->GetCount())
 	{
-		currentRange=0;
+		currentRange=nullptr;
 		return;
 	}
 
@@ -419,7 +417,7 @@ void RangeEditorDialog::setCurrentRange(size_t forceSelected)
 
 		if(selectedItem== wxNOT_FOUND )
 		{
-			currentRange=0;
+			currentRange=nullptr;
 			return;
 		}
 
@@ -499,10 +497,10 @@ void RangeEditorDialog::generateListEntries()
 
 	listPlots->Clear();
 	//Add the plots that the user can get
-	for(size_t ui=0;ui<plotIDs.size();ui++)
+	for(unsigned int id : plotIDs)
 	{
 		unsigned int plotID;
-		plotID = plotIDs[ui];
+		plotID = id;
 
 		std::string title;
 		title=plotWrap.getTitle(plotID);
@@ -515,7 +513,7 @@ void RangeEditorDialog::generateListEntries()
 		// with the plot Id embedded in the element
 		int idx;
 		idx=listPlots->Append((title));
-		listToPlotIDs[idx]=plotIDs[ui];
+		listToPlotIDs[idx]=id;
 	}
 
 	//If there is only one spectrum, select it
@@ -624,19 +622,19 @@ void RangeEditorDialog::generateIonEntries(size_t rowVisibleHint)
 	//Add the incomplete ions
 	incompleteIonOffset=currentRange->getNumIons();
 	gridIons->AppendRows(incompleteIons.size());
-	for(size_t ui=0;ui<incompleteIons.size();ui++)
+	for(auto & incompleteIon : incompleteIons)
 	{
 		gridIons->SetCellValue(curIonRow,
 				ION_COL_PLOT,(title));
 
 		gridIons->SetCellValue(curIonRow,
-				ION_COL_SHORTNAME,(incompleteIons[ui].getShortName()));
+				ION_COL_SHORTNAME,(incompleteIon.getShortName()));
 		gridIons->SetCellValue(curIonRow,
-				ION_COL_LONGNAME,(incompleteIons[ui].getLongName()));
+				ION_COL_LONGNAME,(incompleteIon.getLongName()));
 		
 		//set the colour
 		wxGridCellAttr *attr = gridIons->GetOrCreateCellAttr(curIonRow,ION_COL_COLOUR);
-		RGBf col=incompleteIons[ui].getColour();
+		RGBf col=incompleteIon.getColour();
 
 		unsigned char r,g,b,a;
 		r=col.red*255.0f;
@@ -855,7 +853,7 @@ void RangeEditorDialog::OnGridIonsEditorShown(wxGridEvent &event)
 							(unsigned char)(rgbf.green*255),
 							(unsigned char)(rgbf.blue*255),
 							(unsigned char)(255)));
-				wxColourDialog *colDg=new wxColourDialog(this,&d);
+				auto colDg=new wxColourDialog(this,&d);
 
 				//Check to see if user actually put in a colour
 				if( colDg->ShowModal() != wxID_OK)
@@ -923,7 +921,7 @@ void RangeEditorDialog::OnGridIonsEditorShown(wxGridEvent &event)
 							(unsigned char)(rgbf.green*255),
 							(unsigned char)(rgbf.blue*255),
 							(unsigned char)(255)));
-				wxColourDialog *colDg=new wxColourDialog(this,&d);
+				auto colDg=new wxColourDialog(this,&d);
 
 				if( colDg->ShowModal() != wxID_OK)
 				{
@@ -1275,7 +1273,7 @@ void RangeEditorDialog::OnBtnRangeIonAdd(wxCommandEvent &event)
 	{
 		case GRID_FOCUS_RANGES:
 		{
-			incompleteRanges.push_back(PendingRange(currentRange));
+			incompleteRanges.emplace_back(PendingRange(currentRange));
 
 			size_t visibleRowHint=gridRanges->GetNumberRows();
 			generateRangeEntries(visibleRowHint);
@@ -1283,7 +1281,7 @@ void RangeEditorDialog::OnBtnRangeIonAdd(wxCommandEvent &event)
 		}
 		case GRID_FOCUS_IONS:
 		{
-			incompleteIons.push_back(PendingIon(currentRange));
+			incompleteIons.emplace_back(PendingIon(currentRange));
 			
 			size_t visibleRowHint=gridIons->GetNumberRows();
 			generateIonEntries(visibleRowHint);
