@@ -26,10 +26,6 @@
 
 #include "common/stringFuncs.h"
 
-bool XOR(bool a, bool b)
-{
-	return a == !b;
-}
 
 #ifndef ASSERT
 	#define ASSERT(f) {assert((f));}
@@ -93,7 +89,6 @@ BEGIN_EVENT_TABLE(wxMultiLineGraphPanel, wxPanel)
 	EVT_MOTION(wxMultiLineGraphPanel::mouseMove)
 	EVT_LEFT_DOWN(wxMultiLineGraphPanel::mouseDown)
 	EVT_LEFT_UP(wxMultiLineGraphPanel::mouseReleased)
-	EVT_LEFT_DCLICK(wxMultiLineGraphPanel::mouseDoubleLeftClick) 
 END_EVENT_TABLE()
 
 wxGradientStopPanel::wxGradientStopPanel(wxWindow *p, wxWindowID wid) : wxPanel(p,wid)
@@ -138,9 +133,9 @@ void wxGradientStopPanel::onPaint(wxPaintEvent &evt)
 
 	//Find out if we need to draw the chequer
 	bool drawChequer=stops.empty();
-	for(unsigned int ui=0;ui<stops.size();ui++)
+	for(auto & stop : stops)
 	{
-		if(fabs(stops[ui].second.a() - 1.0f) > std::numeric_limits<float>::epsilon())
+		if(fabs(stop.second.a() - 1.0f) > std::numeric_limits<float>::epsilon())
 		{
 			drawChequer=true;
 			break;
@@ -309,9 +304,9 @@ bool MultiLineGraph::isSelfConsistent() const
 		return false;
 
 	//All y data points should be the same size as the x data
-	for(unsigned int ui=0;ui<lineYData.size();ui++)
+	for(const auto & data : lineYData)
 	{
-		if(lineYData[ui].size() != xData.size())
+		if(data.size() != xData.size())
 			return false;
 	}
 
@@ -372,7 +367,7 @@ void MultiLineGraph::draw(wxDC &dc)
 
 	//Draw the lines between each point
 	int nx,ny;
-	wxWindow *w=NULL;
+	wxWindow *w=nullptr;
 	w=dc.GetWindow();
 
 	if(!w)
@@ -466,13 +461,6 @@ void MultiLineGraph::setBounds(float minX,float minY, float maxX,float maxY)
 
 }
 
-void MultiLineGraph::setXData(const std::vector<float> &xd)
-{
-
-	//we can't use a consistency check here, as the graph may be
-	// incomplete. API should be altered to allow for one-call set.
-}
-
 void MultiLineGraph::setData(const std::vector<float> &xd, 
 		const std::vector<std::vector<float > > &yd, const std::vector<ColourRGBAf> &colour)
 {
@@ -718,8 +706,9 @@ void wxMultiLineGraphPanel::mouseMove(wxMouseEvent &event)
 
 }
 
-void wxMultiLineGraphPanel::mouseDoubleLeftClick(wxMouseEvent &event)
+void wxMultiLineGraphPanel::mouseLeftClick(wxMouseEvent &event)
 {
+
 	int w,h;
 	GetClientSize(&w,&h);
 	wxPoint mousePos =event.GetPosition();
@@ -735,7 +724,7 @@ void wxMultiLineGraphPanel::mouseDoubleLeftClick(wxMouseEvent &event)
 	//Find the distance tolerance in window coordinates
 	// we have to do it in window coords, as a circle in window coords is elliptical in 
 	// graph coords, which will be surprising to interaction
-	const float MAX_DISTANCE_FRACTION=0.015;
+	const float MAX_DISTANCE_FRACTION=0.030;
 
 	//Find the nearest line
 	unsigned int set;
@@ -836,7 +825,7 @@ void TransferEditorDialog::set_properties()
 	leftColourBar->SetBackgroundColour(wxColour(255, 255, 255));
 	leftColourBar->SetToolTip(_("Colour chosen by moving selected node up-down"));
 	graphPanel->SetBackgroundColour(wxColour(255, 255, 255));
-	graphPanel->SetToolTip(_("Drag nodes to move, double click to add nodes"));
+	graphPanel->SetToolTip(_("Drag nodes to move, click to add nodes"));
 	bottomColourBar->SetBackgroundColour(wxColour(255, 255, 255));
 	bottomColourBar->SetToolTip(_("Final colour scale"));
 	checkRed_or_Hue->SetValue(1);
@@ -899,6 +888,8 @@ void TransferEditorDialog::do_layout()
 	topLevelSizer->Add(rightSizer, 0, wxEXPAND, 0);
 	SetSizer(topLevelSizer);
 	topLevelSizer->Fit(this);
+
+	SetMinSize(wxSize(600,200));
 	Layout();
 	// end wxGlade
 }
@@ -1170,7 +1161,11 @@ void MultiLineGraph::moveXData(unsigned int node, float nx)
 void wxMultiLineGraphPanel::mouseReleased(wxMouseEvent &event)
 {
 	if(dragMode == DRAG_MODE_NONE)
+	{
+		//Process as mouse left click
+		mouseLeftClick(event);
 		return;
+	}
 
 	int w,h;
 	w=0;h=0;
@@ -1528,7 +1523,7 @@ std::vector<std::pair<float,ColourRGBAf> > TransferEditorDialog::getTransferFunc
 		col.g(fy[1][ui]);
 		col.b(fy[2][ui]);
 		col.a(fy[3][ui]);
-		v.push_back(make_pair(fx[ui],col));
+		v.emplace_back(fx[ui],col);
 	}
 
 	return v;
