@@ -96,7 +96,7 @@ BasicGLPane::BasicGLPane(wxWindow* parent) : wxGLCanvas(parent, wxID_ANY,  attri
 
 	keyDoubleTapTimer=new wxTimer(this,ID_KEYPRESS_TIMER);
 	lastKeyDoubleTap=(unsigned int)-1;
-	context=0;
+	context=nullptr;
 
 	mouseMoveFactor=mouseZoomFactor=1.0f;	
 	dragging=false;
@@ -714,7 +714,7 @@ void BasicGLPane::keyReleased(wxKeyEvent& event)
 void BasicGLPane::resized(wxSizeEvent& evt)
 {
 	prepare3DViewport(0,0,getWidth(),getHeight()); 
-	wxClientDC *dc=new wxClientDC(this);
+	auto dc=new wxClientDC(this);
 	Refresh();
 
 #ifdef __APPLE__
@@ -809,6 +809,7 @@ void BasicGLPane::render( wxPaintEvent& evt )
 	}
 #endif
 
+
 	wxPaintDC(this); 
 	currentScene->draw();
 	glFlush();
@@ -867,7 +868,7 @@ bool BasicGLPane::saveImage(unsigned int width, unsigned int height,
 		return false;
 	
 	//create new image
-	wxImage *image = new wxImage(width,height);
+	auto image = new wxImage(width,height);
 
 
 	unsigned char *imageBuffer= (unsigned char*) malloc(3*(width)*height);
@@ -931,7 +932,7 @@ bool BasicGLPane::saveImage(unsigned int width, unsigned int height,
 	totalTiles=nRow*nCol*nPass;
 	}
 
-	wxProgressDialog *wxD=0;	
+	wxProgressDialog *wxD=nullptr;	
 	showProgress=showProgress && ( totalTiles > 1);
 	if(showProgress)
 	{
