@@ -133,8 +133,8 @@ wxPanel(parent, id,  wxDefaultPosition, wxDefaultSize)
 	limitInteract=false;
 	mouseDragMode=MOUSE_MODE_ENUM_END;	
 	leftWindow=true;
-	thePlot=0;	
-	gr=0;
+	thePlot=nullptr;	
+	gr=nullptr;
 	lastEditedPlot=lastEditedRegion=-1;
 	regionSelfUpdate=false;
 	plotIsLogarithmic=false;
@@ -213,7 +213,7 @@ void MathGLPane::setPlotWrapper(PlotWrapper *newPlot,bool takeOwnPtr)
 void MathGLPane::render(wxPaintEvent &event)
 {
 	
-	wxAutoBufferedPaintDC   *dc=new wxAutoBufferedPaintDC(this);
+	auto dc=new wxAutoBufferedPaintDC(this);
 
 	if(!thePlot || thePlot->isInteractionLocked() )
 	{
@@ -247,7 +247,7 @@ void MathGLPane::render(wxPaintEvent &event)
 	if(!nItems)
 	{
 #ifdef __WXGTK__
-		wxBrush *b = new wxBrush;
+		auto b = new wxBrush;
 		b->SetColour(wxSystemSettings::GetColour(wxSYS_COLOUR_BACKGROUND));
 		dc->SetBackground(*b);
 
@@ -929,7 +929,9 @@ void MathGLPane::leftMouseReleased(wxMouseEvent& event)
 				//Send the movement to the parent filter
 				thePlot->moveRegion(startMousePlot,startMouseRegion,
 							regionSelfUpdate,regionMoveType,
-								mglX,mglY);	
+								mglX,mglY);
+				//Clear the filter cache
+				thePlot->clearFilterCache(startMousePlot,startMouseRegion);
 				haveUpdates=true;	
 
 			}
@@ -948,10 +950,10 @@ void MathGLPane::leftMouseReleased(wxMouseEvent& event)
 	
 	if(haveUpdates)
 	{
-		for(size_t ui=0;ui<updateHandlers.size(); ui++)
+		for(auto & updateHandler : updateHandlers)
 		{
 			std::pair<wxWindow*,UpdateHandler> u;
-			u=updateHandlers[ui];
+			u=updateHandler;
 
 			//Call the function
 			UpdateHandler h = u.second;
@@ -1126,7 +1128,7 @@ unsigned int MathGLPane::savePNG(const std::string &filename,
 	}
 	catch(std::bad_alloc)
 	{
-		gr=0;
+		gr=nullptr;
 		return MGLPANE_ERR_BADALLOC;
 	}
 
@@ -1145,12 +1147,12 @@ unsigned int MathGLPane::savePNG(const std::string &filename,
 		lastMglErr= gr->Self()->Mess;
 		
 		delete gr;
-		gr=0;
+		gr=nullptr;
 		return MGLPANE_ERR_MGLWARN;
 	}
 
 	delete gr;
-	gr=0;
+	gr=nullptr;
 	//Hack. mathgl does not return an error value from its writer
 	//function :(. Check to see that the file is openable, and nonzero sized
 	
@@ -1195,7 +1197,7 @@ unsigned int MathGLPane::saveSVG(const std::string &filename)
 	{
 		lastMglErr=grS->Self()->Mess;
 		delete grS;
-		grS=0;
+		grS=nullptr;
 		return MGLPANE_ERR_MGLWARN;
 	}
 	delete grS;
