@@ -39,15 +39,12 @@ bool filterTreeTests();
 // Bug was due to incorrect handling of refresh input data stack
 bool filterRefreshNoOut();
 
-//!Test a given filter tree that the refresh works
-bool testFilterTree(const FilterTree &f);
-
 //!Test a given filter tree that the refresh is successful,
 // then return the output. Must delete output with safeDeleteFilterList
-bool testFilterTree(const FilterTree &f,
-	std::list<std::pair<Filter *, std::vector<const FilterStreamData * > > > &outData ) ;
+bool testFilterTree(FilterTree &f,
+	std::list<std::pair<Filter *, std::vector<const FilterStreamData * > > > &outData );
 
-bool testFilterTree(const FilterTree &f)
+bool testFilterTree(FilterTree &f)
 {
 	std::list<std::pair<Filter *, std::vector<const FilterStreamData * > > > outData;
 
@@ -58,7 +55,7 @@ bool testFilterTree(const FilterTree &f)
 	return true;
 }
 
-bool testFilterTree(const FilterTree &f,
+bool testFilterTree(FilterTree &f,
 	std::list<std::pair<Filter *, std::vector<const FilterStreamData * > > > &outData )
 {
 	std::vector<SelectionDevice *> devices;
@@ -152,7 +149,6 @@ bool filterCloneTests()
 	ConfigFile configFile;
     	configFile.read();
 	
-#ifndef WIN32
 	bool fileWarn=false;
 	for(unsigned int ui=0; ui<FILTER_TYPE_ENUM_END; ui++)
 	{
@@ -271,7 +267,6 @@ bool filterCloneTests()
 		delete f;
 		delete g;
 	}
-#endif
 	return true;
 }
 
