@@ -27,9 +27,6 @@
 //Run all the built-in unit tests.
 bool runUnitTests();
 
-//Run the particular specified filter tree
-bool testFilterTree(const FilterTree &f);
-
 #endif
 
 #endif
