@@ -116,9 +116,9 @@ std::string locateDataFile(const char *name)
 	const unsigned int NUM_SEARCH_DIRS=THREEDEP_ARRAYSIZE(possibleDirs);
 
 	std::string s;
-	for(unsigned int ui=0; ui<NUM_SEARCH_DIRS; ui++)
+	for(auto & possibleDir : possibleDirs)
 	{
-		s=std::string(possibleDirs[ui]) + name;
+		s=std::string(possibleDir) + name;
 
 		if(wxFileExists((s)))
 			return s;
@@ -302,6 +302,52 @@ void wxErrMsg(wxWindow *win, const std::string &title, const std::string &mesg)
 	wxMesD->Destroy();
 }
 
+//creates a temporary filename for use
+std::string createTmpFilename(const char *dir,const char *extension)
+{
+	wxString tmpFilename,tmpDir;
+	
+	if(!dir)
+	{
+		tmpDir=wxFileName::GetTempDir();
+
+
+	#if defined(__WIN32__) || defined(__WIN64__)
+		tmpDir=tmpDir + wxT("\\3Depict\\");
+
+	#else
+		tmpDir=tmpDir + wxT("/3Depict/");
+	#endif
+
+	}
+	else
+		tmpDir=dir;
+	
+	if(!wxDirExists(tmpDir))
+		wxMkdir(tmpDir);
+	tmpFilename=wxFileName::CreateTempFileName(tmpDir+ wxT("unittest-"));
+	wxRemoveFile(tmpFilename);
+	if(extension)
+		tmpFilename+=wxT(".pos");
+
+	return stlStr(tmpFilename);
+}
+
+bool canWriteToFile(const char *cpFilename)
+{
+	wxFileName fName;
+	fName.Assign(cpFilename);
+	fName.MakeAbsolute();
+
+	//Check the actual filename is OK for write
+	// and, if a new file, the parent dir is writabLe
+	if(fName.Exists() && !wxIsWritable(cpFilename))
+		return false;
+	else if (!wxFileName::IsDirWritable(fName.GetPath())) //Check dir
+		return false;
+
+	return true;
+}
 
 //Does a process with a given ID both (1) exist, and (2) match the process name?
 
@@ -339,14 +385,14 @@ bool processMatchesName(size_t processID, const std::string &procName)
 		//Return true if *any* field returns true
 		bool pidFound,procNameFound;
 		procNameFound=pidFound=false;
-		for(unsigned int ui=0;ui<strVec.size(); ui++)
+		for(auto & str : strVec)
 		{
-			wxFileName fName((strVec[ui]));
+			wxFileName fName(str);
 			std::string maybeProcName;
 			maybeProcName = stlStr(fName.GetFullName());
 			
 			
-			if( pidStr == strVec[ui])
+			if( pidStr == str)
 				pidFound=true;
 			else if(procName == maybeProcName)
 				procNameFound=true;
@@ -555,8 +601,7 @@ TreePersistNode::TreePersistNode(const wxTreeCtrl *treeCtrl,wxTreeItemId t)
 }
 
 TreePersistNode::TreePersistNode()
-{
-}
+= default;
 
 void TreePersist::saveTreeExpandState(wxTreeCtrl *treeCtrl)
 {
