@@ -17,6 +17,9 @@
 #	along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+#Ensure PYTHONUTF8=1 environment variable is set in parent shell,
+# or imagemagick will complain. I've not yet worked
+# out exactly how to fix this in the code. Decode doesn't seem to work.
 
 import os
 from os import environ
@@ -59,22 +62,24 @@ def loadColDlg(app3depict):
 	return colDlg
 
 def sameImage(fileA,fileB):
-	imA=Magick.Image(fileA);
-	imB=Magick.Image(fileB);
+	imA=Magick.Image(str(fileA));
+	imB=Magick.Image(str(fileB));
 
 	return  imA == imB
 
 def appShot(application,ycrop=0):
 	time.sleep(0.3) # Wait a fraction of second, in case image is not very static
-	shot=screenshot()
+	shot=str(screenshot())
 	mainFrame=application.findChild(element("","frame"))
 	xyStart=mainFrame.position;
 	xySize=mainFrame.size
+	print('App shot, trying to generate imagery')
 	
 	im=Magick.Image(shot);
 	im.crop(Magick.Geometry(xySize[0],xySize[1]-ycrop,xyStart[0],xyStart[1]))
 	im.write(shot)
 
+	print('Shot written sucessfully?')
 	return shot
 def find(target, someList):
 	for item in someList:
@@ -106,6 +111,7 @@ def closeProgram(app3depict):
 #Try executing/aborting the file->open menu
 def openTest(app3depict):
 	global overrideImage	
+	print( '====== OPEN TEST RUNNING========')
 	
 	shotBefore=appShot(app3depict)
 
@@ -144,11 +150,16 @@ def openTest(app3depict):
 	# after loading file - should auto-snap to bounds
 	#Press space to tap 
 	dogtail.rawinput.pressKey("space")
+	print( '====== OPEN TEST COMPLETE========')
 	return True
 
 def filterTests(app3depict):
 	global overrideImage
 	
+	print( '====== FILTER TEST RUNNING========')
+	
+
+
 	#Fudge the bounding box of the
 	# cropping region to exclude stuff like statusbar
 	# - autosave, progress etc can affect this
@@ -258,6 +269,7 @@ def filterTests(app3depict):
 	dogtail.rawinput.pressKey("p")
 	
 	dogtail.rawinput.pressKey("del")
+	print( '====== FILTER TEST COMPLETE========')
 	
 	return True
 
@@ -266,6 +278,7 @@ def filterTests(app3depict):
 # check for change in GUI
 def panelTests(app3depict):
 	global overrideImage
+	print( '====== PANEL TEST RUNNING========')
 	viewMenu=app3depict.menu('View');
 
 	PANEL_TOGGLES=["Control Pane", "Raw Data Pane"]
@@ -281,10 +294,12 @@ def panelTests(app3depict):
 		if sameImage(shotBefore,shotAfter) and not overrideImage:
 			print ('UI did not change, but should have:')
 			return False
+	print( '====== PANEL TEST COMPLETE========')
 	return True
 
 #Try opening preferences menu, and activating a few items
 def prefTests(app3depict):
+	print( '====== PANEL TEST RUNNING========')
 	prefMenu=app3depict.menu("Edit");
 	prefMenu.click();
 	editMenu=prefMenu.menuItem("Preferences");
@@ -307,12 +322,14 @@ def prefTests(app3depict):
 
 	prefDialog.button("Cancel").click()
 
+	print( '====== PANEL TEST COMPLETE========')
 	return True
 
 
 #Try changing some of the view options
 def viewTests(app3depict):
 	global overrideImage
+	print( '====== VIEW TEST RUNNING========')
 	#Show colour dialog
 	colDlg = loadColDlg(app3depict) 
 
@@ -387,10 +404,12 @@ def viewTests(app3depict):
 	if(sameImage(shotAfter,shotBefore)) and not overrideImage:
 		return False
 
+	print( '====== VIEW TEST RUNNING========')
 	return True
 
 #Try saving an image, and see if the file turns up
 def imageTest(app3depict):
+	print( '====== IMAGE TEST RUNNING========')
 	dogtail.rawinput.keyCombo('<Control>i')
 	
 	saveas = app3depict.dialog('Save Image...')
@@ -409,6 +428,7 @@ def imageTest(app3depict):
 
 	if not os.path.isfile(strDogSave) :
 		return False
+	print( '====== IMAGE TEST COMPLETE========')
 
 	return True
 
@@ -478,6 +498,9 @@ if __name__=='__main__':
 	dogtail.config.typingDelay=0.15;
 	dogtail.config.searchCutoffCount=5
 
+	#HACK: Skip warning at start
+	dogtail.rawinput.pressKey("enter")
+	
 
 	#Just complain if anything goes wrong
 	try:
